from typing import *
from vcApi import *

def addState(state_func: Callable[[], None]) -> None:
    """Adds a command state function to Python command.
 The first added command state is the function called when command is executed.
 This method is only available for user-defined Python commands."""
    pass

def cancelNextClick() -> None:
    """Cancels a next click event.
 This prevents a mouse click from being detected during the next mouse up event. This is only useful when called from an event processing handler function. Generally, this is used to prevent the activation of the Select command in response to a mouse click.
 This method is only available for user-defined Python commands and can only be called from within the command script itself."""
    pass

def createProperty(type: int, name: str, constraints: int = ...) -> vcProperty:
    """Adds a new property of a given type and name to command object.
 An optional constraints argument can be used to define constraints for property, which must be done at time of creation.
 See Property Constants for more information.
 This method is only available for user-defined Python commands."""
    pass

@overload
def deleteProperty(property: vcProperty) -> None:
    """Removes a given property or one matching a given name from command.
 This method is only available for user-defined Python commands."""
    pass

@overload
def deleteProperty(name: str) -> None:
    """Removes a given property or one matching a given name from command.
 This method is only available for user-defined Python commands."""
    pass

@overload
def execute(self: Any, *args : Any) -> None:
    """Executes the command, and then waits for the execution of first command state to be completed. If this method is called with no arguments, the arguments used are those currently set in the command object. If this method is called with positional arguments, each value is assigned to command properties in the order they were created before command execution. If the method is called with keyword arguments, the corresponding command parameter property is looked up and assigned the argument value. If a parameter cannot be found, the function fails."""
    pass

@overload
def execute(self: Any, **kwds: Any) -> None:
    """Executes the command, and then waits for the execution of first command state to be completed. If this method is called with no arguments, the arguments used are those currently set in the command object. If this method is called with positional arguments, each value is assigned to command properties in the order they were created before command execution. If the method is called with keyword arguments, the corresponding command parameter property is looked up and assigned the argument value. If a parameter cannot be found, the function fails."""
    pass

@overload
def executeAsTool(self: Any, *args : Any) -> None:
    """Executes the command as if its execution type is VC_COMMAND_TOOL.
This method overrides the command's ExecutionType property."""
    pass

@overload
def executeAsTool(self: Any, **kwds: Any) -> None:
    """Executes the command as if its execution type is VC_COMMAND_TOOL.
This method overrides the command's ExecutionType property."""
    pass

def executeInActionPanel() -> None:
    """Executes a command using a task pane.
 Generally, you would use a task pane to display the options of a registered Python or .NET command and to further control its execution.
 For more information, see Command Task Pane in Creating a Python Add-on topic."""
    pass

def getApplication() -> vcApplication:
    """Returns the application object."""
    pass

def getCommand() -> vcCommand:
    """Returns the command object."""
    pass

def getCommandPath() -> str:
    """Returns the URI used by application to load the Python file of command.
 This method returns an empty string if the command is not a Python command."""
    pass

def getProperty(name: str) -> vcProperty:
    """Returns a property matching a given name in command; otherwise returns None."""
    pass

def getSimulation() -> vcSimulation:
    """Returns the simulation object."""
    pass

def genVarSpaceDialog(command_name: str, dialog_title: str, first_tab_caption: str) -> None:
    """Shows a modal property dialog containing the properties of a registered command matching a given command_name.
 Note: The command_name is specific to Python, so COM or other programming commands cannot be used as an argument.
 The title of the dialog window is set to dialog_title. The first_tab_caption parameter determines whether a tabbed dialog is used. If first_tab_caption is an empty string, the properties are displayed in a single pane. Otherwise, the properties are displayed in separate tabs. In that case, property names are parsed as "tabName::propertyName" and distributed into tabs according to tabName; and properties without a double colon "::" in the name are displayed in the first tab, which will have the caption set to first_tab_caption.
 After the command is executed, the Param_4 property of the command object contains the result of the dialog, as an integer. A value of 1 means a user clicked OK, whereas a value of 2 means a user clicked Cancel."""
    pass

def recompile() -> None:
    """Recompiles the command."""
    pass

def setNextState(state_func: Callable[[], None]) -> None:
    """Sets the next command state function. This is a function which is called with no parameters in order to execute the next state. If None is passed as a parameter, the command will exit after the current state function or event processing function returns.
 Calling this method will also cause the command to leave event processing mode.
 This method is only available in Python commands, and can only be called from within the command script itself.
 For more information, see an example for setting the next state of a snap command."""
    pass
