from typing import *
from vcConstants import *

T = TypeVar('T')


class vc3DIcon(vcLayoutItem):
    """vc3DIcon is a layout item used for rendering sets of Frame features (vcFrameSet), path points (vcMotionPath), and path objects (vcPathObject) as 3D icons in a layout.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vc3DIcon.htm"""

    @property
    def Geometry(self) -> vcGeometryContainer:
        """Gets the container used by the icon to store its geometry."""
        pass

    @property
    def Layer(self) -> vcLayer:
        """Defines the layer the icon belongs to in the 3D world."""
        pass

    @Layer.setter
    def Layer(self, value : vcLayer) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the icon's name."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Uri(self) -> str:
        """Defines the URI of the icon file."""
        pass

    @Uri.setter
    def Uri(self, value : str) -> None:
        pass


class vcAction(vcObject):
    """vcAction is a container of information and user-defined properties for an action that can be executed during a simulation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAction.htm"""

    @property
    def ActionContainer(self) -> vcActionContainer:
        """Gets the action container of action."""
        pass

    @property
    def ActionTime(self) -> float:
        """Gets the creation time of action."""
        pass

    @property
    def AllProperties(self) -> List[vcProperty]:
        """Gets a list of all user-defined properties for the action."""
        pass

    @property
    def Filter(self) -> str:
        """Defines a filter for limiting what resource can perform the action."""
        pass

    @Filter.setter
    def Filter(self, value : str) -> None:
        pass

    @property
    def From(self) -> vcActionContainer:
        """Defines the original sender of this action.
Generally, this is used to track and manipulate where an action is sent from. For example, an action might be forwarded and passed to different resources and task managers."""
        pass

    @From.setter
    def From(self, value : vcActionContainer) -> None:
        pass

    @property
    def Message(self) -> str:
        """Defines the status information about the action's execution."""
        pass

    @Message.setter
    def Message(self, value : str) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of action."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all user-defined properties created for the action after the action container was loaded."""
        pass

    @property
    def Receiver(self) -> vcActionContainer:
        """Defines the receiver of action in its current workflow.
For example, an action might need to be handled at a workstation before the action is sent to a target defined by its To property."""
        pass

    @Receiver.setter
    def Receiver(self, value : vcActionContainer) -> None:
        pass

    @property
    def Sender(self) -> vcActionContainer:
        """Defines the current sender of the action.
Generally, this is used to clearly identify which object is responsible for sending this action."""
        pass

    @Sender.setter
    def Sender(self, value : vcActionContainer) -> None:
        pass

    @property
    def To(self) -> vcActionContainer:
        """Defines the final target where the action should be sent to.
In some cases, an action's final destination might be redefined to handle issues such as quality inspections, rerouting of materials, and availability of resource providers."""
        pass

    @To.setter
    def To(self, value : vcActionContainer) -> None:
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new user-defined property of a given type and name to action, and then returns the new property.
An optional constraints argument can be given to define the constraints of the property, which must be given at the time of creation.
See Property constants for available property types and constraints."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property from action."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns the first property matching a given name in action; otherwise returns None."""
        pass

    def send(self: Any, container: vcActionContainer = ...) -> None:
        """Sends action to the defined container.
If no arguments are given, the action is broadcast to all connected Action Containers."""
        pass

    def sendMessage(self: Any, message: str, container: vcActionContainer = ...) -> None:
        """Sends action with a given message to all connected Action Containers.
An optional container argument can be given to specify which action container receives the action.
Generally, the message of an action defines the action's type and is used by an action container to execute the action. In some cases, the message is used to filter actions."""
        pass


class vcActionContainer(vcBehaviour):
    """vcActionContainer is a container of vcAction objects used for storing, buffering, sending and receiving actions between resource clients, providers and brokers.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcActionContainer.htm"""

    @property
    def ActionCount(self) -> int:
        """Gets the total number of actions in container."""
        pass

    @property
    def Actions(self) -> List[vcAction]:
        """Gets a list of all actions in container."""
        pass

    @property
    def Brokers(self) -> List[vcActionContainer]:
        """Defines a list of connected brokers."""
        pass

    @Brokers.setter
    def Brokers(self, value : List[vcActionContainer]) -> None:
        pass

    @property
    def Clients(self) -> List[vcActionContainer]:
        """Defines a list of connected clients."""
        pass

    @Clients.setter
    def Clients(self, value : List[vcActionContainer]) -> None:
        pass

    @property
    def PendingActionCount(self) -> int:
        """Gets the number of actions in the PendingActions property list."""
        pass

    @property
    def NextFreeTime(self) -> float:
        """Defines the next available time this container is able to process actions during a simulation."""
        pass

    @NextFreeTime.setter
    def NextFreeTime(self, value : float) -> None:
        pass

    @property
    def PendingActions(self) -> List[vcAction]:
        """Gets a list of pending action stored in the container. That is, actions that are received from other action containers and buffered for action processing."""
        pass

    @property
    def Processing(self) -> bool:
        """Defines if this container is executing actions."""
        pass

    @Processing.setter
    def Processing(self, value : bool) -> None:
        pass

    @property
    def Providers(self) -> List[vcActionContainer]:
        """Defines a list of connected providers."""
        pass

    @Providers.setter
    def Providers(self, value : List[vcActionContainer]) -> None:
        pass

    @property
    def Reserved(self) -> vcActionContainer:
        """Defines if this container is reserved by other action container."""
        pass

    @Reserved.setter
    def Reserved(self, value : vcActionContainer) -> None:
        pass

    def clear(self: Any) -> None:
        """Deletes all actions in container."""
        pass

    def clearPending(self: Any) -> None:
        """Deletes all pending actions in container."""
        pass

    def createAction(self: Any, action_name: str) -> vcAction:
        """Creates a new vcAction in container, and then returns the new action."""
        pass

    def createPendingAction(self: Any, name: str) -> vcAction:
        """Creates a new pending action in the container."""
        pass

    @overload
    def deleteAction(self: Any, action: vcAction) -> bool:
        """Deletes a given action or one at a given index from container.
If deletion is successful, returns True; otherwise returns False."""
        pass

    @overload
    def deleteAction(self: Any, index: int) -> bool:
        """Deletes a given action or one at a given index from container.
If deletion is successful, returns True; otherwise returns False."""
        pass

    def deletePendingAction(self: Any, action: vcAction) -> bool:
        """Deletes a given action from the PendingActions property list."""
        pass

    def do(self: Any, action_type: str) -> bool:
        """Executes an action using the container.
If action can be performed, returns True; otherwise returns False.
Each action type has its own set of arguments which are described in Action Constants. Action arguments can be added in the order how they are described in the action parameter table.
An alternative approach is to use Python keywords, which allows only using specific keyword arguments.
See list of possible action types and their arguments."""
        pass

    def getAction(self: Any, index: int) -> vcAction:
        """Returns an action found at the given index in container."""
        pass

    def getPendingAction(self: Any, index: int) -> vcAction:
        """Returns a pending action found at a given index in container."""
        pass

    def getResources(self: Any) -> List[vcActionContainer]:
        """Returns a list of immediate resources connected to container."""
        pass

    def moveAction(self: Any, action: vcAction, index: int) -> bool:
        """Moves a given action to a given index in Actions property list.
If moving is successful, returns True; otherwise returns False."""
        pass

    def movePendingAction(self: Any, action: vcAction, index: int) -> bool:
        """Moves a given action to a new position in the PendingActions property list.
If moving is successful, returns True, otherwise False is returned."""
        pass

    def popPending(self: Any, index: int = ...) -> vcAction:
        """Removes the last action from the PendingActions property list, and then returns that action; otherwise returns None.
If an index argument is given, the action found at that position in the PendingActions property list will be removed and returned by the method; otherwise, returns None."""
        pass

    def release(self: Any) -> bool:
        """Releases the container from the action container defined in the Resource property. If the release is successful, returns True; otherwise returns False."""
        pass

    def removePendingAction(self: Any, action: vcAction) -> bool:
        """Removes a given action from the PendingActions property list."""
        pass

    def reserve(self: Any, resource_filter: str, action_type: str = ...) -> vcActionContainer:
        """Reserves a resource provider matching resource_filter, and then returns the reserved resource.
If resource is not available immediately, the method will wait until resource is available. If no matching resource is available, the method returns None.
An optional action_type argument can be given to reserve the resource for a specific action.
See list of possible action types.
An optional Timeout argument can be given to define how long the method will wait (in seconds) in order to reserve a resource. If the resource cannot be reserved before Timeout expires, the method returns None."""
        pass

    def start(self: Any, action_type: str) -> bool:
        """Executes an action using container regardless if an other action is still running.
If action can be performed, returns True; otherwise returns False.
Generally, start() is used with the wait() method in order to catch when an action executed with start() has been completed.
Each action type has its own set of arguments which are described in Action Constants. Action arguments can be added in the order how they are described in the action parameter table.
An alternative approach is to use Python keywords, which allows only using specific keyword arguments.
See list of possible action types."""
        pass

    def use(self: Any, resource_filter: str, action_type: str, timeout: float = ...) -> bool:
        """Executes an action using a specific resource.
If no resource is found based on resource_filter and the action is available immediately (not in queue), the method will wait until the specified resource is available. If resource can be used to perform action, returns True; otherwise returns False.
Optional timeout keyword argument defines how long the method will wait (in seconds) for the reserved resource to become available. If resource cannot be reserved before timeout expires, return False.
Each action type has its own set of arguments which are described in Action Constants. Action arguments can be added in the order how they are described in the action parameter table.
An alternative approach is to use Python keywords, which allows only using specific keyword arguments.
See list of possible action types."""
        pass

    def wait(self: Any, timeout: float = ...) -> bool:
        """Waits until action called in start() method is completed, and then returns True.
If an optional timeout argument is used, the method will return False if an action is not completed within the allocated time period (in seconds)."""
        pass


class vcAnnotation(vcLayoutItem):
    """vcAnnotation is a layout item used for authoring new and existing annotations in a layout.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAnnotation.htm"""

    @property
    def Height(self) -> float:
        """Defines the height of text displayed in annotation."""
        pass

    @Height.setter
    def Height(self, value : float) -> None:
        pass

    @property
    def LineWidth(self) -> float:
        """Defines the line width of annotation."""
        pass

    @LineWidth.setter
    def LineWidth(self, value : float) -> None:
        pass

    @property
    def Location(self) -> vcMatrix:
        """Defines the position matrix of annotation in World coordinate system)."""
        pass

    @Location.setter
    def Location(self, value : vcMatrix) -> None:
        pass

    @property
    def LockToNode(self) -> bool:
        """Defines if the annotation is attached to a node in component. That is, whether or not the annotation is anchored to a component or 3D world."""
        pass

    @LockToNode.setter
    def LockToNode(self, value : bool) -> None:
        pass

    @property
    def Material(self) -> vcMaterial:
        """Defines the material of annotation."""
        pass

    @Material.setter
    def Material(self, value : vcMaterial) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the annotation's name."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Node(self) -> vcNode:
        """Defines the node the annotation is attached to in the 3D world.
 If the annotation is not locked to a node, the value is None."""
        pass

    @Node.setter
    def Node(self, value : vcNode) -> None:
        pass

    @property
    def Position(self) -> vcMatrix:
        """Defines the location of the annotation in its parent's coordinate system. That is, the anchor point of the annotation.
 If the annotation is not anchored to a component, the location is based in the World (simulation root node) coordinate system."""
        pass

    @Position.setter
    def Position(self, value : vcMatrix) -> None:
        pass

    @property
    def Text(self) -> str:
        """Defines the text of the annotation displayed in an environment."""
        pass

    @Text.setter
    def Text(self, value : str) -> None:
        pass

    @property
    def Thickness(self) -> float:
        """Defines the thickness of the annotation's text in an environment."""
        pass

    @Thickness.setter
    def Thickness(self, value : float) -> None:
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name in the annotation; otherwise returns None."""
        pass


class vcApplication(vcObject):
    """vcApplication is the object type for the main application, thereby granting access to the application's GUI, commands and other common properties.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcApplication.htm"""

    @property
    def ActivationKey(self) -> str:
        """Gets the floating or stand-alone license that is currently used for the licensing of the application."""
        pass

    @property
    def AuthorContext(self) -> vcAuthorContext:
        """Gets the Modeling tab context."""
        pass

    @property
    def Commands(self) -> List[vcCommand]:
        """Gets a list of commands in the application's command registry. That is, registered commands available in the application."""
        pass

    @property
    def Components(self) -> List[vcComponent]:
        """Gets a list of all components in the 3D world."""
        pass

    @property
    def ConfigureContext(self) -> vcConfigureContext:
        """Gets the Home tab context."""
        pass

    @property
    def Contexts(self) -> List[vcContext]:
        """Gets a list of all contexts defined in the application."""
        pass

    @property
    def CurrentContext(self) -> vcContext:
        """Defines the current context of the application."""
        pass

    @CurrentContext.setter
    def CurrentContext(self, value : vcContext) -> None:
        pass

    @property
    def CustomProductVersion(self) -> str:
        """Returns the config file customized product version. If the product name has not been customized, returns the internal version."""
        pass

    @property
    def Dashboard(self) -> vcStatisticsDashboard:
        """Gets the Statistics dashboard."""
        pass

    @property
    def DrawingContext(self) -> vcDrawingContext:
        """Gets the Drawing tab context."""
        pass

    @property
    def IgnoreEvents(self) -> bool:
        """Defines if the application ignores events.
 Generally, a True value is used in situations where events could create cyclic calls and unintentional loops."""
        pass

    @IgnoreEvents.setter
    def IgnoreEvents(self, value : bool) -> None:
        pass

    @property
    def Layers(self) -> List[vcLayer]:
        """Gets a list of all layers in the current layout."""
        pass

    @property
    def LayoutItems(self) -> List[vcLayoutItem]:
        """Gets a list of all layout items in the current layout."""
        pass

    @property
    def LayoutModified(self) -> bool:
        """Defines if the current layout has been modified since it was loaded or its last save.
 LayoutModified acts as a flag for determining if you are prompted to save a layout and the current state of the Save command.
 The value is set to True when a user makes a change to the current layout using the GUI.
 A script that makes changes to a layout should set the value to True in order for the application to know whether or not the layout needs to be saved. This is not needed if the script only makes temporary changes to a layout during a simulation."""
        pass

    @LayoutModified.setter
    def LayoutModified(self, value : bool) -> None:
        pass

    @property
    def LayoutPath(self) -> str:
        """Gets the local path of current layout.
 Generally, the path is the same one you would get from the address bar of the File Explorer in Windows. For example, spaces would not be encoded as + signs.
 See System.Uri.LocalPath in the .NET Framework for more information."""
        pass

    @property
    def LayoutUri(self) -> str:
        """Gets the URI of current layout.
 The URI would contain its scheme, for example a "file:///" prefix, and spaces would be encoded as + signs.
 See Example. Print URI of current layout for more information."""
        pass

    @property
    def LayoutUriInCompatibilityFormat(self) -> str:
        """Gets the URI of current layout in a format that was used in older product versions.
 The URI is similar to LayoutUri. One exception is a forward slash in the URI path is replaced with a backslash."""
        pass

    @property
    def Lights(self) -> List[vcLight]:
        """Gets a list of all lights in the application."""
        pass

    @property
    def Materials(self) -> List[vcMaterial]:
        """Gets a list of all materials in the application."""
        pass

    @property
    def PdfFileName(self) -> str:
        """Defines the filename for a recorded 3D PDF.
 (Deprecated) Use the RecordingFileName property."""
        pass

    @PdfFileName.setter
    def PdfFileName(self, value : str) -> None:
        pass

    @property
    def PdfRecord(self) -> bool:
        """Defines if a simulation is recorded as a 3D PDF.
 (Deprecated) Use the Recording property."""
        pass

    @PdfRecord.setter
    def PdfRecord(self, value : bool) -> None:
        pass

    @property
    def PdfShow(self) -> bool:
        """Defines if the created 3D PDF is opened after recording a simulation.
 (Deprecated) Use the RecordingShow property."""
        pass

    @PdfShow.setter
    def PdfShow(self, value : bool) -> None:
        pass

    @property
    def PdfStepSize(self) -> float:
        """Defines the keyframe rate for recording simulations as 3D PDF.
 (Deprecated) Use the RecordingFrameRate property."""
        pass

    @PdfStepSize.setter
    def PdfStepSize(self, value : float) -> None:
        pass

    @property
    def ProcessContext(self) -> vcProcessContext:
        """Gets the Process tab context."""
        pass

    @property
    def ProductClass(self) -> str:
        """Gets the name of the application's product class.
 Product classes are Creator, Configurator and Viewer."""
        pass

    @property
    def ProductKey(self) -> str:
        """Gets the latest stand-alone key used to activate the application."""
        pass

    @property
    def ProductName(self) -> str:
        """Gets the product name of the application."""
        pass

    @property
    def ProductVersion(self) -> str:
        """Gets the product version of the application.
 The product version format is the major version number, minor version number and the revision number in that order separated by periods."""
        pass

    @property
    def ProgressStatus(self) -> str:
        """Defines the product status message given when the ProgressValue property is set to True.
 Caution: ProgressValue must always be set after setting ProgressStatus. Failure to do so may cause the application's GUI to enter an indefinite locked state."""
        pass

    @ProgressStatus.setter
    def ProgressStatus(self, value : str) -> None:
        pass

    @property
    def ProgressValue(self) -> float:
        """Defines the current state of the application's progress bar.
 Value < 0.0
 Progress is unknown or stalled. Setting this value will lock the GUI and activate the progress bar.
 0.0 <= Value <= 1.0
 The current state of progress is within this range in which 0.0 indicates no progress and 1.0 indicates full progress. Setting this value will lock the GUI and activate progress bar.
 Value > 1.0
 The operation has been completed. Setting this value will unlock the GUI and deactivate the progress bar.
 Caution: If ProgressValue is used to indicate the status of an operation, the set value must always be greater than 1.0 after completing the operation to unlock the application's GUI. Otherwise, the GUI may enter an indefinite locked state."""
        pass

    @ProgressValue.setter
    def ProgressValue(self, value : float) -> None:
        pass

    @property
    def PythonActionPanel(self) -> vcCommandPanelAction:
        """The action panel can be opened when executing a python command"""
        pass

    @property
    def Quantities(self) -> List[vcScalarQuantity]:
        """Gets a list of all scalar quantities in the application."""
        pass

    @property
    def RealTime(self) -> float:
        """Gets the current computer time (in seconds)."""
        pass

    @property
    def RealTimeMode(self) -> bool:
        """Defines if a simulation runs in real time or virtual time.
 A True value means the simulation runs at a speed indicative of the real world environment. A False value means the simulations runs at speed based on the device's CPU processing speed."""
        pass

    @RealTimeMode.setter
    def RealTimeMode(self, value : bool) -> None:
        pass

    @property
    def Recorder(self) -> int:
        """Defines if a simulation is recorded as a 3D PDF or video.
 See Recording Constants for more information."""
        pass

    @Recorder.setter
    def Recorder(self, value : int) -> None:
        pass

    @property
    def Recording(self) -> bool:
        """Turns on/off the recording of a simulation.
 A True value will start a simulation (if it was not already running) and the recording, whereas a False value will stop a simulation and the recording.
 You should define other Recording properties before you start the recording. In order to stop the recording you need to set Recording to False. In cases where you are recording a 3D PDF, stopping or resetting the simulation before you set Recording to False will lose the recording and not generate a file.
 Note: A recording cannot be stopped and continued without generating a new file."""
        pass

    @Recording.setter
    def Recording(self, value : bool) -> None:
        pass

    @property
    def RecordingFileName(self) -> str:
        """Defines the absolute path of a recorded simulation file."""
        pass

    @RecordingFileName.setter
    def RecordingFileName(self, value : str) -> None:
        pass

    @property
    def RecordingFrameRate(self) -> int:
        """Defines the frame rate for recording simulations."""
        pass

    @RecordingFrameRate.setter
    def RecordingFrameRate(self, value : int) -> None:
        pass

    @property
    def RecordingHeight(self) -> int:
        """Defines the height (number of pixels) for a simulation recorded as a video."""
        pass

    @RecordingHeight.setter
    def RecordingHeight(self, value : int) -> None:
        pass

    @property
    def RecordingShow(self) -> bool:
        """Turns on/off the opening of the recorded simulation file after recording is stopped in the 3D world."""
        pass

    @RecordingShow.setter
    def RecordingShow(self, value : bool) -> None:
        pass

    @property
    def RecordingWidth(self) -> int:
        """Defines the width (number of pixels) for a simulation recorded as a video."""
        pass

    @RecordingWidth.setter
    def RecordingWidth(self, value : int) -> None:
        pass

    @property
    def RecordScreen(self) -> bool:
        """Defines if the size of the 3D world viewport defines the dimensions of a simulation recorded as a video.
 A False value means the values of the RecordingHeight and RecordingWidth properties define the dimensions of a recorded video."""
        pass

    @RecordScreen.setter
    def RecordScreen(self, value : bool) -> None:
        pass

    @property
    def ResetSimulationAtLoading(self) -> bool:
        """Turns on/off the automatic reset of a component to its initial state when a new component is added to the 3D world.
 The default value is True. Generally, a False value is used in cases where you want to retain the current joint configuration of robots in the 3D world when teaching positions.
 The effect is the same as executing the Reset button on the simulation controls."""
        pass

    @ResetSimulationAtLoading.setter
    def ResetSimulationAtLoading(self, value : bool) -> None:
        pass

    @property
    def RobotSelectionService(self) -> vcRobotSelectionService:
        """Gets robot selection service"""
        pass

    @RobotSelectionService.setter
    def RobotSelectionService(self, value : vcRobotSelectionService) -> None:
        pass

    @property
    def SelectionManager(self) -> vcSelectionManager:
        """Gets the selection manager of the application which is used for handling selections in an environment."""
        pass

    @property
    def Simulation(self) -> vcSimulation:
        """Gets the simulation object of the application.
 Generally, the simulation object is used to control the execution of a simulation in the 3D world."""
        pass

    @property
    def TeachContext(self) -> vcTeachContext:
        """Gets the Program tab context."""
        pass

    @property
    def UnitFamilies(self) -> List[vcUnitFamily]:
        """Gets a list of all unit families in the application."""
        pass

    @property
    def UnitGroups(self) -> List[vcUnitGroup]:
        """Gets a list of all unit groups in the application."""
        pass

    @property
    def VREvents(self) -> vcVREvents:
        """Gets VR events object of the application.
 Generally, the VR events object is used for interactive Virtual Reality."""
        pass

    @property
    def Views(self) -> List[vcView]:
        """Gets a list of all user-defined views in the current layout."""
        pass

    def loadBitmap(self: Any, uri: str) -> vcBitmap:
        """Loads a bitmap image from a given uri.
 If loading is successful, the bitmap's filename is used to register the bitmap with the application.
 Returns the loaded bitmap image; otherwise returns None."""
        pass

    def saveBitmap(self: Any, bitmap: vcBitmap, uri: str, writer_info: str = ...) -> None:
        """Writes a given bitmap to a given uri.
 By default, the bitmap is saved as a BMP file. An optional writer_info argument can be given to write the bitmap to a different format.
 rbmp writes to BMP.
 rjpegstd or rjpegnstd writes to JPEG.
 rpng writes to PNG.
 rtargareader writes to TGA.
 See vcBitmap for more information."""
        pass

    def findCamera(self: Any, name: str = ...) -> vcCamera:
        """Returns a camera used by the application in an environment.
 An optional name argument can be given to find a specific camera; otherwise the method returns the first found camera.
 If no camera is found, returns None."""
        pass

    def cancelCommand(self: Any, all: bool = ...) -> None:
        """Cancels the execution of the currently active command, after which the default command of the application is activated.
 An optional all argument of can be given to cancel all commands in the command stack or just the top-most command by giving a False value."""
        pass

    def deleteCommand(self: Any, name: str) -> bool:
        """Deletes a registered command that matches a given name."""
        pass

    def findCommand(self: Any, name: str) -> vcCommand:
        """Returns a registered command that matches a given name; otherwise returns None."""
        pass

    def getCommands(self: Any) -> List[vcCommand]:
        """Returns a list of commands registered to the application."""
        pass

    def loadCommand(self: Any, name: str, uri: str) -> vcCommand:
        """Loads a defined script of a given name at a given uri into the application as a Python command.
 Loading registers a command with the given name in the application, which can be used to launch the command itself. Successful command loading returns the command as an object; otherwise, returns None."""
        pass

    def clearWorld(self: Any) -> None:
        """Removes all components from the 3D world."""
        pass

    def cloneComponent(self: Any, component: vcComponent) -> vcComponent:
        """Clones a given component, and then returns the clone.
 Note: This is only for static components when simulation is not running. To clone components when a simulation is running, use vcComponent.clone()."""
        pass

    def connectComponents(self: Any, comp1: vcComponent, comp2: vcComponent) -> bool:
        """Connects all matching interfaces between two given components.
 If a physical connection requires repositioning then comp2 is snapped to comp1.
 If a connection forms a parent-child hierarchy, the child component is moved and attached to the parent component."""
        pass

    def createComponent(self: Any) -> vcComponent:
        """Creates a new component at the 3D world origin, and then returns the new component."""
        pass

    def deleteComponent(self: Any, component: vcComponent) -> None:
        """Deletes a given component from the 3D world."""
        pass

    def findComponent(self: Any, name: str) -> vcComponent:
        """Returns a component in the 3D world that matches a given name.
 If no match is found, returns None."""
        pass

    def load(self: Any, uri: str) -> vcComponent:
        """Loads a component from a given uri in the 3D world.
 If loading is successful, returns the component; otherwise returns None.
 Note: In most cases, the file URI scheme is file:/// followed by the full path to file."""
        pass

    def setContext(self: Any, id: str) -> None:
        """Sets the context of application to the given id.
 Standard ids are:
 Author
 Component modeling
 Configure
 Layout configuration
 Drawing
 2D drawing
 Teach
 Robot programming."""
        pass

    def beginFrameGrab(self: Any, image_format: str, image_width: int, image_height: int) -> None:
        """Starts frame grabbing process using given image_format, image_width and image_height arguments to use with the executeFrameGrab() method."""
        pass

    def endFrameGrab(self: Any) -> None:
        """Ends screen grabbing process and performs cleanup."""
        pass

    def executeFrameGrab(self: Any, uri: str) -> None:
        """Creates a video frame of the current 3D world view and saves the frame at a given uri. The frame's format and size are defined using the beginFrameGrab() method."""
        pass

    def doJogging(self: Any, vector: vcVector) -> None:
        """Does the actual jogging using given vector as a reference location in world coordinates where the jogging ends."""
        pass

    def startJogging(self: Any, vector: vcVector, node: vcNode) -> None:
        """Initializes jogging process by defining what node is jogged and vector where the jogging starts, that is a reference starting location in the world coordinate system."""
        pass

    def stopJogging(self: Any) -> None:
        """Stops jogging."""
        pass

    def createLayer(self: Any, name: str) -> vcLayer:
        """Creates a new layer with a given name in the application.
 If a layer with the given name exists, that layer is returned; otherwise the method returns the new layer. If the layer cannot be created, returns None."""
        pass

    def deleteLayer(self: Any, name: str) -> None:
        """Deletes a layer that matches a given name unless the layer is a system layer."""
        pass

    def findLayer(self: Any, name: str) -> vcLayer:
        """Returns a layer that matches a given name; otherwise returns None."""
        pass

    def createLayoutItem(self: Any, type: int) -> vcLayoutItem:
        """Creates a new layout item of a given type in the current layout.
 See Layout Item constants for types and descriptions."""
        pass

    @overload
    def deleteLayoutItem(self: Any, name: str) -> None:
        """Deletes a given layout_item or one that matches a given name from the current layout."""
        pass

    @overload
    def deleteLayoutItem(self: Any, layout_item: vcLayoutItem) -> None:
        """Deletes a given layout_item or one that matches a given name from the current layout."""
        pass

    def findLayoutItem(self: Any, name: str) -> vcLayoutItem:
        """Returns a layout item that matches a given name in current layout; otherwise returns None."""
        pass

    def createLight(self: Any, name: str) -> vcLight:
        """Creates a new light with a given name which is attached to the 3D world."""
        pass

    def deleteLight(self: Any, name: str) -> None:
        """Deletes a light that matches a given name."""
        pass

    def findLight(self: Any, name: str = ...) -> vcLight:
        """Returns the first found light in the 3D world or a light matching a given name.
 If no light is found with the given name, returns None."""
        pass

    def addMaterial(self: Any, material: vcMaterial) -> bool:
        """Adds a given material to a group of materials registered with the application.
 If the material is registered, returns True. If a material with the same name already exists, returns False."""
        pass

    def createMaterial(self: Any, name: str) -> vcMaterial:
        """Creates a new material with a given name."""
        pass

    def findMaterial(self: Any, name: str, case_sensitive: bool = ...) -> vcMaterial:
        """Returns a material matching a given name. If no material is found with the name, returns None.
 
 Optional case_sensitive argument can be used to specify if the method is case-sensitive. By default, the method returns the first match (not case-sensitive)."""
        pass

    def addMenuButton(self: Any, menu: str, caption: str, command: str, toolSize: int = ...) -> bool:
        """Adds a new menu button in the ribbon (similar to the item). The first three parameters are the same as in addMenuItem, and the toolSize parameter defines the appearance of the button."""
        pass

    def addUxSite(self: Any, siteId: str, position: int = ...) -> None:
        """Adds a new site identified by siteId at the specified position. 
 siteId can be a chained string or a path, thereby allowing you to specify a section of the user interface. For example, 'VcTabDrawing/Example' would create a new ribbon group called Example in the Drawing tab. Note: You can refer to the UXSitesSection element of your application's configuration file to know valid IDs. Each id is an ItemId attribute of a Site element. An optional position parameter specifies the index at which the site should be created in its direct parent."""
        pass

    @overload
    def addMenuItem(self: Any, menu: int, caption: str, position: int, command: str) -> bool:
        """Adds a new menu item to a given menu.
 The menu argument can be a Menu Constant or id indicating the area of user interface where you want to add the menu item.
 The caption argument specifies a default label for the menu item.
 The position parameter specifies where the menu item will be added in the given menu. Any value less than zero is indexed from the end of the menu. By default, a new menu item is appended to the end of a menu.
 The command argument specifies a command by name that is executed when you interact with the menu item. For example, you can pass the name of a command registered to the application or an id that can be referenced when adding gallery menu items.
 The tool_tip argument specifies a default tooltip for the menu item.
 The image argument specifies the icon of the menu item.
 The reference_id argument refers to another menu item by its command name or id. Generally, you would use this to add items to a gallery menu on the Ribbon in which both the gallery and its items are created using the same Python command.
 The control_type argument specifies the control type of the menu item. Generally, you would use this to indicate an item as a GalleryMenuTool or GalleryMenuToolItem. If you are creating a contextual tab group in the Ribbon, you would use this to indicate a ContextualTabGroup or RibbonTab.
 Each call returns an integer that is a handle for the new menu item. Use that value in the removeMenuItem() method to delete the menu item.
 See Creating a Python Add-on for more information and examples.
 See Template for Python Add-on for a template that can be used to quickly implement a new add-on."""
        pass

    @overload
    def addMenuItem(self: Any, menu: str, caption: str, position: int, command: str) -> bool:
        """Adds a new menu item to a given menu.
 The menu argument can be a Menu Constant or id indicating the area of user interface where you want to add the menu item.
 The caption argument specifies a default label for the menu item.
 The position parameter specifies where the menu item will be added in the given menu. Any value less than zero is indexed from the end of the menu. By default, a new menu item is appended to the end of a menu.
 The command argument specifies a command by name that is executed when you interact with the menu item. For example, you can pass the name of a command registered to the application or an id that can be referenced when adding gallery menu items.
 The tool_tip argument specifies a default tooltip for the menu item.
 The image argument specifies the icon of the menu item.
 The reference_id argument refers to another menu item by its command name or id. Generally, you would use this to add items to a gallery menu on the Ribbon in which both the gallery and its items are created using the same Python command.
 The control_type argument specifies the control type of the menu item. Generally, you would use this to indicate an item as a GalleryMenuTool or GalleryMenuToolItem. If you are creating a contextual tab group in the Ribbon, you would use this to indicate a ContextualTabGroup or RibbonTab.
 Each call returns an integer that is a handle for the new menu item. Use that value in the removeMenuItem() method to delete the menu item.
 See Creating a Python Add-on for more information and examples.
 See Template for Python Add-on for a template that can be used to quickly implement a new add-on."""
        pass

    def createBehaviourMenuItem(self: Any, menu_name: str, pos: int, command: vcCommand) -> bool:
        """Creates a new menu item in Behavior tab add-on menu.
 (Deprecated) Use addMenuItem() method."""
        pass

    def createFeatureMenuItem(self: Any, menu_name: str, pos: int, command: vcCommand) -> bool:
        """Creates a new menu item in Geometry tab add-on menu.
 (Deprecated) Use addMenuItem() method."""
        pass

    def createGeometryMenuItem(self: Any, menu_name: str, pos: int, command: vcCommand) -> bool:
        """Creates a new menu item in Geometry tab add-on menu.
 (Deprecated) Use addMenuItem() method."""
        pass

    def createMenuItem(self: Any, menu_name: str, pos: int, command: vcCommand) -> bool:
        """Creates a new menu item in Add-ons menu.
 (Deprecated) Use addMenuItem() method."""
        pass

    @overload
    def getLocalizedString(self: Any, key: str) -> str:
        """Gets the value of a given key in a resource file based on the language of the application.
 Generally, this is used to localize add-ons. If the key is not found, returns the key itself as a string.
 You have two options:
 1-key
 Pass the entire key, for example "ComboKey::Python.MsgBoxTitle.Text".
 3-key
 Pass the key in three separate arguments, for example ("Python","MsgBoxTitle","Text").
 The key_container argument should be "Python" if the localized string was added from Python, for example a PyResouce file associated with your Python add-on.
 The key_item argument should be a unique key for the item you want to localize. For example, "printHelloLocalized.ColorPropName.red" would refer to a step value of a property named "ColorPropName" associated with a command registered to the application as "printHelloLocalized."
 The key_type argument specifies the attribute of an item. For example, a command can have a label, tooltip and icon.
 An item can have one or more attributes:
 Text
 Label for command, ribbon tab or group, message box, etc.
 Name
 Label for command property.
 Tooltip
 Tooltip for command.
 Description
 Tooltip for command property.
 Icon
 Icon for ribbon group or command. In this case, the value is the path to icon file.
 <step value>
 Label for step value of command property.
 See Template for Python Add-on for an example on how to use this method."""
        pass

    @overload
    def getLocalizedString(self: Any, key_container: str, key_item: str, key_type: str) -> str:
        """Gets the value of a given key in a resource file based on the language of the application.
 Generally, this is used to localize add-ons. If the key is not found, returns the key itself as a string.
 You have two options:
 1-key
 Pass the entire key, for example "ComboKey::Python.MsgBoxTitle.Text".
 3-key
 Pass the key in three separate arguments, for example ("Python","MsgBoxTitle","Text").
 The key_container argument should be "Python" if the localized string was added from Python, for example a PyResouce file associated with your Python add-on.
 The key_item argument should be a unique key for the item you want to localize. For example, "printHelloLocalized.ColorPropName.red" would refer to a step value of a property named "ColorPropName" associated with a command registered to the application as "printHelloLocalized."
 The key_type argument specifies the attribute of an item. For example, a command can have a label, tooltip and icon.
 An item can have one or more attributes:
 Text
 Label for command, ribbon tab or group, message box, etc.
 Name
 Label for command property.
 Tooltip
 Tooltip for command.
 Description
 Tooltip for command property.
 Icon
 Icon for ribbon group or command. In this case, the value is the path to icon file.
 <step value>
 Label for step value of command property.
 See Template for Python Add-on for an example on how to use this method."""
        pass

    def removeMenuItem(self: Any, position: int) -> bool:
        """Remove a menu item that was previously added using the addMenuItem() method."""
        pass

    def setContextualTabGroup(self: Any, tab_id: str, show: bool) -> None:
        """Turns on/off the visibility of a contextual tab group in Ribbon.
 The tab_id argument refers to the Id of the contextual tab group.
 See Template for Python Add-on for an example.
 See Creating a Python Add-on for more information and other examples."""
        pass

    def delayRealTime(self: Any, delay: float) -> None:
        """Executes a delay (in seconds) that halts a running simulation."""
        pass

    def getSimulation(self: Any) -> vcSimulation:
        """Returns the simulation object of application."""
        pass

    def resetSimulation(self: Any) -> None:
        """Resets the simulation to its initial state.
 Resetting a simulation removes all dynamic components and returns static components to their initial state at the start of a simulation."""
        pass

    def startSimulation(self: Any, stop_time: float = ...) -> None:
        """Starts a simulation.
 An optional stop_time argument can be given to indicate when to stop running the simulation.
 If the simulation of the application is not at its initial state, the simulation will continue from its current state. That is, the simulation clock will not reset to zero."""
        pass

    def stopSimulation(self: Any) -> None:
        """Immediately stops the execution of a simulation."""
        pass

    def createQuantity(self: Any, name: str, type: int) -> vcScalarQuantity:
        """Create a new quantity of a given name and type.
 The name argument specifies the full name of the new quantity. The type argument specifies whether a scalar or vector quantity.
 See Quantity Constants for more information."""
        pass

    def createUnitFamily(self: Any, name: str) -> vcUnitFamily:
        """Create a new unit family of a given name in application.
 The name argument specifies the name of the unit family and may not contain dot characters."""
        pass

    def createUnitGroup(self: Any, name: str) -> vcUnitGroup:
        """Create a new unit group of a given name.
 The name argument specifies the name of the unit group and may not contain dot characters."""
        pass

    def deleteUnitFamily(self: Any, family: vcUnitFamily) -> None:
        """Deletes a unit family given as an argument.
 Only user-created unit families can be deleted."""
        pass

    def deleteUnitGroup(self: Any, group: vcUnitGroup) -> None:
        """Deletes a unit group given as an argument.
 Only user-created unit groups can be deleted."""
        pass

    def findQuantity(self: Any, name: str) -> vcScalarQuantity:
        """Returns a quantity matching a given name; otherwise returns None."""
        pass

    def findUnit(self: Any, name: str) -> vcUnit:
        """Returns a unit matching a given name; otherwise returns None.
 This method will try to match either the name or suffix of a unit to the given name."""
        pass

    def findUnitFamily(self: Any, name: str) -> vcUnitFamily:
        """Returns a unit family matching a given name; otherwise returns None."""
        pass

    def findUnitGroup(self: Any, name: str) -> vcUnitGroup:
        """Returns a unit group matching a given name; otherwise returns None."""
        pass

    def createView(self: Any, name: str) -> vcView:
        """Creates a new view of a given name based on the current 3D world view.
 The view itself is saved with a layout and listed as a User View in the GUI whenever the layout is loaded in the 3D world."""
        pass

    def deleteView(self: Any, name: str) -> None:
        """Deletes a view matching a given name from the current layout."""
        pass

    def findView(self: Any, name: str) -> vcView:
        """Returns a view matching a given name in the current layout; otherwise returns None."""
        pass

    def setClipPlane(self: Any, index: int, position: vcMatrix) -> None:
        """Sets the clipping plane position."""
        pass

    def setClipPlaneEnabled(self: Any, index: int, enabled: bool) -> None:
        """Defines if the clipping plane is enabled or disabled."""
        pass

    def useView(self: Any, view_name: str, time: float = ...) -> None:
        """Switches the view of the 3D world to a view matching a given name in the current layout.
 An optional time argument can be given to interpolate the linear movement of the camera to new view. That is, a timed camera movement (in seconds)."""
        pass

    def autoShareFeatureTrees(self: Any) -> None:
        """Shares the feature trees of identical components in 3D world.
 For example, exact copies of a conveyor with the same VCID and feature trees can be shared to consume less memory.
 If you need to make a vcComponent object unique again, edit a property that affects one of its features or call its makeUnique() method."""
        pass

    def clearMessages(self: Any) -> None:
        """Clears Output panel."""
        pass

    def clearUndo(self: Any) -> None:
        """Clears the undo history."""
        pass

    def detectFrameOwnerNode(self: Any, position: vcMatrix, tolerance: float, exclude: vcNode = ...) -> vcNode:
        """Returns a node containing the closest Frame feature to a given position based on a distance tolerance.
 An optional exclude argument can be given to exclude frames belonging to specific node."""
        pass

    def getApplicationPath(self: Any) -> str:
        """Returns the Uri of this application's script as a formatted string.
 Generally, this method is used to register a command used in a Python add-on."""
        pass

    def getPythonDllPath(self: Any) -> str:
        """Returns the Uri of Python DLL folder as a formatted string."""
        pass

    def getRandomSeed(self: Any, index: int) -> int:
        """Returns the integer of a random generator at a given index."""
        pass

    def getMessages(self: Any) -> str:
        """Returns all messages currently listed in the Output panel."""
        pass

    def messageBox(self: Any, message: str, title: str = ..., type: int = ..., buttons: int = ...) -> int:
        """Shows a message box displaying the given message.
 An optional title argument can be given to define the title of the message box.
 An optional type argument can given to define the box type and icon.
 An optional buttons argument can be given to show a message box with buttons.
 The method returns a result based on the type of message box and which button is clicked by a user.
 See Message Constants for more information.
 See Example on how to implement this method.
 See Template for Python Add-on on how to localize a message box.
 Warning: If you want to open a message box when you start the application, you should use the OnAppInitialized event to verify it is safe to generate the box."""
        pass

    def rayCast(self: Any, start_position: vcMatrix, ray_length: float, exclude_node: vcNode = ..., use_backface: bool = ..., node_filters: List[Tuple[vcNode, int, int]] = ...) -> Union[None, Tuple[vcNode, vcPolygon, vcMatrix], Tuple[vcNode, None, vcMatrix, vcTriangleSet, int]]:
        """Tests if a ray with a given ray_length and start_position intersects an object in the current layout.
 The position of the ray is based in the World coordinate system, and the length of the ray is directed along the positive Z-axis.
 An optional exclude_node argument can be given to exclude a node, thereby allowing the ray to cast through and ignore collision with the given node and its child nodes.
 An optional use_backface argument has a default True value to include geometry backfaces in ray casting. A False value means the ray ignores geometry backfaces.
 An optional tuple argument of node, inclusion_type and inclusion scope can be given to exclude or include nodes. Excluding nodes allows the ray to cast through and ignore collision with the given nodes. Including one or more nodes will automatically exclude all the other nodes not included.
 See Collision Detector Constants for more information.
 If a ray collides with an object, the collision data is returned as tuple with three or five elements; otherwise returns None.
 The return value tuple's elements are:
 0
 The vcNode object hit by the ray.
 1
 None or a deprecated vcPolygon object hit by the ray. If None, the tuple will have five elements.
 2
 The location where the ray hit as a vcMatrix object. The Z-axis is parallel with the normal of the surface hit by the ray.
 3
 The vcTriangleSet object hit by the ray if the second element is None.
 4
 The index of the triangle hit by the ray in the fourth element.
 See Example on how to implement this method."""
        pass

    def render(self: Any) -> None:
        """Renders the scene of 3D world."""
        pass

    def save(self: Any, uri: str, includecomponents: bool) -> None:
        """Saves the contents of 3D world as a layout using a given uri. Also includecomponents parameter defines if the components are included in the layout."""
        pass

    OnAppInitialized : Callable[[], None]
    """Triggered when the application has been initialized and a window is created to display its user interface."""


    OnContextChanged : Callable[[], None]
    """Triggered when the context changes in application."""


    OnComponentAdded : Callable[[vcComponent], None]
    """Triggered when a component is added to 3D world."""


    OnComponentRemoved : Callable[[vcComponent], None]
    """Triggered when a component is removed from 3D world."""


    OnDynamicComponent : Callable[[vcComponent, vcContainer, bool], None]
    """Triggered when a component is created in 3D world during a simulation."""


    OnIdle : Callable[[], None]
    """Triggered when the application is in an Idle state.
 (Deprecated)"""


    OnProgress : Callable[[float, str], None]
    """Triggered each time the application's progress bar is updated."""


    OnRender : Callable[[vcSimulation], None]
    """Triggered when the application renders a scene in 3D world."""

    OnStart : Callable[[], None]
    """Triggered at the start of the application when main window is being built.
 (Deprecated) Use OnAppInitialized."""



class vcAssemblyConfiguration(vcObject):
    """https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAssemblyConfiguration.htm"""

    @property
    def Name(self) -> str:
        """Name"""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def StepConfigCount(self) -> int:
        """Configuration config count"""
        pass

    @StepConfigCount.setter
    def StepConfigCount(self, value : int) -> None:
        pass

    @overload
    def getStepConfig(self: Any, step: vcAssemblyStep) -> vcAssemblyStepConfiguration:
        """Gets step configuration"""
        pass

    @overload
    def getStepConfig(self: Any, index: int) -> vcAssemblyStepConfiguration:
        """Gets step configuration"""
        pass


class vcAssemblyPattern(vcObject):
    """Assembly pattern is a collection of assembly slots, which form a reusable definition of which product types should be placed in which position and orientation in the assembly. Note that assembly patterns can also exist independently from assembly product types (vcAssemblyProductType).
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAssemblyPattern.htm"""

    @property
    def Properties(self) -> List[vcProperty]:
        """Property container."""
        pass

    @property
    def UniqueID(self) -> str:
        """Unique identifier for this assembly pattern."""
        pass

    @property
    def Slots(self) -> List[vcAssemblyPatternSlot]:
        """List of all slots associated with this pattern."""
        pass

    @property
    def Name(self) -> str:
        """Pattern name."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    def getSlot(self: Any, index: int) -> vcAssemblyPatternSlot:
        """Returns slot from the pattern at specified index."""
        pass

    def createSlot(self: Any, index: int = ...) -> vcAssemblyPatternSlot:
        """Creates slot at index specified by index. If index is specified outside of valid indexes or not specified at all, the slot is appended to the existing ones."""
        pass

    def removeSlot(self: Any, slot: vcAssemblyPatternSlot, index: int) -> None:
        """Deletes the slot, given explicitly as slot, or retrieved based on the index."""
        pass

    def cloneSlotFrom(self: Any, slot: vcAssemblyPatternSlot, index: int = ...) -> vcAssemblyPatternSlot:
        """Creates a copy of given slot at given pattern slot index. If index is specified outside of valid indexes or not specified at all, the slot is appended to the existing ones."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a property of the step."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property of the step."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Creates a new property to the step. See Property Constraint Constants for more information."""
        pass

    OnPatternSlotAdded : Callable[[], None]
    """Triggered when a slot has been added to this pattern."""


    OnPatternSlotRemoving : Callable[[], None]
    """Triggered when a slot is being removed from this pattern."""



class vcAssemblyPatternItem(vcObject):
    """vcAssemblyPatternItem defines the item that fills an assembly slot (vcAssemblyPatternSlot) in an assembly pattern (vcAssemblyPattern).
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAssemblyPatternItem.htm"""

    @property
    def Properties(self) -> List[vcProperty]:
        """Property container."""
        pass

    @property
    def DefaultProductType(self) -> vcProductType:
        """Controls the product that is created by default when this assembly pattern item is created."""
        pass

    @DefaultProductType.setter
    def DefaultProductType(self, value : vcProductType) -> None:
        pass

    @property
    def DefaultBoundsDimensions(self) -> vcVector:
        """Controls the dimensions of the block visualization in Assembly Editor. Ignored when DefaultProductType is set."""
        pass

    @DefaultBoundsDimensions.setter
    def DefaultBoundsDimensions(self, value : vcVector) -> None:
        pass


class vcAssemblyPatternManager(vcObject):
    """vcAssemblyPatternManager is used to create, modify, and delete assembly patterns (vcAssemblyPattern).
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAssemblyPatternManager.htm"""

    @property
    def Patterns(self) -> List[vcAssemblyPattern]:
        """List of all assembly patterns."""
        pass

    def createPattern(self: Any, name: str) -> vcAssemblyPattern:
        """Creates a new assembly pattern with given name. Names must be unique."""
        pass

    def deletePattern(self: Any, name: str, pattern: vcAssemblyPattern) -> None:
        """Deletes the pattern given explicitly, or deletes pattern by name."""
        pass

    def clonePattern(self: Any, name: str, pattern: vcAssemblyPattern) -> vcAssemblyPattern:
        """Creates a copy of the pattern given explicitly, or found pattern with given name."""
        pass

    def findPattern(self: Any, name: str) -> vcAssemblyPattern:
        """Returns an assembly pattern with given name, if it exists."""
        pass

    OnPatternAdded : Callable[[], None]
    """Triggered when a pattern has been added to Pattern Manager."""


    OnPatternRemoving : Callable[[], None]
    """Triggered when a pattern is being removed from Pattern Manager."""



class vcAssemblyPatternSlot(vcObject):
    """Assembly pattern slot defines a single location, including its position and orientation, in the assembly. Assembly slots are child objects of assembly patterns (vcAssemblyPattern).
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAssemblyPatternSlot.htm"""

    @property
    def Properties(self) -> List[vcProperty]:
        """Property container."""
        pass

    @property
    def OrderIndex(self) -> int:
        """Controls the order in which the pattern slots are created."""
        pass

    @OrderIndex.setter
    def OrderIndex(self, value : int) -> None:
        pass

    @property
    def Position(self) -> vcMatrix:
        """Defines the positions of the slot within the pattern."""
        pass

    @Position.setter
    def Position(self, value : vcMatrix) -> None:
        pass

    @property
    def Pattern(self) -> vcAssemblyPattern:
        """Defines the pattern that the slot is part of."""
        pass

    @property
    def UniqueID(self) -> str:
        """Unique identifier for the assembly pattern slot."""
        pass

    @property
    def Item(self) -> vcAssemblyPatternItem:
        """Defines the item that fills the assembly pattern slot in the assembly pattern."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a property of the step."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property of the step."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Creates a new property to the step. See Property Constraint Constants for more information."""
        pass

    OnItemChanged : Callable[[], None]
    """Triggered when the item is replaced by another."""



class vcAssemblyProductType(vcProductType):
    """Assembly product type is a subcategory of a product type that represents an assembly. Assembly product type defines how an assembly is formed from multiple product types, and this information is used to create vcProduct instances with assembly structure metadata.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAssemblyProductType.htm"""

    @property
    def AssemblyConfigurationCount(self) -> int:
        """Configuration count"""
        pass

    @property
    def RootStep(self) -> vcAssemblyStep:
        """The root step of the assembly product type. The root step cannot be removed."""
        pass

    @property
    def AssemblySteps(self) -> List[vcAssemblyStep]:
        """List of all assembly steps defined for the assembly product type."""
        pass

    def canBeAddedTo(self: Any, parent: vcAssemblyStep, child: vcAssemblyStep) -> bool:
        """Returns boolean if child step can be added as a child to theparent step. If the relation already exists, returns False."""
        pass

    def canBeMovedTo(self: Any, parent: vcAssemblyStep, child: vcAssemblyStep, index: int) -> bool:
        """Returns boolean if child step can be moved to be a child of the parent step at a specified index. If index is outside the range of existing steps, the method checks if the step can be appended to existing steps of the parent. If child is already at the requested location within children of parent, returns False."""
        pass

    def cloneStepFrom(self: Any, parent: vcAssemblyStep, stepToClone: vcAssemblyStep, index: int) -> vcAssemblyStep:
        """Creates a copy of stepToClone and adds it as a child to parent at specified index. If index is outside the range of existing steps, the created copy is appended to existing steps of the parent. If successful, returns the cloned step."""
        pass

    def createConfig(self: Any) -> vcAssemblyConfiguration:
        """Creates configuration"""
        pass

    @overload
    def createStepTo(self: Any, parent: vcAssemblyStep, index: int) -> vcAssemblyStep:
        """Create a new assembly step and adds it as a child to parent at specified index. If index is outside the range of existing steps, the created step is appended to existing steps of the parent.
 If successful, returns the created step."""
        pass

    @overload
    def createStepTo(self: Any, parent: vcAssemblyStep, name: str, index: int) -> vcAssemblyStep:
        """Create a new assembly step and adds it as a child to parent at specified index. If index is outside the range of existing steps, the created step is appended to existing steps of the parent.
 If successful, returns the created step."""
        pass

    @overload
    def deleteConfig(self: Any) -> None:
        """Deletes configuration by name or index"""
        pass

    @overload
    def deleteConfig(self: Any, index: int) -> None:
        """Deletes configuration by name or index"""
        pass

    def deleteStep(self: Any, step: vcAssemblyStep) -> None:
        """Deleted the given step."""
        pass

    @overload
    def getConfig(self: Any, name: str) -> vcAssemblyConfiguration:
        """Gets configuration by name or index"""
        pass

    @overload
    def getConfig(self: Any, index: int) -> vcAssemblyConfiguration:
        """Gets configuration by name or index"""
        pass

    def moveStepTo(self: Any, parent: vcAssemblyStep, stepToMove: vcAssemblyStep, index: int) -> None:
        """Moves stepToMove and adds it as a child to parent at specified index. If index is outside the range of existing steps, the moved step is appended to existing steps of the parent."""
        pass

    OnStepAdded : Callable[[int], None]
    """Triggered when a step has been added to the assembly product type. Index identifies the current location of the step within its parent."""


    OnStepRemoving : Callable[[int], None]
    """Triggered when a step is being removed from the assembly product type. Index identifies the current location of the step within its parent."""



class vcAssemblyStep(vcObject):
    """Assembly step is one phase of the entire assembly.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAssemblyStep.htm"""

    @property
    def Properties(self) -> List[vcProperty]:
        """General property container."""
        pass

    @property
    def Name(self) -> str:
        """Step name."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def ProcessParameters(self) -> List[vcProperty]:
        """Process parameters property container."""
        pass

    @ProcessParameters.setter
    def ProcessParameters(self, value : List[vcProperty]) -> None:
        pass

    @property
    def Owner(self) -> vcAssemblyProductType:
        """The assembly product type that the step is part of."""
        pass

    @property
    def ChildSteps(self) -> vcAssemblyStep:
        """Direct children of the assembly step."""
        pass

    @property
    def ParentStep(self) -> vcAssemblyStep:
        """The parent step of the assembly step. The root step of the assembly product type has None as parent."""
        pass

    @property
    def RelativeFrame(self) -> vcMatrix:
        """Relative position of the step with respect to its parent."""
        pass

    @RelativeFrame.setter
    def RelativeFrame(self, value : vcMatrix) -> None:
        pass

    @property
    def AbsoluteFrame(self) -> vcMatrix:
        """Position of the step with respect to the root of assembly product type."""
        pass

    @property
    def Pattern(self) -> vcAssemblyPattern:
        """The assembly pattern used for the assembly step. The value may be None."""
        pass

    @Pattern.setter
    def Pattern(self, value : vcAssemblyPattern) -> None:
        pass

    def moveChildStep(self: Any, step: vcAssemblyStep, index: int) -> None:
        """Moves child step within the vcAssemblyStep to new index."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property of the step."""
        pass

    def deleteProcessParameter(self: Any, property: vcProperty) -> None:
        """Deletes a custom process parameter associated with the step."""
        pass

    def getProcessParameter(self: Any, propertyName: str) -> vcProperty:
        """Returns a custom process parameter associated with the step."""
        pass

    def createProcessParameter(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Creates a new custom process parameter associated to the step. See Property Constraint Constants for more information."""
        pass

    OnChildStepAdded : Callable[[vcAssemblyStep, int], None]
    """Triggered when a step has been added to the assembly step."""


    OnChildStepMoved : Callable[[vcAssemblyStep, int, int], None]
    """Triggered when a step has been moved to a new index within the assembly step."""


    OnChildStepRemoving : Callable[[vcAssemblyStep, int], None]
    """Triggered when a step is being removed from the assembly step."""


    OnPatternChanged : Callable[[vcAssemblyStep, vcAssemblyPattern], None]
    """Triggered when a pattern has changed for the assembly step. Pattern in the parameters is the new pattern."""



class vcAssemblyStepConfiguration(vcObject):
    """https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAssemblyStepConfiguration.htm"""

    @property
    def Step(self) -> vcAssemblyStep:
        """Assembly step"""
        pass

    @property
    def Included(self) -> bool:
        """True if included"""
        pass

    @Included.setter
    def Included(self, value : bool) -> None:
        pass


class vcAuthorContext(vcContext):
    """vcAuthorContext is the context of the application for component modeling.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcAuthorContext.htm"""

    @property
    def ActiveComponent(self) -> vcComponent:
        """Defines the active component in context, thereby clearing ActiveNode and ActiveFeatures properties."""
        pass

    @ActiveComponent.setter
    def ActiveComponent(self, value : vcComponent) -> None:
        pass

    @property
    def ActiveFeatures(self) -> List[Tuple[vcNode, List[vcFeature]]]:
        """Gets a list of active features in context and pairs them with containing node."""
        pass

    @property
    def ActiveNode(self) -> vcNode:
        """Defines the active node in context, thereby clearing the ActiveFeatures properties."""
        pass

    @ActiveNode.setter
    def ActiveNode(self, value : vcNode) -> None:
        pass

    def setActiveFeature(self: Any, activeFeature: vcFeature, activeNode: vcNode) -> None:
        """Sets a given feature in a given node as the active feature in context."""
        pass

    def setActiveFeatures(self: Any, tuples: List[Tuple[vcNode, List[vcFeature]]]) -> None:
        """Sets a given list of features in nodes as the active features in context."""
        pass

    ActiveComponentChanged : Callable[[], None]
    """Triggered when a different component becomes the active component in context."""


    ActiveFeaturesChanged : Callable[[], None]
    """Triggered when a different feature or set of features become the active feature(s) in context."""



class vcBaseContainer(vcBehaviour):
    """vcBaseContainer is a container of Frame features used as base frames.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcBaseContainer.htm"""

    @property
    def Bases(self) -> List[vcBaseFrame]:
        """Gets a list of all base frames in container."""
        pass

    def addBase(self: Any) -> vcBaseFrame:
        """Adds a new base frame to container."""
        pass

    def removeBase(self: Any, base: vcBaseFrame) -> None:
        """Deletes a given base from container."""
        pass


class vcBaseFrame(vcObject):
    """vcBaseFrame allows you to manipulate a Frame feature used as base or tool frame for robot programming.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcBaseFrame.htm"""

    @property
    def IPOMode(self) -> int:
        """Defines the interpolation mode of the frame and the external configuration of a referencing robot controller.
 0
 Default setting, so no effect on robot's external configuration.
 1
 Robot position inherits orientation of base frame.
 2
 Robot position inherits orientation of tool frame.
 Interpolation constants can be used with this property.
 Note: A conflict can occur if a base-tool pair in a referencing robot have the same IPOMode property value or cannot be used with the robot's current configuration."""
        pass

    @IPOMode.setter
    def IPOMode(self, value : int) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of the frame."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Node(self) -> vcNode:
        """Defines the node the frame is attached to in the 3D world."""
        pass

    @Node.setter
    def Node(self, value : vcNode) -> None:
        pass

    @property
    def PositionMatrix(self) -> vcMatrix:
        """Defines the frame's position and orientation in the Node property's coordinate system.
 The position matrix is a result of the node's offset, pivot and joint expressions but can be set manually."""
        pass

    @PositionMatrix.setter
    def PositionMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def PositionExpression(self) -> str:
        """The matrix offset expression for the frame's location."""
        pass

    @PositionExpression.setter
    def PositionExpression(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all user defined properties for base frame."""
        pass

    @property
    def CenterOfGravity(self) -> vcMatrix:
        """This property exist only in: Tool Frame.
Defines the mass center point of payload and if needed the orientation for LoadInertia."""
        pass

    @CenterOfGravity.setter
    def CenterOfGravity(self, value : vcMatrix) -> None:
        pass

    @property
    def Inertia(self) -> vcVector:
        """This property exist only in: Tool Frame.
Defines the inertia value (kgm^2) for each axis defined by LoadCenterOfGravity."""
        pass

    @Inertia.setter
    def Inertia(self, value : vcVector) -> None:
        pass

    @property
    def Mass(self) -> float:
        """This property exist only in: Tool Frame.
Defines the weight (kg) of payload."""
        pass

    @Mass.setter
    def Mass(self, value : float) -> None:
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to component, and then returns the new property.
 An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation. 
 See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property from component."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name in component; otherwise returns None."""
        pass


class vcBehaviour(vcObject):
    """vcBehaviour is the basic implementation of all behavior type objects.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcBehaviour.htm"""

    @property
    def Component(self) -> vcComponent:
        """Gets the component of the behavior."""
        pass

    @property
    def Enabled(self) -> bool:
        """Turns on/off the use of the behavior."""
        pass

    @Enabled.setter
    def Enabled(self, value : bool) -> None:
        pass

    @property
    def IgnoreEvents(self) -> bool:
        """Defines if the behavior ignores events.
 For example, a container type behavior may disregard the transition of a component into and out of the container to avoid passing the event to a user-defined function."""
        pass

    @IgnoreEvents.setter
    def IgnoreEvents(self, value : bool) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of the behavior which is unique for every behavior in a component."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Parent(self) -> vcNode:
        """Gets the node the behavior belongs to in a component."""
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all properties in the behavior."""
        pass

    @property
    def Type(self) -> int:
        """Gets the behavior's type.
 See Behavior Constants for more information."""
        pass

    @property
    def World(self) -> vcNode:
        """Gets the 3D world (simulation root node)."""
        pass

    @property
    def LinkLength1(self) -> float:
        """This property exist only in: Articulated Kinematics (old), Delta Kinematics, Parallelogram Kinematics, Scara Kinematics (Old).
See Articulated Kinematics for descriptions of properties."""
        pass

    @LinkLength1.setter
    def LinkLength1(self, value : float) -> None:
        pass

    @property
    def LinkLength2(self) -> float:
        """This property exist only in: Articulated Kinematics (old), Delta Kinematics, Parallelogram Kinematics, Scara Kinematics (Old)."""
        pass

    @LinkLength2.setter
    def LinkLength2(self, value : float) -> None:
        pass

    @property
    def LinkLength3(self) -> float:
        """This property exist only in: Articulated Kinematics (old), Parallelogram Kinematics."""
        pass

    @LinkLength3.setter
    def LinkLength3(self, value : float) -> None:
        pass

    @property
    def LinkLength4(self) -> float:
        """This property exist only in: Articulated Kinematics (old), Parallelogram Kinematics."""
        pass

    @LinkLength4.setter
    def LinkLength4(self, value : float) -> None:
        pass

    @property
    def LinkLength5(self) -> float:
        """This property exist only in: Articulated Kinematics (old), Parallelogram Kinematics."""
        pass

    @LinkLength5.setter
    def LinkLength5(self, value : float) -> None:
        pass

    @property
    def JointOffset1(self) -> float:
        """This property exist only in: Articulated Kinematics (old), Parallelogram Kinematics, Scara Kinematics (Old)."""
        pass

    @JointOffset1.setter
    def JointOffset1(self, value : float) -> None:
        pass

    @property
    def JointOffset3(self) -> float:
        """This property exist only in: Articulated Kinematics (old), Parallelogram Kinematics, Scara Kinematics (Old)."""
        pass

    @JointOffset3.setter
    def JointOffset3(self, value : float) -> None:
        pass

    @property
    def ConfigName1(self) -> str:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @ConfigName1.setter
    def ConfigName1(self, value : str) -> None:
        pass

    @property
    def ConfigName2(self) -> str:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @ConfigName2.setter
    def ConfigName2(self, value : str) -> None:
        pass

    @property
    def ConfigName3(self) -> str:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new)."""
        pass

    @ConfigName3.setter
    def ConfigName3(self, value : str) -> None:
        pass

    @property
    def ConfigName4(self) -> str:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new)."""
        pass

    @ConfigName4.setter
    def ConfigName4(self, value : str) -> None:
        pass

    @property
    def ConfigName5(self) -> str:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new)."""
        pass

    @ConfigName5.setter
    def ConfigName5(self, value : str) -> None:
        pass

    @property
    def ConfigName6(self) -> str:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new)."""
        pass

    @ConfigName6.setter
    def ConfigName6(self, value : str) -> None:
        pass

    @property
    def ConfigName7(self) -> str:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new)."""
        pass

    @ConfigName7.setter
    def ConfigName7(self, value : str) -> None:
        pass

    @property
    def ConfigName8(self) -> str:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new)."""
        pass

    @ConfigName8.setter
    def ConfigName8(self, value : str) -> None:
        pass

    @property
    def PalletizingMode(self) -> bool:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new)."""
        pass

    @PalletizingMode.setter
    def PalletizingMode(self, value : bool) -> None:
        pass

    @property
    def PalletizingNormal(self) -> vcVector:
        """This property exist only in: Articulated Kinematics (old), Articulated Kinematics (new)."""
        pass

    @PalletizingNormal.setter
    def PalletizingNormal(self, value : vcVector) -> None:
        pass

    @property
    def A45(self) -> float:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @A45.setter
    def A45(self, value : float) -> None:
        pass

    @property
    def JointZeroOffset1(self) -> float:
        """This property exist only in: Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @JointZeroOffset1.setter
    def JointZeroOffset1(self, value : float) -> None:
        pass

    @property
    def JointZeroOffset2(self) -> float:
        """This property exist only in: Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @JointZeroOffset2.setter
    def JointZeroOffset2(self, value : float) -> None:
        pass

    @property
    def JointZeroOffset3(self) -> float:
        """This property exist only in: Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @JointZeroOffset3.setter
    def JointZeroOffset3(self, value : float) -> None:
        pass

    @property
    def JointZeroOffset4(self) -> float:
        """This property exist only in: Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @JointZeroOffset4.setter
    def JointZeroOffset4(self, value : float) -> None:
        pass

    @property
    def JointZeroOffset5(self) -> float:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @JointZeroOffset5.setter
    def JointZeroOffset5(self, value : float) -> None:
        pass

    @property
    def JointZeroOffset6(self) -> float:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @JointZeroOffset6.setter
    def JointZeroOffset6(self, value : float) -> None:
        pass

    @property
    def JointSign1(self) -> int:
        """This property exist only in: Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @JointSign1.setter
    def JointSign1(self, value : int) -> None:
        pass

    @property
    def JointSign2(self) -> int:
        """This property exist only in: Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @JointSign2.setter
    def JointSign2(self, value : int) -> None:
        pass

    @property
    def JointSign3(self) -> int:
        """This property exist only in: Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @JointSign3.setter
    def JointSign3(self, value : int) -> None:
        pass

    @property
    def JointSign4(self) -> int:
        """This property exist only in: Articulated Kinematics (new), Scara Kinematics (New)."""
        pass

    @JointSign4.setter
    def JointSign4(self, value : int) -> None:
        pass

    @property
    def JointSign5(self) -> int:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @JointSign5.setter
    def JointSign5(self, value : int) -> None:
        pass

    @property
    def JointSign6(self) -> int:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @JointSign6.setter
    def JointSign6(self, value : int) -> None:
        pass

    @property
    def Coupling23(self) -> int:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @Coupling23.setter
    def Coupling23(self, value : int) -> None:
        pass

    @property
    def ShoulderValid(self) -> bool:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @ShoulderValid.setter
    def ShoulderValid(self, value : bool) -> None:
        pass

    @property
    def ElbowValid(self) -> bool:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @ElbowValid.setter
    def ElbowValid(self, value : bool) -> None:
        pass

    @property
    def WristValid(self) -> bool:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @WristValid.setter
    def WristValid(self, value : bool) -> None:
        pass

    @property
    def PolarSingularityTolerance(self) -> float:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @PolarSingularityTolerance.setter
    def PolarSingularityTolerance(self, value : float) -> None:
        pass

    @property
    def WristSingularityTolerance(self) -> float:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @WristSingularityTolerance.setter
    def WristSingularityTolerance(self, value : float) -> None:
        pass

    @property
    def ExtendedPositionTolerance(self) -> float:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @ExtendedPositionTolerance.setter
    def ExtendedPositionTolerance(self, value : float) -> None:
        pass

    @property
    def Coupling456(self) -> float:
        """This property exist only in: Articulated Kinematics (new)."""
        pass

    @Coupling456.setter
    def Coupling456(self, value : float) -> None:
        pass

    @property
    def ComponentSignalIn(self) -> vcComponentSignal:
        """This property exist only in: Component Grabber.
Defines the signal used for signaling the arrival of components into the grabber's container."""
        pass

    @ComponentSignalIn.setter
    def ComponentSignalIn(self, value : vcComponentSignal) -> None:
        pass

    @property
    def Container(self) -> vcContainer:
        """This property exist only in: Component Grabber.
Defines the container type behavior used for storing components grasped by the grabber."""
        pass

    @Container.setter
    def Container(self, value : vcContainer) -> None:
        pass

    @property
    def DoneSignalOut(self) -> vcBoolSignal:
        """This property exist only in: Component Grabber.
Defines the signal used for signaling the completion of an action by the grabber."""
        pass

    @DoneSignalOut.setter
    def DoneSignalOut(self, value : vcBoolSignal) -> None:
        pass

    @property
    def FunctionalitySignalIn(self) -> vcSignal:
        """This property exist only in: Component Grabber.
Defines the behavior signal used for signalling the current state of the grabber.
 Note: A Behaviour Signal has a constant value of VC_BEHAVIOURSIGNAL and can only be created using the API."""
        pass

    @FunctionalitySignalIn.setter
    def FunctionalitySignalIn(self, value : vcSignal) -> None:
        pass

    @property
    def GrabReleaseSignalIn(self) -> vcBoolSignal:
        """This property exist only in: Component Grabber.
Defines the signal used for triggering the grasp and release of components by the grabber."""
        pass

    @GrabReleaseSignalIn.setter
    def GrabReleaseSignalIn(self, value : vcBoolSignal) -> None:
        pass

    @property
    def GrabTriggerSignalOut(self) -> vcBoolSignal:
        """This property exist only in: Component Grabber.
Defines the signal used for signaling the completion of a grasp action."""
        pass

    @GrabTriggerSignalOut.setter
    def GrabTriggerSignalOut(self, value : vcBoolSignal) -> None:
        pass

    @property
    def Interface(self) -> vcSimInterface:
        """This property exist only in: Component Grabber.
Defines the interface used for exchanging components between containers."""
        pass

    @Interface.setter
    def Interface(self, value : vcSimInterface) -> None:
        pass

    @property
    def ReleaseMode(self) -> str:
        """This property exist only in: Component Grabber.
Defines the mode for releasing components from the grabber."""
        pass

    @ReleaseMode.setter
    def ReleaseMode(self, value : str) -> None:
        pass

    @property
    def ReleaseTriggerSignalOut(self) -> vcBoolSignal:
        """This property exist only in: Component Grabber.
Defines the signal used for signaling the completion of a release action."""
        pass

    @ReleaseTriggerSignalOut.setter
    def ReleaseTriggerSignalOut(self, value : vcBoolSignal) -> None:
        pass

    @property
    def BoolSignal(self) -> vcBoolSignal:
        """This property exist only in: Component Path Sensor, Raycast Sensor, Volume Sensor.
Defines the signal used for signaling the value of the BoolSignalValue property."""
        pass

    @BoolSignal.setter
    def BoolSignal(self, value : vcBoolSignal) -> None:
        pass

    @property
    def BoolSignalValue(self) -> bool:
        """This property exist only in: Component Path Sensor.
Defines the current state of the sensor. That is, a True value means the sensor has been triggered, whereas a False value means the sensor has either not been triggered or has been reset."""
        pass

    @BoolSignalValue.setter
    def BoolSignalValue(self, value : bool) -> None:
        pass

    @property
    def ComponentSignal(self) -> vcComponentSignal:
        """This property exist only in: Component Path Sensor, Raycast Sensor, Volume Sensor.
Defines the signal used for signaling which component triggered the sensor."""
        pass

    @ComponentSignal.setter
    def ComponentSignal(self, value : vcComponentSignal) -> None:
        pass

    @property
    def Frame(self) -> vcFrameFeature:
        """This property exist only in: Component Path Sensor, Particle System, Raycast Sensor.
Defines the Frame feature referenced as the sensor's physical location."""
        pass

    @Frame.setter
    def Frame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def ResetAt(self) -> int:
        """This property exist only in: Component Path Sensor.
Defines the mode for resetting the sensor.
 See Path Constants for more information."""
        pass

    @ResetAt.setter
    def ResetAt(self, value : int) -> None:
        pass

    @property
    def TriggerAt(self) -> int:
        """This property exist only in: Component Path Sensor.
Defines the mode for triggering the sensor.
 See Path Constants for more information."""
        pass

    @TriggerAt.setter
    def TriggerAt(self, value : int) -> None:
        pass

    @property
    def Height1(self) -> float:
        """This property exist only in: Delta Kinematics.
See Delta Kinematics for descriptions of properties."""
        pass

    @Height1.setter
    def Height1(self, value : float) -> None:
        pass

    @property
    def Height2(self) -> float:
        """This property exist only in: Delta Kinematics."""
        pass

    @Height2.setter
    def Height2(self, value : float) -> None:
        pass

    @property
    def ShoulderOffset(self) -> float:
        """This property exist only in: Delta Kinematics."""
        pass

    @ShoulderOffset.setter
    def ShoulderOffset(self, value : float) -> None:
        pass

    @property
    def WristOffset(self) -> float:
        """This property exist only in: Delta Kinematics."""
        pass

    @WristOffset.setter
    def WristOffset(self, value : float) -> None:
        pass

    @property
    def DOF(self) -> str:
        """This property exist only in: Jog Info.
Defines the degree of freedom (DOF) for interaction, which is either a rotation or translation based in a coordinate axis."""
        pass

    @DOF.setter
    def DOF(self, value : str) -> None:
        pass

    @property
    def Message(self) -> str:
        """This property exist only in: Jog Info.
Defines the message written to the Output panel when the pointer hovers over the Variable property and the Interact or Jog command is enabled."""
        pass

    @Message.setter
    def Message(self, value : str) -> None:
        pass

    @property
    def Offset(self) -> vcMatrix:
        """This property exist only in: Jog Info.
Defines the offset matrix (pivot point) where interaction can occur in the containing node's coordinate system."""
        pass

    @Offset.setter
    def Offset(self, value : vcMatrix) -> None:
        pass

    @property
    def Scale(self) -> float:
        """This property exist only in: Jog Info.
Defines the scale factor for jogging.
 Generally, the value is 1.0 or -1.0 in order to invert the method of interaction in the 3D world."""
        pass

    @Scale.setter
    def Scale(self, value : float) -> None:
        pass

    @property
    def Variable(self) -> vcProperty:
        """This property exist only in: Jog Info.
Defines the property that is modified during interaction, which in all cases must be a Real type property."""
        pass

    @Variable.setter
    def Variable(self, value : vcProperty) -> None:
        pass

    @property
    def Note(self) -> str:
        """This property exist only in: Note.
Defines the text in the note."""
        pass

    @Note.setter
    def Note(self, value : str) -> None:
        pass

    @property
    def BurstAmount(self) -> int:
        """This property exist only in: Particle System.
Defines the amount of particles to use in the burst."""
        pass

    @BurstAmount.setter
    def BurstAmount(self, value : int) -> None:
        pass

    @property
    def BurstLife(self) -> float:
        """This property exist only in: Particle System.
Defines the life span of the particle burst."""
        pass

    @BurstLife.setter
    def BurstLife(self, value : float) -> None:
        pass

    @property
    def BurstMode(self) -> bool:
        """This property exist only in: Particle System.
Defines the burst mode of the particle system."""
        pass

    @BurstMode.setter
    def BurstMode(self, value : bool) -> None:
        pass

    @property
    def BurstSpeed(self) -> float:
        """This property exist only in: Particle System.
Defines the speed of the particle burst."""
        pass

    @BurstSpeed.setter
    def BurstSpeed(self, value : float) -> None:
        pass

    @property
    def Interval(self) -> float:
        """This property exist only in: Particle System.
Defines the time interval of each burst or swarm."""
        pass

    @Interval.setter
    def Interval(self, value : float) -> None:
        pass

    @property
    def Material(self) -> vcMaterial:
        """This property exist only in: Particle System, Physics Cable.
Defines the material of each particle.
 Note: The material must have a texture (vcBitmap) assigned to it in order for particles to be visible in the 3D world."""
        pass

    @Material.setter
    def Material(self, value : vcMaterial) -> None:
        pass

    @property
    def ParticleSize(self) -> float:
        """This property exist only in: Particle System.
Defines the size of each particle."""
        pass

    @ParticleSize.setter
    def ParticleSize(self, value : float) -> None:
        pass

    @property
    def CableLength(self) -> float:
        """This property exist only in: Physics Cable.
Defines the length of cable.
 If 0.0, the length is dynamic and based on the location of cable endpoints."""
        pass

    @CableLength.setter
    def CableLength(self, value : float) -> None:
        pass

    @property
    def ColliderLength(self) -> float:
        """This property exist only in: Physics Cable.
Defines the size of collider relative to length of cable."""
        pass

    @ColliderLength.setter
    def ColliderLength(self, value : float) -> None:
        pass

    @property
    def ColliderOverlap(self) -> float:
        """This property exist only in: Physics Cable.
Defines an acceptable overlap of collider in relation to others."""
        pass

    @ColliderOverlap.setter
    def ColliderOverlap(self, value : float) -> None:
        pass

    @property
    def EndType1(self) -> int:
        """This property exist only in: Physics Cable.
Defines an anchor type of the first endpoint.
 0 = Free
 The cable hangs freely while attached to Node1.
 1 = Rotating
 The cable can swing back and forth or rotate while attached to Node1.
 2 = Fixed
 The cable is securely anchored to Node1."""
        pass

    @EndType1.setter
    def EndType1(self, value : int) -> None:
        pass

    @property
    def EndType2(self) -> int:
        """This property exist only in: Physics Cable.
Defines an anchor type of the second endpoint.
 0 = Free
 The cable hangs freely while attached to Node2.
 1 = Rotating
 The cable can swing back and forth or rotate while attached to Node2.
 2 = Fixed
 The cable is securely anchored to Node2."""
        pass

    @EndType2.setter
    def EndType2(self, value : int) -> None:
        pass

    @property
    def MaterialDensity(self) -> float:
        """This property exist only in: Physics Cable, Physics Entity.
Defines the density of cable material."""
        pass

    @MaterialDensity.setter
    def MaterialDensity(self, value : float) -> None:
        pass

    @property
    def MaterialFrictionDynamic(self) -> float:
        """This property exist only in: Physics Cable.
Defines the dynamic friction of cable material."""
        pass

    @MaterialFrictionDynamic.setter
    def MaterialFrictionDynamic(self, value : float) -> None:
        pass

    @property
    def MaterialFrictionStatic(self) -> float:
        """This property exist only in: Physics Cable.
Defines the static friction of cable material."""
        pass

    @MaterialFrictionStatic.setter
    def MaterialFrictionStatic(self, value : float) -> None:
        pass

    @property
    def MaterialRestitution(self) -> float:
        """This property exist only in: Physics Cable.
Defines the restitution of cable material."""
        pass

    @MaterialRestitution.setter
    def MaterialRestitution(self, value : float) -> None:
        pass

    @property
    def Node1(self) -> vcNode:
        """This property exist only in: Physics Cable.
Defines the node the first endpoint of cable is attached to in 3D world."""
        pass

    @Node1.setter
    def Node1(self, value : vcNode) -> None:
        pass

    @property
    def Node2(self) -> vcNode:
        """This property exist only in: Physics Cable.
Defines the node the second endpoint of cable is attached to in 3D world."""
        pass

    @Node2.setter
    def Node2(self, value : vcNode) -> None:
        pass

    @property
    def RenderingSteps(self) -> int:
        """This property exist only in: Physics Cable.
Defines the amount of steps for rendering cable."""
        pass

    @RenderingSteps.setter
    def RenderingSteps(self, value : int) -> None:
        pass

    @property
    def SolverIterExternal(self) -> int:
        """This property exist only in: Physics Cable.
Defines the number of iterations for solving external setting of cable."""
        pass

    @SolverIterExternal.setter
    def SolverIterExternal(self, value : int) -> None:
        pass

    @property
    def SolverIterInternal(self) -> int:
        """This property exist only in: Physics Cable.
Defines the number of iterations for solving internal setting of cable."""
        pass

    @SolverIterInternal.setter
    def SolverIterInternal(self, value : int) -> None:
        pass

    @property
    def SolverIterPosition(self) -> int:
        """This property exist only in: Physics Cable.
Defines the number of iterations for solving position of cable."""
        pass

    @SolverIterPosition.setter
    def SolverIterPosition(self, value : int) -> None:
        pass

    @property
    def SolverIterProjections(self) -> int:
        """This property exist only in: Physics Cable.
Defines the number of iterations for solving the projection of cable."""
        pass

    @SolverIterProjections.setter
    def SolverIterProjections(self, value : int) -> None:
        pass

    @property
    def SolverIterVelocity(self) -> int:
        """This property exist only in: Physics Cable.
Defines the number of iterations for solving the velocity of cable."""
        pass

    @SolverIterVelocity.setter
    def SolverIterVelocity(self, value : int) -> None:
        pass

    @property
    def SolverSeparationLimit(self) -> float:
        """This property exist only in: Physics Cable.
Defines a limit for cable separation."""
        pass

    @SolverSeparationLimit.setter
    def SolverSeparationLimit(self, value : float) -> None:
        pass

    @property
    def SpringDamping(self) -> float:
        """This property exist only in: Physics Cable.
Defines the damping of cable, thereby affecting its bounciness."""
        pass

    @SpringDamping.setter
    def SpringDamping(self, value : float) -> None:
        pass

    @property
    def SpringStrength(self) -> float:
        """This property exist only in: Physics Cable.
Defines the strength of cable relative to applied force when compressing or stretching the cable, for example its tensile strength."""
        pass

    @SpringStrength.setter
    def SpringStrength(self, value : float) -> None:
        pass

    @property
    def SpringTangentialDamping(self) -> float:
        """This property exist only in: Physics Cable.
Defines the tangential damping of cable relative to applied forced when contacting a surface."""
        pass

    @SpringTangentialDamping.setter
    def SpringTangentialDamping(self, value : float) -> None:
        pass

    @property
    def SpringTangentialStrength(self) -> float:
        """This property exist only in: Physics Cable.
Defines the tangential strength of cable relative to applied force when contacting a surface."""
        pass

    @SpringTangentialStrength.setter
    def SpringTangentialStrength(self, value : float) -> None:
        pass

    @property
    def Stiffness(self) -> int:
        """This property exist only in: Physics Cable.
Defines the rigidity of cable.
 0 = Low
 Cable is very flexible.
 1 = Medium
 (Default) Cable is fairly flexible.
 2 = High
 Cable is very rigid."""
        pass

    @Stiffness.setter
    def Stiffness(self, value : int) -> None:
        pass

    @property
    def Thickness(self) -> float:
        """This property exist only in: Physics Cable.
Defines the thickness of cable."""
        pass

    @Thickness.setter
    def Thickness(self, value : float) -> None:
        pass

    @property
    def TotalLengthFactor(self) -> float:
        """This property exist only in: Physics Cable.
Defines a factor for determining cable length."""
        pass

    @TotalLengthFactor.setter
    def TotalLengthFactor(self, value : float) -> None:
        pass

    @property
    def AngularDamping(self) -> float:
        """This property exist only in: Physics Entity.
Defines the angular damping of entity."""
        pass

    @AngularDamping.setter
    def AngularDamping(self, value : float) -> None:
        pass

    @property
    def CenterOfGravity(self) -> vcMatrix:
        """This property exist only in: Physics Entity.
Defines the mass center point of payload and if needed the orientation for LoadInertia."""
        pass

    @CenterOfGravity.setter
    def CenterOfGravity(self, value : vcMatrix) -> None:
        pass

    @property
    def DynamicFriction(self) -> float:
        """This property exist only in: Physics Entity.
Defines the kinetic friction of entity."""
        pass

    @DynamicFriction.setter
    def DynamicFriction(self, value : float) -> None:
        pass

    @property
    def Inertia(self) -> vcVector:
        """This property exist only in: Physics Entity.
Defines the inertia value (kgm^2) for each axis defined by LoadCenterOfGravity."""
        pass

    @Inertia.setter
    def Inertia(self, value : vcVector) -> None:
        pass

    @property
    def LinearDamping(self) -> float:
        """This property exist only in: Physics Entity.
Defines the linear damping of entity."""
        pass

    @LinearDamping.setter
    def LinearDamping(self, value : float) -> None:
        pass

    @property
    def Mass(self) -> float:
        """This property exist only in: Physics Entity.
Defines the weight (kg) of payload."""
        pass

    @Mass.setter
    def Mass(self, value : float) -> None:
        pass

    @property
    def PhysicsType(self) -> int:
        """This property exist only in: Physics Entity.
Defines the physics type of entity.
 See Entity Constants for more information."""
        pass

    @PhysicsType.setter
    def PhysicsType(self, value : int) -> None:
        pass

    @property
    def Restitution(self) -> float:
        """This property exist only in: Physics Entity.
Defines the restitution of entity."""
        pass

    @Restitution.setter
    def Restitution(self, value : float) -> None:
        pass

    @property
    def SolverPositionIterations(self) -> int:
        """This property exist only in: Physics Entity.
Defines the number of iterations for solving the motion of entity in relation to its position."""
        pass

    @SolverPositionIterations.setter
    def SolverPositionIterations(self, value : int) -> None:
        pass

    @property
    def SolverVelocityIterations(self) -> int:
        """This property exist only in: Physics Entity.
Defines the number of iterations for solving the motion of entity in relation to its velocity."""
        pass

    @SolverVelocityIterations.setter
    def SolverVelocityIterations(self, value : int) -> None:
        pass

    @property
    def StaticFriction(self) -> float:
        """This property exist only in: Physics Entity.
Defines the static friction of entity."""
        pass

    @StaticFriction.setter
    def StaticFriction(self, value : float) -> None:
        pass

    @property
    def UpdatePhysics(self) -> bool:
        """This property exist only in: Physics Entity.
Updates the changes on the component during the simulation runtime. Note: You need to call the update() method at the end of the changes to do the commit."""
        pass

    @UpdatePhysics.setter
    def UpdatePhysics(self, value : bool) -> None:
        pass

    @property
    def Attachinchildmat(self) -> vcMatrix:
        """This property exist only in: Physics Joint.
Defines anchor point of joint in coordinate system of connected node."""
        pass

    @Attachinchildmat.setter
    def Attachinchildmat(self, value : vcMatrix) -> None:
        pass

    @property
    def Attachinparentmat(self) -> vcMatrix:
        """This property exist only in: Physics Joint.
Defines anchor point of joint in coordinate system of parent node.
 Note: The joint behavior can be contained in one node, but attached to a different node. The node attached to a joint is its parent."""
        pass

    @Attachinparentmat.setter
    def Attachinparentmat(self, value : vcMatrix) -> None:
        pass

    @property
    def BreakForce(self) -> float:
        """This property exist only in: Physics Joint.
Defines force needed to break joint."""
        pass

    @BreakForce.setter
    def BreakForce(self, value : float) -> None:
        pass

    @property
    def BreakTorque(self) -> float:
        """This property exist only in: Physics Joint.
Defines torque needed to break joint."""
        pass

    @BreakTorque.setter
    def BreakTorque(self, value : float) -> None:
        pass

    @property
    def ExMotion(self) -> int:
        """This property exist only in: Physics Joint.
Defines movement of joint in X-axis.
 0 = Locked
 1 = Limited
 2 = Free"""
        pass

    @ExMotion.setter
    def ExMotion(self, value : int) -> None:
        pass

    @property
    def EyMotion(self) -> int:
        """This property exist only in: Physics Joint.
Defines movement of joint in Y-axis.
 0 = Locked
 1 = Limited
 2 = Free"""
        pass

    @EyMotion.setter
    def EyMotion(self, value : int) -> None:
        pass

    @property
    def EzMotion(self) -> int:
        """This property exist only in: Physics Joint.
Defines movement of joint in Z-axis.
 0 = Locked
 1 = Limited
 2 = Free"""
        pass

    @EzMotion.setter
    def EzMotion(self, value : int) -> None:
        pass

    @property
    def LinearLimitdamping(self) -> float:
        """This property exist only in: Physics Joint.
Defines damping of spring for linear limit of joint."""
        pass

    @LinearLimitdamping.setter
    def LinearLimitdamping(self, value : float) -> None:
        pass

    @property
    def LinearLimitdistance(self) -> float:
        """This property exist only in: Physics Joint.
Defines limit for linear movement of joint based on the distance from its origin."""
        pass

    @LinearLimitdistance.setter
    def LinearLimitdistance(self, value : float) -> None:
        pass

    @property
    def LinearLimitextend(self) -> float:
        """This property exist only in: Physics Joint.
Defines extended limit for linear movement of joint."""
        pass

    @LinearLimitextend.setter
    def LinearLimitextend(self, value : float) -> None:
        pass

    @property
    def LinearLimitrestitution(self) -> float:
        """This property exist only in: Physics Joint.
Defines restitution for linear limit of joint."""
        pass

    @LinearLimitrestitution.setter
    def LinearLimitrestitution(self, value : float) -> None:
        pass

    @property
    def LinearLimitsoft(self) -> bool:
        """This property exist only in: Physics Joint.
Turns on/off soft linear limit of joint."""
        pass

    @LinearLimitsoft.setter
    def LinearLimitsoft(self, value : bool) -> None:
        pass

    @property
    def LinearLimitspring(self) -> float:
        """This property exist only in: Physics Joint.
Defines stiffness of spring for linear limit of joint."""
        pass

    @LinearLimitspring.setter
    def LinearLimitspring(self, value : float) -> None:
        pass

    @property
    def ProjectionAngular(self) -> float:
        """This property exist only in: Physics Joint.
Defines angular tolerance for solver to project joint and its bodies back together."""
        pass

    @ProjectionAngular.setter
    def ProjectionAngular(self, value : float) -> None:
        pass

    @property
    def ProjectionLinear(self) -> float:
        """This property exist only in: Physics Joint.
Defines linear tolerance for solver to project joint and its bodies back together."""
        pass

    @ProjectionLinear.setter
    def ProjectionLinear(self, value : float) -> None:
        pass

    @property
    def Swing1Motion(self) -> int:
        """This property exist only in: Physics Joint.
Defines freedom of joint to rotate around its X-axis.
 0 = Locked
 1 = Limited
 2 = Free
 Note: Swing refers to rotation around X- and Y-axes of joint."""
        pass

    @Swing1Motion.setter
    def Swing1Motion(self, value : int) -> None:
        pass

    @property
    def Swing2Motion(self) -> int:
        """This property exist only in: Physics Joint.
Defines freedom of joint to rotate around its Y-axis.
 0 = Locked
 1 = Limited
 2 = Free"""
        pass

    @Swing2Motion.setter
    def Swing2Motion(self, value : int) -> None:
        pass

    @property
    def SwingLimitdamping(self) -> float:
        """This property exist only in: Physics Joint.
Defines damping of spring for swing limit of joint."""
        pass

    @SwingLimitdamping.setter
    def SwingLimitdamping(self, value : float) -> None:
        pass

    @property
    def Swinglimitdistance(self) -> float:
        """This property exist only in: Physics Joint.
Defines limit for swing movement of joint based on the distance from its origin."""
        pass

    @Swinglimitdistance.setter
    def Swinglimitdistance(self, value : float) -> None:
        pass

    @property
    def SwingLimitrestitution(self) -> float:
        """This property exist only in: Physics Joint.
Defines restitution for swing limit of joint."""
        pass

    @SwingLimitrestitution.setter
    def SwingLimitrestitution(self, value : float) -> None:
        pass

    @property
    def SwingLimitsoft(self) -> bool:
        """This property exist only in: Physics Joint.
Turns on/off soft swing limit of joint."""
        pass

    @SwingLimitsoft.setter
    def SwingLimitsoft(self, value : bool) -> None:
        pass

    @property
    def SwingLimitspring(self) -> float:
        """This property exist only in: Physics Joint.
Defines stiffness of spring for swing limit of joint."""
        pass

    @SwingLimitspring.setter
    def SwingLimitspring(self, value : float) -> None:
        pass

    @property
    def SwingLimitYangle(self) -> float:
        """This property exist only in: Physics Joint.
Defines limit for swing movement of joint around its X-axis."""
        pass

    @SwingLimitYangle.setter
    def SwingLimitYangle(self, value : float) -> None:
        pass

    @property
    def SwingLimitZangle(self) -> float:
        """This property exist only in: Physics Joint.
Defines limit for swing movement of joint around its Y-axis."""
        pass

    @SwingLimitZangle.setter
    def SwingLimitZangle(self, value : float) -> None:
        pass

    @property
    def TwistLimitdamping(self) -> float:
        """This property exist only in: Physics Joint.
Defines damping of spring for twist limit of joint."""
        pass

    @TwistLimitdamping.setter
    def TwistLimitdamping(self, value : float) -> None:
        pass

    @property
    def Twistlimitdistance(self) -> float:
        """This property exist only in: Physics Joint.
Defines limit for twist movement of joint based on the distance from its origin."""
        pass

    @Twistlimitdistance.setter
    def Twistlimitdistance(self, value : float) -> None:
        pass

    @property
    def TwistLimitLower(self) -> float:
        """This property exist only in: Physics Joint.
Defines lower limit for twist movement of joint."""
        pass

    @TwistLimitLower.setter
    def TwistLimitLower(self, value : float) -> None:
        pass

    @property
    def TwistLimitrestitution(self) -> float:
        """This property exist only in: Physics Joint.
Defines restitution for twist limit of joint."""
        pass

    @TwistLimitrestitution.setter
    def TwistLimitrestitution(self, value : float) -> None:
        pass

    @property
    def TwistLimitsoft(self) -> bool:
        """This property exist only in: Physics Joint.
Turns on/off soft twist limit of joint."""
        pass

    @TwistLimitsoft.setter
    def TwistLimitsoft(self, value : bool) -> None:
        pass

    @property
    def TwistLimitspring(self) -> float:
        """This property exist only in: Physics Joint.
Defines stiffness of spring for twist limit of joint."""
        pass

    @TwistLimitspring.setter
    def TwistLimitspring(self, value : float) -> None:
        pass

    @property
    def TwistLimitUpper(self) -> float:
        """This property exist only in: Physics Joint.
Defines upper limit for twist movement of joint."""
        pass

    @TwistLimitUpper.setter
    def TwistLimitUpper(self, value : float) -> None:
        pass

    @property
    def TwistMotion(self) -> int:
        """This property exist only in: Physics Joint.
Defines freedom of joint to rotate around its Z-axis.
 0 = Locked
 1 = Limited
 2 = Free
 Note: Twist refers to rotation around Z-axis of joint."""
        pass

    @TwistMotion.setter
    def TwistMotion(self, value : int) -> None:
        pass

    @property
    def Path(self) -> List[vcFrameFeature]:
        """This property exist only in: Physics Path.
Defines the points of path."""
        pass

    @Path.setter
    def Path(self, value : List[vcFrameFeature]) -> None:
        pass

    @property
    def PushingFeatures(self) -> List[vcFeature]:
        """This property exist only in: Physics Path.
Defines the geometry of path used to push objects."""
        pass

    @PushingFeatures.setter
    def PushingFeatures(self, value : List[vcFeature]) -> None:
        pass

    @property
    def Speed(self) -> float:
        """This property exist only in: Physics Path.
Defines the speed of the path. If a negative value is given, the path direction will be the opposite."""
        pass

    @Speed.setter
    def Speed(self, value : float) -> None:
        pass

    @property
    def Script(self) -> str:
        """This property exist only in: Python Script.
Defines the code of the script."""
        pass

    @Script.setter
    def Script(self, value : str) -> None:
        pass

    @property
    def DetectionContainer(self) -> vcContainer:
        """This property exist only in: Raycast Sensor, Volume Sensor.
Defines if the sensor only detects components in a specific container type behavior."""
        pass

    @DetectionContainer.setter
    def DetectionContainer(self, value : vcContainer) -> None:
        pass

    @property
    def DetectionThreshold(self) -> float:
        """This property exist only in: Raycast Sensor.
Defines the distance at which the RangeSignal property will start to send distance information for a detected component."""
        pass

    @DetectionThreshold.setter
    def DetectionThreshold(self, value : float) -> None:
        pass

    @property
    def MaxRange(self) -> float:
        """This property exist only in: Raycast Sensor.
Defines the length of the ray cast by the sensor."""
        pass

    @MaxRange.setter
    def MaxRange(self, value : float) -> None:
        pass

    @property
    def RangeSignal(self) -> vcRealSignal:
        """This property exist only in: Raycast Sensor.
Defines the signal used for signaling the range of a detected component to sensor's location."""
        pass

    @RangeSignal.setter
    def RangeSignal(self, value : vcRealSignal) -> None:
        pass

    @property
    def SampleTime(self) -> float:
        """This property exist only in: Raycast Sensor, Volume Sensor.
Defines the time interval (in seconds) for detecting components when the UseSampling property has a True value."""
        pass

    @SampleTime.setter
    def SampleTime(self, value : float) -> None:
        pass

    @property
    def ShowRay(self) -> bool:
        """This property exist only in: Raycast Sensor.
Turns on/off the visibility of the ray in the 3D world.
 The ray is rendered as a red line."""
        pass

    @ShowRay.setter
    def ShowRay(self, value : bool) -> None:
        pass

    @property
    def TestParent(self) -> bool:
        """This property exist only in: Raycast Sensor, Volume Sensor.
Defines if the sensor can detect geometry contained in the sensor's node.
 Generally, a True value is used when you want to detect self collisions."""
        pass

    @TestParent.setter
    def TestParent(self, value : bool) -> None:
        pass

    @property
    def UpdateScene(self) -> bool:
        """This property exist only in: Raycast Sensor, Volume Sensor.
Turns on/off the rendering of the scene in the 3D world when a component triggers the sensor.
 Generally, a True value is used in cases where there are many moving parts, whereas a False value should be used if only the sensor's component moves during a simulation."""
        pass

    @UpdateScene.setter
    def UpdateScene(self, value : bool) -> None:
        pass

    @property
    def UseSampling(self) -> bool:
        """This property exist only in: Raycast Sensor, Volume Sensor.
Defines the rate at which the sensor detects components.
 A True value means detection occurs at a sampling interval defined by the SampleTime property. A False value means detection occurs when a signal is received from a connected Boolean Signal (pulse mode)."""
        pass

    @UseSampling.setter
    def UseSampling(self, value : bool) -> None:
        pass

    @property
    def Listeners(self) -> List[vcBehaviour]:
        """This property exist only in: Real Signal Map.
Defines a list of behaviors using the signal map."""
        pass

    @Listeners.setter
    def Listeners(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def PortCount(self) -> int:
        """This property exist only in: Real Signal Map.
Defines the amount of ports in the signal map."""
        pass

    @PortCount.setter
    def PortCount(self, value : int) -> None:
        pass

    @property
    def LowerFrame(self) -> vcFrameFeature:
        """This property exist only in: Volume Sensor.
Defines the bottom-left corner of the sensor's detection box."""
        pass

    @LowerFrame.setter
    def LowerFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def ShowVolume(self) -> bool:
        """This property exist only in: Volume Sensor.
Turns on/off the visibility of the sensor's detection box in the 3D world."""
        pass

    @ShowVolume.setter
    def ShowVolume(self, value : bool) -> None:
        pass

    @property
    def TestMethod(self) -> int:
        """This property exist only in: Volume Sensor.
Defines the mode used by the sensor for detecting components.
 0
 BBox Intersect
 1
 BBox Center Inside
 2
 BBox Fully Inside
 3
 Precise Test"""
        pass

    @TestMethod.setter
    def TestMethod(self, value : int) -> None:
        pass

    @property
    def TestOnlyContained(self) -> bool:
        """This property exist only in: Volume Sensor.
Defines if the sensor only tests components stored in container type behaviors."""
        pass

    @TestOnlyContained.setter
    def TestOnlyContained(self, value : bool) -> None:
        pass

    @property
    def TestSiblings(self) -> bool:
        """This property exist only in: Volume Sensor.
Defines if the sensor can detect geometry at the same level of the sensor in a node hierarchy. That is, any geometry contained in siblings of the sensor's node."""
        pass

    @TestSiblings.setter
    def TestSiblings(self, value : bool) -> None:
        pass

    @property
    def UpperFrame(self) -> vcFrameFeature:
        """This property exist only in: Volume Sensor.
Defines the top-right corner of the sensor's detection box."""
        pass

    @UpperFrame.setter
    def UpperFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def VolumeMaterial(self) -> vcMaterial:
        """This property exist only in: Volume Sensor.
Defines the material of the sensor's detection box."""
        pass

    @VolumeMaterial.setter
    def VolumeMaterial(self, value : vcMaterial) -> None:
        pass

    def delete(self: Any) -> bool:
        """Deletes the behavior."""
        pass

    def update(self: Any) -> None:
        """Updates the behavior."""
        pass


class vcBitmap(vcObject):
    """vcBitmap represents an image file used in the application, for example as material textures.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcBitmap.htm"""

    @property
    def Format(self) -> int:
        """Gets the format of bitmap.
 See Bitmap Constants for more information."""
        pass

    @property
    def Height(self) -> int:
        """Gets the height (in pixels) of bitmap."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of bitmap."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def URI(self) -> str:
        """Gets the filename of source file."""
        pass

    @property
    def Width(self) -> int:
        """Gets the width (in pixels) of bitmap."""
        pass


class vcBooleanSignalMap(vcBehaviour):
    """vcBooleanSignalMap allows you to map Boolean signals to ports in a continuous IO space.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcBooleanSignalMap.htm"""

    @property
    def Listeners(self) -> List[vcBehaviour]:
        """Defines a list of behaviors using the signal map."""
        pass

    @Listeners.setter
    def Listeners(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def Direction(self) -> int:
        """Defines the direction of ports in the signal map. Ports can be set as inputs, outputs or undefined. If ports are defined as inputs, they cannot be used as outputs or vice versa. To set the direction it is recommended to use the trySetDirection Method instead.
 See Signal Map Constants for more information"""
        pass

    @Direction.setter
    def Direction(self, value : int) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of the signal map."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def StartIndex(self) -> int:
        """Defines the start index of ports in the signal map. It can be used in conjunction with EndIndex to define the amount of ports in the signal map."""
        pass

    @StartIndex.setter
    def StartIndex(self, value : int) -> None:
        pass

    @property
    def EndIndex(self) -> int:
        """Defines the end index of ports in the signal map. Its value is updated automatically when setting Ports or PortCount."""
        pass

    @EndIndex.setter
    def EndIndex(self, value : int) -> None:
        pass

    @property
    def PortCount(self) -> int:
        """Same as Ports, defines the number of ports in map."""
        pass

    @PortCount.setter
    def PortCount(self, value : int) -> None:
        pass

    @property
    def Ports(self) -> int:
        """Same as PortCount, defines the number of ports in the signal map."""
        pass

    @Ports.setter
    def Ports(self, value : int) -> None:
        pass

    def addPort(self: Any, index: int, signal: vcBoolSignal) -> None:
        """Connects a port at a given index to a given signal.
 The port index starts from 0. The PortCount property should have enough ports. In other words, to add a boolean signal to port 3 the PortCount value should be at least 4 (ports 0-3), otherwise calling this method will return an error."""
        pass

    @overload
    def connect(self: Any, indexPort1: int, SignalMap2: vcBooleanSignalMap, indexPort2: int) -> None:
        """Creates a remote connection with another signal map or signal.
 If a port is connected to a signal, refer to the abstract interface of the connection to disconnect only that signal. Otherwise, the disconnect() method will disconnect all signals connected to the port.
 Signals in components can act as abstract interfaces between ports, sending and receiving information via signal maps. 
 
 See vcBoolSignal for more information."""
        pass

    @overload
    def connect(self: Any, indexPort1: int, signal: vcBoolSignal) -> None:
        """Creates a remote connection with another signal map or signal.
 If a port is connected to a signal, refer to the abstract interface of the connection to disconnect only that signal. Otherwise, the disconnect() method will disconnect all signals connected to the port.
 Signals in components can act as abstract interfaces between ports, sending and receiving information via signal maps. 
 
 See vcBoolSignal for more information."""
        pass

    def disconnect(self: Any, index: int) -> None:
        """Disconnects a port at a given index from its connections."""
        pass

    def getAllConnectedPorts(self: Any) -> List[int]:
        """Returns a list of all connected ports in the signal map."""
        pass

    def getPortName(self: Any, index: int) -> str:
        """Returns the name of a port at a given index.
 Note: If the port has no signal then its name is an empty string."""
        pass

    def getInternalPortSignal(self: Any, index: int) -> vcBoolSignal:
        """Returns the signal connected to a port at given index; otherwise returns None."""
        pass

    def getConnectedExternalSignals(self: Any, index: int) -> List[vcBoolSignal]:
        """Returns a list of all signals in other components connected to a local port at the given index in the signal map; otherwise returns an empty list."""
        pass

    def getConnectedExternalPorts(self: Any, index: int) -> List[Tuple[vcBooleanSignalMap, int]]:
        """Returns a list of all ports in other components connected to a local port at a given index in the signal map; otherwise returns an empty list."""
        pass

    def input(self: Any, index: int) -> bool:
        """Returns the value of a port at a given index."""
        pass

    def output(self: Any, index: int, value: bool) -> None:
        """Sets the value of a port at a given index to a given value."""
        pass

    def setPortName(self: Any, index: int, name: str) -> None:
        """Sets the name of a port at a given index to a given name.
 Note: The port must have a signal in order to be assigned a name."""
        pass

    def setPortSignal(self: Any, index: int, signal: vcBoolSignal = ...) -> None:
        """Sets the signal of a port at a given index.
 An optional signal argument can be given to assign the port a signal in its component. Otherwise, the port is assigned a dynamic, application signal."""
        pass

    def trySetDirection(self: Any, type: int) -> bool:
        """Tries to set a direction for the Boolean Signal Map.
 If setting the direction was successful, returns True. Otherwise, returns False. To see the valid string options for this method, see Signal Map Constants."""
        pass

    OnDirectionChanged : Callable[[vcBooleanSignalMap, int, bool], None]
    """Triggered when the value of the Direction property is changed."""


    OnSignalTrigger : Callable[[vcBooleanSignalMap, int, bool], None]
    """Triggered when the value of a signal mapped to a port has a new value."""



class vcBoolSignal(vcSignal):
    """vcBoolSignal is a signal that can send a Boolean value.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcBoolSignal.htm"""

    @property
    def Value(self) -> bool:
        """Defines the value of signal.
 Setting this value does not trigger the OnSignal event unless you use the signal() method."""
        pass

    @Value.setter
    def Value(self, value : bool) -> None:
        pass

    def signal(self: Any, value: bool = ...) -> None:
        """Signals the current value of signal to all connected behaviors, thereby triggering the OnSignal event.
 An optional value argument can be given to set the Value property of the signal."""
        pass


class vcCamera(vcObject):
    """vcCamera provides the capability of controlling a virtual camera and its view for an environment.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCamera.htm"""

    @property
    def ClipFar(self) -> float:
        """Defines how far objects can be from a camera in order to be displayed. If objects are too far then they are not visible."""
        pass

    @ClipFar.setter
    def ClipFar(self, value : float) -> None:
        pass

    @property
    def ClippingMethod(self) -> int:
        """Defines the clipping mode for a camera's view.
 Clipping is used to determine how close and far objects can be from a camera to be displayed on screen.
 
 0 = VC_RENDER_CLIPPING_AUTOMATIC
 1 = VC_RENDER_CLIPPING_CLASSIC
 2 = VC_RENDER_CLIPPING_MANUAL
 Classic is the default setting for the application. Automatic tries to keep all objects in view of a camera visible. Manual allows a user to specify the near and far distances for clipping.
 Manual mode uses ClipNear and ClipFar properties to define a clip-volume space of a camera's projected view. Objects within the area defined by ClipNear and ClipFar are displayed based on a camera's center of interest and eye settings.
 Example. Clipping a camera's perspective view
 
 Clipping can be defined manually in orthographic view when needed; otherwise, Classic mode is recommended."""
        pass

    @ClippingMethod.setter
    def ClippingMethod(self, value : int) -> None:
        pass

    @property
    def ClipNear(self) -> float:
        """Defines how close objects can be to a camera in order to be displayed. If objects are too close then they are not visible."""
        pass

    @ClipNear.setter
    def ClipNear(self, value : float) -> None:
        pass

    @property
    def Coi(self) -> vcVector:
        """Defines camera's center of interest location."""
        pass

    @Coi.setter
    def Coi(self, value : vcVector) -> None:
        pass

    @property
    def Eye(self) -> vcVector:
        """Defines camera's eye location."""
        pass

    @Eye.setter
    def Eye(self, value : vcVector) -> None:
        pass

    @property
    def Matrix(self) -> vcMatrix:
        """Defines the whole camera matrix."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of the camera."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def NavigationDisabled(self) -> bool:
        """Defines if navigation commands in GUI are turned on or off to allow camera orientation with other tools."""
        pass

    @NavigationDisabled.setter
    def NavigationDisabled(self, value : bool) -> None:
        pass

    def getRay(self: Any, px: float, py: float) -> Tuple[vcMatrix, float]:
        """Gets the ray based on the image coordinate system."""
        pass


class vcCapacityController(vcBehaviour):
    """Inherits: vcBehaviour
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCapacityController.htm"""

    @property
    def Capacity(self) -> int:
        """Total logical capacity of the controller."""
        pass

    @Capacity.setter
    def Capacity(self, value : int) -> None:
        pass


class vcCaseScope(vcScope):
    """vcCaseScope is the case clause to use in “Switch Case” statement.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCaseScope.htm"""

    @property
    def CaseCondition(self) -> str:
        """Gets or sets an expression which will 
	 be evaluated against statement’s Condition."""
        pass

    @CaseCondition.setter
    def CaseCondition(self, value : str) -> None:
        pass


class vcCollisionDetector(vcLayoutItem):
    """vcCollisionDetector is a layout item used for detecting the collision of objects in the 3D world. A collision test can detect a collision using geometry in different nodes and/or a bound box defined by two corner points.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCollisionDetector.htm"""

    @property
    def Active(self) -> bool:
        """Turns on/off the use of collision test."""
        pass

    @Active.setter
    def Active(self, value : bool) -> None:
        pass

    @property
    def CollisionMaterial(self) -> vcMaterial:
        """Get/Set material of the collided node."""
        pass

    @CollisionMaterial.setter
    def CollisionMaterial(self, value : vcMaterial) -> None:
        pass

    @property
    def DisplayMinimumDistance(self) -> bool:
        """Turns on/off the display of minimum distance in the 3D world between objects in a collision test that uses a distance tolerance greater than zero."""
        pass

    @DisplayMinimumDistance.setter
    def DisplayMinimumDistance(self, value : bool) -> None:
        pass

    @property
    def HitCount(self) -> int:
        """Gets the number of detected collisions."""
        pass

    @property
    def IgnoreClosestNodes(self) -> bool:
        """Ignores collisions between two nodes if a node is either parent or child to the other node. This can be used to test self-collision of a component. Default value is False."""
        pass

    @IgnoreClosestNodes.setter
    def IgnoreClosestNodes(self, value : bool) -> None:
        pass

    @property
    def IgnoreDifferentComponents(self) -> bool:
        """Ignores collisions between nodes when they are on different components. This can be used to test multiple self-collisions of components. Default value is False."""
        pass

    @IgnoreDifferentComponents.setter
    def IgnoreDifferentComponents(self, value : bool) -> None:
        pass

    @property
    def NodeBCollisionMaterial(self) -> vcMaterial:
        """Get/Set material of the collided node B. This property will define the node B material over CollisionMaterial."""
        pass

    @NodeBCollisionMaterial.setter
    def NodeBCollisionMaterial(self, value : vcMaterial) -> None:
        pass

    @property
    def NodeListA(self) -> List[Tuple[vcNode, int, int]]:
        """Defines a list of nodes to compare with NodeListB.
 See Collision Detector Constants for more information."""
        pass

    @NodeListA.setter
    def NodeListA(self, value : List[Tuple[vcNode, int, int]]) -> None:
        pass

    @property
    def NodeListB(self) -> List[Tuple[vcNode, int, int]]:
        """Defines a list of nodes to compare with NodeListA.
 See Collision Detector Constants for more information."""
        pass

    @NodeListB.setter
    def NodeListB(self, value : List[Tuple[vcNode, int, int]]) -> None:
        pass

    @property
    def Tolerance(self) -> float:
        """Defines a distance tolerance for detecting collisions before objects in the test collide with one another. Note that if Tolerance is set to zero, a simplified collision detection algorithm is used. This algorithm does not detect collisions if one geometry is completely enclosed by the other, so for example, if the bounding box surfaces do not intersect."""
        pass

    @Tolerance.setter
    def Tolerance(self, value : float) -> None:
        pass

    def getBBoxGeometry(self: Any, corner1: vcVector, corner2: vcVector, transformation: vcMatrix = ...) -> vcPolygonSet:
        """Returns a bound box defined by given corner points as a set of geometry.
 An optional transformation argument can be given to transform the bound box using World coordinates."""
        pass

    def getHitFeatureA(self: Any, index: int) -> vcFeature:
        """Returns the feature in NodeListA in the detected collision."""
        pass

    def getHitFeatureB(self: Any, index: int) -> vcFeature:
        """Returns the feature in NodeListB in the detected collision."""
        pass

    def getHitGeometrySetA(self: Any, index: int) -> vcGeometrySet:
        """Returns the geometry set in NodeListA in the detected collision."""
        pass

    def getHitGeometrySetB(self: Any, index: int) -> vcGeometrySet:
        """Returns the geometry set in NodeListB in the detected collision."""
        pass

    def getHitNodeA(self: Any, index: int) -> vcNode:
        """Returns the node in NodeListA in the detected collision."""
        pass

    def getHitNodeB(self: Any, index: int) -> vcNode:
        """Returns the node in NodeListB in the detected collision."""
        pass

    def getMinimumDistanceDistance(self: Any, index: int) -> float:
        """Returns the distance between objects in a detected collision when testing with a tolerance/minimum distance."""
        pass

    def getMinimumDistancePoint1(self: Any, index: int) -> vcVector:
        """Returns the point in NodeListA in a detected collision when using a tolerance."""
        pass

    def getMinimumDistancePoint2(self: Any, index: int) -> vcVector:
        """Returns the point in NodeListB in a detected collision when using a tolerance."""
        pass

    def testAllBBoxCollisions(self: Any, corner1: vcVector, corner2: vcVector, transformation: vcMatrix = ..., tolerance: float = ...) -> bool:
        """Returns true if any collision between NodeListA and a bound box defined by given corner points.
 An optional transformation argument can be given to transform the bound box using World coordinates.
 If no tolerance is given, test uses zero distance."""
        pass

    def testAllCollisions(self: Any, tolerance: float = ...) -> bool:
        """Returns true if any collision between NodeListA and NodeListB.
 If no tolerance is given, test uses zero distance."""
        pass

    def testBBoxComponentCollisions(self: Any, corner1: vcVector, corner2: vcVector, bbox_reference: vcMatrix = ...) -> bool:
        """Returns true if a component collides with a bound box defined by given corner points.
 An optional bbox_reference argument can be given to transform the bound box using World coordinates."""
        pass

    def testBBoxNodeCollisions(self: Any, corner1: vcVector, corner2: vcVector, bbox_reference: vcMatrix = ...) -> bool:
        """Returns true if a node collides with a bound box defined by given corner points.
 An optional bbox_reference argument can be given to transform the bound box using World coordinates."""
        pass

    def testComponentCollisions(self: Any) -> bool:
        """Returns true if collision detected with component."""
        pass

    def testMinimumDistance(self: Any, tolerance: float) -> bool:
        """Returns true if collision detected with a given tolerance value."""
        pass

    def testNodeCollisions(self: Any) -> bool:
        """Returns true if collision detected with node."""
        pass

    def testOneBBoxCollision(self: Any, corner1: vcVector, corner2: vcVector, transformation: vcMatrix = ..., tolerance: float = ...) -> bool:
        """Returns true for first collision between NodeListA and a bound box defined by given corner points.
 An optional transformation argument can be given to transform the bound box using World coordinates.
 If no tolerance is given, test uses zero distance."""
        pass

    def testOneCollision(self: Any, tolerance: float = ...) -> bool:
        """Returns true for first collision between NodeListA and NodeListB.
 If no tolerance is given, test uses zero distance."""
        pass

    OnCollision : Callable[[vcCollisionDetector], None]
    """Triggered when a collision is detected and test is active."""



class vcCombinationFilterOperation(vcObject):
    """Operation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCombinationFilterOperation.htm"""

    @property
    def Filter(self) -> vcProductFilter:
        """Filter"""
        pass

    @property
    def Operation(self) -> int:
        """Operation.
 See Combination Boolean Operation constants for more information."""
        pass


class vcCombinationProductFilter(vcProductFilter):
    """Inherits: vcProductFilter
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCombinationProductFilter.htm"""

    @property
    def Filters(self) -> List[vcCombinationFilterOperation]:
        """Gets list of combination filters and its operations."""
        pass

    def insertFilter(self: Any, index: int, filterType: vcProductTypeFilter, booleanOp: int) -> vcCombinationFilterOperation:
        """Inserts new filter.
 See CombinationBooleanOperation constants for more info."""
        pass

    def setFilter(self: Any, index: int, filterType: vcProductTypeFilter, booleanOp: int) -> vcCombinationFilterOperation:
        """Sets current filter.
 See CombinationBooleanOperation constants for more info."""
        pass

    def removeFilter(self: Any, index: int) -> bool:
        """Removes filter."""
        pass

    def setFilterOperation(self: Any, index: int, booleanOp: int) -> vcCombinationFilterOperation:
        """Set filter operation.
 See CombinationBooleanOperation constants for more info."""
        pass


class vcCommand(vcObject):
    """vcCommand is the object type for commands that can be executed using Python API and made available in user interface of application.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCommand.htm"""

    @property
    def Application(self) -> vcApplication:
        """Gets the application object."""
        pass

    @property
    def Checked(self) -> bool:
        """Defines if command is checked or visually indicated as active in the GUI, which is only for Python commands."""
        pass

    @Checked.setter
    def Checked(self, value : bool) -> None:
        pass

    @property
    def Enabled(self) -> bool:
        """Defines if command is enabled/disabled, which is only for Python commands.
 A False value means the command will be greyed out in the GUI."""
        pass

    @Enabled.setter
    def Enabled(self, value : bool) -> None:
        pass

    @property
    def ExecutionType(self) -> int:
        """Defines how other active commands are managed when executing this command.
 See Command Constants for more information."""
        pass

    @ExecutionType.setter
    def ExecutionType(self, value : int) -> None:
        pass

    @property
    def Icon(self) -> vcBitmap:
        """Defines the icon of command in the GUI."""
        pass

    @Icon.setter
    def Icon(self, value : vcBitmap) -> None:
        pass

    @property
    def IgnoreEvents(self) -> bool:
        """Defines if event passing is ignored when executing command.
 This flag is used in situations where events could create cyclic calls."""
        pass

    @IgnoreEvents.setter
    def IgnoreEvents(self, value : bool) -> None:
        pass

    @property
    def IsActive(self) -> bool:
        """Gets the current state of command.
 A True value means the command is active."""
        pass

    @property
    def IsModelingCommand(self) -> bool:
        """Defines if command is used for manipulating geometry and related properties."""
        pass

    @IsModelingCommand.setter
    def IsModelingCommand(self, value : bool) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of command."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list containing all properties of command.
 Generally, properties are used to pass information to and from the command implementation for execution."""
        pass

    @property
    def Simulation(self) -> vcSimulation:
        """Gets the simulation object."""
        pass

    @property
    def SupportsOverrideActivation(self) -> bool:
        """Defines if command is restarted after the execution of an override command, which is only for Python commands."""
        pass

    @SupportsOverrideActivation.setter
    def SupportsOverrideActivation(self, value : bool) -> None:
        pass

    def addState(self: Any, state_func: Callable[[], None]) -> None:
        """Adds a command state function to Python command.
 The first added command state is the function called when command is executed.
 This method is only available for user-defined Python commands."""
        pass

    def cancelNextClick(self: Any) -> None:
        """Cancels a next click event.
 This prevents a mouse click from being detected during the next mouse up event. This is only useful when called from an event processing handler function. Generally, this is used to prevent the activation of the Select command in response to a mouse click.
 This method is only available for user-defined Python commands and can only be called from within the command script itself."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to command object.
 An optional constraints argument can be used to define constraints for property, which must be done at time of creation.
 See Property Constants for more information.
 This method is only available for user-defined Python commands."""
        pass

    @overload
    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Removes a given property or one matching a given name from command.
 This method is only available for user-defined Python commands."""
        pass

    @overload
    def deleteProperty(self: Any, name: str) -> None:
        """Removes a given property or one matching a given name from command.
 This method is only available for user-defined Python commands."""
        pass

    @overload
    def execute(self: Any, *args : Any) -> None:
        """Executes the command, and then waits for the execution of first command state to be completed. If this method is called with no arguments, the arguments used are those currently set in the command object. If this method is called with positional arguments, each value is assigned to command properties in the order they were created before command execution. If the method is called with keyword arguments, the corresponding command parameter property is looked up and assigned the argument value. If a parameter cannot be found, the function fails."""
        pass

    @overload
    def execute(self: Any, **kwds: Any) -> None:
        """Executes the command, and then waits for the execution of first command state to be completed. If this method is called with no arguments, the arguments used are those currently set in the command object. If this method is called with positional arguments, each value is assigned to command properties in the order they were created before command execution. If the method is called with keyword arguments, the corresponding command parameter property is looked up and assigned the argument value. If a parameter cannot be found, the function fails."""
        pass

    @overload
    def executeAsTool(self: Any, *args : Any) -> None:
        """Executes the command as if its execution type is VC_COMMAND_TOOL.
 This method overrides the command's ExecutionType property."""
        pass

    @overload
    def executeAsTool(self: Any, **kwds: Any) -> None:
        """Executes the command as if its execution type is VC_COMMAND_TOOL.
 This method overrides the command's ExecutionType property."""
        pass

    def executeInActionPanel(self: Any) -> None:
        """Executes a command using a task pane.
 Generally, you would use a task pane to display the options of a registered Python or .NET command and to further control its execution.
 For more information, see Command Task Pane in Creating a Python Add-on topic."""
        pass

    def getApplication(self: Any) -> vcApplication:
        """Returns the application object."""
        pass

    def getCommand(self: Any) -> vcCommand:
        """Returns the command object."""
        pass

    def getCommandPath(self: Any) -> str:
        """Returns the URI used by application to load the Python file of command.
 This method returns an empty string if the command is not a Python command."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name in command; otherwise returns None."""
        pass

    def getSimulation(self: Any) -> vcSimulation:
        """Returns the simulation object."""
        pass

    def genVarSpaceDialog(self: Any, command_name: str, dialog_title: str, first_tab_caption: str) -> None:
        """Shows a modal property dialog containing the properties of a registered command matching a given command_name.
 Note: The command_name is specific to Python, so COM or other programming commands cannot be used as an argument.
 The title of the dialog window is set to dialog_title. The first_tab_caption parameter determines whether a tabbed dialog is used. If first_tab_caption is an empty string, the properties are displayed in a single pane. Otherwise, the properties are displayed in separate tabs. In that case, property names are parsed as "tabName::propertyName" and distributed into tabs according to tabName; and properties without a double colon "::" in the name are displayed in the first tab, which will have the caption set to first_tab_caption.
 After the command is executed, the Param_4 property of the command object contains the result of the dialog, as an integer. A value of 1 means a user clicked OK, whereas a value of 2 means a user clicked Cancel."""
        pass

    def recompile(self: Any) -> None:
        """Recompiles the command."""
        pass

    def setNextState(self: Any, state_func: Callable[[], None]) -> None:
        """Sets the next command state function. This is a function which is called with no parameters in order to execute the next state. If None is passed as a parameter, the command will exit after the current state function or event processing function returns.
 Calling this method will also cause the command to leave event processing mode.
 This method is only available in Python commands, and can only be called from within the command script itself.
 For more information, see an example for setting the next state of a snap command."""
        pass

    OnStart : Callable[[], None]
    """Triggered at the start of command execution."""


    OnStop : Callable[[], None]
    """Triggered at the end of command execution, regardless if the command exited properly or was aborted."""


    OnPreExecute : Callable[[vcCommand], None]
    """Triggered immediately before the start of command execution. See an example below."""


    OnPostExecute : Callable[[vcCommand], None]
    """Triggered immediately after the end of command execution.
 
 See an example below."""



class vcCommandPanelAction(vcObject):
    """The action panel can be opened when executing a python command. To open the panel, import vcCommand * and use the executeInActionPanel() method
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCommandPanelAction.htm"""

    OnPanelClosed : Callable[[], None]
    """Triggered when a close button on an action panel is clicked."""



class vcCompactLineSet(vcGeometrySet):
    """vcCompactLineSet is used for creating and reading line type geometry, which is a set of two or more points.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCompactLineSet.htm"""

    @property
    def CurveData(self) -> vcCurveData:
        """Gets the container of mathematical information used for rendering curves."""
        pass

    @property
    def Lines(self) -> List[List[vcVector]]:
        """Gets a list of lines where each line is a list of position vectors for its points."""
        pass

    @property
    def LineCount(self) -> int:
        """Gets the total number of lines in the set."""
        pass

    @property
    def LineWidth(self) -> float:
        """Defines the width of each line in the set."""
        pass

    @LineWidth.setter
    def LineWidth(self, value : float) -> None:
        pass

    def addLine(self: Any, points: List[vcVector]) -> None:
        """Creates a new line in set using a list of given points."""
        pass

    def deleteLine(self: Any, index: int) -> None:
        """Deletes a line at a given index from set."""
        pass

    def getLinePointCount(self: Any, index: int) -> int:
        """Returns the number of points in a line at a given index in set."""
        pass

    def getLine(self: Any, index: int) -> List[vcVector]:
        """Returns a list of position vectors for each point of a line at a given index in set."""
        pass


class vcComponent(vcNode):
    """vcComponent is the object type for a component and its associated root node.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcComponent.htm"""

    @property
    def BackfaceMode(self) -> int:
        """Defines the mode for rendering geometry backfaces of component. That is, geometry not facing active camera.
 See Component Constants for more information."""
        pass

    @BackfaceMode.setter
    def BackfaceMode(self, value : int) -> None:
        pass

    @property
    def BOM(self) -> bool:
        """If a component is included in the bill of materials."""
        pass

    @BOM.setter
    def BOM(self, value : bool) -> None:
        pass

    @property
    def BOMdescription(self) -> str:
        """Component description in the bill of materials."""
        pass

    @BOMdescription.setter
    def BOMdescription(self, value : str) -> None:
        pass

    @property
    def BOMname(self) -> str:
        """Component name in the bill of materials."""
        pass

    @BOMname.setter
    def BOMname(self, value : str) -> None:
        pass

    @property
    def Category(self) -> str:
        """Defines the component group in Cell Graph."""
        pass

    @Category.setter
    def Category(self, value : str) -> None:
        pass

    @property
    def Container(self) -> vcContainer:
        """Gets the container storing the component.
 If a component is not stored in a container, the value is None.
 Note: Container refers to a behavior that can store components, for example a One Way Path."""
        pass

    @property
    def CreationTime(self) -> float:
        """Defines the creation time of component.
 Generally, creation time is used for gathering statistics about components created during a simulation.
 In some cases, you might want to edit the creation time of a component for filtering, tracking, assembly and manufacturing purposes."""
        pass

    @CreationTime.setter
    def CreationTime(self, value : float) -> None:
        pass

    @property
    def IsUnique(self) -> bool:
        """Indicates if the component is sharing its feature trees with other components."""
        pass

    @property
    def Locked(self) -> bool:
        """Defines if the component is locked from being edited or manipulated in 3D world."""
        pass

    @Locked.setter
    def Locked(self, value : bool) -> None:
        pass

    @property
    def Material(self) -> vcMaterial:
        """Defines the material of component and any of its features which do not have an assigned material or whose node is set to inherit a material.
 This material definition is persistent data, meaning that the definition is stored when saving component.
 Note: Changing the material definition of a component causes all geometries to be rebuilt, which can be a computing intensive operation. For in-simulation visualization purposes, we recommend using the NodeMaterial property instead."""
        pass

    @Material.setter
    def Material(self, value : vcMaterial) -> None:
        pass

    @property
    def MovementOrigin(self) -> vcMatrix:
        """Defines the offset of component when moving on a path."""
        pass

    @MovementOrigin.setter
    def MovementOrigin(self, value : vcMatrix) -> None:
        pass

    @property
    def PackFolder(self) -> vcPackFolder:
        """Gets the mechanism for attaching files to component."""
        pass

    @property
    def PathAcceleration(self) -> float:
        """Defines the acceleration of component when moving on a path."""
        pass

    @PathAcceleration.setter
    def PathAcceleration(self, value : float) -> None:
        pass

    @property
    def PathDeceleration(self) -> float:
        """Defines the deceleration of component when moving on a path."""
        pass

    @PathDeceleration.setter
    def PathDeceleration(self, value : float) -> None:
        pass

    @property
    def PathVelocity(self) -> float:
        """Defines the velocity of component when moving on and in the direction of a path.
 If a zero value, the velocity of the component is defined by the path."""
        pass

    @PathVelocity.setter
    def PathVelocity(self, value : float) -> None:
        pass

    @property
    def PDFExportLevel(self) -> int:
        """Defines the level of detail when exporting component to a 3D PDF.
 See Component Constants for more information."""
        pass

    @PDFExportLevel.setter
    def PDFExportLevel(self, value : int) -> None:
        pass

    @property
    def Product(self) -> vcProduct:
        """The Process Modeling product instance linked to this component, if any."""
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all user defined properties in component."""
        pass

    @property
    def SimulationLevel(self) -> int:
        """Defines the simulation level of the component.
 See Component Constants for more information."""
        pass

    @SimulationLevel.setter
    def SimulationLevel(self, value : int) -> None:
        pass

    @property
    def Uri(self) -> str:
        """Gets the URI of component"""
        pass

    @property
    def VCID(self) -> str:
        """Defines the VCID of component. That is, the unique key identifier of the component.
 Generally, you should never set this property. Instead, allow the application to generate a VCID when you save the component."""
        pass

    @VCID.setter
    def VCID(self, value : str) -> None:
        pass

    @property
    def Visible(self) -> bool:
        """Turns on/off the visibility of component in 3D world."""
        pass

    @Visible.setter
    def Visible(self, value : bool) -> None:
        pass

    def clone(self: Any, shared: int = ...) -> vcComponent:
        """Creates a clone of component in 3D world, and then returns the new component.
 If shared argument is non-zero the clone and original share geometry. That is, feature tree is shared not copied. This improves performance during simulation, but the cloned components cannot be edited separately (changing the appearance of either clone or original component affects all the others.)
 Cloning of a component is not allowed when 1) it's not attached to World 2) there is a hierarchy lock in the node tree, which happens during layout loading, or while moving a node from one place to another."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to component, and then returns the new property.
 An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation.
 See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property from component."""
        pass

    def getPathDistance(self: Any) -> float:
        """If component is on a path, for example a conveyor path, returns the distance of component on path."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name in component; otherwise returns None."""
        pass

    def getTransportInfo(self: Any, targetComponent: vcComponent) -> Tuple[int, vcNode, vcContainer, vcMatrix]:
        """Returns information about a transport action for a given component.
 Generally, a transport action is defined using an Action Container, Python Script and Transport Protocol.
 See Transportation Constants for information on availability options."""
        pass

    def incrementRevision(self: Any) -> None:
        """Increments the revision number of a file when using the save() method.
 The effect is the same as the Increment Revision property in the Credits dialog when saving a file."""
        pass

    def makeUnique(self: Any) -> None:
        """Makes the feature trees of the component unique, thereby they are not shared with other components."""
        pass

    def save(self: Any, uri: str) -> None:
        """Saves component to file using a given uri.
 To save the component with a new VCID, set the VCID property of the component to an empty string."""
        pass

    def saveState(self: Any) -> None:
        """Saves the current state of component as its initial state."""
        pass

    def startMovement(self: Any) -> None:
        """Start the movement of component in a flow, for example a path.
 An optional Boolean argument can be used to override flow logic, thereby forcing component to move in flow."""
        pass

    def stopMovement(self: Any) -> None:
        """Stops the movement of component in a flow, for example a path.
 An optional Boolean argument can be used to override flow logic, thereby forcing component to not move in flow."""
        pass

    @overload
    def transfer(self: Any, behaviour: vcBehaviour, port: int) -> None:
        """Transfers component into a flow and blocks Python execution until completion of transfer.
 One option allows you to give two separate arguments for a behavior and port.
 Another option allows you to give a connector for performing transfer.
 A given behavior must be or derive from vcFlow and you should check for available capacity."""
        pass

    @overload
    def transfer(self: Any, connector: vcConnector) -> None:
        """Transfers component into a flow and blocks Python execution until completion of transfer.
 One option allows you to give two separate arguments for a behavior and port.
 Another option allows you to give a connector for performing transfer.
 A given behavior must be or derive from vcFlow and you should check for available capacity."""
        pass

    def transferNonBlocking(self: Any, behaviour: vcBehaviour, port: int) -> None:
        """Transfers component into a flow defined by a given behaviour and port without blocking Python execution. That is, call is executed immediately and does not wait for completion of transfer.
 A given behavior must be or derive from vcFlow and you should check for available capacity."""
        pass

    OnNodeConfigurationChange : Callable[[int, vcNode, vcNode], None]
    """Triggered when a change occurs in component node hierarchy.
 The node1 and node2 arguments are nodes affected by change.
 The type argument is the type of change that occurred in component.
 See Component Constants for more information."""


    OnContainerTransition : Callable[[vcContainer, bool], None]
    """Triggered when component enters or exits a vcContainer object.
 The value argument will be True if component is entering a container; otherwise value is False if component exiting a container."""



class vcComponentContainer(vcContainer):
    """Inherits: vcContainer
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcComponentContainer.htm"""


class vcComponentCreator(vcContainer):
    """vcComponentCreator uses a component as a template for creating other components.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcComponentCreator.htm"""

    @property
    def BlockingOptimization(self) -> bool:
        """Turns on/off the optimization of creator when making new components, thereby improving simulation performance.
 If True, the creator will not check for capacity rather listen for event. The creator is informed, for example by component or capacity controller, when there is capacity to make a new component."""
        pass

    @BlockingOptimization.setter
    def BlockingOptimization(self, value : bool) -> None:
        pass

    @property
    def Interval(self) -> float:
        """Defines the interval (in seconds) for creating components."""
        pass

    @Interval.setter
    def Interval(self, value : float) -> None:
        pass

    @property
    def Limit(self) -> int:
        """Defines the maximum number of components that can be created by creator during a simulation."""
        pass

    @Limit.setter
    def Limit(self, value : int) -> None:
        pass

    @property
    def Part(self) -> str:
        """Defines the URI or VCID of template component."""
        pass

    @Part.setter
    def Part(self, value : str) -> None:
        pass

    @property
    def PartPooling(self) -> bool:
        """Turns on/off the reuse of components made by the creator, thereby improving simulation performance.
 If True, dynamic components removed during simulation are recirculated to make new components, thereby reducing memory allocation.
 Caution: Be careful when recirculating components that were modified during simulation, for example a change in node material."""
        pass

    @PartPooling.setter
    def PartPooling(self, value : bool) -> None:
        pass

    @property
    def TemplateComponent(self) -> vcComponent:
        """Defines the template used by creator to create new components during a simulation.
 Either this property or Part can be used to define the template component of creator."""
        pass

    @TemplateComponent.setter
    def TemplateComponent(self, value : vcComponent) -> None:
        pass

    def create(self: Any, wait: bool = ...) -> vcComponent:
        """Creates a new component from template, and then returns the new component. 
 An optional wait argument can be given to use BlockingOptimization. If True, the creator waits for capacity before trying to make a component.
 
 If creation fails, returns None. Generally, this occurs when the template is undefined or because of capacity issues.
 Tip: Set the Limit property to zero in order to disable the internal logic of the creator."""
        pass


class vcComponentFlowProxy(vcFlow):
    """vcComponentFlowProxy gives information about components attempting to enter a flow proxy, and then routes components by testing the available capacity of connected behaviors.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcComponentFlowProxy.htm"""

    @property
    def ComponentSignal(self) -> vcComponentSignal:
        """Defines the signal used for signaling what component has been transferred into proxy.
This property and PortSignal should be used to determine what and where a component has entered the proxy."""
        pass

    @ComponentSignal.setter
    def ComponentSignal(self, value : vcComponentSignal) -> None:
        pass

    @property
    def DynamicConnections(self) -> bool:
        """Defines if the connectors of proxy are dynamic. That is, connections will be established during a simulation by using a Python script or command."""
        pass

    @DynamicConnections.setter
    def DynamicConnections(self, value : bool) -> None:
        pass

    @property
    def InternalConnectorCount(self) -> int:
        """Gets the number of connectors in proxy.
An internal connector is always paired with an external connector, so this count will match the count for the proxy's external connectors."""
        pass

    @property
    def PortSignal(self) -> vcIntegerSignal:
        """Defines the signal used for signaling which connector a component used to enter proxy.
The value is the index position of the connector in the proxy's list of connectors."""
        pass

    @PortSignal.setter
    def PortSignal(self, value : vcIntegerSignal) -> None:
        pass

    def connectInternally(self: Any, index: int, to_connector: vcConnector) -> None:
        """Connects an internal connector at a given index in proxy to a given connector."""
        pass

    def createConnector(self: Any) -> vcConnector:
        """Creates a new connector in proxy.
This creates a pair of internal and external connectors."""
        pass

    def deleteConnector(self: Any, index: int) -> None:
        """Deletes a connector at a given index from proxy.
This deletes a pair of internal and external connectors."""
        pass

    def getInternalConnector(self: Any, index: int) -> vcConnector:
        """Returns an internal connector at a given index in proxy."""
        pass

    def resetConnectorPort(self: Any, index: int) -> None:
        """Resets a connector at a given index in proxy, thereby disconnecting the connector from all of its connections."""
        pass


class vcComponentSignal(vcSignal):
    """vcComponentSignal is a signal that can send a vcComponent object.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcComponentSignal.htm"""

    @property
    def Value(self) -> vcComponent:
        """Defines the value of signal.
 Setting this value does not trigger the OnSignal event unless you use the signal() method."""
        pass

    @Value.setter
    def Value(self, value : vcComponent) -> None:
        pass

    def signal(self: Any, value: vcComponent = ...) -> None:
        """Signals the current value of signal to all connected behaviors, thereby triggering the OnSignal event.
 An optional value argument can be given to set the Value property of the signal."""
        pass


class vcConfigurableProductTypeFilter(vcProductTypeFilter):
    """vcConfigurableProductTypeFilter is a product filter type that can be 
 configured through the properties shown in the Visual Components user 
 interface.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcConfigurableProductTypeFilter.htm"""

    @property
    def AcceptAllProductTypes(self) -> bool:
        """(Deprecated) Use vcProductFilter.IsEnabled 
	 property instead.
	
	When set to True, any product is accepted and AcceptedFlowGroups 
	 and AcceptedProductTypes are ignored.
	
	AcceptAllProductTypes property is synchronized with an inverse 
	 of vcProductFilter.IsEnabled.
	This way: 
	
	Setting AcceptAllProductTypes to True will set IsEnabled 
	 to False.
	Setting IsEnabled to True will set AcceptAllProductTypes 
	 to False."""
        pass

    @AcceptAllProductTypes.setter
    def AcceptAllProductTypes(self, value : bool) -> None:
        pass

    @property
    def AcceptAllProductTypesProperty(self) -> vcProperty:
        """Returns True if all product types are accepted.
	
	Returns False if some product types are not accepted."""
        pass

    @property
    def AcceptedFlowGroupsProperty(self) -> vcProperty:
        """Returns the list of flow groups (vcProcessFlowGroup) 
	 that are accepted."""
        pass

    @property
    def AcceptedProductTypesProperty(self) -> vcProperty:
        """Returns the list of product types (vcProductType) 
	 that are accepted."""
        pass

    def bindToStatement(self: Any, parentObject: vcStatement, startingVarGroup: int = ...) -> None:
        """Adds the filter properties to the given parentObject. 
	 If the filter is already bound, this method first removes the 
	 filter properties from the current parent object, and then adds 
	 the properties to the new parent object.
	
	To remove the filter properties from the current parent object, 
	 set the value of parentObject to None. 
	 
	startingVarGroup defines the vcProperty.Group 
	 value to assign to the first of the properties. The group of the 
	 other properties is based on that value. This defines the order 
	 of the properties in the Visual Components user interface in relation 
	 to the other properties of the parent object. 
	 
	The default of startingVarGroup value 
	 is 10."""
        pass


class vcConfigureContext(vcContext):
    """vcConfigureContext is the context of the application for building layouts. Currently, there are no additional properties, methods or events for this context.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcConfigureContext.htm"""


class vcConnector(vcObject):
    """vcConnector allows you to establish connections between behaviors in order to transfer components. For example, flow type behaviors may have any number of connections (ports/connectors) to manage the receiving and sending of components.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcConnector.htm"""

    @property
    def Behaviour(self) -> vcBehaviour:
        """Gets the behavior that the connector is connected to in a component.
 If no connection, the value is None."""
        pass

    @property
    def CapacityTest(self) -> int:
        """Define the mode for testing capacity before transferring a component to an outgoing connection.
 See Connector Constants for more information."""
        pass

    @CapacityTest.setter
    def CapacityTest(self, value : int) -> None:
        pass

    @property
    def Connection(self) -> vcConnector:
        """Defines connector that the connector is connected to in a component.
 If no connection, the value is None."""
        pass

    @Connection.setter
    def Connection(self, value : vcConnector) -> None:
        pass

    @property
    def Index(self) -> int:
        """Gets the position of the connector in its behavior's list of connectors."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of connector."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Type(self) -> int:
        """Defines the connector's type. That is, whether the connector is an Input, Output or Input/Output type port.
 See Connector Constants for more information."""
        pass

    @Type.setter
    def Type(self, value : int) -> None:
        pass

    def connect(self: Any, connector: vcConnector = ...) -> None:
        """Connects the connector to a given connector.
 If no argument is given, this method will remove all connections of the connector."""
        pass

    def testCapacity(self: Any) -> bool:
        """Tests the capacity of connector's behavior.
 Returns True if not at capacity; otherwise returns False if at full capacity. If the behavior of a connector does not have physical capacity, for example Component Flow Proxy, returns None."""
        pass

    def testConnectedCapacity(self: Any) -> bool:
        """Tests the capacity of behavior connected to the connector.
 Returns True if not at capacity; otherwise returns False if at full capacity. If the behavior of a connector does not have physical capacity, for example Component Flow Proxy, returns None."""
        pass


class vcContainer(vcFlow):
    """vcContainer is a base class for all behaviors that can contain components, for example buffers, stackers and conveyors.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcContainer.htm"""

    @property
    def Capacity(self) -> int:
        """Defines the maximum number of components that can be stored in the container at any given time. That is, the logical capacity of the container."""
        pass

    @Capacity.setter
    def Capacity(self, value : int) -> None:
        pass

    @property
    def CapacityBlocks(self) -> List[vcBehaviour]:
        """Defines a list of Capacity Controller type behaviors that globally control the capacity of the container.
 This property overrides the container's Capacity."""
        pass

    @CapacityBlocks.setter
    def CapacityBlocks(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def ComponentCount(self) -> int:
        """Gets the amount of components stored in the container."""
        pass

    @property
    def Components(self) -> List[vcComponent]:
        """Gets a list of components stored in the container."""
        pass

    @property
    def ContentVisible(self) -> bool:
        """Sets the visibility of components stored in the container."""
        pass

    @ContentVisible.setter
    def ContentVisible(self, value : bool) -> None:
        pass

    @property
    def HeadComponent(self) -> vcComponent:
        """Gets a component stored at the head of the container."""
        pass

    @property
    def Statistics(self) -> vcStatistics:
        """Defines a Statistics behavior that collects data generated by the container during a simulation."""
        pass

    @Statistics.setter
    def Statistics(self, value : vcStatistics) -> None:
        pass

    @property
    def TailComponent(self) -> vcComponent:
        """Gets a component stored at the tail of the container."""
        pass

    @property
    def TransitionSignal(self) -> vcBoolSignal:
        """Defines the signal used for signaling when a component enters/exits the container.
 A True value means a component has entered the container, whereas a False value means a component has exited the container."""
        pass

    @TransitionSignal.setter
    def TransitionSignal(self, value : vcBoolSignal) -> None:
        pass

    @property
    def BackBucket(self) -> vcGeometryFeature:
        """This property exist only in: Bucket Path.
Defines a Geometry feature that represents the back section of each bucket.
 The geometry will be visible only if the ShowContent property of the feature is set to False."""
        pass

    @BackBucket.setter
    def BackBucket(self, value : vcGeometryFeature) -> None:
        pass

    @property
    def Buckets(self) -> int:
        """This property exist only in: Bucket Path.
Defines the amount of buckets used in the path."""
        pass

    @Buckets.setter
    def Buckets(self, value : int) -> None:
        pass

    @property
    def BucketSize(self) -> float:
        """This property exist only in: Bucket Path.
Defines the minimum distance between each bucket."""
        pass

    @BucketSize.setter
    def BucketSize(self, value : float) -> None:
        pass

    @property
    def Direction(self) -> int:
        """This property exist only in: Bucket Path.
Defines the direction buckets move along the path.
 See Conveyor Direction Constants for more information."""
        pass

    @Direction.setter
    def Direction(self, value : int) -> None:
        pass

    @property
    def FrontBucket(self) -> vcGeometryFeature:
        """This property exist only in: Bucket Path.
Defines a Geometry feature that represents the front section of each bucket.
 The geometry will be visible only if the ShowContent property of the feature is set to False."""
        pass

    @FrontBucket.setter
    def FrontBucket(self, value : vcGeometryFeature) -> None:
        pass

    @property
    def Interpolation(self) -> int:
        """This property exist only in: Bucket Path.
Defines the mode of interpolating the motion of each bucket along the path.
 See Conveyor Interpolation Mode Constants for more information."""
        pass

    @Interpolation.setter
    def Interpolation(self, value : int) -> None:
        pass

    @property
    def OutFrame(self) -> vcFeature:
        """This property exist only in: Bucket Path.
Defines a Frame feature that is referenced as the location of the path's output port.
 The path must have a defined output port in order to empty the contents of a passing bucket. Therefore, the OutFrame must be included in the Path property's list of frames."""
        pass

    @OutFrame.setter
    def OutFrame(self, value : vcFeature) -> None:
        pass

    @property
    def Path(self) -> List[vcFeature]:
        """This property exist only in: Bucket Path.
Defines an ordered list of Frame features that represent waypoints of the path."""
        pass

    @Path.setter
    def Path(self, value : List[vcFeature]) -> None:
        pass

    @property
    def PulseDriven(self) -> bool:
        """This property exist only in: Bucket Path.
Defines if the path is pulse driven in which a connected Integer signal sends a step size for moving each bucket."""
        pass

    @PulseDriven.setter
    def PulseDriven(self, value : bool) -> None:
        pass

    @property
    def RetainOffset(self) -> bool:
        """This property exist only in: Bucket Path.
Defines if the location of a component is retained when the component is placed or transferred onto the path.
 A True value means a component is not snapped to the axis of the path defined by its waypoints."""
        pass

    @RetainOffset.setter
    def RetainOffset(self, value : bool) -> None:
        pass

    @property
    def Sensors(self) -> List[vcBehaviour]:
        """This property exist only in: Bucket Path.
Defines a list of sensor type behaviors connected to the path."""
        pass

    @Sensors.setter
    def Sensors(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def Speed(self) -> float:
        """This property exist only in: Bucket Path.
Defines the speed (mm/s) of the path."""
        pass

    @Speed.setter
    def Speed(self, value : float) -> None:
        pass

    @property
    def StatusSignal(self) -> vcBoolSignal:
        """This property exist only in: Bucket Path.
Defines a signal that signals when the path is moving/not moving in pulse mode."""
        pass

    @StatusSignal.setter
    def StatusSignal(self, value : vcBoolSignal) -> None:
        pass

    def getComponent(self: Any, component_index: int) -> vcComponent:
        """Returns a component at a given index stored in the container."""
        pass

    def getPathPosition(self: Any, path_distance: float) -> vcMatrix:
        """Returns a position matrix for a point on the path at a given distance.
 The position matrix is based in the node coordinate system of the container."""
        pass

    def getContainerProximity(self: Any, position: vcVector) -> float:
        """Returns the orthogonal distance from a given position to the container.
 Note: If the container is static, this method may return a very large value for any position."""
        pass

    def grab(self: Any, component: vcComponent, assembly_mode: int = ...) -> None:
        """Attaches a given component to this container.
 If the container is static, the component will automatically retain its location.
 If the Assembly feature is used in Process Modeling, the optional assembly_mode argument defines how the Assembly Instance is handled when grabbing the product. See Grab Constants for more information."""
        pass

    def startFailure(self: Any) -> None:
        """Sets the state of container to failure.
 In a failure state, a container cannot react to anything during a simulation until its shifted to a different state."""
        pass

    def stopFailure(self: Any) -> None:
        """Shifts state of component to a different state, thereby ending a failure.
 Generally, this method is used to end a failure state and mark the end of a repair made to the container."""
        pass

    OnTransition : Callable[[vcComponent, bool], None]
    """Triggered when a component is transferred to or from the container.
 The component argument is the component in question, and the arrive_leave argument is a Boolean value that is True if the component has arrived to the container or False if the component has departed.
 If the OnTransition() event is triggered with an arrive_leave value True, the component has just been added and is in a well-defined state with respect to its container. It is then safe to manipulate the component.
 If arrive_leave value is False, the component is in the process of being removed and its Container is not well-defined. In this case, DO NOT use the Container property of the component being transferred."""



class vcContainerFiller(vcFlow):
    """Inherits: vcFlow
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcContainerFiller.htm"""

    @property
    def Container(self) -> str:
        """Defines the name of the container to be filled with a component.
 Generally, you would not want to set this property unless you know the exact name of the container type behavior to be filled in a component."""
        pass

    @Container.setter
    def Container(self, value : str) -> None:
        pass

    @property
    def Part(self) -> str:
        """Defines the URI or VCID of the filler's template."""
        pass

    @Part.setter
    def Part(self, value : str) -> None:
        pass

    @property
    def TemplateComponent(self) -> vcComponent:
        """Defines the template used by filler to create components in a container."""
        pass

    @TemplateComponent.setter
    def TemplateComponent(self, value : vcComponent) -> None:
        pass


class vcContext(vcObject):
    """vcContext is a base class for all contexts defined in the application. A context refers to the current state of main window, its workspace and scene, and the availability of commands.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcContext.htm"""

    @property
    def Id(self) -> str:
        """Gets the id of the context."""
        pass


class vcCurveData(vcObject):
    """vcCurveData provides access to mathematical information used for rendering curves and curved surfaces in components.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcCurveData.htm"""

    def clearCurves(self: Any) -> None:
        """Removes all curves from set."""
        pass

    def createCurveNurbs(self: Any, degree: int, pts: List[vcVector]) -> int:
        """Adds a new NURBS to set, and then returns the index of curve in set."""
        pass

    def createCurvePolyLine(self: Any, pts: List[vcVector]) -> int:
        """Adds a new polyline to set, and then returns the index of curve in set."""
        pass

    def createCurveSpline(self: Any, degree: int, pts: List[vcVector], multiplicities: List[int], knots: List[float], weights: List[float]) -> int:
        """Adds a new spline to set, and then returns the index of curve in set."""
        pass

    def deleteCurve(self: Any, curve: int) -> None:
        """Deletes a curve at a given index in set.
 Note: Update the scene in order to show visualization changes in the 3D world."""
        pass

    def getCurveEnds(self: Any, curve: int) -> Tuple[vcVector, vcVector, float, float]:
        """Returns curve end point information for a curve at a given index in set.
 The information defines both curve endpoint vectors and their weight values, for example if a NURBS curve is selected."""
        pass

    def getCurveLength(self: Any, curve: int) -> float:
        """Returns the length of a curve at a given index in set."""
        pass

    def getCurveMinCurveDistance(self: Any, curve: int, othercurve: int) -> Tuple[float, float, float]:
        """Returns the minimum distance between two curves at given indices in set.
 The returned value describes the minimum distance between curves and minimum distance between either end points of curves."""
        pass

    def getCurveMinDistance(self: Any, curve: int, point: vcVector) -> Tuple[float, float]:
        """Returns the minimum distance of a curve at a given index in set to a given point as well as the length of curve."""
        pass

    def getCurvePoint(self: Any, curve: int, distance: float) -> vcVector:
        """Returns a point on a curve at a given index in set and distance from beginning of curve."""
        pass

    def getCurvePointAndDerivate(self: Any, curve: int, distance: float) -> Tuple[vcVector, vcVector]:
        """Returns a point and first derivate vector of a curve at a given index in set and distance from beginning of curve."""
        pass

    def getCurvePointCount(self: Any, curve: int) -> int:
        """Returns the total number of points for a curve at a given index in set."""
        pass

    def getCurvePositions(self: Any, curve: int) -> List[vcMatrix]:
        """Returns a list of position matrices for each point on a curve at a given index in set."""
        pass

    def getCurveType(self: Any, curve: int) -> int:
        """Returns the type of curve at a given index in set.
 See Topology Constants for more information."""
        pass

    def getPolyLineCurvePoints(self: Any, curve: int) -> List[vcVector]:
        """Returns a list of points for a polyline at a given index in set; otherwise returns an empty list."""
        pass

    def getSplineCurveControlPoint(self: Any, curve: int) -> List[vcVector]:
        """Returns a list of control points for a spline at a given index in set; otherwise returns an empty list."""
        pass

    def getSplineCurveControlWeights(self: Any, curve: int) -> List[float]:
        """Returns a list of control weight values for a spline at a given index in set; otherwise returns an empty list."""
        pass

    def getSplineCurveDegree(self: Any, curve: int) -> int:
        """Returns the degree of a spline at a given index in set."""
        pass

    def getSplineCurveKnots(self: Any, curve: int) -> Tuple[List[int], List[float]]:
        """Returns spline knot multiplicities (knot recurrence) and knot values for a curve at a given index in set."""
        pass


class vcDataContainer(vcObject):
    """General purpose Python wrapper for data such as event arguments. The available Properties are different depending on each use case.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcDataContainer.htm"""


class vcDimension(vcLayoutItem):
    """vcDimension is a type of layout item used for authoring new and existing dimensions in a layout.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcDimension.htm"""

    @property
    def ArrowSize(self) -> float:
        """Defines the size of the head and tail arrows of dimension."""
        pass

    @ArrowSize.setter
    def ArrowSize(self, value : float) -> None:
        pass

    @property
    def Dimension(self) -> float:
        """Gets the magnitude (distance in millimeters) of dimension."""
        pass

    @property
    def Height(self) -> float:
        """Defines the height of text in dimension."""
        pass

    @Height.setter
    def Height(self, value : float) -> None:
        pass

    @property
    def LineWidth(self) -> float:
        """Defines the line width of dimension."""
        pass

    @LineWidth.setter
    def LineWidth(self, value : float) -> None:
        pass

    @property
    def Location(self) -> vcMatrix:
        """Defines the position matrix of the dimension in World coordinate system."""
        pass

    @Location.setter
    def Location(self, value : vcMatrix) -> None:
        pass

    @property
    def Material(self) -> vcMaterial:
        """Defines the material of dimension."""
        pass

    @Material.setter
    def Material(self, value : vcMaterial) -> None:
        pass

    @property
    def Node1(self) -> vcNode:
        """Defines the node the head of the dimension is attached to in 3D world."""
        pass

    @Node1.setter
    def Node1(self, value : vcNode) -> None:
        pass

    @property
    def Node2(self) -> vcNode:
        """Defines the node the tail of the dimension is attached to in 3D world."""
        pass

    @Node2.setter
    def Node2(self, value : vcNode) -> None:
        pass

    @property
    def Position1(self) -> vcMatrix:
        """Defines the position matrix of dimension's head relative to Node1 property's coordinate system."""
        pass

    @Position1.setter
    def Position1(self, value : vcMatrix) -> None:
        pass

    @property
    def Position2(self) -> vcMatrix:
        """Defines the position matrix of dimension's tail relative to Node2 property's coordinate system."""
        pass

    @Position2.setter
    def Position2(self, value : vcMatrix) -> None:
        pass

    @property
    def Thickness(self) -> float:
        """Defines the thickness of text in dimension."""
        pass

    @Thickness.setter
    def Thickness(self, value : float) -> None:
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns the first property matching a given name in the dimension."""
        pass


class vcDistributionModeProductLineEntry(vcObject):
    """vcDistributionModeProductLineEntry is an entry used for creating a product based on a weighted probability. Entries are associated with a vcProductCreatorDistributionMode and used when a vcProductCreator object is using a distribution feed mode.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcDistributionModeProductLineEntry.htm"""

    @property
    def Probability(self) -> float:
        """Defines the weight of the product type, which is used to calculate the probability for creating product instances of. 
It is evaluated as relative to the sum of all configured probabilities like a weight value in a weighted sum. The value must be greater than or equal to zero."""
        pass

    @Probability.setter
    def Probability(self, value : float) -> None:
        pass

    @property
    def ProductType(self) -> vcProductType:
        """Defines the product type of entry to create product instances of."""
        pass

    @ProductType.setter
    def ProductType(self, value : vcProductType) -> None:
        pass


class vcDof(vcObject):
    """vcDof defines the joint properties of a node, its degrees of freedom, and whether or not the joint is assigned to a controller of a robot or servo.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcDof.htm"""

    @property
    def JointLinkType(self) -> int:
        """Gets the JointType of the link.
See Joint Constants for more information."""
        pass

    @property
    def JointServoType(self) -> int:
        """Defines whether a joint assigned to a controller is rotational or translational.
See Joint Constants for more information."""
        pass

    @JointServoType.setter
    def JointServoType(self, value : int) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of DOF object and joint."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def VALUE(self) -> float:
        """Defines the current value of the joint."""
        pass

    @VALUE.setter
    def VALUE(self, value : float) -> None:
        pass

    @property
    def Controller(self) -> Union[vcServoController, vcRobotController]:
        """This property exist only in: Custom Joint, Rotational Joint, Translational Joint.
Gets/Sets the controller assigned the joint."""
        pass

    @Controller.setter
    def Controller(self, value : Union[vcServoController, vcRobotController]) -> None:
        pass

    @property
    def InitialValue(self) -> float:
        """This property exist only in: Custom Joint, Rotational Joint, Translational Joint.
Defines the default value of the joint at its initial state."""
        pass

    @InitialValue.setter
    def InitialValue(self, value : float) -> None:
        pass

    @property
    def Joint(self) -> str:
        """This property exist only in: Custom Joint.
Defines an expression that when evaluated returns the joint definition of the joint.
VALUE can be used to referenced the current value of the joint, for example "VALUE+10"."""
        pass

    @Joint.setter
    def Joint(self, value : str) -> None:
        pass

    @property
    def MinLimit(self) -> str:
        """This property exist only in: Custom Joint, Rotational Joint, Translational Joint.
Defines an expression that when evaluated returns the minimum value of the joint."""
        pass

    @MinLimit.setter
    def MinLimit(self, value : str) -> None:
        pass

    @property
    def MaxLimit(self) -> str:
        """This property exist only in: Custom Joint, Rotational Joint, Translational Joint.
Defines an expression that when evaluated returns the maximum value of the joint."""
        pass

    @MaxLimit.setter
    def MaxLimit(self, value : str) -> None:
        pass

    @property
    def Pivot(self) -> str:
        """This property exist only in: Custom Joint.
Defines an expression that when evaluated returns the pivot point definition of the joint.
VALUE can be used to referenced the current value of the joint, for example "VALUE+10"."""
        pass

    @Pivot.setter
    def Pivot(self, value : str) -> None:
        pass

    @property
    def AxisType(self) -> int:
        """This property exist only in: Follower Joint, Rotational Joint, Translational Joint.
Defines the axis of the joint.
See Joint Axis Constants for more information."""
        pass

    @AxisType.setter
    def AxisType(self, value : int) -> None:
        pass

    @property
    def Driver(self) -> vcDof:
        """This property exist only in: Follower Joint.
Defines the DOF object and joint referenced by a follower joint."""
        pass

    @Driver.setter
    def Driver(self, value : vcDof) -> None:
        pass

    @property
    def ValueExpression(self) -> str:
        """This property exist only in: Follower Joint, Rotational Joint, Translational Joint.
Defines an expression that when evaluated returns the value of the joint.
VALUE can be used to referenced the current value of the joint, for example "VALUE+10"."""
        pass

    @ValueExpression.setter
    def ValueExpression(self, value : str) -> None:
        pass

    @property
    def LagTime(self) -> float:
        """Defines the lag time (in seconds) of joint."""
        pass

    @LagTime.setter
    def LagTime(self, value : float) -> None:
        pass

    @property
    def MaxAcceleration(self) -> float:
        """Defines the maximum acceleration (units/degrees per second squared) of joint."""
        pass

    @MaxAcceleration.setter
    def MaxAcceleration(self, value : float) -> None:
        pass

    @property
    def MaxDeceleration(self) -> float:
        """Defines the maximum deceleration (units/degrees per second squared) of joint."""
        pass

    @MaxDeceleration.setter
    def MaxDeceleration(self, value : float) -> None:
        pass

    @property
    def MaxSpeed(self) -> float:
        """Defines the maximum speed (units/degrees per second squared) of joint."""
        pass

    @MaxSpeed.setter
    def MaxSpeed(self, value : float) -> None:
        pass

    @property
    def SettleTime(self) -> float:
        """Defines the settle time (in seconds) of joint."""
        pass

    @SettleTime.setter
    def SettleTime(self, value : float) -> None:
        pass

    @property
    def SoftMinLimit(self) -> float:
        """Defines the soft limit for minimum joint value."""
        pass

    @SoftMinLimit.setter
    def SoftMinLimit(self, value : float) -> None:
        pass

    @property
    def SoftMaxLimit(self) -> float:
        """Defines the soft limit for maximum joint value."""
        pass

    @SoftMaxLimit.setter
    def SoftMaxLimit(self, value : float) -> None:
        pass


class vcDrawingContext(vcContext):
    """vcDrawingContext is the context of the application for making 2D drawings. Currently, there are no additional properties, methods or events for this context.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcDrawingContext.htm"""


class vcEdge(vcPrimitive):
    """vcEdge is an edge defined by two points and may be shared with one or more polygons.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcEdge.htm"""

    @property
    def Direction(self) -> vcVector:
        """Gets a vector from the first point to the second point in edge."""
        pass

    @property
    def Points(self) -> List[vcPolygonPoint]:
        """Gets a list of two points that define the edge."""
        pass

    @property
    def Polygons(self) -> List[vcPolygon]:
        """Gets a list of polygons that share the edge."""
        pass

    @property
    def Type(self) -> int:
        """Gets the edge type.
See Edge Types for more information."""
        pass


class vcElseIfScope(vcScope):
    """ElseIf scopes can be added in If statements between ThenScope and ElseScope. The first ElseIf scope whose condition returns True will be executed. If none of the ElseIf scopes' conditions return True, the ElseScope of statements will be executed.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcElseIfScope.htm"""

    @property
    def Condition(self) -> str:
        """Defines an expression that when evaluated returns a True or False value.
A True value means the If statement will execute this scope.
A False value means the If statement will not execute this scope."""
        pass

    @Condition.setter
    def Condition(self, value : str) -> None:
        pass


class vcEventReturnData(vcObject):
    """Events do not have return values, so having this object as a parameter allows passing some information back from event handler(s) to the event publisher.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcEventReturnData.htm"""

    @property
    def Handled(self) -> bool:
        """Defines if this event has already been handled.
This is used when an event should only be handled once. All listeners of the event should begin by checking this value before performing any operations. If True, then no further operations should be performed. Otherwise, logic can continue.
If the listener then handles this event and no further handling should be done to it, the listener should write True here."""
        pass

    @Handled.setter
    def Handled(self, value : bool) -> None:
        pass


class vcExecutor(vcBehaviour):
    """vcExecutor allows you to execute a robot or servo program.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcExecutor.htm"""

    @property
    def Controller(self) -> Union[vcRobotController, vcServoController]:
        """Defines the controller associated with the executor."""
        pass

    @Controller.setter
    def Controller(self, value : Union[vcRobotController, vcServoController]) -> None:
        pass

    @property
    def CurrentStatement(self) -> vcStatement:
        """Gets the statement currently being executed by the executor."""
        pass

    @property
    def DigitalInputSignals(self) -> vcBooleanSignalMap:
        """Defines the input signal device associated with the executor."""
        pass

    @DigitalInputSignals.setter
    def DigitalInputSignals(self, value : vcBooleanSignalMap) -> None:
        pass

    @property
    def DigitalOutputSignals(self) -> vcBooleanSignalMap:
        """Defines the output signal device associated with the executor."""
        pass

    @DigitalOutputSignals.setter
    def DigitalOutputSignals(self, value : vcBooleanSignalMap) -> None:
        pass

    @property
    def IsEnabled(self) -> bool:
        """Defines if the program is executed during simulation."""
        pass

    @IsEnabled.setter
    def IsEnabled(self, value : bool) -> None:
        pass

    @property
    def IsLooping(self) -> bool:
        """Defines if the executor loops its program."""
        pass

    @IsLooping.setter
    def IsLooping(self, value : bool) -> None:
        pass

    @property
    def ProcessHandlers(self) -> List[vcPythonProcessHandler]:
        """Defines a list of process handlers for overriding or modifying statements of robot program and executing process statements.
 (Deprecated) Use StatementHandler."""
        pass

    @ProcessHandlers.setter
    def ProcessHandlers(self, value : List[vcPythonProcessHandler]) -> None:
        pass

    @property
    def Program(self) -> vcProgram:
        """Gets the program associated with the executor."""
        pass

    @property
    def StatementHandler(self) -> vcPythonProcessHandler:
        """Defines a process handler for controlling the execution of statements in robot program.
 See an example of modifying a point-to-point motion statement.
 Important: Process statements and Path statements with assigned process handlers are executed by their handlers. That is, those statements are not passed on to the statement handler of executor. Do not call nor try to execute them with the statement handler."""
        pass

    @StatementHandler.setter
    def StatementHandler(self, value : vcPythonProcessHandler) -> None:
        pass

    @property
    def UseExternalExecutor(self) -> bool:
        """Defines if the component is controlled by external execution mechanism, for example a virtual robot controller."""
        pass

    @UseExternalExecutor.setter
    def UseExternalExecutor(self, value : bool) -> None:
        pass

    @overload
    def callRoutine(self: Any, routine: vcRoutine, suspendScript: bool = ..., clearCallStack: bool = ...) -> None:
        """Executes a routine.
 By default, Python execution is suspended until the routine has been completed.
 An optional suspendScript argument can be given a False value, thereby Python execution continues immediately.
 An optional clearCallStack argument can be given a False value, thereby the call stack of executor is not cleared before executing routine."""
        pass

    @overload
    def callRoutine(self: Any, name: str, suspendScript: bool = ..., clearCallStack: bool = ...) -> None:
        """Executes a routine.
 By default, Python execution is suspended until the routine has been completed.
 An optional suspendScript argument can be given a False value, thereby Python execution continues immediately.
 An optional clearCallStack argument can be given a False value, thereby the call stack of executor is not cleared before executing routine."""
        pass

    def callStatement(self: Any, statement: vcStatement, suspendScript: bool = ...) -> None:
        """Executes a statement.
 By default, Python execution is suspended until the statement has been completed.
 An optional suspendScript argument can be given a False value, thereby Python execution continues immediately.
 Note: You can use callStatement() with a process handler to modify the default execution of statements in robot program, for example point-to-point motions, as well as the pre/post execution of statements."""
        pass

    def setOutput(self: Any, output_index: int, value: bool) -> None:
        """Sets the value of a signal connected to a port at a given output_index in robot."""
        pass

    def trySetDigitalInputSignals(self: Any, signal_map: vcBooleanSignalMap) -> bool:
        """Tries to set the given boolean signal map behavior as the digital input signals.
 
 If setting the behavior is successful, returns True. Otherwise, returns False."""
        pass

    def trySetDigitalOutputSignals(self: Any, signal_map: vcBooleanSignalMap) -> bool:
        """Tries to set the given boolean signal map behavior as the digital output signals.
 
 If setting the behavior is successful, returns True. Otherwise, returns False."""
        pass

    def waitInput(self: Any, input_index: int, value: bool) -> None:
        """Schedules the executor to wait until a signal connected to a port at a given input_index in robot has a given value.
 Note: Python execution continues immediately."""
        pass

    OnCurrentStatementChanged : Callable[[], None]
    """Triggered when the current statement of executor changes to a different statement. (Deprecated) Use OnPreExecuteStatement."""


    OnPostExecuteStatement : Callable[[vcStatement, bool], None]
    """Triggered after execution of a statement."""


    OnPreExecuteStatement : Callable[[vcStatement, bool], None]
    """Triggered before execution of a statement. The isImmediate argument defines if the statement will be executed immediately (non time-consuming mode)"""


    OnProgramFinished : Callable[[vcExecutor], None]
    """Triggered when the execution of program has finished."""



class vcFeature(vcObject):
    """vcFeature is the base class for all types of features in a component.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcFeature.htm"""

    @property
    def Children(self) -> List[vcFeature]:
        """Gets a list of feature's immediate child features."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of feature."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def NodePositionMatrix(self) -> vcMatrix:
        """Gets the position matrix of the feature relative to its node's coordinate system."""
        pass

    @property
    def Parent(self) -> vcFeature:
        """Gets the parent of this feature in the node feature tree.
 If the feature is root feature, return value is None."""
        pass

    @property
    def PhysicsCollider(self) -> int:
        """Defines the type of collider used by the feature for physics.
 Note: A feature inherits the collider of its parent feature.
 See Collider Constants for more information."""
        pass

    @PhysicsCollider.setter
    def PhysicsCollider(self, value : int) -> None:
        pass

    @property
    def PositionMatrix(self) -> vcMatrix:
        """Defines the position matrix of this feature relative to its parent feature's coordinate system."""
        pass

    @PositionMatrix.setter
    def PositionMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all properties in feature."""
        pass

    @property
    def Type(self) -> int:
        """Gets the feature type.
 See Feature Constants for more information."""
        pass

    @property
    def Visible(self) -> bool:
        """Turns on/off the visibility of the frame in the 3D world."""
        pass

    @Visible.setter
    def Visible(self, value : bool) -> None:
        pass

    @property
    def Count(self) -> str:
        """This property exist only in: Angular Clone, Linear Clone.
Defines an expression that when evaluated returns the number of times to clone the feature's subtree.
 0
 No geometry is rendered.
 1
 The original geometry of the feature's subtree is rendered.
 1+n
 The original geometry is rendered and cloned n amount of times.
 When evaluated, the expression should return an integer."""
        pass

    @Count.setter
    def Count(self, value : str) -> None:
        pass

    @property
    def Offset(self) -> str:
        """This property exist only in: Angular Clone, Mirror.
Defines an expression that when evaluated returns a vector used to offset the direction of each clone from one another."""
        pass

    @Offset.setter
    def Offset(self, value : str) -> None:
        pass

    @property
    def Step(self) -> str:
        """This property exist only in: Angular Clone, Linear Clone.
Defines an expression that when evaluated returns the angular distance used to offset each clone from one another."""
        pass

    @Step.setter
    def Step(self, value : str) -> None:
        pass

    @property
    def Height(self) -> str:
        """This property exist only in: Block, Cone, Cylinder.
Defines an expression that when evaluated returns the height of the block projected along its Z-axis."""
        pass

    @Height.setter
    def Height(self, value : str) -> None:
        pass

    @property
    def Length(self) -> str:
        """This property exist only in: Block, Extrude.
Defines an expression that when evaluated returns the length of the block projected along its X-axis."""
        pass

    @Length.setter
    def Length(self, value : str) -> None:
        pass

    @property
    def Material(self) -> vcMaterial:
        """This property exist only in: Block, Boolean, Cone, Cylinder, Extrude, Revolve, Sphere, Text, Wedge.
Defines the material of the block."""
        pass

    @Material.setter
    def Material(self, value : vcMaterial) -> None:
        pass

    @property
    def Width(self) -> str:
        """This property exist only in: Block, Wedge.
Defines an expression that when evaluated returns the width of the block projected along its Y-axis."""
        pass

    @Width.setter
    def Width(self, value : str) -> None:
        pass

    @property
    def Operation(self) -> int:
        """This property exist only in: Boolean.
Defines how the geometry is visualized."""
        pass

    @Operation.setter
    def Operation(self, value : int) -> None:
        pass

    @property
    def BottomRadius(self) -> str:
        """This property exist only in: Cone.
Defines an expression that when evaluated returns the bottom radius of the cone."""
        pass

    @BottomRadius.setter
    def BottomRadius(self, value : str) -> None:
        pass

    @property
    def Caps(self) -> bool:
        """This property exist only in: Cone, Cylinder, Revolve, Sphere.
Turns on/off the rendering of caps for the cone."""
        pass

    @Caps.setter
    def Caps(self, value : bool) -> None:
        pass

    @property
    def EndSweep(self) -> str:
        """This property exist only in: Cone, Cylinder, Sphere.
Defines an expression that when evaluated returns the angle where the cone's geometry is swept to relative to the cone's center."""
        pass

    @EndSweep.setter
    def EndSweep(self, value : str) -> None:
        pass

    @property
    def Sections(self) -> str:
        """This property exist only in: Cone, Cylinder, Revolve, Sphere.
Defines an expression that when evaluated returns the number of sections (sides) generated for the cone."""
        pass

    @Sections.setter
    def Sections(self, value : str) -> None:
        pass

    @property
    def StartSweep(self) -> str:
        """This property exist only in: Cone, Cylinder, Sphere.
Defines an expression that when evaluated returns the angle where the cone's geometry is swept from relative to the cone's center."""
        pass

    @StartSweep.setter
    def StartSweep(self, value : str) -> None:
        pass

    @property
    def TopRadius(self) -> str:
        """This property exist only in: Cone.
Defines an expression that when evaluated returns the top radius of the cone."""
        pass

    @TopRadius.setter
    def TopRadius(self, value : str) -> None:
        pass

    @property
    def Radius(self) -> str:
        """This property exist only in: Cylinder, Sphere.
Defines an expression that when evaluated returns the radius of the cylinder."""
        pass

    @Radius.setter
    def Radius(self, value : str) -> None:
        pass

    @property
    def Direction(self) -> str:
        """This property exist only in: Extrude, Linear Clone.
Defines an expression that when evaluated returns a vector defining the direction of the extrusion."""
        pass

    @Direction.setter
    def Direction(self, value : str) -> None:
        pass

    @property
    def ShowBackFaces(self) -> bool:
        """This property exist only in: Extrude.
Turns on/off the rendering of geometry backfaces in the extrusion."""
        pass

    @ShowBackFaces.setter
    def ShowBackFaces(self, value : bool) -> None:
        pass

    @property
    def UseAsGuide(self) -> int:
        """This property exist only in: Frame.
Defines if the frame can be selected when adding dimensions in the Drawing view."""
        pass

    @UseAsGuide.setter
    def UseAsGuide(self, value : int) -> None:
        pass

    @property
    def HideOriginal(self) -> bool:
        """This property exist only in: Mirror.
Turns on/off the visibility of feature being mirrored."""
        pass

    @HideOriginal.setter
    def HideOriginal(self, value : bool) -> None:
        pass

    @property
    def Size(self) -> str:
        """This property exist only in: Plane, Text.
Defines an expression that when evaluated returns the length and width of the plane."""
        pass

    @Size.setter
    def Size(self, value : str) -> None:
        pass

    @property
    def Script(self) -> str:
        """This property exist only in: Python Feature.
Defines the code of the Python feature."""
        pass

    @Script.setter
    def Script(self, value : str) -> None:
        pass

    @property
    def RevolveAngle(self) -> str:
        """This property exist only in: Revolve.
Defines an expression that when evaluated returns the angle for revolving geometry."""
        pass

    @RevolveAngle.setter
    def RevolveAngle(self, value : str) -> None:
        pass

    @property
    def RevolveAxis(self) -> str:
        """This property exist only in: Revolve.
Defines an expression that when evaluated returns a vector/direction for revolving geometry, for example (0,0,1) would revolve geometry around Z-axis."""
        pass

    @RevolveAxis.setter
    def RevolveAxis(self, value : str) -> None:
        pass

    @property
    def RevolveOffset(self) -> str:
        """This property exist only in: Revolve.
Defines an expression that when evaluated returns an offset for revolved geometry."""
        pass

    @RevolveOffset.setter
    def RevolveOffset(self, value : str) -> None:
        pass

    @property
    def Reverse(self) -> bool:
        """This property exist only in: Revolve.
Turns on/off the inverting of revolved geometry."""
        pass

    @Reverse.setter
    def Reverse(self, value : bool) -> None:
        pass

    @property
    def Spans(self) -> str:
        """This property exist only in: Sphere.
Defines an expression that when evaluated returns the number of sections/sides between the equator and poles of swept geometry."""
        pass

    @Spans.setter
    def Spans(self, value : str) -> None:
        pass

    @property
    def Choice(self) -> str:
        """This property exist only in: Switch.
Defines an expression that when evaluated returns which immediate child of the switch to render in 3D world.
 A zero value selects the switch, thereby not rendering any of its subfeatures. That is, indexing starts at one."""
        pass

    @Choice.setter
    def Choice(self, value : str) -> None:
        pass

    @property
    def IsFloating(self) -> bool:
        """This property exist only in: Text.
Defines if the text floats freely in 3D world or is anchored directly to feature location."""
        pass

    @IsFloating.setter
    def IsFloating(self, value : bool) -> None:
        pass

    @property
    def IsReadOnly(self) -> bool:
        """This property exist only in: Text.
Defines if the text is read-only and locked from editing."""
        pass

    @IsReadOnly.setter
    def IsReadOnly(self, value : bool) -> None:
        pass

    @property
    def Text(self) -> str:
        """This property exist only in: Text.
Defines an expression that when evaluated returns the text to be visualized in the 3D world."""
        pass

    @Text.setter
    def Text(self, value : str) -> None:
        pass

    @property
    def Expression(self) -> str:
        """This property exist only in: Transform.
Defines an expression for transforming subfeatures."""
        pass

    @Expression.setter
    def Expression(self, value : str) -> None:
        pass

    @property
    def BiggerHeight(self) -> str:
        """This property exist only in: Wedge.
Defines an expression that when evaluated returns the Z-axis height of the wedge's back end."""
        pass

    @BiggerHeight.setter
    def BiggerHeight(self, value : str) -> None:
        pass

    @property
    def BiggerLength(self) -> str:
        """This property exist only in: Wedge.
Defines an expression that when evaluated returns the X-axis length of the wedge's bottom."""
        pass

    @BiggerLength.setter
    def BiggerLength(self, value : str) -> None:
        pass

    @property
    def MirrorBack(self) -> bool:
        """This property exist only in: Wedge.
Turns on/off the mirroring of the wedge along its X-axis."""
        pass

    @MirrorBack.setter
    def MirrorBack(self, value : bool) -> None:
        pass

    @property
    def MirrorDown(self) -> bool:
        """This property exist only in: Wedge.
Turns on/off the mirroring of the wedge along its negative Z-axis."""
        pass

    @MirrorDown.setter
    def MirrorDown(self, value : bool) -> None:
        pass

    @property
    def SmallerHeight(self) -> str:
        """This property exist only in: Wedge.
Defines an expression that when evaluated returns the Z-axis height of the wedge's front end."""
        pass

    @SmallerHeight.setter
    def SmallerHeight(self, value : str) -> None:
        pass

    @property
    def SmallerLength(self) -> str:
        """This property exist only in: Wedge.
Defines an expression that when evaluated returns the X-axis length of the wedge's top."""
        pass

    @SmallerLength.setter
    def SmallerLength(self, value : str) -> None:
        pass

    def attach(self: Any, feature: vcFeature, rebuild: bool = ...) -> bool:
        """Attaches a given feature to this feature, thereby allowing you to reorder the containing node's feature tree.
 The given feature cannot be the root feature or parent of this feature.
 An optional rebuild argument can be used to control the rebuilding of geometry for an attached feature. Default is False value and will not rebuild geometry, whereas a True value will rebuild geometry.
 Returns True if attachment is successful; otherwise returns False."""
        pass

    def clone(self: Any) -> vcFeature:
        """Copies the feature to the same level in containing node's feature tree, and then returns the clone."""
        pass

    def collapse(self: Any) -> None:
        """Collapses the feature into a new Geometry feature.
 The original feature will be deleted, thereby you need to get handle for the new feature."""
        pass

    def createFeature(self: Any, type: int, name: str) -> vcFeature:
        """Adds a new feature of a given type and name as a child of this feature.
 See Feature Constants for more information."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to the feature.
 An optional constraints argument can be given to define constraints for the new property, which must be done at the time of creation.
 See Property Constants for more information."""
        pass

    def delete(self: Any) -> bool:
        """Deletes the feature and its subfeatures, and then returns True; otherwise returns False."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property from the feature."""
        pass

    def getFeature(self: Any) -> vcFeature:
        """Returns the feature."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property of the feature that matches the given name; otherwise returns None."""
        pass

    def rebuild(self: Any) -> None:
        """Rebuilds the feature and its subfeature tree."""
        pass


class vcFeedOptionFlowInfo(vcObject):
    """FeedOptionFlowInfo indicates an expanded direction (inexact location) in the product flow. Used by vcProductFeed objects, to be matched with Need objects available in the simulation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcFeedOptionFlowInfo.htm"""

    @property
    def FlowStep(self) -> vcProcessFlowStep:
        """Specifies ProcessFlowStep"""
        pass

    @property
    def GroupId(self) -> str:
        """Specifies ProcessGroup's ID inside the FlowStep.
 Alternatively, user can use “” (empty string) to indicate that any matching ProcessGroup is fine."""
        pass

    @property
    def Group(self) -> vcProcessGroup:
        """Specifies vcProcessGroup object. In case a custom ID is used for GroupId, this will be None."""
        pass

    def setStep(self: Any, step: vcProcessFlowStep) -> None:
        """Sets the FlowStep property. 
 Resets Group to None and GroupId to “”, if such ProcessGroup is not present in the new FlowStep."""
        pass

    @overload
    def setGroup(self: Any, groupId: str) -> None:
        """Sets the GroupId and Group properties to match. 
 If a custom Id is used, Group is set to None. If the new ProcessGroup cannot be found in the current FlowStep, FlowStep is set to None."""
        pass

    @overload
    def setGroup(self: Any, group: vcProcessGroup) -> None:
        """Sets the GroupId and Group properties to match. 
 If a custom Id is used, Group is set to None. If the new ProcessGroup cannot be found in the current FlowStep, FlowStep is set to None."""
        pass


class vcFlow(vcBehaviour):
    """vcFlow is a base class for behaviors that support the transfer of components and material flow using connectors/ports.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcFlow.htm"""

    @property
    def CapacityAvailable(self) -> bool:
        """Defines if flow object will accept an incoming component.
 This is not the same as a logical capacity test since flow type behaviors do not to store components."""
        pass

    @CapacityAvailable.setter
    def CapacityAvailable(self, value : bool) -> None:
        pass

    @property
    def ConnectorCount(self) -> int:
        """Gets the amount of connectors/ports in flow object."""
        pass

    @property
    def Connectors(self) -> List[vcConnector]:
        """Gets a list of connectors in flow object."""
        pass

    @property
    def Statistics(self) -> vcStatistics:
        """Defines a Statistics behavior that collects data generated by this flow during a simulation."""
        pass

    @Statistics.setter
    def Statistics(self, value : vcStatistics) -> None:
        pass

    @property
    def Create(self) -> bool:
        """This property exist only in: Boolean Property Creator, Integer Property Creator, Real Property Creator, String property Creator.
Defines if a property is created when no property in a component matches VariableName."""
        pass

    @Create.setter
    def Create(self, value : bool) -> None:
        pass

    @property
    def Enabled(self) -> bool:
        """This property exist only in: Boolean Property Creator, Integer Property Creator, Real Property Creator, String property Creator.
Turns on/off the use of the creator."""
        pass

    @Enabled.setter
    def Enabled(self, value : bool) -> None:
        pass

    @property
    def Value(self) -> bool:
        """This property exist only in: Boolean Property Creator, Integer Property Creator, Real Property Creator, String property Creator.
Defines the value of a property in a component matching VariableName."""
        pass

    @Value.setter
    def Value(self, value : bool) -> None:
        pass

    @property
    def VariableName(self) -> str:
        """This property exist only in: Boolean Property Creator, Integer Property Creator, Real Property Creator, String property Creator.
Defines the name of a property to create/set in a component."""
        pass

    @VariableName.setter
    def VariableName(self, value : str) -> None:
        pass

    def checkCapacity(self: Any, component: vcComponent, index: int) -> bool:
        """Tests if the flow object has the capacity to store a given component that passes through a connector at a given index.
 Generally, this method is used to test the arrival of components at different connectors in order to route components effectively and avoid bottlenecks.
 The test passes if CapacityAvailable is set to True. In cases where the flow object has physical capacity to store components, the test depends on the container's ComponentCount and Capacity properties as well as the capacity test used by a connector.
 See vcConnector for more information."""
        pass

    def getConnectorCount(self: Any) -> int:
        """Gets the number of connectors/ports in the flow object."""
        pass

    @overload
    def getConnector(self: Any, index: int) -> vcConnector:
        """Returns a connector at a given index or one that matches a given name in the flow object; otherwise returns None."""
        pass

    @overload
    def getConnector(self: Any, name: str) -> vcConnector:
        """Returns a connector at a given index or one that matches a given name in the flow object; otherwise returns None."""
        pass

    def setConnection(self: Any, index: int, to_connector: vcConnector) -> vcConnector:
        """Connects a connector at a given index in the flow object to a given connector."""
        pass


class vcFlowStepProcessConfiguration(vcObject):
    """Process
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcFlowStepProcessConfiguration.htm"""

    @property
    def ProcessGroup(self) -> vcProcessGroup:
        """The process groups this configuration is applied to."""
        pass

    @property
    def IsOptional(self) -> bool:
        """Defines whether ProcessGroup is optional inside a vcProcessFlowStep."""
        pass

    @IsOptional.setter
    def IsOptional(self, value : bool) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets the properties of this vcFlowStepProcessConfiguration."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property of the vcFlowStepProcessConfiguration."""
        pass


class vcFrameFeature(vcFeature):
    """vcFrameFeature is a type of feature used to reference a point in the 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcFrameFeature.htm"""

    @property
    def FramePositionMatrix(self) -> vcMatrix:
        """Gets the position matrix of frame."""
        pass

    @property
    def OriginalFramePositionMatrix(self) -> vcMatrix:
        """Gets the original position matrix of frame."""
        pass


class vcFrameSet(vcGeometrySet):
    """vcFrameSet is a type of geometry set that contains a collection of frames.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcFrameSet.htm"""

    @property
    def FrameCount(self) -> int:
        """Gets the number of frames in set."""
        pass

    def createFrame(self: Any) -> None:
        """Creates a new frame in set."""
        pass

    def deleteFrame(self: Any, index: int) -> None:
        """Deletes a frame at a given index from set."""
        pass

    def getFrame(self: Any, index: int) -> vcMatrix:
        """Returns the position matrix of a frame at a given index in set."""
        pass

    def setFrame(self: Any, index: int, frame_matrix: vcMatrix) -> None:
        """Sets the position matrix of a frame at a given index in set."""
        pass

    def update(self: Any) -> None:
        """Updates all frames in set, thereby updating the set's bound box."""
        pass


class vcFrameSetVisualization(vcObject):
    """vcFrameSetVisualization is a list containing properties that affect the display of frames in the 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcFrameSetVisualization.htm"""

    @property
    def AxisTextVisible(self) -> bool:
        """Turns on/off the display of axis labels for Frame features in set. That is, XYZ labels for coordinate axes in a Frame feature.
This property is disabled if FramesVisible is set to False."""
        pass

    @AxisTextVisible.setter
    def AxisTextVisible(self, value : bool) -> None:
        pass

    @property
    def ConnectingLinesVisible(self) -> bool:
        """Defines if lines are drawn in the 3D world between each Frame feature in set.
The line type is defined by the LineDisplayMode property."""
        pass

    @ConnectingLinesVisible.setter
    def ConnectingLinesVisible(self, value : bool) -> None:
        pass

    @property
    def CustomIcon(self) -> str:
        """Defines the name of a vc3DIcon object used for rendering each Frame feature in set.
Other properties determine if and how a 3D icon is used with the set."""
        pass

    @CustomIcon.setter
    def CustomIcon(self, value : str) -> None:
        pass

    @property
    def FixedSize(self) -> bool:
        """Defines if CustomIcon is scaled to have a constant size relative to a user's 3D world view.
This property is enabled when FrameDisplayMode is set to use icons and FramesVisible is set to True."""
        pass

    @FixedSize.setter
    def FixedSize(self, value : bool) -> None:
        pass

    @property
    def FrameDisplayMode(self) -> int:
        """Defines the mode for rendering Frame features in set.
This property is disabled if FramesVisible is set to False.
See Frame Display Mode Constants for more information."""
        pass

    @FrameDisplayMode.setter
    def FrameDisplayMode(self, value : int) -> None:
        pass

    @property
    def FramesVisible(self) -> bool:
        """Turns on/off the display of Frame features in set."""
        pass

    @FramesVisible.setter
    def FramesVisible(self, value : bool) -> None:
        pass

    @property
    def LineDisplayMode(self) -> int:
        """Defines the mode for rendering lines between Frame features in set.
This property is disabled if ConnectingLinesVisible is set to False.
See Line Display Mode Constants for more information."""
        pass

    @LineDisplayMode.setter
    def LineDisplayMode(self, value : int) -> None:
        pass

    @property
    def LoopLines(self) -> bool:
        """Defines if a line is drawn to connect the first and last Frame feature in set.
This property is disabled if ConnectingLinesVisible is set to False."""
        pass

    @LoopLines.setter
    def LoopLines(self, value : bool) -> None:
        pass

    @property
    def Material(self) -> str:
        """Defines the material of Frame features in set.
This might be overridden by the material of CustomIcon or an individual Frame feature."""
        pass

    @Material.setter
    def Material(self, value : str) -> None:
        pass

    @property
    def NamesVisible(self) -> bool:
        """Defines if the name of each Frame feature in set is displayed in the 3D world.
This property is disabled if FramesVisible is set to False.
Note: Displaying the names of Frame features can slow performance and degrade usability when a large amount of Frame features are contained in a small area."""
        pass

    @NamesVisible.setter
    def NamesVisible(self, value : bool) -> None:
        pass


class vcGeometryContainer(vcObject):
    """vcGeometryContainer is a container used to store all types of geometry sets for nodes and Geometry features.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcGeometryContainer.htm"""

    @property
    def BoundCenter(self) -> vcVector:
        """Gets a vector from the origin to the center of the container's bound box."""
        pass

    @property
    def BoundDiagonal(self) -> vcVector:
        """Gets a half diagonal vector from the center to an upper corner of the container's bound box using positive axis directions."""
        pass

    @property
    def GeometrySetCount(self) -> int:
        """Gets the amount of geometry sets in container."""
        pass

    @property
    def GeometrySets(self) -> List[vcGeometrySet]:
        """Gets a list of geometry sets in container."""
        pass

    def clear(self: Any) -> None:
        """Removes all geometry sets from container."""
        pass

    def cloneGeometrySets(self: Any, container: vcGeometryContainer, offset: vcMatrix = ...) -> None:
        """Copies all geometry sets in the container to a given container.
 An optional offset argument can be given to offset the copied geometry, thereby making it easier to distinguish the original from its copy.
 In this case, geometry is shared between both containers."""
        pass

    def createGeometrySet(self: Any, type: int) -> vcGeometrySet:
        """Creates a new geometry set of a given type in container.
 See Geometry Constants for more information."""
        pass

    @overload
    def deleteGeometrySet(self: Any, index: int) -> None:
        """Deletes a given geometry set or one at a given index from container."""
        pass

    @overload
    def deleteGeometrySet(self: Any, set: vcGeometrySet) -> None:
        """Deletes a given geometry set or one at a given index from container."""
        pass

    def getGeometrySet(self: Any, index: int) -> vcGeometrySet:
        """Returns a geometry set at a given index in container."""
        pass

    def moveGeometrySets(self: Any, container: vcGeometryContainer, offset: vcMatrix = ...) -> None:
        """Moves all geometry sets in the container to a given container.
 An optional offset argument can be given to offset the moved geometry, for example to apply a node offset.
 In this case, geometry is not shared between both containers since the original container is now empty."""
        pass

    def setModified(self: Any) -> None:
        """Marks the geometry of container as being modified, thereby alerting the application that changes need to be saved to file."""
        pass

    def transformContent(self: Any, matrix: vcMatrix) -> None:
        """Transforms all geometry sets of container by the given matrix."""
        pass

    def update(self: Any) -> None:
        """Updates the bound box of container."""
        pass


class vcGeometryFeature(vcFeature):
    """vcGeometryFeature is the object type for Geometry features in a component.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcGeometryFeature.htm"""

    @property
    def AmbientOcclusion(self) -> int:
        """Defines if geometry supporting ambient occlusion is rendered in the 3D world.
 0
 VC_AMBIENT_OCCLUSION_NONE
 1
 VC_AMBIENT_OCCLUSION_VERTEX"""
        pass

    @AmbientOcclusion.setter
    def AmbientOcclusion(self, value : int) -> None:
        pass

    @property
    def CreaseAngle(self) -> float:
        """Defines an angle tolerance for smoothing surfaces based on camera angle and lighting calculations.
 For example, if the angle between edges of a surface is less than CreaseAngle, the affected triangle sets will appear as one smooth face."""
        pass

    @CreaseAngle.setter
    def CreaseAngle(self, value : float) -> None:
        pass

    @property
    def Geometry(self) -> vcGeometryContainer:
        """Gets the container of feature's geometry."""
        pass

    @property
    def IsUnique(self) -> bool:
        """Indicates if the feature and its geometry is unique or shared with other features.
 (Deprecated) Use the IsUnique property in vcComponent."""
        pass

    @property
    def OnDemandLoad(self) -> bool:
        """Defines if geometry of feature is loaded when the feature is being used or enabled in its node.
 Generally, this property is used with a Switch feature to show/hide geometry based on a user's choice."""
        pass

    @OnDemandLoad.setter
    def OnDemandLoad(self, value : bool) -> None:
        pass

    @property
    def Pickable(self) -> bool:
        """Turns on/off the ability to select geometry of feature in the 3D world.
 Note: This affects all commands and tools that use snap types."""
        pass

    @Pickable.setter
    def Pickable(self, value : bool) -> None:
        pass

    @property
    def ShowContent(self) -> bool:
        """Turns on/off the visibility of feature."""
        pass

    @ShowContent.setter
    def ShowContent(self, value : bool) -> None:
        pass

    @property
    def ShowBackfaces(self) -> bool:
        """Turns on/off the rendering of geometry in the feature that is not facing the camera of the 3D world."""
        pass

    @ShowBackfaces.setter
    def ShowBackfaces(self, value : bool) -> None:
        pass

    @property
    def TesselationQuality(self) -> float:
        """Defines the quality of feature's geometry by affecting both angle and chord height tolerances used for tessellating the feature.
 Note: This property does not set any fractional tolerance values as it relates to the degree of accuracy."""
        pass

    @TesselationQuality.setter
    def TesselationQuality(self, value : float) -> None:
        pass

    @property
    def Uri(self) -> str:
        """Defines the URI of source file for geometry used in feature.
 Writing this property will override any existing geometry in the feature and cannot be undone."""
        pass

    @Uri.setter
    def Uri(self, value : str) -> None:
        pass

    def makeUnique(self: Any) -> None:
        """Makes the feature and its geometry unique, thereby the geometry is not shared with other features.
 (Deprecated) Use the makeUnique() method in vcComponent."""
        pass


class vcGeometrySet(vcObject):
    """vcGeometrySet is the base class for any type of geometry set in a component.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcGeometrySet.htm"""

    @property
    def BillBoard(self) -> bool:
        """Defines if geometry of set is always facing the 3D world camera.
Generally, this property is used for billboard text and is only supported for the following types:
vcCompactLineSet
vcPointSet
vcText2DSet
vcTriangleSet"""
        pass

    @BillBoard.setter
    def BillBoard(self, value : bool) -> None:
        pass

    @property
    def BoundCenter(self) -> vcVector:
        """Gets a vector from the origin to the center of the container's bound box."""
        pass

    @property
    def BoundDiagonal(self) -> vcVector:
        """Gets a half diagonal vector from the center to an upper corner of the container's bound box using positive axis directions."""
        pass

    @property
    def Container(self) -> vcGeometryContainer:
        """Gets the geometry container of set."""
        pass

    @property
    def Feature(self) -> vcFeature:
        """Gets the feature that the set belongs to in node feature tree."""
        pass

    @property
    def FixedSize(self) -> bool:
        """Defines if the size of set visually remains the same in the 3D world regardless of camera position.
This property is only supported for the following types:
vcCompactLineSet
vcPointSet
vcText2DSet
vcTriangleSet"""
        pass

    @FixedSize.setter
    def FixedSize(self, value : bool) -> None:
        pass

    @property
    def HasMaterialInheritance(self) -> bool:
        """Determines if the geometry set has material inheritance (geo set will use the inherited material or its own)."""
        pass

    @HasMaterialInheritance.setter
    def HasMaterialInheritance(self, value : bool) -> None:
        pass

    @property
    def Layer(self) -> vcLayer:
        """Defines the layer that the set belongs to in layout."""
        pass

    @Layer.setter
    def Layer(self, value : vcLayer) -> None:
        pass

    @property
    def LightAmbientTexture(self) -> bool:
        """Defines if the material texture of set is used to affect ambient light intensity and shininess of surfaces.
(Deprecated)"""
        pass

    @LightAmbientTexture.setter
    def LightAmbientTexture(self, value : bool) -> None:
        pass

    @property
    def LightAmbientVertex(self) -> bool:
        """Defines if vertex color/intensity is blended with light rays to render ambient lighting effect.
(Deprecated)"""
        pass

    @LightAmbientVertex.setter
    def LightAmbientVertex(self, value : bool) -> None:
        pass

    @property
    def Material(self) -> vcMaterial:
        """Defines the material of set.
If None, the set uses default render settings."""
        pass

    @Material.setter
    def Material(self, value : vcMaterial) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of set."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Type(self) -> int:
        """Gets the set type.
See Geometry Constants for more information."""
        pass

    @property
    def UseBackface(self) -> bool:
        """Defines if geometry of set is rendered when not facing the 3D world camera."""
        pass

    @UseBackface.setter
    def UseBackface(self, value : bool) -> None:
        pass

    @property
    def VertexColor(self) -> int:
        """Defines if the set uses vertex coloring.
See Geometry Constants for more information."""
        pass

    @VertexColor.setter
    def VertexColor(self, value : int) -> None:
        pass

    @overload
    def updateBoundIncrementally(self: Any, x: float, y: float, z: float) -> vcVector:
        """Increments the bound box of the set's component."""
        pass

    @overload
    def updateBoundIncrementally(self: Any, vector: vcVector) -> vcVector:
        """Increments the bound box of the set's component."""
        pass


class vcIfStatement(vcStatement):
    """A vcIfStatement is a robot statement that execute one of two scopes of statements based on a condition. If the condition is true, the statement executes its ThenScope of statements. If the condition is false, the statement executes is ElseScope of statements. In robot programming, you can also add one or more ElseIfScopes (vcElseIfScope) between ThenScope and ElseScope.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcIfStatement.htm"""

    @property
    def Condition(self) -> str:
        """Defines an expression that when evaluated returns a True or False value.
 A True value means the statement will execute its ThenScope of statements.
 A False value means the statement will execute its ElseScope of statements."""
        pass

    @Condition.setter
    def Condition(self, value : str) -> None:
        pass

    @property
    def ThenScope(self) -> vcScope:
        """Gets the scope of statements executed by the statement if Condition is true."""
        pass

    @property
    def ElseIfScopes(self) -> List[vcElseIfScope]:
        """Gets a list of ElseIfScopes in the statement."""
        pass

    @property
    def ElseScope(self) -> vcScope:
        """Gets the scope of statements executed by the statement if Condition is false."""
        pass

    def addElseIfScope(self: Any, index: int = ...) -> vcElseIfScope:
        """Adds vcElseIfScope to the statement and returns that scope.
 The default value of index is -1, so a new vcElseIfScope is inserted immediately before ElseScope."""
        pass

    def deleteElseIfScope(self: Any, scope: vcElseIfScope) -> None:
        """Deletes given scope from the statement."""
        pass


class vcIntegerSignal(vcSignal):
    """vcIntegerSignal is a signal that can send an integer value.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcIntegerSignal.htm"""

    @property
    def Value(self) -> int:
        """Defines the value of signal.
Setting this value does not trigger the OnSignal event unless you use the signal() method."""
        pass

    @Value.setter
    def Value(self, value : int) -> None:
        pass

    def signal(self: Any, value: int = ...) -> None:
        """Signals the current value of signal to all connected behaviors, thereby triggering the OnSignal event.
An optional value argument can be given to set the Value property of the signal."""
        pass


class vcIntegerSignalMap(vcBehaviour):
    """vcIntegerSignalMap allows you to map Integer signals to ports in a continuous IO space.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcIntegerSignalMap.htm"""

    @property
    def Listeners(self) -> List[vcBehaviour]:
        """Defines a list of behaviors using the signal map."""
        pass

    @Listeners.setter
    def Listeners(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def PortCount(self) -> int:
        """Defines the amount of ports in signal map."""
        pass

    @PortCount.setter
    def PortCount(self, value : int) -> None:
        pass

    def getPortName(self: Any, index: int) -> str:
        """Returns the name of a port at a given index in map."""
        pass

    def input(self: Any, index: int) -> int:
        """Returns the value of a port at a given index in map."""
        pass

    def output(self: Any, index: int, value: int) -> None:
        """Sets the value of a port at a given index to a given value in map."""
        pass

    def setPortName(self: Any, index: int, name: str) -> None:
        """Sets the name of a port at a given index to a given name in map."""
        pass

    OnSignalTrigger : Callable[[vcIntegerSignalMap, int], None]
    """Triggered when the value of a signal mapped to a port has a new value."""



class vcInterpolatingTransportController(vcContainer):
    """System transport controller that does linear interpolation of product position and orientation in a set amount of time. Supports (practically) unlimited number of parallel transport operations..
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcInterpolatingTransportController.htm"""

    @property
    def IsSystem(self) -> bool:
        """Always returns True"""
        pass


class vcJacobian(vcObject):
    """vcJacobian allows you to calculate inverse and forward kinematics solutions. For example, you can solve for joint values of a robot at a given position.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcJacobian.htm"""

    @property
    def ForwardKin(self) -> Callable[[], None]:
        """Defines the function for forward kinematics calculation.
 If None, uses built-in method."""
        pass

    @ForwardKin.setter
    def ForwardKin(self, value : Callable[[], None]) -> None:
        pass

    @property
    def FractionalStep(self) -> float:
        """Defines the fractional step of calculation.
 The default value is 0.5."""
        pass

    @FractionalStep.setter
    def FractionalStep(self, value : float) -> None:
        pass

    @property
    def IgnoreOrientation(self) -> bool:
        """Turns on/off the calculation of orientation.
 The default value is False in which orientation is calculated for solution.
 Generally, a True value would be used when orientation is not important, for example with Cartesian robots."""
        pass

    @IgnoreOrientation.setter
    def IgnoreOrientation(self, value : bool) -> None:
        pass

    @property
    def JacobianJointCount(self) -> int:
        """Defines the number of joints in calculation."""
        pass

    @JacobianJointCount.setter
    def JacobianJointCount(self, value : int) -> None:
        pass

    @property
    def NumIterationsInner(self) -> int:
        """Defines the number of iterations for calculating inner product."""
        pass

    @NumIterationsInner.setter
    def NumIterationsInner(self, value : int) -> None:
        pass

    @property
    def NumIterationsOuter(self) -> int:
        """Defines the number of iterations for calculating outer product."""
        pass

    @NumIterationsOuter.setter
    def NumIterationsOuter(self, value : int) -> None:
        pass

    @property
    def OrientationMaxStep(self) -> float:
        """Defines the max step for orientation in calculation."""
        pass

    @OrientationMaxStep.setter
    def OrientationMaxStep(self, value : float) -> None:
        pass

    @property
    def OrientationTolerance(self) -> float:
        """Defines the tolerance for orientation in calculation."""
        pass

    @OrientationTolerance.setter
    def OrientationTolerance(self, value : float) -> None:
        pass

    @property
    def PositionalMaxStep(self) -> float:
        """Defines the max step for position in calculation."""
        pass

    @PositionalMaxStep.setter
    def PositionalMaxStep(self, value : float) -> None:
        pass

    @property
    def PositionalTolerance(self) -> float:
        """Defines the tolerance for position in calculation."""
        pass

    @PositionalTolerance.setter
    def PositionalTolerance(self, value : float) -> None:
        pass

    @property
    def RotationalJointStepSize(self) -> float:
        """Defines the step for rotational joint values in calculation."""
        pass

    @RotationalJointStepSize.setter
    def RotationalJointStepSize(self, value : float) -> None:
        pass

    def inverse(self: Any, target: vcMatrix, values: List[float], fixed: List[bool] = ...) -> Tuple[List[float], int]:
        """Calculates the joint values of robot for a given target and list of joint values.
 An optional fixed argument can be given to identify fixed joints in the robot.
 The returned value will identify joint values of robot and status of solution to target.
 See Solution Constants for more information."""
        pass


class vcJogInfo(vcBehaviour):
    """vcJogInfo is an event listener for an interactive object defined by Jog Info behavior.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcJogInfo.htm"""

    OnInteract : Callable[[vcBehaviour, int, List[Tuple[int, int, bool, int, int, vcVector, vcVector, vcVector, vcVector]]], None]
    """Triggered when user interaction occurs with an object defined by a Jog Info behavior.
 The type argument is the Jog Info behavior of the object.
 The cursor_action argument is the type of mouse action that occurs in the jog area.
 0
 Hover in.
 1
 Click or drag
 2
 Hover out
 The data argument provides a list of jog info that includes command event data and XY coordinates (in pixels) where interaction occurs on the viewport."""



class vcJoint(vcObject):
    """vcJoint is a joint that can be defined using kinematics, driven by controllers and affected by physics.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcJoint.htm"""

    @property
    def Controller(self) -> Union[vcRobotController, vcServoController]:
        """Gets the controller of joint.
 If joint is not driven by controller, value is None."""
        pass

    @property
    def CurrentValue(self) -> float:
        """Defines the joint's value."""
        pass

    @CurrentValue.setter
    def CurrentValue(self, value : float) -> None:
        pass

    @property
    def Dof(self) -> vcDof:
        """Gets the Dof object of joint."""
        pass

    @property
    def ExternalController(self) -> Union[vcRobotController, vcServoController]:
        """Gets the external controller of joint.
 If joint is not driven by an external controller, value is None."""
        pass

    @property
    def InitialValue(self) -> float:
        """Defines the initial value of joint. That is, the initial state of the joint."""
        pass

    @InitialValue.setter
    def InitialValue(self, value : float) -> None:
        pass

    @property
    def LagTime(self) -> float:
        """Defines the lag time (in seconds) of joint."""
        pass

    @LagTime.setter
    def LagTime(self, value : float) -> None:
        pass

    @property
    def MaxAcceleration(self) -> float:
        """Defines the maximum acceleration (units/degrees per second squared) of joint."""
        pass

    @MaxAcceleration.setter
    def MaxAcceleration(self, value : float) -> None:
        pass

    @property
    def MaxDeceleration(self) -> float:
        """Defines the maximum deceleration (units/degrees per second squared) of joint."""
        pass

    @MaxDeceleration.setter
    def MaxDeceleration(self, value : float) -> None:
        pass

    @property
    def MaxSpeed(self) -> float:
        """Defines the maximum speed (units/degrees per second) of joint."""
        pass

    @MaxSpeed.setter
    def MaxSpeed(self, value : float) -> None:
        pass

    @property
    def MaxValue(self) -> str:
        """Defines an expression that when evaluated returns the maximum value of joint."""
        pass

    @MaxValue.setter
    def MaxValue(self, value : str) -> None:
        pass

    @property
    def MinValue(self) -> str:
        """Defines an expression that when evaluated returns the minimum value of joint."""
        pass

    @MinValue.setter
    def MinValue(self, value : str) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the joint's name."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def SettleTime(self) -> float:
        """Defines the settle time (in seconds) of joint."""
        pass

    @SettleTime.setter
    def SettleTime(self, value : float) -> None:
        pass

    @property
    def Type(self) -> int:
        """Defines the joint type.
 See Joint Constants for more information."""
        pass

    @Type.setter
    def Type(self, value : int) -> None:
        pass


class vcKinObject(vcObject):
    """vcKinObject stores custom kinematics data implemented by a user in a Python Kinematics behavior.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcKinObject.htm"""

    @property
    def CustomData(self) -> Any:
        """Defines an instance of a user-defined class, thereby allowing you to implement custom properties and methods for the kinematics object."""
        pass

    @CustomData.setter
    def CustomData(self, value : Any) -> None:
        pass

    @property
    def JointCount(self) -> int:
        """Gets the joint count of the kinematics object."""
        pass

    @property
    def JointMaxLimits(self) -> List[float]:
        """Gets the maximum value for each joint of the kinematics object."""
        pass

    @property
    def JointMinLimits(self) -> List[float]:
        """Gets the minimum value for each joint of the kinematics object."""
        pass

    @property
    def JointsRotational(self) -> List[bool]:
        """Gets the joint type for each joint of the kinematics object.
 A True value indicates a rotational joint."""
        pass

    @property
    def JointValues(self) -> List[float]:
        """Defines the joint values of the kinematics object."""
        pass

    @JointValues.setter
    def JointValues(self, value : List[float]) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets the dynamic properties of the kinematics object."""
        pass

    @property
    def SecondaryJointValues(self) -> List[float]:
        """Defines the external joint values of the kinematics object."""
        pass

    @SecondaryJointValues.setter
    def SecondaryJointValues(self, value : List[float]) -> None:
        pass

    @property
    def Solutions(self) -> List[Tuple]:
        """Defines a list of possible solutions for the kinematics object and its Target.
 Generally, the format of a solution is a configuration warning followed by joint values for the motion target.
 See Solution Constants for more information."""
        pass

    @Solutions.setter
    def Solutions(self, value : List[Tuple]) -> None:
        pass

    @property
    def Target(self) -> vcMatrix:
        """Defines the motion target of the kinematics object."""
        pass

    @Target.setter
    def Target(self, value : vcMatrix) -> None:
        pass

    def createJacobian(self: Any) -> vcJacobian:
        """Creates a new Jacobian matrix object for calculating inverse and forward kinematics solutions."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to the kinematics object.
 An optional constraints argument can be given to define constraints for the new property, which must be defined at the time of creation.
 See Property Constants for more information."""
        pass

    def getJointMoveDist(self: Any, index: int, value: float) -> float:
        """Returns the distance a joint at a given index must move in order to reach a given value."""
        pass

    def getJointMoveTo(self: Any, index: int, value: float) -> Tuple[bool, float]:
        """Indicates whether a joint at a given index can move to a given value.
 Returns True and the given value if joint can reach target. Otherwise, returns False and the amount exceeding the joint's limits."""
        pass

    def moveJointTo(self: Any, index: int, value: float) -> bool:
        """Drives a joint at a given index to a given value.
 Returns True if joint reached target; otherwise returns False."""
        pass


class vcLayer(vcObject):
    """vcLayer allows you to group objects in the 3D world into separate layers.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLayer.htm"""

    @property
    def Name(self) -> str:
        """Defines the name of layer."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Visibility(self) -> bool:
        """Turns on/off the visibility of layer and all of its objects."""
        pass

    @Visibility.setter
    def Visibility(self, value : bool) -> None:
        pass


class vcLayoutItem(vcObject):
    """vcLayoutItem is the basic implementation of all layout items.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLayoutItem.htm"""

    @property
    def IsPersistent(self) -> bool:
        """Defines if the item is saved with layout."""
        pass

    @IsPersistent.setter
    def IsPersistent(self, value : bool) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of item."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all properties for item."""
        pass

    @property
    def Type(self) -> str:
        """Defines the item type.
See Layout Item Constants for more information."""
        pass

    @Type.setter
    def Type(self, value : str) -> None:
        pass

    def update(self: Any) -> None:
        """Updates the item in its layout."""
        pass


class vcLayoutPackFolder(vcLayoutItem):
    """vcLayoutPackFolder is a layout item used for packing files with the current layout of the 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLayoutPackFolder.htm"""

    @property
    def PackFolder(self) -> vcPackFolder:
        """Gets the mechanism for attaching files to component."""
        pass


class vcLayoutPropertyList(vcLayoutItem):
    """vcLayoutPropertyList is a layout item used to add and edit a list of properties for a layout.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLayoutPropertyList.htm"""

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to the layout item.
An optional constraints argument can be given to define constraints for the new property, which must be defined at the time of creation.
See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property from the item."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property of the item that matches the given name; otherwise returns None."""
        pass


class vcLayoutSchemaPropertyList(vcLayoutItem):
    """vcLayoutSchemaPropertyList is a layout item and data structure used for handling large amounts of data.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLayoutSchemaPropertyList.htm"""

    @property
    def DataCount(self) -> int:
        """Gets the number of records in schema."""
        pass

    @property
    def FrameColorSchemaIndex(self) -> int:
        """Defines the index of schema property used for coloring frame.
 The schema property should be a vector data type."""
        pass

    @FrameColorSchemaIndex.setter
    def FrameColorSchemaIndex(self, value : int) -> None:
        pass

    @property
    def FrameDataSchemaIndex(self) -> int:
        """Defines the index of schema property used for positional data of record.
 Generally, the schema property is a matrix data type. The positional data is used for visualizing record as a Frame feature in 3D world."""
        pass

    @FrameDataSchemaIndex.setter
    def FrameDataSchemaIndex(self, value : int) -> None:
        pass

    @property
    def FrameNameColorSchemaIndex(self) -> int:
        """Defines the index of schema property used for coloring the label of frame.
 The schema property should be a vector data type."""
        pass

    @FrameNameColorSchemaIndex.setter
    def FrameNameColorSchemaIndex(self, value : int) -> None:
        pass

    @property
    def FrameNameSchemaIndex(self) -> int:
        """Defines the index of schema property used for labeling the Frame feature of record in 3D world.
 The schema property should be a string data type.
 The default is -1. This means the Frame feature of record will not be labeled with its custom name rather the number of record in schema."""
        pass

    @FrameNameSchemaIndex.setter
    def FrameNameSchemaIndex(self, value : int) -> None:
        pass

    @property
    def FrameNameVisibleSchemaIndex(self) -> int:
        """Defines the index of schema property used for controlling the visibility of label of record in 3D world.
 The schema property should be a Boolean data type.
 The default is -1. This means labels are visible."""
        pass

    @FrameNameVisibleSchemaIndex.setter
    def FrameNameVisibleSchemaIndex(self, value : int) -> None:
        pass

    @property
    def FrameVisibleSchemaIndex(self) -> int:
        """Defines the index of schema property used for controlling the visibility of Frame feature of record in 3D world.
 The schema property should be a Boolean data type.
 This also affects the visibility of label of record in 3D world."""
        pass

    @FrameVisibleSchemaIndex.setter
    def FrameVisibleSchemaIndex(self, value : int) -> None:
        pass

    @property
    def LineDisplaySchemaIndex(self) -> int:
        """Define the index of schema property used for the position of record in 3D world. This allows you to connect positions with a line generated in 3D world."""
        pass

    @LineDisplaySchemaIndex.setter
    def LineDisplaySchemaIndex(self, value : int) -> None:
        pass

    @property
    def Node(self) -> vcNode:
        """Defines a node the Frame features of records are attached to in 3D world.
 In some cases, this might be the simulation root node/World node. In other cases, this might be the root node of a workpiece."""
        pass

    @Node.setter
    def Node(self, value : vcNode) -> None:
        pass

    @property
    def PositionMatrix(self) -> vcMatrix:
        """Defines an offset for position of record in 3D world.
 The offset is based in coordinate system of Node property.
 Generally, an offset is applied to compensate for weld torch flares or to adjust position based on Z-axis direction of robot TCP."""
        pass

    @PositionMatrix.setter
    def PositionMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def SchemaProperties(self) -> List[vcProperty]:
        """Gets a list of all schema properties in the layout item.
 Note: This does not include data values for each record in the schema."""
        pass

    def clearSchema(self: Any) -> None:
        """Empties the schema, thereby removing all schema properties and setting the data count to zero."""
        pass

    def cloneSchemaObject(self: Any, from_dataindex: int, count: int, to_dataindex: int) -> bool:
        """Clones a set of records in a given range.
 The from_dataindex argument defines the first record in range. The count argument defines how many records to clone. The to_dataindex argument defines where to insert the copies.
 Warning: Currently, you cannot append cloned records to the end of the table. You must insert the copies before an existing record."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to the layout item.
 An optional constraints argument can be given to define constraints for the new property, which must be defined at the time of creation.
 See Property Constants for more information."""
        pass

    def createSchemaProperty(self: Any, type: int, name: str) -> vcProperty:
        """Adds a new schema property of a given type and name to the layout item.
 See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property of the layout item."""
        pass

    def deleteSchemaObject(self: Any, from_dataindex: int, count: int) -> None:
        """Deletes a set of records in a given range.
 The from_dataindex argument defines the first record in range. The count argument defines how many records to delete."""
        pass

    def deleteSchemaProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property that is a schema property of the layout item."""
        pass

    def getDataValue(self: Any, dataindex: int, itemindex: int) -> Any:
        """Returns the value of a data field at a given dataindex and itemindex."""
        pass

    def getDataValues(self: Any, dataindex: int) -> Tuple:
        """Returns the values of a record at a given dataindex."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property of the layout item that matches the given name; otherwise returns None."""
        pass

    def getSchemaProperty(self: Any, name: str) -> vcProperty:
        """Returns a schema property of the layout item that matches the given name; otherwise returns None."""
        pass

    def setDataValue(self: Any, dataindex: int, itemindex: int, value: Any) -> None:
        """Sets the value of a data field at a given dataindex and itemindex.
 The value argument must be a supported data type and match the type of the schema property; otherwise the data field will not reference the new value.
 Note: The value argument can be a vcProperty object, thereby the value of that property is passed to the data field."""
        pass

    def setDataValues(self: Any, dataindex: int, itemindex: int, values: Tuple) -> None:
        """Sets all values for schema properties of a record at a given dataindex.
 The values argument must be a tuple with the same amount of elements as there are schema properties. Each element's value must be a supported data type and match the type of the corresponding schema property; otherwise the data field will not reference the new value.
 Note: An element of a tuple given as the values argument can be a vcProperty object, thereby the value of that property is passed to the data field."""
        pass

    def updateData(self: Any, count: int) -> None:
        """Allocates the size of the schema to support a potential amount of elements/entries for schema properties based on the given count.
 Note: The allocation is optional as size is updated automatically based on number of entries."""
        pass


class vcLight(vcObject):
    """vcLight provides the ability to create and control lights in the 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLight.htm"""

    @property
    def ConstantAttenuation(self) -> float:
        """Defines the constant light attenuation of the light."""
        pass

    @ConstantAttenuation.setter
    def ConstantAttenuation(self, value : float) -> None:
        pass

    @property
    def Direction(self) -> vcVector:
        """Defines the direction of the light by using a vector."""
        pass

    @Direction.setter
    def Direction(self, value : vcVector) -> None:
        pass

    @property
    def Enabled(self) -> bool:
        """Turns on/off the use of the light."""
        pass

    @Enabled.setter
    def Enabled(self, value : bool) -> None:
        pass

    @property
    def Intensity(self) -> int:
        """Defines the light's intensity."""
        pass

    @Intensity.setter
    def Intensity(self, value : int) -> None:
        pass

    @property
    def LinearAttenuation(self) -> float:
        """Defines the linear light attenuation of the light."""
        pass

    @LinearAttenuation.setter
    def LinearAttenuation(self, value : float) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of light."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Position(self) -> vcVector:
        """Defines the position of the light in World coordinate system."""
        pass

    @Position.setter
    def Position(self, value : vcVector) -> None:
        pass

    @property
    def QuadraticAttenuation(self) -> float:
        """Defines the quadratic light attenuation of the light."""
        pass

    @QuadraticAttenuation.setter
    def QuadraticAttenuation(self, value : float) -> None:
        pass

    @property
    def SpotAngle(self) -> float:
        """Defines the angle of the light if its type is spot."""
        pass

    @SpotAngle.setter
    def SpotAngle(self, value : float) -> None:
        pass

    @property
    def SpotExponent(self) -> float:
        """Defines the exponent of the light if its type is spot."""
        pass

    @SpotExponent.setter
    def SpotExponent(self, value : float) -> None:
        pass

    @property
    def Type(self) -> int:
        """Defines the light type.
See Light Constants for more information."""
        pass

    @Type.setter
    def Type(self, value : int) -> None:
        pass


class vcLine(vcPrimitive):
    """vcLine is the object type for line and polyline primitives containing one or more points.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLine.htm"""

    @property
    def Points(self) -> List[vcPoint]:
        """Gets a list of all points in the line."""
        pass

    @property
    def PointCount(self) -> int:
        """Gets the amount of points in the line."""
        pass

    def getPoint(self: Any, index: int) -> vcLinePoint:
        """Returns a point at a given index in the line."""
        pass

    def addPoint(self: Any) -> None:
        """Adds a new point to the line."""
        pass

    def removePoint(self: Any, index: int) -> None:
        """Removes a point at a given index from the line."""
        pass

    def update(self: Any) -> None:
        """Updates the internal structure of the line."""
        pass


class vcLinePoint(vcPoint):
    """vcLinePoint is used to define points in lines.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLinePoint.htm"""

    @property
    def LineCount(self) -> int:
        """Gets the total number of lines using the point."""
        pass

    def getLine(self: Any, index: int) -> vcLine:
        """Returns a line using the point at a given index since a point may belong to more than one line."""
        pass


class vcLineSet(vcGeometrySet):
    """vcLineSet is a collection of line primitives and their points.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcLineSet.htm"""

    @property
    def Lines(self) -> List[vcLine]:
        """Gets a list of all lines in the set."""
        pass

    @property
    def Points(self) -> List[vcLinePoint]:
        """Gets a list of all points in the set."""
        pass

    @property
    def LineCount(self) -> int:
        """Gets the amount of lines in the set."""
        pass

    @property
    def LineWidth(self) -> int:
        """Defines the width (in pixels) of lines in the set."""
        pass

    @LineWidth.setter
    def LineWidth(self, value : int) -> None:
        pass

    @overload
    def createPoint(self: Any, x: float, y: float, z: float) -> vcLinePoint:
        """Creates a new point in the set at a given vector or XYZ coordinates, and then returns the point; otherwise returns None."""
        pass

    @overload
    def createPoint(self: Any, vector: vcVector) -> vcLinePoint:
        """Creates a new point in the set at a given vector or XYZ coordinates, and then returns the point; otherwise returns None."""
        pass

    def createLine(self: Any) -> vcLine:
        """Creates a new line in the set, and then returns the new line."""
        pass

    @overload
    def deleteLine(self: Any, index: int) -> None:
        """Deletes a given line from the set or one at a given index."""
        pass

    @overload
    def deleteLine(self: Any, line: vcLine) -> None:
        """Deletes a given line from the set or one at a given index."""
        pass

    def getLine(self: Any, index: int) -> vcLine:
        """Gets a line in the set at a given index."""
        pass

    def update(self: Any) -> None:
        """Updates the line set, thereby recalculating the bound box of the set."""
        pass


class vcMaterial(vcObject):
    """vcMaterial is a material used by geometry and solid shapes in the 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcMaterial.htm"""

    @property
    def Ambient(self) -> vcVector:
        """Defines a vector used for calculating the ambient value of material."""
        pass

    @Ambient.setter
    def Ambient(self, value : vcVector) -> None:
        pass

    @property
    def ColorMask(self) -> int:
        """Defines the RGB/RGBA color mask used for rendering material.
 See Material Constants for more information."""
        pass

    @ColorMask.setter
    def ColorMask(self, value : int) -> None:
        pass

    @property
    def DepthComparison(self) -> int:
        """Controls the visibility of geometry assigned the material based on pixel depth (distance from camera) in comparison to a Z-axis buffer.
 Depth comparison is important for defining how a material is rendered in terms of elevation and depth and its interference with other materials.
 See Material Constants for more information."""
        pass

    @DepthComparison.setter
    def DepthComparison(self, value : int) -> None:
        pass

    @property
    def Diffuse(self) -> vcVector:
        """Defines a vector used for calculating diffuse reflection of light hitting material."""
        pass

    @Diffuse.setter
    def Diffuse(self, value : vcVector) -> None:
        pass

    @property
    def LineStippling(self) -> bool:
        """Turns on/off the use of stippling in the material to create light and dark shades based on point density."""
        pass

    @LineStippling.setter
    def LineStippling(self, value : bool) -> None:
        pass

    @property
    def LineWidth(self) -> float:
        """Defines the width of line primitives used for stippling."""
        pass

    @LineWidth.setter
    def LineWidth(self, value : float) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of material."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Opacity(self) -> float:
        """Defines the material's opacity, thereby its transparency."""
        pass

    @Opacity.setter
    def Opacity(self, value : float) -> None:
        pass

    @property
    def OpacityType(self) -> int:
        """Defines the opacity type used by material.
 See Material Constants for more information."""
        pass

    @OpacityType.setter
    def OpacityType(self, value : int) -> None:
        pass

    @property
    def RenderOrder(self) -> int:
        """Defines the order in which geometry using this material is rendered in 3D world.
 See Material Constants for more information."""
        pass

    @RenderOrder.setter
    def RenderOrder(self, value : int) -> None:
        pass

    @property
    def Shininess(self) -> float:
        """Defines the intensity of light reflected from material, thereby defining its luster."""
        pass

    @Shininess.setter
    def Shininess(self, value : float) -> None:
        pass

    @property
    def Specular(self) -> vcVector:
        """Defines a vector used for calculating specular reflection of light hitting material."""
        pass

    @Specular.setter
    def Specular(self, value : vcVector) -> None:
        pass

    @property
    def StipplingPattern(self) -> int:
        """Defines the stippling pattern of material based on the bits of an integer."""
        pass

    @StipplingPattern.setter
    def StipplingPattern(self, value : int) -> None:
        pass

    @property
    def StipplingScale(self) -> int:
        """Defines scale factor of the material's stippling pattern which, by default, is 1."""
        pass

    @StipplingScale.setter
    def StipplingScale(self, value : int) -> None:
        pass

    @property
    def Texture(self) -> vcBitmap:
        """Gets a bitmap defining the texture of material."""
        pass

    @Texture.setter
    def Texture(self, value : vcBitmap) -> None:
        pass

    @property
    def TextureMapping(self) -> int:
        """Defines how the material's texture is projected or defined using coordinates.
 See Material Constants for more information."""
        pass

    @TextureMapping.setter
    def TextureMapping(self, value : int) -> None:
        pass


class vcMatrix(vcObject):
    """vcMatrix is a 4x4 matrix and is generally used to perform linear transformations and contain the position and orientation of objects.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcMatrix.htm"""

    @property
    def N(self) -> vcVector:
        """Defines Normal vector that is unit vector in X-axis direction."""
        pass

    @N.setter
    def N(self, value : vcVector) -> None:
        pass

    @property
    def O(self) -> vcVector:
        """Defines Orientation vector that is unit vector in Y-axis direction."""
        pass

    @O.setter
    def O(self, value : vcVector) -> None:
        pass

    @property
    def A(self) -> vcVector:
        """Defines Approach vector that is unit vector in Z-axis direction."""
        pass

    @A.setter
    def A(self, value : vcVector) -> None:
        pass

    @property
    def P(self) -> vcVector:
        """Defines Position vector."""
        pass

    @P.setter
    def P(self, value : vcVector) -> None:
        pass

    @property
    def WPR(self) -> vcVector:
        """Defines roll, pitch and yaw angles."""
        pass

    @WPR.setter
    def WPR(self, value : vcVector) -> None:
        pass

    def __mul__(self: Any, other: vcMatrix) -> vcMatrix:
        """Performs matrix multiplication with another vcMatrix object or transforms a vcVector object. If the multiplier is a vcVector object, the product will be a vcVector object."""
        pass

    def getAxisAngle(self: Any) -> vcVector:
        """Returns the orientation of the matrix as a rotation of its identity matrix about the axis defined by the XYZ values of the returned vector.
 The W property of the returned vector is the rotation angle (in degrees)."""
        pass

    def getEuler(self: Any) -> vcVector:
        """Returns the orientation of the matrix as a set of absolute rotations (in fixed coordinate system) around the Z-axis, followed by the Y-axis, and then again the Z-axis, in the form of a vector containing those angles (in degrees)."""
        pass

    def getQuaternion(self: Any) -> vcVector:
        """Returns the orientation of the matrix as a quaternion in the form of a vector."""
        pass

    def getWPR(self: Any) -> vcVector:
        """Returns the orientation of the matrix as a set of relative rotations around ZYX axes, in that order, in the form of a vector containing those angles (in degrees)."""
        pass

    def identity(self: Any) -> None:
        """Sets matrix to equal its identity."""
        pass

    def invert(self: Any) -> None:
        """Sets the matrix to equal its inverse."""
        pass

    def rotateAbsX(self: Any, value: float) -> None:
        """Rotates the matrix around X-axis in absolute coordinate system."""
        pass

    def rotateAbsY(self: Any, value: float) -> None:
        """Rotates the matrix around Y-axis in absolute coordinate system."""
        pass

    def rotateAbsZ(self: Any, value: float) -> None:
        """Rotates the matrix around Z-axis in absolute coordinate system."""
        pass

    def rotateAbsV(self: Any, v: vcVector, angle: float) -> None:
        """Rotates the matrix around an axis defined by a given vector by a given angle in absolute coordinate system."""
        pass

    def rotateRelX(self: Any, value: float) -> None:
        """Rotates the matrix around X-axis in coordinate system relative to matrix position."""
        pass

    def rotateRelY(self: Any, value: float) -> None:
        """Rotate the matrix around Y-axis in coordinate system relative to matrix position."""
        pass

    def rotateRelZ(self: Any, value: float) -> None:
        """Rotates the matrix around Z-axis in coordinate system relative to matrix position."""
        pass

    def rotateRelV(self: Any, v: vcVector, angle: float) -> None:
        """Rotates the matrix around an axis defined by a given vector by a given angle in coordinate system relative to matrix position."""
        pass

    def scaleAbs(self: Any, x: float, y: float, z: float) -> None:
        """Scales the matrix in relation to 3D world origin."""
        pass

    def scaleRel(self: Any, x: float, y: float, z: float) -> None:
        """Scales the matrix in relation to matrix position."""
        pass

    def setAxisAngle(self: Any, x: float, y: float, z: float, w: float) -> None:
        """Rotates the matrix around an axis.
 The x, y and z arguments define a unit vector and direction of axis. The w argument defines the rotation (in degrees) around that axis."""
        pass

    def setEuler(self: Any, x: float, y: float, z: float) -> None:
        """Sets the orientation of the matrix by executing a set of absolute rotations (in degrees) around Z-axis, followed by Y-axis, and then around Z-axis in fixed coordinate system."""
        pass

    def setIJK(self: Any, i: float, j: float, k: float) -> None:
        """Sets the orientation of the matrix so that its Approach vector (Z-axis) is aligned with a vector defined by i, j and k arguments."""
        pass

    def setQuaternion(self: Any, q1: float, q2: float, q3: float, q4: float) -> None:
        """Sets the orientation of the matrix by using a quaternion defined by four given arguments."""
        pass

    def setWPR(self: Any, yaw: float, pitch: float, roll: float) -> None:
        """Sets the orientation of the matrix by using roll, pitch and yaw arguments."""
        pass

    def translateAbs(self: Any, x: float, y: float, z: float) -> None:
        """Translates the matrix position by a given offset (XYZ values) in reference (Parent) coordinate system. Parent can be for example the World or a Node."""
        pass

    def translateRel(self: Any, x: float, y: float, z: float) -> None:
        """Translates the matrix position by a given offset (XYZ values) in Object coordinate system."""
        pass

    def uniform(self: Any) -> None:
        """Modifies the matrix to be orthogonal and contain no scaling."""
        pass


class vcMatrixSignal(vcSignal):
    """vcMatrixSignal is a signal that can send a 4x4 vcMatrix object.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcMatrixSignal.htm"""

    @property
    def Value(self) -> vcMatrix:
        """Defines the value of signal.
Setting this value does not trigger the OnSignal event unless you use the signal() method."""
        pass

    @Value.setter
    def Value(self, value : vcMatrix) -> None:
        pass

    def signal(self: Any, value: vcMatrix = ...) -> None:
        """Signals the current value of signal to all connected behaviors, thereby triggering the OnSignal event.
An optional value argument can be given to set the Value property of the signal."""
        pass


class vcMotionInterpolator(vcObject):
    """vcMotionInterpolator is used by a robot to interpolate motion targets and joint values.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcMotionInterpolator.htm"""

    @property
    def DefaultTargetMode(self) -> int:
        """Defines the relationship between motion targets and robot.
See Motion Target Constants for more information."""
        pass

    @DefaultTargetMode.setter
    def DefaultTargetMode(self, value : int) -> None:
        pass

    @property
    def Targets(self) -> List[vcMotionTarget]:
        """Lists all motion targets in the interpolator."""
        pass

    @Targets.setter
    def Targets(self, value : List[vcMotionTarget]) -> None:
        pass

    def createTarget(self: Any, target: vcMatrix = ..., motiontype: int = ..., speed: float = ..., accuracy: float = ...) -> vcMotionTarget:
        """Adds a new motion target to the interpolator using either the robot's current posture or given arguments.
If motiontype argument is VC_MOTIONTARGET_MT_LINEAR, speed argument defines CartesianSpeed (mm/s) property of motion target.
If motiontype argument is VC_MOTIONTARGET_MT_JOINT, speed argument defines JointSpeedFactor (mm/s) property of motion target.
See vcRslMotionStatement and vcMotionTarget for more information."""
        pass

    def getCycleTimeAtTarget(self: Any, index: int) -> float:
        """Returns the cycle time of a motion target at a given index in interpolator's Targets property."""
        pass

    def interpolate(self: Any, cycletime: float) -> vcMotionTarget:
        """Returns an interpolated motion target based on a given cycletime."""
        pass


class vcMotionPath(vcContainer):
    """vcMotionPath is a wrapper class for One Way Path and Two Way Path behaviors.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcMotionPath.htm"""

    @property
    def Acceleration(self) -> float:
        """Defines rate of acceleration (mm/s^2) for components moving on path.
 If zero, acceleration is not calculated."""
        pass

    @Acceleration.setter
    def Acceleration(self, value : float) -> None:
        pass

    @property
    def Accumulate(self) -> bool:
        """Turns on/off pile-up of components moving on path.
 If True, components on the path stop moving when they encounter a blocked component. If False, components on the path stop moving when a component is blocked from exiting the path."""
        pass

    @Accumulate.setter
    def Accumulate(self, value : bool) -> None:
        pass

    @property
    def Deceleration(self) -> float:
        """Defines rate of deceleration (mm/s^2) for components moving on path.
 If zero, deceleration is not calculated."""
        pass

    @Deceleration.setter
    def Deceleration(self, value : float) -> None:
        pass

    @property
    def DetailCurveMotion(self) -> bool:
        """Turns on/off detailed movement of components to and from path, for example when moving from linear path to curved path.
 If True, bound box of component is used to avoid intersecting with other components. This might create a gap between components, for example components that are cylindrical. This also decreases simulation performance.
 You can disable DetailCurveMotion if components are cylindrical or if a slight intersection between components when transferring from linear to curved path is not a concern."""
        pass

    @DetailCurveMotion.setter
    def DetailCurveMotion(self, value : bool) -> None:
        pass

    @property
    def Direction(self) -> int:
        """Defines the direction components move on path, but only if the path supports two or more directions.
 See Conveyor Direction Constants for more information."""
        pass

    @Direction.setter
    def Direction(self, value : int) -> None:
        pass

    @property
    def FastScheduling(self) -> bool:
        """Turns on/off the optimization of moving components on the path.
 If True, the path limits the amount of generated events, thereby improving simulation performance.
 If False, the path moves components at shorter increments, thereby increasing the amount of events and decreasing simulation performance."""
        pass

    @FastScheduling.setter
    def FastScheduling(self, value : bool) -> None:
        pass

    @property
    def Interpolation(self) -> int:
        """Defines mode used by path to interpolate its waypoints set in Path property.
 See Conveyor Interpolation Mode Constants for more information."""
        pass

    @Interpolation.setter
    def Interpolation(self, value : int) -> None:
        pass

    @property
    def Path(self) -> List[vcFeature]:
        """Defines an ordered list of Frame features referenced as waypoints of path.
 If set, path is calculated based on its interpolation mode."""
        pass

    @Path.setter
    def Path(self, value : List[vcFeature]) -> None:
        pass

    @property
    def PathAxis(self) -> int:
        """Defines mode for calculating how much space a component occupies on path, thereby allowing the path to utilize its space and determine if one or more components are blocked if SpaceUtilization property is set to True.
 See Path Axis Mode Constants for more information."""
        pass

    @PathAxis.setter
    def PathAxis(self, value : int) -> None:
        pass

    @property
    def PathLength(self) -> float:
        """Gets the length of path. That is, the distance from first to last waypoint along the path."""
        pass

    @property
    def RetainOffset(self) -> bool:
        """Defines if a component entering, placed or grabbed by the path is snapped to and aligned with path's axis.
 If True, a component retains its offset while moving on path. If False, component is snapped to nearest point on path and its origin is aligned with calculated path."""
        pass

    @RetainOffset.setter
    def RetainOffset(self, value : bool) -> None:
        pass

    @property
    def SegmentSize(self) -> float:
        """Defines the size of segments when path uses segmentation to move components to and from different sections of the path.
 If value is greater than zero, the number of path segments is calculated in order to determine the capacity of each segment based on total capacity of path. Therefore, components move on path based on the capacity of a proceeding segment."""
        pass

    @SegmentSize.setter
    def SegmentSize(self, value : float) -> None:
        pass

    @property
    def Sensors(self) -> List[vcBehaviour]:
        """List of sensors connected to path, which must be either component path or process point type sensors."""
        pass

    @Sensors.setter
    def Sensors(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def SpaceUtilization(self) -> bool:
        """Defines if components accumulating on path are kept separate from one another and how new components enter path.
 If False, components may overlap one another and/or pile up side by side, which might be useful if RetainOffset is set to True."""
        pass

    @SpaceUtilization.setter
    def SpaceUtilization(self, value : bool) -> None:
        pass

    @property
    def Speed(self) -> float:
        """Defines the speed (mm/s) of path."""
        pass

    @Speed.setter
    def Speed(self, value : float) -> None:
        pass

    OnMotionChanged : Callable[[vcComponent, int], None]
    """Triggered when the state of a component's motion changes on a path.
 If the state of a path is changed so that it affects the motion of all components on that path, this event is called for each of those components.
 See Path Motion State Constants for more information."""


    OnPhysicalTransition : Callable[[vcContainer, vcComponent, bool], None]
    """Triggered when either a) the leading edge of a component enters path or b) the trailing edge of a component exits path.
 The Container argument is the current container of the component given in the Component argument, which may not be the container of component at the time of the call since the component may have transitioned elsewhere.
 The arrive_leave argument is True if component is entering path; otherwise False means a component is exiting path."""



class vcMotionStatement(vcPositionStatement):
    """vcMotionStatement is an abstract class used for implementing motion type statements.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcMotionStatement.htm"""

    @property
    def AccuracyMethod(self) -> int:
        """Defines the zone of accuracy type to use for the target, for example distance, time or velocity.
See Motion Target Constants for more information."""
        pass

    @AccuracyMethod.setter
    def AccuracyMethod(self, value : int) -> None:
        pass

    @property
    def AccuracyValue(self) -> float:
        """Defines the limit used in AccuracyMethod."""
        pass

    @AccuracyValue.setter
    def AccuracyValue(self, value : float) -> None:
        pass

    @property
    def Base(self) -> vcBaseFrame:
        """Defines the base frame used by robot for the statement."""
        pass

    @Base.setter
    def Base(self, value : vcBaseFrame) -> None:
        pass

    @property
    def CycleTime(self) -> float:
        """Defines the total elapsed time (in seconds) for executing motion statement, which may scale speed and acceleration of joints.
If zero, CycleTime is ignored."""
        pass

    @CycleTime.setter
    def CycleTime(self, value : float) -> None:
        pass

    @property
    def ExternalTCP(self) -> bool:
        """Defines the interpolation mode for targeting motion.
0 = False
Default setting that uses Base to Tool configuration; position created at tool frame.
1 = True
Interpolation from Tool to Base; position created at base frame."""
        pass

    @ExternalTCP.setter
    def ExternalTCP(self, value : bool) -> None:
        pass

    @property
    def Tool(self) -> vcBaseFrame:
        """Defines the tool frame used by robot for the statement."""
        pass

    @Tool.setter
    def Tool(self, value : vcBaseFrame) -> None:
        pass

    @property
    def Acceleration(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum Cartesian acceleration of motion (units/s^2) used to calculate target trajectory."""
        pass

    @Acceleration.setter
    def Acceleration(self, value : float) -> None:
        pass

    @property
    def AngularAcceleration(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum angular acceleration of motion (degrees/s^2) used to calculate target trajectory."""
        pass

    @AngularAcceleration.setter
    def AngularAcceleration(self, value : float) -> None:
        pass

    @property
    def AngularDeceleration(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum angular deceleration of motion (degrees/s^2) used to calculate target trajectory."""
        pass

    @AngularDeceleration.setter
    def AngularDeceleration(self, value : float) -> None:
        pass

    @property
    def ConfigurationMode(self) -> int:
        """This property exist only in: Linear Motion.
Defines the configuration mode for joints driven by robot controller during linear motion interpolation.
0 = Fixed
No change. That is, current configuration is used and does not change.
1 = Follow frame
Configuration closest to previous joint values is used.
2 = Interpolate joint values
Configuration is determined by point-to-point interpolation of joint values.
See Motion Target Constants for more information."""
        pass

    @ConfigurationMode.setter
    def ConfigurationMode(self, value : int) -> None:
        pass

    @property
    def Deceleration(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum Cartesian deceleration of motion (units/s^2) used to calculate target trajectory."""
        pass

    @Deceleration.setter
    def Deceleration(self, value : float) -> None:
        pass

    @property
    def MaxAngularSpeed(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum angular speed (degrees/s^2) used to calculate target trajectory."""
        pass

    @MaxAngularSpeed.setter
    def MaxAngularSpeed(self, value : float) -> None:
        pass

    @property
    def MaxSpeed(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum Cartesian speed (units/s) used to calculate target trajectory."""
        pass

    @MaxSpeed.setter
    def MaxSpeed(self, value : float) -> None:
        pass

    @property
    def OrientationInterpolationMode(self) -> int:
        """This property exist only in: Linear Motion.
Defines the orientation interpolation mode for linear movement.
See Orientation Interpolation Mode Constants for more information."""
        pass

    @OrientationInterpolationMode.setter
    def OrientationInterpolationMode(self, value : int) -> None:
        pass

    @property
    def JointForce(self) -> float:
        """This property exist only in: Point-to-Point Motion.
Defines the percentage of joint acceleration and deceleration values to use in statement."""
        pass

    @JointForce.setter
    def JointForce(self, value : float) -> None:
        pass

    @property
    def JointSpeed(self) -> float:
        """This property exist only in: Point-to-Point Motion.
Defines the maximum speed for joints driven by robot controller as a percentage of nominal joint speed."""
        pass

    @JointSpeed.setter
    def JointSpeed(self, value : float) -> None:
        pass

    def readIn(self: Any) -> None:
        """Initializes a declared motion statement to current state of controller.
For example, a robot arm is moved to a location, the location is recorded as a motion statement in the robot's program, and then the motion statement is defined by the current pose of robot.
In some cases, you would import positional data and record them as motion statements by driving robot to each position (target), creating a motion statement and calling readIn()."""
        pass

    def writeToTarget(self: Any, target: vcMotionTarget) -> None:
        """Updates a given target to match the motion of the statement.
For example, you adjust a robot motion, and then update its corresponding target that is known to the controller."""
        pass


class vcMotionTarget(vcObject):
    """vcMotionTarget is a motion target for a robot, which may include joint and tool behavior as well as speed and configuration settings for orientation solutions.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcMotionTarget.htm"""

    @property
    def AccuracyMethod(self) -> int:
        """Defines the zone of accuracy type to use for the target, for example distance, time or velocity.
 See Motion Target Constants for more information."""
        pass

    @AccuracyMethod.setter
    def AccuracyMethod(self, value : int) -> None:
        pass

    @property
    def AccuracyValue(self) -> float:
        """Defines the limit used in AccuracyMethod."""
        pass

    @AccuracyValue.setter
    def AccuracyValue(self, value : float) -> None:
        pass

    @property
    def AngularSpeed(self) -> float:
        """Defines the rate of target rotation (degrees/s), which is only used for non-joint motions."""
        pass

    @AngularSpeed.setter
    def AngularSpeed(self, value : float) -> None:
        pass

    @property
    def BaseMatrix(self) -> vcMatrix:
        """Defines a matrix referenced by the target as robot base frame. If set, this property overrides BaseName."""
        pass

    @BaseMatrix.setter
    def BaseMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def BaseName(self) -> str:
        """Defines base frame in robot controller referenced by the target."""
        pass

    @BaseName.setter
    def BaseName(self, value : str) -> None:
        pass

    @property
    def CartesianAcceleration(self) -> float:
        """Defines the maximum Cartesian acceleration (units/s^2) of linear motion to target."""
        pass

    @CartesianAcceleration.setter
    def CartesianAcceleration(self, value : float) -> None:
        pass

    @property
    def CartesianDeceleration(self) -> float:
        """Defines the maximum Cartesian deceleration (units/s^2) of linear motion to target."""
        pass

    @CartesianDeceleration.setter
    def CartesianDeceleration(self, value : float) -> None:
        pass

    @property
    def CartesianSpeed(self) -> float:
        """Defines the maximum Cartesian speed (units/s) of linear motion to target."""
        pass

    @CartesianSpeed.setter
    def CartesianSpeed(self, value : float) -> None:
        pass

    @property
    def ConfigCount(self) -> int:
        """Gets the number of available configurations in robot."""
        pass

    @property
    def ConfigurationMode(self) -> int:
        """Defines the robot's joint configuration during linear interpolation, which can be fixed, an attempt to maintain current configuration or one interpolated using joint values.
 See Motion Target Constants for more information."""
        pass

    @ConfigurationMode.setter
    def ConfigurationMode(self, value : int) -> None:
        pass

    @property
    def JointSpeedFactor(self) -> float:
        """Defines the joint speed at the target, as a factor of maximum speed determined in robot controller."""
        pass

    @JointSpeedFactor.setter
    def JointSpeedFactor(self, value : float) -> None:
        pass

    @property
    def JointTurnMode(self) -> int:
        """Defines the turn mode for joints in the target.
 The default mode is for joints to turn nearest within their set limits.
 See Motion Target Constants for more information."""
        pass

    @JointTurnMode.setter
    def JointTurnMode(self, value : int) -> None:
        pass

    @property
    def JointValues(self) -> List[float]:
        """Defines joints values of target if using joint interpolation.
 To read and write joint values, first get a handle for this property, edit the values of that handle, and then assign that handle as the value of this property.
 See Example. Edit joint values in motion target for more information."""
        pass

    @JointValues.setter
    def JointValues(self, value : List[float]) -> None:
        pass

    @property
    def MotionType(self) -> int:
        """Defines the motion type of the target, which is either linear or point-to-point/joint.
 See Motion Target Constants for more information."""
        pass

    @MotionType.setter
    def MotionType(self, value : int) -> None:
        pass

    @property
    def OrientationInterpolationMode(self) -> int:
        """Defines the orientation interpolation mode for linear movement.
 See Orientation Interpolation Mode Constants for more information."""
        pass

    @OrientationInterpolationMode.setter
    def OrientationInterpolationMode(self, value : int) -> None:
        pass

    @property
    def PositionerIndex(self) -> int:
        """Defines current positioner used by robot to reach target."""
        pass

    @PositionerIndex.setter
    def PositionerIndex(self, value : int) -> None:
        pass

    @property
    def RobotConfig(self) -> int:
        """Defines robot configuration at target, which is dependent on the kinematic structure."""
        pass

    @RobotConfig.setter
    def RobotConfig(self, value : int) -> None:
        pass

    @property
    def Target(self) -> vcMatrix:
        """Defines position matrix of target relative to its base frame or matrix."""
        pass

    @Target.setter
    def Target(self, value : vcMatrix) -> None:
        pass

    @property
    def TargetMode(self) -> int:
        """Defines how position matrix of target relates to robot.
 See Motion Target Constants for more information."""
        pass

    @TargetMode.setter
    def TargetMode(self, value : int) -> None:
        pass

    @property
    def ToolMatrix(self) -> vcMatrix:
        """Defines a matrix referenced by the target as the robot tool frame. If set, this property overrides ToolName."""
        pass

    @ToolMatrix.setter
    def ToolMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def ToolName(self) -> str:
        """Defines tool frame in robot referenced by target."""
        pass

    @ToolName.setter
    def ToolName(self, value : str) -> None:
        pass

    @property
    def UseJoints(self) -> bool:
        """Defines if JointValues property is used to define target or its Target property. That is, whether the target is defined using joint values or a position matrix that is used to calculate joint values.
 If you set JointValues, this property is automaticaly set to True.
 If you set Target, this property is automatically set to False."""
        pass

    @UseJoints.setter
    def UseJoints(self, value : bool) -> None:
        pass

    def getConfigWarning(self: Any, configuration: int) -> int:
        """Tests a robot configuration for any potential issues associated with target.
 The returned value indicates singularity (S), joint limits (J) and unreachable (U) errors using a format of SJU.
 0 = 000
 No errors.
 1 = 001
 Reachability error in robot.
 2 = 010
 One or more joints exceeding limits.
 3 = 011
 Reachability and joint limit errors.
 4 = 100
 Singularity detected, for example in articulated robot wrist.
 5 = 101
 Singularity and reachability errors.
 6 = 110
 Singularity and joint limit errors.
 7 = 111
 Singularity, joint limit and reachability errors.
 See Motion Target Constants for more information."""
        pass

    def getConfigWarnings(self: Any) -> List[int]:
        """Tests all configurations in kinematic structure for potentials errors related to target.
 See getConfigWarning() method for more information on possible returned values."""
        pass

    def getPositionerRootToPositionerFlange(self: Any) -> vcMatrix:
        """Returns the offset from robot positioner root node to its flange node."""
        pass

    def getRootNodeToPositionerRoot(self: Any) -> vcMatrix:
        """Returns the offset from root node to robot positioner root node."""
        pass

    def getRootNodeToRobotRoot(self: Any) -> vcMatrix:
        """Returns the offset from root node to robot root node."""
        pass

    def getRobotRootToRobotFlange(self: Any) -> vcMatrix:
        """Returns the offset from robot root node to robot flange node."""
        pass

    def getSimWorldToRootNode(self: Any) -> vcMatrix:
        """Returns the offset from 3D world origin to root node."""
        pass

    def getSimWorldToRobotTool(self: Any) -> vcMatrix:
        """Returns the offset from 3D world origin to tool frame active in robot."""
        pass

    def getSimWorldToRobotWorld(self: Any) -> vcMatrix:
        """Returns the offset from 3D world origin to Robot World Frame."""
        pass

    def getWorldToRootNode(self: Any) -> vcMatrix:
        """Returns the offset from 3D world origin to root node. (Deprecated)"""
        pass

    def getWorldToRobotTool(self: Any) -> vcMatrix:
        """Returns the offset from 3D world origin to tool frame active in robot. (Deprecated)"""
        pass


class vcNextProcessFlowInfo(vcObject):
    """NextFlowInfo indicates a direction (inexact location) in the product flow, with extra parameters (ForceExactFlowStep/ForceExactProcessGroup) to indicate how to evaluate this direction. Internally, it will be expanded into multiple FeedOptionFlowInfo objects, which in turn will be used for Feed-Need matching. Used in Product’s NextProcessFlowInfo.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcNextProcessFlowInfo.htm"""

    @property
    def FlowStep(self) -> vcProcessFlowStep:
        """Specifies ProcessFlowStep"""
        pass

    @FlowStep.setter
    def FlowStep(self, value : vcProcessFlowStep) -> None:
        pass

    @property
    def Group(self) -> vcProcessGroup:
        """Specifies ProcessGroup inside the FlowStep."""
        pass

    @Group.setter
    def Group(self, value : vcProcessGroup) -> None:
        pass

    @property
    def ForceExactFlowStep(self) -> bool:
        """Expansion into vcFeedOptionFlowInfo objects may result in multiple options with multiple FlowSteps (e.g., when given FlowStep is Optional).
 Setting this to True will filter the results to contain only the given FlowStep."""
        pass

    @ForceExactFlowStep.setter
    def ForceExactFlowStep(self, value : bool) -> None:
        pass

    @property
    def ForceExactProcessGroup(self) -> bool:
        """Expansion into vcFeedOptionFlowInfo objects may result in multiple options with multiple ProcessGroups (e.g., when given FlowStep contains multiple ProcessGroups).
 Setting this to True will filter the results to contain only the given ProcessGroup (based on GroupID)."""
        pass

    @ForceExactProcessGroup.setter
    def ForceExactProcessGroup(self, value : bool) -> None:
        pass


class vcNode(vcObject):
    """vcNode is the object type for nodes, which are used by components and other objects to form simple and complex tree structures.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcNode.htm"""

    @property
    def Behaviours(self) -> List[vcBehaviour]:
        """Gets a list of all behaviors in node."""
        pass

    @property
    def BoundCenter(self) -> vcVector:
        """Gets a vector from node origin to center of its geometry bound box."""
        pass

    @property
    def BoundDiagonal(self) -> vcVector:
        """Gets a vector from center of node's geometry bound box to its upper corner using positive axis directions."""
        pass

    @property
    def ChildComponents(self) -> List[vcComponent]:
        """Gets a list of all components attached to the node at any depth in structure."""
        pass

    @property
    def Children(self) -> List[vcNode]:
        """Gets a list of nodes attached to the node at first level. That is, the node is parent to those nodes."""
        pass

    @property
    def Component(self) -> vcComponent:
        """Gets the component of node."""
        pass

    @property
    def ComponentChildren(self) -> List[vcComponent]:
        """Gets a list of components attached to the node at first level. That is, the node is parent to those component root nodes."""
        pass

    @property
    def Dof(self) -> vcDof:
        """Gets the degree-of-freedom (DOF) object that defines the joint properties of the node and its mechanism of movement.
 If JointType is fixed, Dof will be assigned None."""
        pass

    @property
    def Geometry(self) -> vcGeometryContainer:
        """Gets the container of geometry in node.
 Geometry in container is result of evaluating node's feature tree, but can be manually set."""
        pass

    @property
    def IgnoreEvents(self) -> bool:
        """Defines if node ignores event passing in order to avoid the creation of cyclic calls."""
        pass

    @IgnoreEvents.setter
    def IgnoreEvents(self, value : bool) -> None:
        pass

    @property
    def InverseWorldPositionMatrix(self) -> vcMatrix:
        """Gets inverse of node's position matrix in World coordinate system.
 Note: Using World matrix requires scene updating."""
        pass

    @property
    def JointExpression(self) -> str:
        """Defines an expression that when evaluated returns the joint definition of the node.
 (Deprecated) Use vcNode.Dof.Joint if joint type is custom."""
        pass

    @JointExpression.setter
    def JointExpression(self, value : str) -> None:
        pass

    @property
    def JointType(self) -> int:
        """Defines the joint type of the node.
 See Joint Constants for more information."""
        pass

    @JointType.setter
    def JointType(self, value : int) -> None:
        pass

    @property
    def MaterialInheritance(self) -> int:
        """Defines the mode for managing NodeMaterial property.
 For example, node material could override feature materials and child nodes.
 See Node Constants for more information."""
        pass

    @MaterialInheritance.setter
    def MaterialInheritance(self, value : int) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the node's name."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def NodeMaterial(self) -> vcMaterial:
        """Defines the node's material.
 This property is used with MaterialInheritance to define how the node's material is assigned to its features and child nodes."""
        pass

    @NodeMaterial.setter
    def NodeMaterial(self, value : vcMaterial) -> None:
        pass

    @property
    def NodeVisible(self) -> bool:
        """Turns on/off the visibility of the node but not its child nodes."""
        pass

    @NodeVisible.setter
    def NodeVisible(self, value : bool) -> None:
        pass

    @property
    def Offset(self) -> str:
        """Defines an expression that when evaluated returns the offset of node."""
        pass

    @Offset.setter
    def Offset(self, value : str) -> None:
        pass

    @property
    def OffsetExpression(self) -> str:
        """Defines an expression that when evaluated returns node offset.
 (Deprecated) Use Offset property."""
        pass

    @OffsetExpression.setter
    def OffsetExpression(self, value : str) -> None:
        pass

    @property
    def Parent(self) -> vcNode:
        """Gets the parent node of this node."""
        pass

    @property
    def PivotExpression(self) -> str:
        """Defines an expression that when evaluated returns the pivot point definition of node.
 (Deprecated) Use vcNode.Dof.Pivot if joint type is custom."""
        pass

    @PivotExpression.setter
    def PivotExpression(self, value : str) -> None:
        pass

    @property
    def PositionMatrix(self) -> vcMatrix:
        """Defines position matrix of node in parent coordinate system."""
        pass

    @PositionMatrix.setter
    def PositionMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def RootFeature(self) -> vcFeature:
        """Gets the root feature of node."""
        pass

    @property
    def Type(self) -> int:
        """Gets the node's type, which identifies the node as either a simulation root node, component root node or a link in a component.
 See Node Constants for more information."""
        pass

    @property
    def UserGeometry(self) -> vcGeometryContainer:
        """Gets a container of geometry that is unique to the node. That is, the geometry of this container is never shared with other nodes."""
        pass

    @property
    def Visible(self) -> bool:
        """Turns on/off the visibility of the node and its child nodes."""
        pass

    @Visible.setter
    def Visible(self, value : bool) -> None:
        pass

    @property
    def World(self) -> vcNode:
        """Gets the 3D world/simulation root node."""
        pass

    @property
    def WorldPositionMatrix(self) -> vcMatrix:
        """Gets the position matrix of node in World coordinate system.
 Note: Using World matrix requires scene updating."""
        pass

    def attach(self: Any, node: vcNode, permanent: bool = ...) -> None:
        """Attaches a given node.
 The permanent argument is optional, and its value is set to True by default. If you set the value to False, the Save button in the Visual Components user interface will remain disabled when you attach the node.
 See Example. Attach a node to another node during a simulation for more information."""
        pass

    def createNode(self: Any, type: int, name: str) -> vcNode:
        """Creates a new child node of a given type and name for this node.
 This cannot be used to create a new 3D world root node.
 See Node Constants for more information."""
        pass

    def createBehaviour(self: Any, type: int, name: str) -> vcBehaviour:
        """Creates a new behavior of a given type and name in node.
 See Behavior Constants for more information."""
        pass

    def delete(self: Any) -> None:
        """Deletes the node.
 Deletion will fail if method is called in Python Script contained in the node."""
        pass

    def findBehaviour(self: Any, name: str) -> vcBehaviour:
        """Returns the first behavior matching a given name in node or in one of its child nodes; otherwise returns None."""
        pass

    def findBehavioursByType(self: Any, type: int) -> List[vcBehaviour]:
        """Returns a list of all behaviors matching a given type in node and all of its child nodes; otherwise returns an empty list.
 See Behavior Constants for more information."""
        pass

    def findFeature(self: Any, name: str) -> vcFeature:
        """Returns the first feature matching a given name in node or in one of its child nodes; otherwise returns None."""
        pass

    def findNode(self: Any, name: str) -> vcNode:
        """Returns the first child node matching a given name; otherwise returns None."""
        pass

    def getBehaviour(self: Any, name: str) -> vcBehaviour:
        """Returns the first behavior matching a given name in node; otherwise returns None."""
        pass

    def getBehavioursByType(self: Any, type: int) -> List[vcBehaviour]:
        """Returns a list of all behaviors matching a given type in the node; otherwise returns an empty list.
 See Behavior Constants for more information."""
        pass

    def getFeature(self: Any, name: str) -> vcFeature:
        """Returns the first feature matching a given name in node; otherwise returns None."""
        pass

    @overload
    def localToWorld(self: Any, matrix: vcMatrix) -> Union[vcMatrix, vcVector]:
        """Transforms the given matrix or vector from node’s coordinate system to the world coordinate system and returns that with a new instance."""
        pass

    @overload
    def localToWorld(self: Any, vector: vcVector) -> Union[vcMatrix, vcVector]:
        """Transforms the given matrix or vector from node’s coordinate system to the world coordinate system and returns that with a new instance."""
        pass

    @overload
    def measureDistance(self: Any, list: List[vcNode]) -> Tuple[float, vcVector, vcVector, vcVector]:
        """Returns the minimum distance between the geometry of this node and a node or a given list of nodes. Additional values returned are position vectors for the two closest points, point1 and point2, as well as a direction vector indicating the distance and direction from those points. If no minimum distance found, returns None. Note: The returned vector is based in the coordinate system of the node calling this method."""
        pass

    @overload
    def measureDistance(self: Any, tuple: Tuple) -> Tuple[float, vcVector, vcVector, vcVector]:
        """Returns the minimum distance between the geometry of this node and a node or a given list of nodes. Additional values returned are position vectors for the two closest points, point1 and point2, as well as a direction vector indicating the distance and direction from those points. If no minimum distance found, returns None. Note: The returned vector is based in the coordinate system of the node calling this method."""
        pass

    def rebuild(self: Any, rebuild_tree: int = ...) -> None:
        """Rebuilds the geometry of node and its hierarchy by re-evaluating their feature trees. The hierarchy contains child components. Note: Try to avoid using this method during a simulation."""
        pass

    def update(self: Any, update_tree: int = ...) -> None:
        """Updates the node and its hierarchy. The hierarchy contains child components."""
        pass

    @overload
    def worldToLocal(self: Any, matrix: vcMatrix) -> Union[vcMatrix, vcVector]:
        """Transforms the given matrix or vector from world coordinate system to the node’s local coordinate system and returns with a new instance."""
        pass

    @overload
    def worldToLocal(self: Any, vector: vcVector) -> Union[vcMatrix, vcVector]:
        """Transforms the given matrix or vector from world coordinate system to the node’s local coordinate system and returns with a new instance."""
        pass

    OnNodeTransform : Callable[[vcNode], None]
    """Triggered when a node is transformed in 3D world."""



class vcNodeList(vcBehaviour):
    """vcNodeList is a behavior type used to generate a filtered list of nodes.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcNodeList.htm"""

    @property
    def Nodes(self) -> List[Tuple[vcNode, int, int]]:
        """Defines a node and filters used to generate the list's content.
 See Collision Detector Constants for information about inclusion type and scope arguments."""
        pass

    @Nodes.setter
    def Nodes(self, value : List[Tuple[vcNode, int, int]]) -> None:
        pass

    @property
    def PureNodes(self) -> List[vcNode]:
        """Gets a list of unfiltered nodes in the list."""
        pass

    def getFilteredNodes(self: Any, node: vcNode = ...) -> List[vcNode]:
        """Returns a list of filtered nodes in the list."""
        pass


class vcObject:
    """vcObject is base class of all VC Python API objects.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcObject.htm"""

    @property
    def ObjectHash(self) -> int:
        """A non-unique hashing value for the underlying object."""
        pass

    @property
    def ObjectType(self) -> str:
        """Data type of this object."""
        pass


class vcObservableList(Generic[T], vcObject):
    """The vcObservableList<T> is practically a simple list/vector of elements of type T, with added OnListChanged event, that the user can subscribe to notice any changes to the list.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcObservableList_T_.htm"""

    @property
    def Owner(self) -> vcObject:
        """List owner. The type depends on context where the list is used."""
        pass

    @property
    def IsReadOnly(self) -> bool:
        """When true, the contents of this list cannot be changed."""
        pass

    def size(self: Any) -> int:
        """Returns number of contained elements"""
        pass

    def get(self: Any, index: int) -> T:
        """Returns element at index"""
        pass

    def insert(self: Any, index: int, object: T = ...) -> T:
        """Inserts element into the list.
 If called without the object argument, creates a new element in-place.
 If called with the object argument, inserts that object
 Returns the created or inserted object."""
        pass

    def indexOf(self: Any, object: T) -> int:
        """Returns object’s index, or -1, if not found."""
        pass

    def remove(self: Any, index: int) -> bool:
        """Returns True on successful removal, otherwise False."""
        pass

    def clear(self: Any) -> None:
        """Removes all contained elements from the container."""
        pass

    OnListChanged : Callable[[vcObservableList[T], int, T, T, int, int], None]
    """Single event handler for all list content change types.
 See Observable List constants for changeType values.
 Relevant parameters (T newItem, T oldItem, int newIndex, int oldIndex):
 
 VC_LIST_ADD: value, None, index -1
 VC_LIST_REMOVE: value, None, index, -1
 VC_LIST_REPLACE: newvalue, oldvalue, index, -1
 VC_LIST_RESET: None, None, -1, -1"""



class vcOneDirectionalPath(vcContainer):
    """Inherits: vcContainer
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcOneDirectionalPath.htm"""

    @property
    def Interpolation(self) -> int:
        """Defines the mode of interpolating the motion of components along the path.
 See Conveyor Interpolation Mode Constants for more information."""
        pass

    @Interpolation.setter
    def Interpolation(self, value : int) -> None:
        pass

    @property
    def Path(self) -> List[vcFeature]:
        """Defines an ordered list of Frame features that represent waypoints of the path."""
        pass

    @Path.setter
    def Path(self, value : List[vcFeature]) -> None:
        pass

    @property
    def RetainOffset(self) -> bool:
        """Defines if the location of a component is retained when the component is placed or transferred onto the path.
 A True value means a component is not snapped to the axis of the path defined by its waypoints."""
        pass

    @RetainOffset.setter
    def RetainOffset(self, value : bool) -> None:
        pass

    @property
    def Sensors(self) -> List[vcBehaviour]:
        """Defines a list of sensor type behaviors connected to the path.
 This type of path only supports Component Path and Process Point sensors."""
        pass

    @Sensors.setter
    def Sensors(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def Speed(self) -> float:
        """Defines the speed (mm/s) of the path."""
        pass

    @Speed.setter
    def Speed(self, value : float) -> None:
        pass


class vcPackFolder(vcObject):
    """vcPackFolder allows you to pack files with a VCMX file and extract them. Files are contained in a folder that is mapped to a layout or component. Generally, you would map a temporary folder that you want to save with a VCMX file, and then extract the folder and its contents when you open the VCMX file. This allows you to share a layout or component that contains other files, for example a CSV file of robot position data.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPackFolder.htm"""

    @property
    def PackFolderLocalPath(self) -> str:
        """Gets the file path of mapped folder."""
        pass

    @property
    def State(self) -> int:
        """Gets the state of mapped folder.
 0
 Undefined, no folder is mapped.
 1
 Defined, but folder is not mapped.
 2
 Folder is mapped."""
        pass

    def mapFolder(self: Any, uri: str = ...) -> None:
        """Maps a temporary folder generated by the application or an existing folder at the given uri which must be a file path.
 Files will be packed/extracted at the time of call."""
        pass

    def remapFolder(self: Any, uri: str) -> None:
        """Remaps a different folder.
 This will not override the other folder until you save the VCMX file. Files in the other folder will also not be deleted unless they were contained in a temporary folder generated by the application."""
        pass

    def rollbackFolder(self: Any) -> None:
        """Removes mapping to folder.
 Generally, this is used before you map a different folder."""
        pass


class vcPathObject(vcLayoutItem):
    """vcPathObject is a layout item used for creating and storing path object nodes and segments.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPathObject.htm"""

    @property
    def ActionNodeCount(self) -> int:
        """Gets the number of action nodes in path object."""
        pass

    @property
    def ActionNodeVisualization(self) -> vcFrameSetVisualization:
        """Gets the object controlling the visualization of action nodes in path object."""
        pass

    @property
    def MotionNodeCount(self) -> int:
        """Gets the number of motion nodes in path object."""
        pass

    @property
    def MotionNodeVisualization(self) -> vcFrameSetVisualization:
        """Gets the object controlling the visualization of motion nodes in path object."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of path object."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def ParameterNodeCount(self) -> int:
        """Gets the number of parameter nodes in path object."""
        pass

    @property
    def ParameterNodeVisualization(self) -> vcFrameSetVisualization:
        """Gets the object controlling the visualization of parameter nodes in path object."""
        pass

    @property
    def Persistent(self) -> int:
        """Defines if the path object is saved with a layout.
 If 0, path object is not saved with layout. If 1, path object is saved with layout."""
        pass

    @Persistent.setter
    def Persistent(self, value : int) -> None:
        pass

    @property
    def ReferenceNodeCount(self) -> int:
        """Gets the number of reference nodes in path object."""
        pass

    @property
    def ReferenceNodeVisualization(self) -> vcFrameSetVisualization:
        """Gets the object controlling the visualization of reference nodes in the path object."""
        pass

    @property
    def SegmentCount(self) -> int:
        """Gets the number of segments in the path object."""
        pass

    def clear(self: Any) -> None:
        """Removes all nodes and segments from path object."""
        pass

    def clearNodes(self: Any, type: int) -> None:
        """Removes all nodes of a given type from path object.
 See Path Object Constants for more information."""
        pass

    def clearSegments(self: Any) -> None:
        """Removes all segments from path object."""
        pass

    def createNode(self: Any, type: int, index: int = ...) -> Any:
        """Adds a new node of a given type to the path object, and then returns the new node.
 See Path Object Constants for more information."""
        pass

    def createSegment(self: Any, index: int) -> vcPathObjectSegment:
        """Adds a new segment to the path object at a given index, and then returns the new segment."""
        pass

    def deleteNode(self: Any, node: vcPathObjectNode) -> None:
        """Deletes a given node from path object."""
        pass

    @overload
    def deleteSegment(self: Any, segment: vcPathObjectSegment) -> None:
        """Deletes a given segment or one at a given index from the path object."""
        pass

    @overload
    def deleteSegment(self: Any, index: int) -> None:
        """Deletes a given segment or one at a given index from the path object."""
        pass

    def findNode(self: Any, name: str) -> Any:
        """Returns a node matching a given name in path object."""
        pass

    def findSegment(self: Any, logical_distance: float) -> vcPathObjectSegment:
        """Returns a segment at a given logical_distance in path object."""
        pass

    def getNode(self: Any, type: int, index: int) -> Any:
        """Returns a node of a given type at a given index in path object."""
        pass

    def getNodes(self: Any, type: int) -> List[Any]:
        """Returns a list of nodes of a given type in path object."""
        pass

    def getSegment(self: Any, index: int) -> vcPathObjectSegment:
        """Returns a segment at a given index in path object."""
        pass


class vcPathObjectActionNode(vcPathObjectNode):
    """vcPathObjectActionNode is a node describing an action and relevant data in path object.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPathObjectActionNode.htm"""

    @property
    def LogicalPosition(self) -> float:
        """Defines the distance of motion node in relation to length of its path object container."""
        pass

    @LogicalPosition.setter
    def LogicalPosition(self, value : float) -> None:
        pass

    @property
    def MotionNode(self) -> vcPathObjectMotionNode:
        """Defines motion node associated with the action node."""
        pass

    @MotionNode.setter
    def MotionNode(self, value : vcPathObjectMotionNode) -> None:
        pass

    @property
    def Offset(self) -> float:
        """Defines offset of action node from its referenced motion node."""
        pass

    @Offset.setter
    def Offset(self, value : float) -> None:
        pass


class vcPathObjectMotionNode(vcPathObjectNode):
    """vcPathObjectMotionNode is a node used to define the trajectory of a motion in path object.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPathObjectMotionNode.htm"""

    @property
    def LogicalPosition(self) -> float:
        """Defines the distance of motion node in relation to length of its path object container."""
        pass

    @LogicalPosition.setter
    def LogicalPosition(self, value : float) -> None:
        pass

    @property
    def PositionMatrix(self) -> vcMatrix:
        """Defines the position matrix of the node in World coordinate system or in relation to a defined reference node."""
        pass

    @PositionMatrix.setter
    def PositionMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def ReferenceNode(self) -> vcPathObjectReferenceNode:
        """Defines a reference node in path object used for defining location of parameter node."""
        pass

    @ReferenceNode.setter
    def ReferenceNode(self, value : vcPathObjectReferenceNode) -> None:
        pass


class vcPathObjectNode(vcObject):
    """vcPathObjectNode is the basic implementation for path object nodes.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPathObjectNode.htm"""

    @property
    def Name(self) -> str:
        """Defines the name of node."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def PathObject(self) -> vcPathObject:
        """Gets the path object container of the node."""
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all properties of the node."""
        pass

    @property
    def Type(self) -> int:
        """Gets the node type.
 See Path Object Constants for more information."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to the node.
 An optional constraints argument can be given to define the new property's constraints, which must be done at the time of creation.
 See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property from node."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns the first property matching a given name in the node; otherwise returns None."""
        pass


class vcPathObjectParameterNode(vcPathObjectNode):
    """vcPathObjectParameterNode is a node used to store any kind of data related to a location, for example calibration data, and is not part of a path object's trajectory.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPathObjectParameterNode.htm"""

    @property
    def PositionMatrix(self) -> vcMatrix:
        """Defines the position matrix of parameter node in World coordinate system or in relation to a reference node."""
        pass

    @PositionMatrix.setter
    def PositionMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def ReferenceNode(self) -> vcPathObjectReferenceNode:
        """Defines a reference node in path object used for defining location of parameter node."""
        pass

    @ReferenceNode.setter
    def ReferenceNode(self, value : vcPathObjectReferenceNode) -> None:
        pass


class vcPathObjectReferenceNode(vcPathObjectNode):
    """vcPathObjectReferenceNode is a node for defining the location of its path object relative to a node in 3D world or in reference to World coordinate system.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPathObjectReferenceNode.htm"""

    @property
    def Node(self) -> vcNode:
        """Defines a node the reference node is attached to in 3D world."""
        pass

    @Node.setter
    def Node(self, value : vcNode) -> None:
        pass

    @property
    def PositionMatrix(self) -> vcMatrix:
        """Defines the position matrix of reference node.
If Node has a set value, the position matrix will reference that node's coordinate system or else the World coordinate system."""
        pass

    @PositionMatrix.setter
    def PositionMatrix(self, value : vcMatrix) -> None:
        pass


class vcPathObjectSegment(vcObject):
    """vcPathObjectSegment is used for customizing the visualization of object trajectories between motion nodes.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPathObjectSegment.htm"""

    @property
    def BeginLogicalDistance(self) -> float:
        """Defines where the segment starts in relation to length of its path object container."""
        pass

    @BeginLogicalDistance.setter
    def BeginLogicalDistance(self, value : float) -> None:
        pass

    @property
    def EndLogicalDistance(self) -> float:
        """Defines where the segment ends in relation to its beginning distance in path object container."""
        pass

    @EndLogicalDistance.setter
    def EndLogicalDistance(self, value : float) -> None:
        pass

    @property
    def PatObject(self) -> vcPathObject:
        """Gets the path object container of segment."""
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all properties in segment."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to the segment.
 An optional constraints argument can be given to define the new property's constraints, which must be done at the time of creation.
 See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property from segment."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns the first property matching a given name in segment; otherwise returns None."""
        pass


class vcPathStatement(vcPositionStatement):
    """A vcPathStatement is a type of robot statement that can execute a set of positions. It allows you to manage a large amount of data used for robot motion planning.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPathStatement.htm"""

    @property
    def Base(self) -> vcBaseFrame:
        """Defines the base frame of the path statement."""
        pass

    @Base.setter
    def Base(self, value : vcBaseFrame) -> None:
        pass

    @property
    def FrameNameField(self) -> int:
        """Defines the index of schema property used for labeling position in 3D world.
 The schema property should be a string data type.
 The default is -1. This means the position will not be labeled with its custom name rather the number of position in path."""
        pass

    @FrameNameField.setter
    def FrameNameField(self, value : int) -> None:
        pass

    @property
    def FrameNameVisibleField(self) -> int:
        """Defines the index of schema property used for controlling the visibility of position label in 3D world.
 The schema property should be a Boolean data type.
 The default is -1. This means the labels are visible."""
        pass

    @FrameNameVisibleField.setter
    def FrameNameVisibleField(self, value : int) -> None:
        pass

    @property
    def ExternalTCP(self) -> bool:
        """Defines if external tcp mode is used for the path statement."""
        pass

    @ExternalTCP.setter
    def ExternalTCP(self, value : bool) -> None:
        pass

    @property
    def Positions(self) -> vcPositionFrameIterator:
        """Gets an iterator for positions in the path statement.
 Each position is of type vcSchemaPositionFrame."""
        pass

    @property
    def ProcessHandler(self) -> vcPythonProcessHandler:
        """Defines the process handler used by robot to execute path statement."""
        pass

    @ProcessHandler.setter
    def ProcessHandler(self, value : vcPythonProcessHandler) -> None:
        pass

    @property
    def SchemaProperties(self) -> List[vcProperty]:
        """Gets a list of schema properties for path statement.
 See "Schema Properties" section for more information."""
        pass

    @property
    def ShowReferenceFrames(self) -> bool:
        """Turns on/off visibility of positions marked as reference points."""
        pass

    @ShowReferenceFrames.setter
    def ShowReferenceFrames(self, value : bool) -> None:
        pass

    @property
    def Tool(self) -> vcBaseFrame:
        """Defines the tool frame of the path statement."""
        pass

    @Tool.setter
    def Tool(self, value : vcBaseFrame) -> None:
        pass

    @property
    def FrameVisible(self) -> bool:
        """This property exist only in: Default.
Turns on/off the visibility of the position in 3D world."""
        pass

    @FrameVisible.setter
    def FrameVisible(self, value : bool) -> None:
        pass

    @property
    def IsContinuous(self) -> bool:
        """This property exist only in: Default.
Defines if robot motion to and from position should be one continuous motion."""
        pass

    @IsContinuous.setter
    def IsContinuous(self, value : bool) -> None:
        pass

    @property
    def IsReference(self) -> bool:
        """This property exist only in: Default.
Indicates if position is used as reference for calculating adjustments to path positions."""
        pass

    @IsReference.setter
    def IsReference(self, value : bool) -> None:
        pass

    @property
    def LineColor(self) -> vcVector:
        """This property exist only in: Default.
Defines the color of line to position."""
        pass

    @LineColor.setter
    def LineColor(self, value : vcVector) -> None:
        pass

    @property
    def LineVisible(self) -> bool:
        """This property exist only in: Default.
Defines if line to position is visible in 3D world."""
        pass

    @LineVisible.setter
    def LineVisible(self, value : bool) -> None:
        pass

    @property
    def Position(self) -> vcMatrix:
        """This property exist only in: Default.
Defines the position matrix of position."""
        pass

    @Position.setter
    def Position(self, value : vcMatrix) -> None:
        pass

    @property
    def PositionStatus(self) -> int:
        """This property exist only in: Default.
Indicates the status of position, for example whether or not it is unreachable.
 Status is determined by three flags.
 1
 Reachable
 2
 Within joint limits of robot
 4
 No singularity
 The default is 7. The status is not updated automatically by application. You would need to manually test the position as a vcMotionTarget object and evaluate configuration warnings. The configuration warning and position status values are flipped, so a configuration warning of 0 would be a status of 7.
 If you do not modify LineColor, the color of position in 3D world will automatically be updated based on PositionStatus. For example, green is reachable and red is unreachable.
 See Configuration Warnings constants for more information or review the example in vcSchemaPositionFrame."""
        pass

    @PositionStatus.setter
    def PositionStatus(self, value : int) -> None:
        pass

    @property
    def Acceleration(self) -> float:
        """This property exist only in: Optional.
Defines the maximum Cartesian acceleration of motion (units/s^2) used to calculate target trajectory."""
        pass

    @Acceleration.setter
    def Acceleration(self, value : float) -> None:
        pass

    @property
    def AccuracyMethod(self) -> int:
        """This property exist only in: Optional.
Defines the zone of accuracy type to use for the position, for example distance, time or velocity.
 See Motion Target Constants for more information."""
        pass

    @AccuracyMethod.setter
    def AccuracyMethod(self, value : int) -> None:
        pass

    @property
    def AccuracyValue(self) -> float:
        """This property exist only in: Optional.
Defines the limit used in AccuracyMethod."""
        pass

    @AccuracyValue.setter
    def AccuracyValue(self, value : float) -> None:
        pass

    @property
    def AngularAcceleration(self) -> float:
        """This property exist only in: Optional.
Defines the maximum angular acceleration of motion (degrees/s^2) used to calculate target trajectory."""
        pass

    @AngularAcceleration.setter
    def AngularAcceleration(self, value : float) -> None:
        pass

    @property
    def AngularDeceleration(self) -> float:
        """This property exist only in: Optional.
Defines the maximum angular deceleration of motion (degrees/s^2) used to calculate target trajectory."""
        pass

    @AngularDeceleration.setter
    def AngularDeceleration(self, value : float) -> None:
        pass

    @property
    def Deceleration(self) -> float:
        """This property exist only in: Optional.
Defines the maximum Cartesian deceleration of motion (units/s^2) used to calculate target trajectory."""
        pass

    @Deceleration.setter
    def Deceleration(self, value : float) -> None:
        pass

    @property
    def MaxAngularSpeed(self) -> float:
        """This property exist only in: Optional.
Defines the maximum angular speed (degrees/s^2) used to calculate target trajectory."""
        pass

    @MaxAngularSpeed.setter
    def MaxAngularSpeed(self, value : float) -> None:
        pass

    @property
    def MaxSpeed(self) -> float:
        """This property exist only in: Optional.
Defines the maximum Cartesian speed (units/s) used to calculate target trajectory."""
        pass

    @MaxSpeed.setter
    def MaxSpeed(self, value : float) -> None:
        pass

    def addSchemaProperties(self: Any, properties: List[Any]) -> List[int]:
        """Adds a list of custom properties for each position in path statement, and then returns a list of indices for the added properties in SchemaProperties.
 The list should contain one or more value pairs Enumeration type, String name. Each pair defines a single property to add."""
        pass

    def beginBatchUpdate(self: Any, schema_size: int) -> None:
        """Sets the initial amount of schema database entries, for example 100 entries for 100 path positions. This is done to allocate enough memory for storing schema property values for each path position.
 Note: This method is required if there is no existing schema database. If the database exists, this is optional.
 Note: Using size value -1 doesn't allocate space for new schema items and doesn't reset current data. It only blocks notify events when items are updated between this call and EndBatchUpdate."""
        pass

    def clearPositions(self: Any) -> None:
        """Removes all positions from path statement, thereby removing all schema database entries."""
        pass

    def endBatchUpdate(self: Any, schema_size: int) -> None:
        """Sets the final amount of schema database entries, for example 96 entries for 96 path positions. This is done to not allocate more memory than is needed to store schema property values for each path position."""
        pass

    def getSchemaSize(self: Any) -> int:
        """Returns the total amount of entries for schema database of path statement."""
        pass

    def getSchemaValue(self: Any, position_index: int, property_name: str) -> Any:
        """Returns the value of schema property for path position."""
        pass

    @overload
    def setSchemaValues(self: Any, position_index: int, property_name: str, value: Any) -> None:
        """Sets one or more schema properties for path position.
 Note: The method should not be called when there are no rows in the schema database or if the row's index value does not exist."""
        pass

    @overload
    def setSchemaValues(self: Any, position_index: int, property_indices: List[int], values: List[Any]) -> None:
        """Sets one or more schema properties for path position.
 Note: The method should not be called when there are no rows in the schema database or if the row's index value does not exist."""
        pass

    @overload
    def removeSchemaProperties(self: Any, property_names: List[str]) -> None:
        """Removes properties referenced by property_names list or properties list arguments"""
        pass

    @overload
    def removeSchemaProperties(self: Any, properties: List[vcProperty]) -> None:
        """Removes properties referenced by property_names list or properties list arguments"""
        pass


class vcPatternContainer(vcComponentContainer):
    """vcPatternContainer is a static container used for storing components in a defined pattern.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPatternContainer.htm"""

    def fill(self: Any, component: vcComponent) -> None:
        """Fills the container with a given component."""
        pass


class vcPoint(vcPrimitive):
    """vcPoint is an abstract base class for all primitive types of points in the 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPoint.htm"""

    @property
    def Position(self) -> vcVector:
        """Defines the position of point in 3D world."""
        pass

    @Position.setter
    def Position(self, value : vcVector) -> None:
        pass

    def update(self: Any) -> None:
        """Updates the primitive object containing the point, which includes any polygons and lines sharing the point."""
        pass


class vcPointSet(vcGeometrySet):
    """vcPointSet is a type of geometry set used for creating and rendering point clouds and/or data points.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPointSet.htm"""

    @property
    def ColorConfiguration(self) -> int:
        """Defines the color format for points. By default, the color format is RGBA.
 See Color Format Constants for more information.
 
 Gets or sets the current color configuration. There are 2 VC_COLOR_CONFIGURATION_RGBA and VC_COLOR_CONFIGURATION_BGRA"""
        pass

    @ColorConfiguration.setter
    def ColorConfiguration(self, value : int) -> None:
        pass

    @property
    def IncrementalBoundUpdate(self) -> bool:
        """Defines if the bound box should be updated on every added point or not."""
        pass

    @IncrementalBoundUpdate.setter
    def IncrementalBoundUpdate(self, value : bool) -> None:
        pass

    @property
    def PointCount(self) -> float:
        """Total amount of points in the point set."""
        pass

    @property
    def PointSize(self) -> float:
        """Defines the size (in pixels) of points in set."""
        pass

    @PointSize.setter
    def PointSize(self, value : float) -> None:
        pass

    @property
    def Scale(self) -> float:
        """Defines a factor for scaling rendered points in set."""
        pass

    @Scale.setter
    def Scale(self, value : float) -> None:
        pass

    @overload
    def addPoint(self: Any, x: float, y: float, z: float) -> int:
        """Adds a point to set, and then returns the index of point in the set.
 One option is to give XYZ coordinates for point in World coordinate system, thereby the point is assigned default color.
 A second option is to give XYZ coordinates and RGB color for the point.
 A third option is to give XYZ coordinates and RGB color with alpha channel for the point.
 If you are assigning a color, the RGB values must be normalized XYZ values for RGB color space."""
        pass

    @overload
    def addPoint(self: Any, x: float, y: float, z: float, r: float, g: float, b: float) -> int:
        """Adds a point to set, and then returns the index of point in the set.
 One option is to give XYZ coordinates for point in World coordinate system, thereby the point is assigned default color.
 A second option is to give XYZ coordinates and RGB color for the point.
 A third option is to give XYZ coordinates and RGB color with alpha channel for the point.
 If you are assigning a color, the RGB values must be normalized XYZ values for RGB color space."""
        pass

    @overload
    def addPoint(self: Any, x: float, y: float, z: float, r: float, g: float, b: float, a: float) -> int:
        """Adds a point to set, and then returns the index of point in the set.
 One option is to give XYZ coordinates for point in World coordinate system, thereby the point is assigned default color.
 A second option is to give XYZ coordinates and RGB color for the point.
 A third option is to give XYZ coordinates and RGB color with alpha channel for the point.
 If you are assigning a color, the RGB values must be normalized XYZ values for RGB color space."""
        pass

    def clearPoints(self: Any) -> None:
        """Removes all points from set."""
        pass

    def getPointColor(self: Any, Index: int) -> vcVector:
        """Gets a point color given an index."""
        pass

    def getPointPosition(self: Any, Index: int) -> vcVector:
        """Gets a point position given an index."""
        pass

    def update(self: Any) -> None:
        """Updates the bound box of set."""
        pass

    def updatePointColor(self: Any, Index: int, r: float, g: float, b: float) -> None:
        """Updates the color of the point defined by the index."""
        pass

    def updatePointPosition(self: Any, Index: int, x: float, y: float, z: float) -> None:
        """Updates a point position given an index."""
        pass


class vcPolygon(vcPrimitive):
    """vcPolygon represents an n-sided face in the 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPolygon.htm"""

    @property
    def Edges(self) -> List[vcEdge]:
        """Gets a list of all edges in polygon."""
        pass

    @property
    def Normal(self) -> vcVector:
        """Gets the Normal vector of polygon."""
        pass

    @property
    def PointCount(self) -> int:
        """Get the number of points in polygon."""
        pass

    @property
    def Points(self) -> List[vcPolygonPoint]:
        """Gets a list of all points in polygon."""
        pass

    def addPoint(self: Any, point: vcPolygonPoint) -> None:
        """Adds a given point to the polygon.
Note: Points can be shared by different polygons."""
        pass

    def getNeighbors(self: Any, point_index: int) -> List[vcPolygon]:
        """Returns a list of polygons sharing an edge with the polygon based on a given point_index."""
        pass

    def getPoint(self: Any, index: int) -> vcPolygonPoint:
        """Returns a point of the polygon at a given index."""
        pass

    def getPointNormal(self: Any, index: int) -> vcVector:
        """Returns the Normal vector of a point in the polygon at a given index."""
        pass

    @overload
    def removePoint(self: Any, point: vcPolygonPoint) -> None:
        """Removes a given point or one at a given index from the polygon."""
        pass

    @overload
    def removePoint(self: Any, index: int) -> None:
        """Removes a given point or one at a given index from the polygon."""
        pass

    def reverse(self: Any) -> None:
        """Inverts the face of polygon."""
        pass

    def update(self: Any) -> None:
        """Updates the structure of polygon, which is required when changing point count and point properties."""
        pass


class vcPolygonPoint(vcPoint):
    """vcPolygonPoint is a point/vertex used to define polygons.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPolygonPoint.htm"""

    @property
    def Color(self) -> vcVector:
        """Defines the color of the point by using a vector containing RGBA values.
Note: The geometry set of point and its polygon must support a VertexColor property; otherwise point will not have color."""
        pass

    @Color.setter
    def Color(self, value : vcVector) -> None:
        pass

    @property
    def Edges(self) -> List[vcEdge]:
        """Gets a list of all edges using the point."""
        pass

    @property
    def PolygonCount(self) -> int:
        """Gets the number of polygons using the point."""
        pass

    @property
    def U(self) -> float:
        """Defines a U texture coordinate for point."""
        pass

    @U.setter
    def U(self, value : float) -> None:
        pass

    @property
    def V(self) -> float:
        """Defines a V texture coordinate for point."""
        pass

    @V.setter
    def V(self, value : float) -> None:
        pass

    def getAverageNormal(self: Any) -> vcVector:
        """Returns the Normal vector of point, which is an average of all polygons using that point."""
        pass

    def getPolygon(self: Any, index: int) -> vcPolygon:
        """Returns a polygon using the point at a given index; otherwise returns None."""
        pass


class vcPolygonSet(vcGeometrySet):
    """vcPolygonSet is a collection of n-sided polygons, which are either manually created or the result of tessellation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPolygonSet.htm"""

    @property
    def CreaseAngle(self) -> float:
        """Defines an angle (in degrees) between polygons and edges considered hard, thereby rendering uses polygon normals instead of point normals."""
        pass

    @CreaseAngle.setter
    def CreaseAngle(self, value : float) -> None:
        pass

    @property
    def Edges(self) -> List[vcEdge]:
        """Gets a list of all edges in the set."""
        pass

    @property
    def Points(self) -> List[vcPolygonPoint]:
        """Gets a list of all points in the set."""
        pass

    @property
    def PolygonCount(self) -> int:
        """Gets the number of polygons in the set."""
        pass

    @property
    def Polygons(self) -> List[vcPolygon]:
        """Gets a list of polygons in the set."""
        pass

    @overload
    def createPoint(self: Any, vec: vcVector) -> vcPolygonPoint:
        """Adds a new point to the set using either a given vector or XYZ coordinates, and then returns the new point."""
        pass

    @overload
    def createPoint(self: Any, x: float, y: float, z: float) -> vcPolygonPoint:
        """Adds a new point to the set using either a given vector or XYZ coordinates, and then returns the new point."""
        pass

    def createPolygon(self: Any) -> vcPolygon:
        """Adds a new empty polygon to the set, and then returns the new polygon."""
        pass

    @overload
    def deletePolygon(self: Any, polygon: vcPolygon) -> None:
        """Deletes a given polygon from the set or a polygon at a given index in the set."""
        pass

    @overload
    def deletePolygon(self: Any, index: int) -> None:
        """Deletes a given polygon from the set or a polygon at a given index in the set."""
        pass

    def filterDuplicatePolygons(self: Any) -> None:
        """Traverses through set and removes all duplicate polygons, thereby reducing data count."""
        pass

    def getPolygon(self: Any, index: int) -> vcPolygon:
        """Returns a polygon at a given index in the set."""
        pass

    def smoothGroupProcessing(self: Any) -> None:
        """Performs a cleanup operation for grouped polygon sets in order to render smooth surfaces."""
        pass

    def triangulate(self: Any) -> None:
        """Performs a cleanup operation for polygons in the set to have three sides, thereby possibly increasing data count."""
        pass

    def update(self: Any) -> None:
        """Updates the set, thereby recalculating all polygons in the set and its bound box."""
        pass

    def updatePointSurrounding(self: Any, point: vcPolygonPoint) -> None:
        """Updates points in the set neighboring a given point."""
        pass


class vcPositionFrame(vcObject):
    """vcPositionFrame is a motion target for a robot that can be referenced by a statement.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPositionFrame.htm"""

    @property
    def Name(self) -> str:
        """Defines the name of the position."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def ReferencePoint(self) -> bool:
        """Turns on or off the use of a reference point to define the location of the position."""
        pass

    @ReferencePoint.setter
    def ReferencePoint(self, value : bool) -> None:
        pass

    @property
    def Configuration(self) -> str:
        """Defines the configuration of the robot for the position."""
        pass

    @Configuration.setter
    def Configuration(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of properties in the position."""
        pass

    @property
    def Statement(self) -> vcStatement:
        """Gets the statement referencing the position."""
        pass

    @property
    def JointValues(self) -> List[float]:
        """Gets a list of all the robot joint values (internal and external) for the position."""
        pass

    @property
    def InternalJointValues(self) -> List[float]:
        """Gets a list of internal robot joint values for the position."""
        pass

    @property
    def ExternalJointValues(self) -> List[float]:
        """Gets a list of external robot joint values for the position."""
        pass

    @property
    def PositionInReference(self) -> vcMatrix:
        """Defines the position matrix in reference to its base/parent coordinate system."""
        pass

    @PositionInReference.setter
    def PositionInReference(self, value : vcMatrix) -> None:
        pass

    @property
    def PositionInWorld(self) -> vcMatrix:
        """Defines the position matrix in reference to World coordinate system."""
        pass

    @PositionInWorld.setter
    def PositionInWorld(self, value : vcMatrix) -> None:
        pass

    def setJoints(self: Any, values: List[float]) -> None:
        """Sets the joint values of the position using a given list of values that must be equal or smaller in length than the total robot joint count (including external joints)."""
        pass

    def setExternalJoints(self: Any, values: List[float]) -> None:
        """Sets the external joint values of the position."""
        pass

    def createProperty(self: Any, type: int, name: str) -> vcProperty:
        """Creates a new property of a given type and name in the position, and then returns the new property.
An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation.
See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property in the position."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name in the position; otherwise returns None."""
        pass


class vcPositionFrameIterator(vcObject):
    """vcPositionFrameIterator is an iterator for positions of a motion statement. Generally, this is used with a vcPathStatement object which has schema properties for handling a large amount of positional data.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPositionFrameIterator.htm"""


class vcPositionStatement(vcStatement):
    """vcPositionStatement is an abstract class used for creating robot positions executed by motion type statements. For example, you can create a custom statement by implementing a vcPositionStatement as a process handler.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPositionStatement.htm"""

    @property
    def Base(self) -> vcBaseFrame:
        """Defines the base frame of the statement."""
        pass

    @Base.setter
    def Base(self, value : vcBaseFrame) -> None:
        pass

    @property
    def ExternalTCP(self) -> bool:
        """Defines if external tcp mode is used for the statement."""
        pass

    @ExternalTCP.setter
    def ExternalTCP(self, value : bool) -> None:
        pass

    @property
    def Positions(self) -> List[vcPositionFrame]:
        """Gets the list of positions in the statement."""
        pass

    @property
    def Tool(self) -> vcBaseFrame:
        """Defines the tool frame of the statement."""
        pass

    @Tool.setter
    def Tool(self, value : vcBaseFrame) -> None:
        pass

    def createPosition(self: Any, name: str) -> vcPositionFrame:
        """Creates a new position with a given name."""
        pass

    def deletePosition(self: Any, position: vcPositionFrame) -> None:
        """Deletes a given position."""
        pass


class vcPrimitive(vcObject):
    """vcPrimitive is an abstract base class for all geometry primitives, for examples polygons and lines.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPrimitive.htm"""

    @property
    def GeometrySet(self) -> vcGeometrySet:
        """Gets the geometry set of primitive."""
        pass

    @property
    def Id(self) -> int:
        """Defines a number identifying the primitive."""
        pass

    @Id.setter
    def Id(self, value : int) -> None:
        pass


class vcProcessContext(vcContext):
    """Inherits: vcContext
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessContext.htm"""


class vcProcessController(vcBehaviour):
    """Process controller is a root access point for all Process Modeling data and APIs. It provides several services as separate classes. A global instance of vcProcessController can be always accessed from vcSimulation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessController.htm"""

    @property
    def FlowTable(self) -> vcProcessFlowTable:
        """Gets this controller’s process flow table service for managing process sequences."""
        pass

    @property
    def FlowTable2(self) -> vcProcessFlowTable2:
        """FlowTable used for Flow v2"""
        pass

    @property
    def TransportSystem(self) -> vcTransportSystem:
        """Gets this controller’s transport system service for managing transport nodes, transport links and transport controllers and querying the transport graph."""
        pass

    @property
    def FlowGroupManager(self) -> vcProcessFlowGroupManager:
        """Gets this controller’s manager service for process flow groups."""
        pass

    @property
    def ProductTypeManager(self) -> vcProductTypeManager:
        """Gets this controller’s manager service for product types."""
        pass

    @property
    def ProductMatcher(self) -> vcProductMatcher:
        """Gets the product matcher."""
        pass

    @property
    def ProcessManager(self) -> vcProcessManager:
        """Gets this controller’s process group manager service."""
        pass

    @property
    def ProcessData(self) -> vcProcessControllerData:
        """Gets the “database” of this process controller that stores all associated layout-level information."""
        pass

    @property
    def AssemblyPatternManager(self) -> vcAssemblyPatternManager:
        """Gets the assembly pattern manager."""
        pass


class vcProcessControllerData(vcLayoutItem):
    """Process controller data is a layout item that stores all layout-level information for a Process controller including product types, process flow sequences, transport links etc. The data should be accessed and manipulated only through the service classes accessible from vcProcessController.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessControllerData.htm"""


class vcProcessExecutor(vcExecutor):
    """Process executor is a behavior that holds and runs process routines (vcProcessRoutine). Each process routine is an implementation of a process. The execution order of the process routines is controlled by the parent process controller (vcProcessController).
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessExecutor.htm"""

    @property
    def ProcessController(self) -> vcProcessController:
        """Gets the associated process controller."""
        pass

    @property
    def Processes(self) -> List[vcProcessRoutine]:
        """Gets all process routines in this executor.
 Returns None if the executor does not have a program."""
        pass

    @property
    def TransportNode(self) -> vcTransportNode:
        """Gets the associated transport node that this executor’s processes use to receive and send product instances.
 Setting this property also sets the ProcessExecutor property on the new transport node, and clears the property from the old transport node, if there was one."""
        pass

    @TransportNode.setter
    def TransportNode(self, value : vcTransportNode) -> None:
        pass

    def addProcess(self: Any, name: str) -> vcProcessRoutine:
        """Creates a new process routine and adds it to this executor’s program.
 The routine name has to be unique within this executor’s program.
 Returns None if the executor doesn’t have a program."""
        pass

    def deleteProcess(self: Any, routine: vcProcessRoutine) -> None:
        """Removes the given routine from this executor’s program and deletes it."""
        pass


class vcProcessFlowGroup(vcObject):
    """Process flow group is a grouping of product types that share same process flow sequence and can navigate through the same transport links. Every product type (vcProductType) belongs to exactly one flow group, with the only exception being the system “Any” product type that doesn’t belong to a flow group.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessFlowGroup.htm"""

    @property
    def Name(self) -> str:
        """Name of the group. Must be unique within the process controller."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def FlowGroupManager(self) -> vcProcessFlowGroupManager:
        """Gets the manager this flow group belongs to."""
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets the properties of this flow group. All properties might not have a vcProperty implementation."""
        pass

    @property
    def ProductTypes(self) -> List[vcProductType]:
        """The list of product types that belong to this group."""
        pass

    @property
    def IsVisible(self) -> bool:
        """Whether this group is visible in certain areas of the user interface."""
        pass

    @IsVisible.setter
    def IsVisible(self, value : bool) -> None:
        pass

    def getProperty(self: Any, Name: str) -> vcProperty:
        """Returns a property matching a given name in the group; otherwise returns None. All properties might not have a vcProperty implementation."""
        pass

    def clone(self: Any) -> vcProcessFlowGroup:
        """Returns a clone of this vcProcessFlowGroup."""
        pass

    OnProductTypeAdded : Callable[[vcProcessFlowGroup, vcProductType], None]
    """Triggered when a product type has been added to this flow group."""


    OnProductTypeRemoving : Callable[[vcProcessFlowGroup, vcProductType], None]
    """Triggered when a product type is being removed from this flow group."""



class vcProcessFlowGroupManager(vcObject):
    """The flow group manager is used to create, access and delete the process flow groups (vcProcessFlowGroup objects) within its owner vcProcessController.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessFlowGroupManager.htm"""

    @property
    def Controller(self) -> vcProcessController:
        """Gets the process controller owner."""
        pass

    @property
    def Groups(self) -> List[vcProcessFlowGroup]:
        """The list of all registered flow groups."""
        pass

    def createGroup(self: Any, groupName: str) -> vcProcessFlowGroup:
        """Tries to create a new group with the given name. The name must be unique within the process controller."""
        pass

    def findGroup(self: Any, groupName: str) -> vcProcessFlowGroup:
        """Gets a flow group with the given name."""
        pass

    @overload
    def deleteGroup(self: Any, group: vcProcessFlowGroup) -> None:
        """Tries to delete the given group. Can not delete groups from different process controller.
 Note: Deleting a flow group also causes deletion of any contained product types and other tied data such as process flow sequence."""
        pass

    @overload
    def deleteGroup(self: Any, groupName: str) -> None:
        """Tries to find and delete a group with given name."""
        pass

    def clearGroups(self: Any) -> None:
        """Deletes all groups."""
        pass

    def moveProductType(self: Any, typeToMove: vcProductType, destination: vcProcessFlowGroup) -> None:
        """Tries to move the given product type to the given target group."""
        pass

    OnGroupAdded : Callable[[vcProcessFlowGroup], None]
    """Triggered when a new flow group has been added to this process controller."""


    OnGroupRemoving : Callable[[vcProcessFlowGroup], None]
    """Triggered when a flow group is being removed from this process controller."""



class vcProcessFlowState(vcObject):
    """FlowState indicates an exact location in the product flow. Used in Product’s CurrentProcessFlowState.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessFlowState.htm"""

    @property
    def FlowStep(self) -> vcProcessFlowStep:
        """Specifies ProcessFlowStep the product is in currently."""
        pass

    @FlowStep.setter
    def FlowStep(self, value : vcProcessFlowStep) -> None:
        pass

    @property
    def GroupId(self) -> str:
        """Specifies ProcessGroup inside the FlowStep the product is in currently."""
        pass

    @GroupId.setter
    def GroupId(self, value : str) -> None:
        pass

    @property
    def Routine(self) -> vcProcessRoutine:
        """Specifies the specific ProcessRoutine the product is in currently."""
        pass

    @Routine.setter
    def Routine(self, value : vcProcessRoutine) -> None:
        pass


class vcProcessFlowStep(vcObject):
    """FlowStep is one step in FlowGroup’s sequence of steps and container for flow step properties. FlowStep may contain one or more ProcessGroups.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessFlowStep.htm"""

    @property
    def Groups(self) -> vcObservableList[vcProcessGroup]:
        """List of ProcessGroups in the step."""
        pass

    @property
    def Name(self) -> str:
        """Name of FlowStep."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def IsOptional(self) -> bool:
        """Defines if the products can potentially skip this FlowStep in their flow sequence."""
        pass

    @IsOptional.setter
    def IsOptional(self, value : bool) -> None:
        pass

    @property
    def ProcessMode(self) -> int:
        """Defines how products go through this FlowStep:
 
 AllInAnyOrder: all process groups must be visited, before moving to next step.
 FirstMatch: only one of process groups must be visited, before moving to next step."""
        pass

    @ProcessMode.setter
    def ProcessMode(self, value : int) -> None:
        pass

    @property
    def ProcessConfigurations(self) -> vcObservableList[vcFlowStepProcessConfiguration]:
        """A read-only observable list of vcFlowStepProcessConfiguration instances, affecting vcProcessGroup instances in this vcProcessFlowStep."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Creates a new property to the Flow Step itself."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a property of the Flow Step itself."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property of the Flow Step itself."""
        pass

    def startBatch(self: Any) -> None:
        """Start batch update of Groups and delay updating ProcessConfigurations until `endBatch` is called."""
        pass

    def endBatch(self: Any) -> None:
        """End batch updating of Groups and apply delayed updates to ProcessConfigurations."""
        pass


class vcProcessFlowTable(vcObject):
    """The process flow table holds the sequences of processes (vcProcessSequence) that each product (vcProduct) belonging to a certain flow group (vcProcessFlowGroup) shall follow as it travels in the simulation under this process controller (vcProcessController).
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessFlowTable.htm"""

    @property
    def Controller(self) -> vcProcessController:
        """The controller that owns this object."""
        pass

    @property
    def Sequences(self) -> List[vcProcessSequence]:
        """All sequences in this table."""
        pass

    @overload
    def createSequence(self: Any, groupName: str) -> vcProcessSequence:
        """Creates a new sequence for the given group."""
        pass

    @overload
    def createSequence(self: Any, group: vcProcessFlowGroup) -> vcProcessSequence:
        """Creates a new sequence for the given group."""
        pass

    @overload
    def deleteSequence(self: Any, groupName: str) -> None:
        """Deletes the sequence for a given group."""
        pass

    @overload
    def deleteSequence(self: Any, group: vcProcessFlowGroup) -> None:
        """Deletes the sequence for a given group."""
        pass

    @overload
    def getSequence(self: Any, groupName: str) -> vcProcessSequence:
        """Returns a sequence for the given group, if found."""
        pass

    @overload
    def getSequence(self: Any, group: vcProcessFlowGroup) -> vcProcessSequence:
        """Returns a sequence for the given group, if found."""
        pass

    def copySequenceFrom(self: Any, source: vcProcessFlowGroup, target: vcProcessFlowGroup) -> vcProcessSequence:
        """Copies the sequence defined for the given source flow group and adds it to this flow table, for the target flow group. There should not already be a sequence registered for the target flow group."""
        pass

    OnSequenceAdded : Callable[[vcProcessSequence], None]
    """Triggered when a new sequence has been added."""


    OnSequenceRemoving : Callable[[vcProcessSequence], None]
    """Triggered when a sequence is about to be removed."""



class vcProcessFlowTable2(vcObject):
    """FlowTable2 contains a list of ProcessSequence2, one or none for each ProcessFlowGroup.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessFlowTable2.htm"""

    @property
    def Controller(self) -> vcProcessController:
        """Owner of this FlowTable2"""
        pass

    @property
    def Sequences(self) -> List[vcProcessSequence2]:
        """List of sequences"""
        pass

    def createSequence(self: Any, group: vcProcessFlowGroup) -> Union[vcProcessSequence2, None]:
        """Creates sequence associated with given FlowGroup. Returns None, if sequence already exists."""
        pass

    def deleteSequence(self: Any, group: vcProcessFlowGroup) -> None:
        """Deletes sequences associated with given FlowGroup."""
        pass

    def getSequence(self: Any, group: vcProcessFlowGroup) -> Union[vcProcessSequence2, None]:
        """Gets sequence associated with given FlowGroup. Returns None, if FlowGroups does not have a sequence."""
        pass

    def copySequenceFrom(self: Any, source: vcProcessFlowGroup, target: vcProcessFlowGroup) -> Union[vcProcessSequence2, None]:
        """Copies a sequences from FlowGroup `source` to FlowGroup `target`. Returns None (and does nothing), if the target FlowGroup already has a sequence."""
        pass

    OnSequenceAdded : Callable[[], None]
    """Triggered when a sequence is added."""


    OnSequenceRemoving : Callable[[], None]
    """Triggered when a sequence is being removed."""



class vcProcessGroup(vcObject):
    """Process group is an automatic grouping of all process implementations that have the same process id (identifier). The process implementations are not owned but only referenced by this object. The parent vcProcessManager provides events for tracking the changes.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessGroup.htm"""

    @property
    def Implementations(self) -> List[vcProcessRoutine]:
        """Gets all process implementations."""
        pass

    @property
    def Manager(self) -> vcProcessManager:
        """The process manager that owns this group object."""
        pass

    @property
    def ProcessId(self) -> str:
        """The process identifier (name) all these implementations share."""
        pass


class vcProcessIfStatement(vcStatement):
    """A vcProcessIfStatement is a process statement that execute one of two scopes of statements based on a condition. If the condition is true, the statement executes its ThenScope of statements. If the condition is false, the statement executes is ElseScope of statements. If condition is invalid neither ThenScope nor ElseScope are executed.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessIfStatement.htm"""

    @property
    def Condition(self) -> str:
        """Condition expression to evaluate when the statement is executed.
 See also Process Statement Expressions."""
        pass

    @Condition.setter
    def Condition(self, value : str) -> None:
        pass

    @property
    def ElseScope(self) -> vcScope:
        """Scope to execute when Condition evaluates to False."""
        pass

    @property
    def ThenScope(self) -> vcScope:
        """Scope to execute when Condition evaluates to True."""
        pass


class vcProcessManager(vcObject):
    """The process manager service automatically creates, updates and removes process groups (vcProcessGroup) when process implementations (vcProcessRoutine) are added, renamed or removed within its parent process controller. The process groups can be used to easily find all implementations of a process.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessManager.htm"""

    @property
    def Controller(self) -> vcProcessController:
        """Gets the process controller owner."""
        pass

    @property
    def ProcessGroups(self) -> List[vcProcessGroup]:
        """Gets a list of all current processes in this process controller."""
        pass

    def findProcessGroup(self: Any, processId: str) -> vcProcessGroup:
        """Tries to find a process group that contains all processes with the given id.
 Returns None if no such processes exist."""
        pass

    def changeGroupId(self: Any, group: vcProcessGroup, newId: str) -> None:
        """Tries to rename a process i.e. change id of all process implementations in a process group. This can fail non-trivially if some process executor already contains a process with the new id.
 Either the rename succeeds fully or no changes are made, throws an exception if the operation didn’t succeed."""
        pass

    OnProcessAdded : Callable[[vcProcessRoutine, vcProcessGroup], None]
    """Triggered when a new process implementation has been added."""


    OnProcessRemoving : Callable[[vcProcessRoutine, vcProcessGroup], None]
    """Triggered when a process implementation is about to be removed."""


    OnGroupIdChanged : Callable[[vcProcessGroup, str], None]
    """Triggered when all processes within a group changed their id. The usual case is when the group only contains a single process implementation and its id gets changed."""



class vcProcessPointSensor(vcBehaviour):
    """vcProcessPointSensor is the object type for Process Point Sensor behaviors.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessPointSensor.htm"""

    @property
    def Frame(self) -> vcFeature:
        """Defines a Frame feature referenced as the location of sensor in 3D world."""
        pass

    @Frame.setter
    def Frame(self, value : vcFeature) -> None:
        pass

    @property
    def BoolSignal(self) -> vcBoolSignal:
        """Defines a Boolean Signal used to send a True value when processing starts and a False value when processing ends."""
        pass

    @BoolSignal.setter
    def BoolSignal(self, value : vcBoolSignal) -> None:
        pass

    @property
    def ProcessAt(self) -> int:
        """Defines the trigger used to initialize processing in sensor.
See Path Constants for more information."""
        pass

    @ProcessAt.setter
    def ProcessAt(self, value : int) -> None:
        pass

    @property
    def RuleComponent(self) -> int:
        """Defines the processing rule of sensor.
See Process Point Constants for more information."""
        pass

    @RuleComponent.setter
    def RuleComponent(self, value : int) -> None:
        pass

    @property
    def TriggerAt(self) -> int:
        """Defines whether a path connected to sensor or component triggering sensor is stopped during processing.
See Process Point Constants for more information."""
        pass

    @TriggerAt.setter
    def TriggerAt(self, value : int) -> None:
        pass

    def processValue(self: Any, from_connector_index: float, component: vcComponent, behavior: vcBehaviour = ...) -> float:
        """Calculates the processing time of a given component entering from an input port of a path connected to sensor, and then returns the total time from start to finish."""
        pass

    def setValue(self: Any, value: float) -> None:
        """Sets the processing time of sensor.
Generally, this method is used with OnValue event to define multiple processing times and handle issues, for example bottlenecks and simulated failures."""
        pass

    def startFailure(self: Any) -> None:
        """Sets the state of sensor to Failure, thereby stopping all tasks performed by sensor.
Sensor will stay in failure state until either simulation is reset or sensor calls stopFailure() method."""
        pass

    def stopFailure(self: Any) -> None:
        """Brings sensor out of failure state, for example to simulate a repair."""
        pass

    OnValue : Callable[[int, vcComponent, vcBehaviour], None]
    """Triggered when sensor starts processing a component.
To override default processing time, use setValue() method."""



class vcProcessRoutine(vcRoutine):
    """Process routine is a routine in the executor’s program that implements a Process Modeling process. It has an additional internal routine for the special process requirement statements that control when this process’s execution starts.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessRoutine.htm"""

    @property
    def Requirements(self) -> vcRoutine:
        """Gets the process requirements routine of this process implementation."""
        pass

    @property
    def Description(self) -> str:
        """Can be used to give a description for the process implementation."""
        pass

    @Description.setter
    def Description(self, value : str) -> None:
        pass


class vcProcessSequence(vcObject):
    """Defines the sequence of process steps (vcProcessGroup) that any product type (vcProductType) belonging to a particular flow group (vcProcessFlowGroup) shall follow in the Process Modeling system.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessSequence.htm"""

    @property
    def FlowTable(self) -> vcProcessFlowTable:
        """The flow table that owns this sequence."""
        pass

    @property
    def TargetGroup(self) -> vcProcessFlowGroup:
        """The flow group that this sequence is defined for."""
        pass

    @property
    def ProcessGroups(self) -> List[vcProcessGroup]:
        """The ordered list of processes that the products belonging to the target flow group should go through."""
        pass

    def addProcessGroup(self: Any, processGroup: vcProcessGroup) -> None:
        """Adds the given process group to this sequence."""
        pass

    def removeProcessGroup(self: Any, processGroup: vcProcessGroup) -> None:
        """Removes the given process group from this sequence."""
        pass

    def insertProcessGroup(self: Any, index: int, processGroup: vcProcessGroup) -> None:
        """Inserts the given process group into the given index in this sequence."""
        pass

    def setProcessGroup(self: Any, index: int, processGroup: vcProcessGroup) -> None:
        """Sets the process group in the given index in this sequence."""
        pass

    def getProcessGroup(self: Any, index: int) -> vcProcessGroup:
        """Returns the process group in the given index in this sequence."""
        pass


class vcProcessSequence2(vcObject):
    """In the image below, outlined in green is the vcProcessSequence2. There's one for each FlowGroup, and it contains a sequence of steps. Outlined In blue are two vcProcessFlowStep (out of 7). They may contain ProcessGroups (those A,B,C,D,...) and different modes of operation (First available process, All processes in any order). These modes affect how single products move through the flow (they may skip optional steps, ...).
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessSequence2.htm"""

    @property
    def FlowSteps(self) -> vcObservableList[vcProcessFlowStep]:
        """List of FlowSteps"""
        pass

    @property
    def ProcessConfigurations(self) -> vcObservableList[vcSequenceProcessConfiguration]:
        """A read-only observable list of vcSequenceProcessConfiguration instances, affecting vcProcessGroup instances in this vcProcessSequence2."""
        pass

    @overload
    def getNextProcessOptions(self: Any, next: vcNextProcessFlowInfo) -> List[vcFeedOptionFlowInfo]:
        """Returns a list of possible FlowInfo options in priority order given the inputs.
 
 
 Includes ProcessGroups from next non-optional steps, starting from `next`, and all optional steps in between.
 Same as (1), but takes product’s history in account, to include All processes in any order steps."""
        pass

    @overload
    def getNextProcessOptions(self: Any, next: vcNextProcessFlowInfo, product: vcProduct) -> List[vcFeedOptionFlowInfo]:
        """Returns a list of possible FlowInfo options in priority order given the inputs.
 
 
 Includes ProcessGroups from next non-optional steps, starting from `next`, and all optional steps in between.
 Same as (1), but takes product’s history in account, to include All processes in any order steps."""
        pass

    def createStepFrom(self: Any, step: vcProcessFlowStep, index: int) -> vcProcessFlowStep:
        """Creates a copy of a FlowStep and inserts it at the given index. If the given index is less than zero or greater than the current item count, the item will be inserted at the end. The given step may belong to any vcProcessSequence2."""
        pass

    def endBatch(self: Any) -> None:
        """End batch update of the FlowSteps and apply delayed updates to ProcessConfigurations."""
        pass

    def startBatch(self: Any) -> None:
        """Start batch update of FlowSteps and delay updating ProcessConfigurations until `endBatch` is called."""
        pass


class vcProcessStatement(vcPositionStatement):
    """Inherits: vcStatement
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessStatement.htm"""

    @property
    def Filter(self) -> vcProductFilter:
        """Gets current product filter"""
        pass

    @property
    def AcceptAllProductTypes(self) -> bool:
        """(Deprecated) Use vcProductFilter.IsEnabled property instead.
 
 When set to True, any product is accepted and AcceptedFlowGroups and AcceptedProductTypes are ignored.
 
 AcceptAllProductTypes property is synchronized with an inverse of vcProductFilter.IsEnabled.
 This way:
 
 Setting AcceptAllProductTypes to True will set IsEnabled to False.
 Setting IsEnabled to True will set AcceptAllProductTypes to False."""
        pass

    @AcceptAllProductTypes.setter
    def AcceptAllProductTypes(self, value : bool) -> None:
        pass

    @property
    def AcceptedFlowGroups(self) -> List[vcProcessFlowGroup]:
        """(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected flow groups."""
        pass

    @AcceptedFlowGroups.setter
    def AcceptedFlowGroups(self, value : List[vcProcessFlowGroup]) -> None:
        pass

    @property
    def AcceptedProductTypes(self) -> List[vcProductType]:
        """(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected product types."""
        pass

    @AcceptedProductTypes.setter
    def AcceptedProductTypes(self, value : List[vcProductType]) -> None:
        pass

    OnFilterChanged : Callable[[], None]
    """Triggered when filter is changed"""



class vcProcessWhileStatement(vcStatement):
    """While statement executes Scope in a loop as long as Condition evaluates to True.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProcessWhileStatement.htm"""

    @property
    def Condition(self) -> str:
        """Condition expression to evaluate on each loop iteration.
 See also Process Statement Expressions."""
        pass

    @Condition.setter
    def Condition(self, value : str) -> None:
        pass

    @property
    def Scope(self) -> vcScope:
        """Scope to keep executing while Condition evaluates to True."""
        pass


class vcProduct(vcObject):
    """A product instance is a data object corresponding to a specific vcProductType and associated to a dynamic vcComponent that gives it a physical presence in the 3D world. The product type of vcProduct instance can change during its lifetime, but is always explicitly defined. Every vcProduct is always linked to exactly one dynamic vcComponent, and this linking doesn’t change during the product’s lifetime.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProduct.htm"""

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets the properties that have vcProperty implementation."""
        pass

    @property
    def ProductType(self) -> vcProductType:
        """The type of this product."""
        pass

    @property
    def Component(self) -> vcComponent:
        """The component associated with this product instance."""
        pass

    @property
    def CurrentProcessFlowState(self) -> vcProcessFlowState:
        """Current FlowState of the product."""
        pass

    @CurrentProcessFlowState.setter
    def CurrentProcessFlowState(self, value : vcProcessFlowState) -> None:
        pass

    @property
    def TransportSolution(self) -> vcTransportSolution:
        """Latest transport solution assigned to this product instance. Note that the product may already have reached the destination node and continued further by other means."""
        pass

    @TransportSolution.setter
    def TransportSolution(self, value : vcTransportSolution) -> None:
        pass

    @property
    def LastEnteredNode(self) -> vcTransportNode:
        """Gets the transport node this product instance has last arrived in. Can be used to determine the product’s position along its transport solution."""
        pass

    @property
    def NextProcessFlowInfo(self) -> vcNextProcessFlowInfo:
        """Information used to determine next FlowState of a product."""
        pass

    @NextProcessFlowInfo.setter
    def NextProcessFlowInfo(self, value : vcNextProcessFlowInfo) -> None:
        pass

    @property
    def WorldPositionMatrix(self) -> vcMatrix:
        """Gets (as a copy) or sets the product instance position in world coordinates. This takes into account the defined offset between the product’s component and the product itself."""
        pass

    @WorldPositionMatrix.setter
    def WorldPositionMatrix(self, value : vcMatrix) -> None:
        pass

    def changeType(self: Any, newType: vcProductType, deleteAttachedComponents: bool = ...) -> bool:
        """Recreates this product instance and its visualization component to match the new product type defined by newType. An optional argument deleteAttachedComponents can be used to delete any other components attached to the component of this product instance. Returns True if successful, False otherwise. Any errors messages are concatenated into a Python error message."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a property from this product instance."""
        pass

    def enterProcess(self: Any, currentRoutine: vcProcessRoutine) -> None:
        """Registers start of given process for this product, updating the CurrentProcessFlowState and NextProcessFlowInfo based on the applicable flow sequence.
 currentRoutine - The process implementation this product enters."""
        pass

    def exitCurrentProcess(self: Any, clearNextFlowInfo: bool) -> None:
        """Registers that this product has left the current process, clearing CurrentProcessFlowState. The NextProcessFlowInfo should be cleared when the product is about to enter an assembly or product bundle.
 clearNextFlowInfo - Whether to clear NextProcessFlowInfo."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property from this product instance."""
        pass

    def createProperty(self: Any, property: vcProperty) -> vcProperty:
        """Creates a new property to this product instance."""
        pass

    def createProduct(self: Any, container: vcContainer = ...) -> vcProduct:
        """Creates and returns a new product instance of this product type. If container is given, the product component will be added to it, otherwise the product is added to the world container."""
        pass


class vcProductCreator(vcFlow):
    """vcProductCreator acts as a feeder and creates one or more types of products for use in a Process Modeling.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductCreator.htm"""

    @property
    def ApplyProductTypeOrigin(self) -> bool:
        """Defines whether origin offset defined in the Product Type is taking into account or not. See vcProductType.OriginFrame"""
        pass

    @ApplyProductTypeOrigin.setter
    def ApplyProductTypeOrigin(self, value : bool) -> None:
        pass

    @property
    def BatchFeed(self) -> vcProductCreatorBatchMode:
        """Gets the configuration for batch feed mode."""
        pass

    @property
    def DistributionFeed(self) -> vcProductCreatorDistributionMode:
        """Gets the configuration for distribution feed mode."""
        pass

    @property
    def FeedMode(self) -> int:
        """Defines the mode for feeding products. That is, when and what type of product to create during a simulation.
 See Feed Mode Constants for more information."""
        pass

    @FeedMode.setter
    def FeedMode(self, value : int) -> None:
        pass

    @property
    def PartPooling(self) -> bool:
        """Turns on/off the reuse of components made by the creator, thereby improving simulation performance.
 If True, dynamic components removed during simulation are recirculated to make new components, thereby reducing memory allocation.
 Note: Be careful when recirculating components that were modified during simulation, for example a change in node material."""
        pass

    @PartPooling.setter
    def PartPooling(self, value : bool) -> None:
        pass

    @property
    def SingleFeed(self) -> vcProductCreatorSingleMode:
        """Gets the configuration for single feed mode."""
        pass

    @property
    def TableFeed(self) -> vcProductCreatorTableMode:
        """Gets the configuration for table feed mode."""
        pass

    OnProductCreated : Callable[[vcProduct], None]
    """Triggered when a new product instance has been created by this creator."""



class vcProductCreatorBatchMode(vcObject):
    """Configuration for batch feed mode in vcProductCreator. Creates batches of vcProductType instances in a sequence. Each batch defines the type of vcProduct to create, interval between instances and the maximum number of products to be created.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductCreatorBatchMode.htm"""

    @property
    def BatchInterval(self) -> float:
        """Amount to delay between batches in seconds. Should be zero or greater."""
        pass

    @BatchInterval.setter
    def BatchInterval(self, value : float) -> None:
        pass

    @property
    def Loop(self) -> bool:
        """Turns on/off the looping of the sequence."""
        pass

    @Loop.setter
    def Loop(self, value : bool) -> None:
        pass

    @property
    def ProductBatches(self) -> List[vcProductCreatorFeedBatch]:
        """List of all currently defined batches."""
        pass

    def createBatch(self: Any) -> vcProductCreatorFeedBatch:
        """Creates a new batch with default values and adds to the end."""
        pass

    def deleteBatch(self: Any, batch: vcProductCreatorFeedBatch) -> None:
        """Deletes the given batch from this configuration."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name; otherwise returns None."""
        pass

    def moveBatch(self: Any, batch: vcProductCreatorFeedBatch, index: int) -> None:
        """Moves the given batch to the given index.
The index must be greater than or equal to 0."""
        pass

    OnBatchesChanged : Callable[[vcProductCreatorBatchMode], None]
    """Triggered when the ProductBatches collection content has changed."""



class vcProductCreatorDistributionMode(vcObject):
    """vcProductCreatorDistributionMode allows you to define the probability of feeding one or more types of products when a vcProductCreator object uses a FeedMode of Distribution. A distribution feed mode uses entries. Each entry is a vcDistributionModeProductLineEntry object that defines a product type and weighted probability.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductCreatorDistributionMode.htm"""

    @property
    def Interval(self) -> str:
        """Time to wait in seconds between creating products.
 Note: Pseudo-random real number generated by an expression that defines a distribution.
 normal([stream], u, s)
 Normal distribution for mean value u and standard deviation s with an optional stream for seeding a random value to generator.
 exponential([stream], lambda)
 Exponential distribution where mean value is 1/lambda and variance is 1/lambda^2 with an optional stream for seeding a random value to generator.
 gamma([stream], k, theta)
 Gamma distribution with shape k and scale theta with an optional stream for seeding a random value to generator.
 lognormal([stream], u, s)
 Log normal distribution for mean value u and standard deviation s with an optional stream for seeding a random value to generator.
 triangular([stream], min, mode, max)
 Triangular distribution for given min, mode and max values with an optional stream for seeding a random value to generator.
 uniform([stream], a, b)
 Uniform distribution in range a <= x < b with an optional stream for seeding a random value to generator.
 weibull([stream], k, lambda)
 Weibull distribution with shape k and scale lambda with an optional stream for seeding a random value to generator."""
        pass

    @Interval.setter
    def Interval(self, value : str) -> None:
        pass

    @property
    def Limit(self) -> int:
        """Number of products to create. Must be 0 or greater."""
        pass

    @Limit.setter
    def Limit(self, value : int) -> None:
        pass

    @property
    def ProductEntries(self) -> List[vcDistributionModeProductLineEntry]:
        """List of all currently defined entries."""
        pass

    @property
    def RandomStream(self) -> int:
        """Index of the pseudo-random number generator to use when picking the next product type to instantiate. Must be in inclusive range 0-63."""
        pass

    @RandomStream.setter
    def RandomStream(self, value : int) -> None:
        pass

    def addProductEntry(self: Any, productType: vcProductType, probability: float) -> vcDistributionModeProductLineEntry:
        """Adds a new entry to the distribution mode configuration based on the given productType and probability. Notes:
 
 The productType must not be None.
 The probability must be greater than or equal to zero.
 Having more than one entry with same vcProductType is allowed but not recommended."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name; otherwise returns None."""
        pass

    def removeProductEntry(self: Any, entry: vcDistributionModeProductLineEntry) -> None:
        """Deletes the given entry from this configuration."""
        pass

    OnProductEntriesChanged : Callable[[vcProductCreatorDistributionMode], None]
    """Triggered when the ProductEntries collection content has changed."""



class vcProductCreatorFeedBatch(vcObject):
    """Configuration of a single batch in vcProductCreatorBatchMode. A batch creates a set number of product instances from the same vcProductType one after another with interval delay in between.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductCreatorFeedBatch.htm"""

    @property
    def Part(self) -> vcProductType:
        """The product type to create instances of."""
        pass

    @Part.setter
    def Part(self, value : vcProductType) -> None:
        pass

    @property
    def Limit(self) -> int:
        """Number of products to create. Must be 0 or greater."""
        pass

    @Limit.setter
    def Limit(self, value : int) -> None:
        pass

    @property
    def Interval(self) -> str:
        """Time to wait in seconds between creating products.
 Note: Pseudo-random real number generated by an expression that defines a distribution.
 normal([stream], u, s)
 Normal distribution for mean value u and standard deviation s with an optional stream for seeding a random value to generator.
 exponential([stream], lambda)
 Exponential distribution where mean value is 1/lambda and variance is 1/lambda^2 with an optional stream for seeding a random value to generator.
 gamma([stream], k, theta)
 Gamma distribution with shape k and scale theta with an optional stream for seeding a random value to generator.
 lognormal([stream], u, s)
 Log normal distribution for mean value u and standard deviation s with an optional stream for seeding a random value to generator.
 triangular([stream], min, mode, max)
 Triangular distribution for given min, mode and max values with an optional stream for seeding a random value to generator.
 uniform([stream], a, b)
 Uniform distribution in range a <= x < b with an optional stream for seeding a random value to generator.
 weibull([stream], k, lambda)
 Weibull distribution with shape k and scale lambda with an optional stream for seeding a random value to generator."""
        pass

    @Interval.setter
    def Interval(self, value : str) -> None:
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name; otherwise returns None."""
        pass


class vcProductCreatorSingleMode(vcObject):
    """Configuration for single feed mode in vcProductCreator. Creates instances of a single vcProductType at a given time interval until the limit is reached.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductCreatorSingleMode.htm"""

    @property
    def Part(self) -> vcProductType:
        """The product type to create instances of."""
        pass

    @Part.setter
    def Part(self, value : vcProductType) -> None:
        pass

    @property
    def Limit(self) -> int:
        """Number of products to create. Must be 0 or greater."""
        pass

    @Limit.setter
    def Limit(self, value : int) -> None:
        pass

    @property
    def Interval(self) -> str:
        """Time to wait in seconds between creating products.
 Note: Real-valued distribution property."""
        pass

    @Interval.setter
    def Interval(self, value : str) -> None:
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name; otherwise returns None."""
        pass


class vcProductCreatorTableMode(vcObject):
    """Configuration for table feed mode in vcProductCreator. Holds a list of rows, each defining which vcProductType to instantiate and at what simulation time. The rows are automatically sorted in ascending order by the product creation time. The rows can be loaded from a file or defined using methods of this class. Modifying the rows during simulation is allowed but may result in e.g. inaccurate timing of when the products are created.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductCreatorTableMode.htm"""

    @property
    def File(self) -> str:
        """Uri pointing to an xls file where to load the rows. Changing the value will cause an immediate attempt to read the file and replace all ProductRows if successful.
 Any errors are printed to output.
 (Deprecated) Use the ReadRowsFromFile and ReplaceAllRows methods."""
        pass

    @File.setter
    def File(self, value : str) -> None:
        pass

    @property
    def RowCount(self) -> int:
        """Gets the current product row count."""
        pass

    @property
    def ProductRows(self) -> List[vcProductCreatorTableRow]:
        """List of all currently defined product rows. The rows are returned as copies."""
        pass

    def addRow(self: Any, newRow: vcProductCreatorTableRow) -> int:
        """Adds a new row as a copy. The row gets inserted immediately after all existing rows with the same or smaller product creation time. Returns index of the new row. Throws an exception if the new row contains invalid values."""
        pass

    def clearRows(self: Any) -> None:
        """Deletes all product rows."""
        pass

    def deleteRow(self: Any, index: int) -> None:
        """Deletes the product row at given index. The index must be in inclusive range 0 to RowCount – 1"""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name; otherwise returns None."""
        pass

    def getRow(self: Any, index: int) -> vcProductCreatorTableRow:
        """Returns a copy of a product row at the given index. The index must be in inclusive range 0 to RowCount – 1"""
        pass

    def readRowsFromFile(self: Any, fileUri: str, showErrorMessages: bool) -> List[vcProductCreatorTableRow]:
        """Attempts to load rows from an xls file and returns them as a list if successful.
 Does not modify this table mode configuration. Returns None if reading or parsing the file failed. If showErrorMessages is True, any errors are printed to the output."""
        pass

    def replaceAllRows(self: Any, newRows: List[vcProductCreatorTableRow]) -> None:
        """Deletes all rows and then adds the new rows as copies. The rows are sorted by the creation time using a stable sort algorithm. Throws an exception if any of the new rows contains invalid values."""
        pass


class vcProductCreatorTableRow(vcObject):
    """Configuration for creating a single product instance at a specified simulation time in vcProductCreatorTableMode. Note that instances of this class are stand-alone objects, not wrappers for internal native objects, which means that modifying them will not change anything in vcProductCreatorTableMode.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductCreatorTableRow.htm"""

    @property
    def ProductType(self) -> vcProductType:
        """The product type to instantiate. Value should not be None."""
        pass

    @ProductType.setter
    def ProductType(self, value : vcProductType) -> None:
        pass

    @property
    def CreationTime(self) -> float:
        """Simulation time in seconds when to create the product instance. Value must be greater than or equal to zero."""
        pass

    @CreationTime.setter
    def CreationTime(self, value : float) -> None:
        pass


class vcProductFeed(vcObject):
    """A product feed is an abstract object that informs Visual Components about a product that is ready for transport or the next process.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductFeed.htm"""

    @property
    def Product(self) -> vcProduct:
        """Product instance in the simulation."""
        pass

    @property
    def NextProcessFlowOptions(self) -> List[vcFeedOptionFlowInfo]:
        """List of options (in priority order) to be matched to possible needs."""
        pass

    @property
    def NextProcessGroupId(self) -> str:
        """Name of the target process."""
        pass

    @property
    def SourceNode(self) -> vcTransportNode:
        """Current location of the product instance."""
        pass

    def tryCancel(self: Any) -> bool:
        """Cancels a match and removes the feed from vcProductMatcher. A match cannot be cancelled after the match has been finalized. Returns True if the match was cancelled or the feed was not found in the product matcher."""
        pass

    OnMatched : Callable[[vcProductNeedFeedMatch], None]
    """Triggered when the feed is matched with a need."""



class vcProductFeedInfo(vcObject):
    """A product feed is an abstract object that informs Visual Components about a product that is ready for transport or the next process.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductFeedInfo.htm"""

    @property
    def Product(self) -> vcProduct:
        """Product instance in the simulation."""
        pass

    @property
    def NextProcessFlowOptions(self) -> List[vcFeedOptionFlowInfo]:
        """List of options (in priority order) to be matched to possible needs."""
        pass

    @property
    def NextProcessGroupId(self) -> str:
        """Name of the target process."""
        pass

    @property
    def SourceNode(self) -> vcTransportNode:
        """Current location of the product instance."""
        pass


class vcProductFilter(vcObject):
    """vcProductFilter is a base class for all product filters. A product filter determines if a particular product instance is accepted or not.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductFilter.htm"""

    @property
    def Name(self) -> str:
        """Filter name"""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def IsEnabled(self) -> bool:
        """When set to true, the filter will be active.
 When set to false, the filter will accept any product."""
        pass

    @IsEnabled.setter
    def IsEnabled(self, value : bool) -> None:
        pass

    @property
    def Owner(self) -> Union[vcStatement, vcProductTypeAssemblyPatternItem]:
        """Gets filter owner"""
        pass

    @property
    def ProductAccessor(self) -> str:
        """This property exist only in: ExpressionFilter Properties.
Product name accessor"""
        pass

    @ProductAccessor.setter
    def ProductAccessor(self, value : str) -> None:
        pass

    @property
    def Expression(self) -> str:
        """This property exist only in: ExpressionFilter Properties.
Expression to compare against"""
        pass

    @Expression.setter
    def Expression(self, value : str) -> None:
        pass

    @property
    def FilterDiagnosticsMode(self) -> int:
        """This property exist only in: ExpressionFilter Properties, ProductPropertyFilter Properties.
Print additional diagnostic messages if product is not matched by filter.
 See FilterDiagnosticsMode constants for more information."""
        pass

    @FilterDiagnosticsMode.setter
    def FilterDiagnosticsMode(self, value : int) -> None:
        pass

    @property
    def TargetProperty(self) -> str:
        """This property exist only in: ProductPropertyFilter Properties.
Target property name"""
        pass

    @TargetProperty.setter
    def TargetProperty(self, value : str) -> None:
        pass

    @property
    def Operator(self) -> int:
        """This property exist only in: ProductPropertyFilter Properties.
Comparison operation.
 See Boolean Comparison Operator constants for more information."""
        pass

    @Operator.setter
    def Operator(self, value : int) -> None:
        pass

    @property
    def ComparisonValue(self) -> str:
        """This property exist only in: ProductPropertyFilter Properties.
Value to compare against"""
        pass

    @ComparisonValue.setter
    def ComparisonValue(self, value : str) -> None:
        pass

    @property
    def ProductVariableName(self) -> str:
        """This property exist only in: SpecificProductFilter Properties.
Product variable name"""
        pass

    @ProductVariableName.setter
    def ProductVariableName(self, value : str) -> None:
        pass

    @property
    def CompareMode(self) -> int:
        """This property exist only in: SpecificProductFilter Properties.
Comparison mode – used only when product variable is a list.
 See CompareMode constants for more information."""
        pass

    @CompareMode.setter
    def CompareMode(self, value : int) -> None:
        pass

    def acceptsProduct(self: Any, product: vcProduct) -> bool:
        """Tests the given product instance against the filter. Returns True if the product instance passes the filter. Throws an error if the product is None."""
        pass

    def reset(self: Any) -> None:
        """Resets filter"""
        pass

    def createProperty(self: Any, type: int, name: str) -> vcProperty:
        """Creates property"""
        pass

    def deleteProperty(self: Any) -> None:
        """Deletes property"""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Gets property"""
        pass

    def getComponent(self: Any) -> vcNode:
        """Returns the component if the filter is in a statement/process"""
        pass


class vcProductFilterStatement(vcStatement):
    """https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductFilterStatement.htm"""

    @property
    def Filter(self) -> vcProductFilter:
        """Filter"""
        pass

    @property
    def AcceptAllProductTypes(self) -> bool:
        """(Deprecated) Use vcProductFilter.IsEnabled property instead.
 When set to True, any product is accepted and AcceptedFlowGroups and AcceptedProductTypes are ignored.
 
 AcceptAllProductTypes property is synchronized with an inverse of vcProductFilter.IsEnabled.
 This way:
 
 Setting AcceptAllProductTypes to True will set IsEnabled to False
 Setting IsEnabled to True will set AcceptAllProductTypes to False."""
        pass

    @AcceptAllProductTypes.setter
    def AcceptAllProductTypes(self, value : bool) -> None:
        pass

    @property
    def AcceptedFlowGroups(self) -> List[vcProcessFlowGroup]:
        """(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected flow groups."""
        pass

    @AcceptedFlowGroups.setter
    def AcceptedFlowGroups(self, value : List[vcProcessFlowGroup]) -> None:
        pass

    @property
    def AcceptedProductTypes(self) -> List[vcProductType]:
        """(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected product types."""
        pass

    @AcceptedProductTypes.setter
    def AcceptedProductTypes(self, value : List[vcProductType]) -> None:
        pass

    def setFilter(self: Any, filterType: vcProductTypeFilter) -> vcProductFilter:
        """Sets to specific filter"""
        pass

    def replaceFrom(self: Any, other: vcProductFilterStatement) -> vcProductFilter:
        """Sets filter from other container"""
        pass

    def promoteToCombinationFilter(self: Any) -> vcProductFilter:
        """Upgrades current filter to combination filter"""
        pass

    def demoteFromCombinationFilter(self: Any) -> vcProductFilter:
        """Downgrades back to filter, filter count must have 1 or 0 filters."""
        pass

    OnFilterChanged : Callable[[], None]
    """Triggered when filter is changed"""



class vcProductMatcher(vcObject):
    """vcProductMatcher monitors product needs (vcProductNeed) and feeds (vcProductFeed) and matches the needs and feeds with each other. A vcProductNeedFeedMatch instance is created for each matched pair.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductMatcher.htm"""

    @property
    def PendingNeedsCount(self) -> int:
        """Number of needs that have not yet been matched."""
        pass

    @property
    def PendingNeeds(self) -> List[vcProductNeedInfo]:
        """List of all pending needs."""
        pass

    @property
    def PendingFeedsCount(self) -> int:
        """Number of feeds that have not yet been matched."""
        pass

    @property
    def PendingFeeds(self) -> List[vcProductFeedInfo]:
        """List of all pending feeds."""
        pass

    def getPendingNeed(self: Any, index: int) -> vcProductNeedInfo:
        """Returns a pending need found at a given index in list."""
        pass

    def getPendingFeed(self: Any, index: int) -> vcProductFeedInfo:
        """Returns a pending feed found at a given index in list."""
        pass

    def addNeed(self: Any, productNeed: vcProductNeed) -> None:
        """Adds the productNeed to the product matcher to be matched with a feed.
An error occurs if the same productNeed has already been added, or if the productNeed is linked to an active vcProductNeedFeedMatch object."""
        pass

    def addFeed(self: Any, productFeed: vcProductFeed) -> None:
        """Adds the productFeed to the product matcher to be matched with a need.

An error occurs if the same productFeed has already been added, or if the productFeed is already linked to an active vcProductNeedFeedMatch object."""
        pass

    OnPendingNeedAdded : Callable[[vcProductNeedInfo], None]
    """Triggered when a new need has been added to the product matcher."""


    OnPendingFeedAdded : Callable[[vcProductFeedInfo], None]
    """Triggered when a new feed has been added to the product matcher."""



class vcProductNeed(vcObject):
    """A product need is an abstract object that informs Visual Components about a process that is ready for a product.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductNeed.htm"""

    @property
    def ProductFilter(self) -> vcProductFilter:
        """Filter defining the products that the process accepts."""
        pass

    @property
    def TargetProcessGroupId(self) -> str:
        """Name of the target process. To be matched with a feed, TargetProcessGroupId needs to have the same value as the feed's NextProcessGroupId property."""
        pass

    @property
    def TargetNode(self) -> vcTransportNode:
        """Target location of the product. This is usually the process that creates the need.
 
 For a need and feed to be matched, a valid transportation solution must exist between the feed's SourceNode and the need's TargetNode."""
        pass

    @property
    def NeedMatchType(self) -> int:
        """Type and requirements for matching the need with a feed. 
 See the product match types in Product Matcher Constants."""
        pass

    @property
    def RegistrationSimTime(self) -> float:
        """Time in the simulation when the need has been added to the product matcher."""
        pass

    def tryCancel(self: Any) -> bool:
        """Cancels a match and removes the need from the product matcher. A match cannot be cancelled after the match has been finalized. Returns True if a match was cancelled or the need was not found in the product matcher."""
        pass

    OnMatched : Callable[[vcProductNeedFeedMatch], None]
    """Triggered when the need is matched with a feed."""



class vcProductNeedFeedMatch(vcObject):
    """vcProductNeedFeedMatch is created when vcProductMatcher matches a need and a feed with each other. vcProductNeedFeedMatch stores the properties of the mached need and feed, and controls the state of the match.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductNeedFeedMatch.htm"""

    @property
    def State(self) -> int:
        """State of the match. See the match state options in Product Matcher Constants."""
        pass

    @property
    def SelectedProcessFlowInfo(self) -> vcNextProcessFlowInfo:
        """FlowInfo that was selected in the Feed-Need matching process."""
        pass

    @property
    def MatchedNeed(self) -> vcProductNeedInfo:
        """Properties of the matched need. After a match has been disposed, the value is None."""
        pass

    @property
    def MatchedFeed(self) -> vcProductFeedInfo:
        """Properties of the matched feed. After a match has been disposed, the value is None."""
        pass

    def tryCancelMatch(self: Any) -> None:
        """Attempt to cancel the match. Returns true if cancelling is successful. A match cannot be cancelled after the match has been finalized."""
        pass

    def finalizeMatch(self: Any, receivingNeed: vcProductNeed = ...) -> None:
        """Sets the match state to Finalized. Normally, done by the need owner in vcProductNeed.OnMatched event handler. Optionally, can replace the MatchedNeed if receivingNeed is given."""
        pass

    def dispose(self: Any) -> None:
        """Disposes a completed or cancelled match, so that the vcProductNeed and vcProductFeed objects can be reused for another match. Changes the State to Disposed and sets the values of MatchedNeed and MatchedFeed to None. If dispose is called from within a state change event handler, disposing is delayed and will only be executed after all event handlers have been called. dispose can only be called when the State is Finalized, Cancelled, or Disposed. If the State is already Disposed, dispose does nothing."""
        pass

    OnStateChanged : Callable[[vcProductNeedFeedMatch, int], None]
    """Triggered when the state of the match has been changed.
 See the match state options in Product Matcher Constants."""


    OnNeedOrFeedDead : Callable[[vcProductNeedFeedMatch], None]
    """Triggered when the value of either MatchedNeed or MatchedFeed is set to None."""



class vcProductNeedInfo(vcObject):
    """A product need is an abstract object that informs Visual Components about a process that is ready for a product.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductNeedInfo.htm"""

    @property
    def ProductFilter(self) -> vcProductFilter:
        """Filter defining the products that the process accepts."""
        pass

    @property
    def TargetProcessGroupId(self) -> str:
        """Name of the target process. To be matched with a feed, TargetProcessGroupId needs to have the same value as the feed's NextProcessGroupId property."""
        pass

    @property
    def TargetNode(self) -> vcTransportNode:
        """Target location of the product. This is usually the process that creates the need.
 
 For a need and feed to be matched, a valid transportation solution must exist between the feed's SourceNode and the need's TargetNode."""
        pass

    @property
    def NeedMatchType(self) -> int:
        """Type and requirements for matching the need with a feed. 
 See the product match types in Product Matcher Constants."""
        pass

    @property
    def RegistrationSimTime(self) -> float:
        """Time in the simulation when the need has been added to the product matcher."""
        pass


class vcProductType(vcObject):
    """Product type is a product definition that is used to create vcProduct instances.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductType.htm"""

    @property
    def Name(self) -> str:
        """Name of this product type. Must be unique within the owning process controller."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def UniqueId(self) -> str:
        """Unique identifier for this product type used internally."""
        pass

    @property
    def FlowGroup(self) -> vcProcessFlowGroup:
        """The flow group that this product type belongs to. Use methods in vcProcessFlowGroup to associate the type to another flow group."""
        pass

    @property
    def IsAssembly(self) -> bool:
        """Returns True if this product type is assembly product type."""
        pass

    @property
    def IsSystem(self) -> bool:
        """Returns True if this product type is special internal type."""
        pass

    @property
    def ParentProduct(self) -> vcProductType:
        """The product type this type is derived from."""
        pass

    @ParentProduct.setter
    def ParentProduct(self, value : vcProductType) -> None:
        pass

    @property
    def OriginFrame(self) -> vcMatrix:
        """Defines relative position of product and its component as offset from component origin to origin of product instance."""
        pass

    @OriginFrame.setter
    def OriginFrame(self, value : vcMatrix) -> None:
        pass

    @property
    def ComponentUri(self) -> str:
        """Simulation component type used to visualize product instances created from this product type. Setting this Uri causes the product type to immediately attempt to load and make an internal copy of the component.
 Note: Special “component” Uri scheme (component:componentName) can be used to point to an existing static component in the simulation layout."""
        pass

    @ComponentUri.setter
    def ComponentUri(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets the properties of this product type itself. All properties might not have a vcProperty implementation."""
        pass

    @property
    def ComponentProperties(self) -> List[vcProperty]:
        """Gets the properties that are applied to components of product instances created from this product type."""
        pass

    @property
    def ProductProperties(self) -> List[vcProperty]:
        """Gets the properties that are applied to product instances created from this product type."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a property of the product type itself."""
        pass

    def createProduct(self: Any, container: vcContainer = ..., assemblyConfiguration: vcAssemblyConfiguration = ...) -> vcProduct:
        """Creates and returns a new product instance of this product type. If container is given, the product component will be added to it, otherwise the product is added to the world container."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property of the product type itself."""
        pass

    def createProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Creates a new property to the product type itself.
 An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation.
 See Property Constants for more information."""
        pass

    def createComponentProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Creates a new component instance property to this product type.
 An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation.
 See Property Constants for more information."""
        pass

    def deleteComponentProperty(self: Any, property: vcProperty) -> None:
        """Deletes a component instance property from this product type."""
        pass

    def getComponentProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a component instance property defined in this product type."""
        pass

    def createProductProperty(self: Any, type: int, name: str, constraints: int = ...) -> vcProperty:
        """Creates a new product instance property to this product type.
 An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation.
 See Property Constants for more information."""
        pass

    def deleteProductProperty(self: Any, property: vcProperty) -> None:
        """Deletes a product instance property from this product type."""
        pass

    def getProductProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a product instance property defined in this product type."""
        pass

    def resetUniqueId(self: Any) -> None:
        """Assigns a new unique id for this product type."""
        pass


class vcProductTypeAssemblyPatternItem(vcAssemblyPatternItem):
    """Inherits: vcAssemblyPatternItem
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductTypeAssemblyPatternItem.htm"""

    @property
    def Filter(self) -> vcProductFilter:
        """Filter"""
        pass

    @property
    def AcceptAllProductTypes(self) -> bool:
        """(Deprecated) Use vcProductFilter.IsEnabled property instead.
 
 When set to True, any product is accepted and AcceptedFlowGroups and AcceptedProductTypes are ignored.
 
 AcceptAllProductTypes property is synchronized with an inverse of vcProductFilter.IsEnabled.
 This way:
 
 Setting AcceptAllProductTypes to True will set IsEnabled to False.
 Setting IsEnabled to True will set AcceptAllProductTypes to False."""
        pass

    @AcceptAllProductTypes.setter
    def AcceptAllProductTypes(self, value : bool) -> None:
        pass

    @property
    def AcceptedProductTypes(self) -> List[vcProductType]:
        """(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected product types."""
        pass

    @AcceptedProductTypes.setter
    def AcceptedProductTypes(self, value : List[vcProductType]) -> None:
        pass

    @property
    def AcceptedFlowGroups(self) -> List[vcProcessFlowGroup]:
        """(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected flow groups."""
        pass

    @AcceptedFlowGroups.setter
    def AcceptedFlowGroups(self, value : List[vcProcessFlowGroup]) -> None:
        pass

    def setFilter(self: Any, filterType: vcProductTypeFilter) -> vcProductFilter:
        """Sets to specific filter"""
        pass

    OnFilterChanged : Callable[[], None]
    """Triggered when filter is changed"""



class vcProductTypeFilter(vcProductFilter):
    """vcProductTypeFilter is a product filter that accepts or rejects products 
 based on the vcProductType of the vcProduct 
 instance. A product will be accepted by the product filter if the product 
 type or its flow group matches the filter, unless the AcceptAllProductTypesproperty 
 is set to True.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductTypeFilter.htm"""

    @property
    def AcceptAllProductTypes(self) -> bool:
        """(Deprecated) Use vcProductFilter.IsEnabled 
	 property instead.
	
	When set to True, any product is accepted and AcceptedFlowGroups 
	 and AcceptedProductTypes are ignored.
	
	AcceptAllProductTypes property is synchronized with an inverse 
	 of vcProductFilter.IsEnabled.
	This way: 
	
	Setting AcceptAllProductTypes to True will set IsEnabled 
	 to False.
	Setting IsEnabled to True will set AcceptAllProductTypes 
	 to False."""
        pass

    @AcceptAllProductTypes.setter
    def AcceptAllProductTypes(self, value : bool) -> None:
        pass

    @property
    def AcceptedFlowGroups(self) -> List[vcProcessFlowGroup]:
        """Allows only the selected flow groups."""
        pass

    @AcceptedFlowGroups.setter
    def AcceptedFlowGroups(self, value : List[vcProcessFlowGroup]) -> None:
        pass

    @property
    def AcceptedProductTypes(self) -> List[vcProductType]:
        """Allows only the selected product types."""
        pass

    @AcceptedProductTypes.setter
    def AcceptedProductTypes(self, value : List[vcProductType]) -> None:
        pass


class vcProductTypeManager(vcObject):
    """The product type manager is used to create, modify and delete vcProductType or vcAssemblyProductType objects. It is owned by a vcProcessController.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProductTypeManager.htm"""

    @property
    def Controller(self) -> vcProcessController:
        """Gets the owner process controller."""
        pass

    @property
    def ProductTypes(self) -> Union[List[vcProductType], vcAssemblyProductType]:
        """Gets a list of all product types in this process controller. vcAssemblyProductType are listed where appropriate."""
        pass

    def createProductType(self: Any, name: str, groupToPlaceObject: vcProcessFlowGroup, createAssemblyProductType: bool) -> Union[vcProductType, vcAssemblyProductType]:
        """Creates new product type and assigns it to the given flow group. The name must be unique.
 When createAssemblyProductType is set to True, creates and returns vcAssemblyProductType. Otherwise, creates and returns vcProductType."""
        pass

    @overload
    def deleteProductType(self: Any, typeToDelete: vcProductType) -> None:
        """Tries to delete the given product type. Cannot delete system product types or product types from a different process controller.
 Tries to delete product type with given name. Cannot delete system product types or product types from a different process controller."""
        pass

    @overload
    def deleteProductType(self: Any, typeName: str) -> None:
        """Tries to delete the given product type. Cannot delete system product types or product types from a different process controller.
 Tries to delete product type with given name. Cannot delete system product types or product types from a different process controller."""
        pass

    def findProductType(self: Any, name: str) -> vcProductType:
        """Tries to find a product type with the given name. Returns None if not found."""
        pass

    OnProductTypeAdded : Callable[[Union[vcProductType, vcAssemblyProductType]], None]
    """Triggered when a new product type has been added to this process controller."""


    OnProductTypeRemoving : Callable[[Union[vcProductType, vcAssemblyProductType]], None]
    """Triggered when a product type is being removed from this process controller."""



class vcProgram(vcObject):
    """vcProgram is an executable program that can be run by vcExecutor objects. Every executor, by default, has its own a built-in program.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProgram.htm"""

    @property
    def Executor(self) -> vcExecutor:
        """Gets the executor of the program."""
        pass

    @property
    def MainRoutine(self) -> vcRoutine:
        """Gets the main routine of the program."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of the program."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of properties in the program."""
        pass

    @property
    def Routines(self) -> List[vcRoutine]:
        """Gets a list of all routines in the program other than the main routine."""
        pass

    def addRoutine(self: Any, name: str) -> vcRoutine:
        """Creates a new routine of a given name in the program, and then returns the new routine."""
        pass

    def createProperty(self: Any, type: int, name: str) -> vcProperty:
        """Creates a new property of a given type and name in the program, and then returns the new property.
An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation.
See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property in the program."""
        pass

    def deleteRoutine(self: Any, routine: vcRoutine) -> None:
        """Deletes a given routine from the program."""
        pass

    def findRoutine(self: Any, name: str) -> vcRoutine:
        """Returns a routine matching a given name in the program; otherwise returns None."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name in the program; otherwise returns None."""
        pass

    OnRoutineAdded : Callable[[vcRoutine], None]
    """Triggered when a new routine is added to the program."""


    OnRoutineRemoving : Callable[[vcRoutine], None]
    """Triggered when a routine is being deleted from the program."""


    OnStatementAdded : Callable[[vcStatement], None]
    """Triggered when a statement is added to the program."""


    OnStatementRemoving : Callable[[vcStatement], None]
    """Triggered when a statement is removed from the program."""



class vcProperty(vcObject):
    """vcProperty is a property object with its own set of properties, methods and event handlers.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcProperty.htm"""

    @property
    def CalculatedValue(self) -> Any:
        """Gets the calculated value of property.
 Generally, this is used to get the result of an Expression type property whose Value is an expression passed as a string. All other types, except Distribution, would return the same as Value."""
        pass

    @property
    def ChangeOnRebuild(self) -> bool:
        """Defines if component geometry is rebuilt when property value is changed."""
        pass

    @ChangeOnRebuild.setter
    def ChangeOnRebuild(self, value : bool) -> None:
        pass

    @property
    def ChangeOnReconfigure(self) -> bool:
        """Defines if component structure is reconfigured when property value is changed."""
        pass

    @ChangeOnReconfigure.setter
    def ChangeOnReconfigure(self, value : bool) -> None:
        pass

    @property
    def ChangeOnUpdate(self) -> bool:
        """Defines if simulation world is updated when property value is changed."""
        pass

    @ChangeOnUpdate.setter
    def ChangeOnUpdate(self, value : bool) -> None:
        pass

    @property
    def Distribution(self) -> str:
        """If Distribution type property, defines an expression to use for calculating values.
 Available functions include:
 normal( u, s )
 Normal distribution for mean value u, and the standard deviation s.
 lognormal( u, s )
 Log normal distribution for mean u, and the standard deviation s.
 uniform( a, b )
 Uniform distribution in range a <= x < b.
 exponential( lambda )
 Exponential distribution where the mean is 1/lambda and the variance is 1/lambda^2.
 gamma( k, theta )
 Gamma distribution with shape k and scale theta.
 triangular( min, mode, max )
 Triangular distribution with the specified minimum, mode and maximum values.
 weibull( k, lambda )
 Weibull distribution with shape k and scale lambda.
 Tip: Use RandomStream to have the distribution use a stream for seeding a value and generating the same set of random numbers during a simulation. That is, if you reset and run a simulation you should expect the same values given in the previous simulation."""
        pass

    @Distribution.setter
    def Distribution(self, value : str) -> None:
        pass

    @property
    def Group(self) -> int:
        """Defines the group assignment of property.
 Properties are ordered by groups, and a group number is automatically assigned at the time of creation. This order can be overridden to have properties come before or after one another when listed in the GUI."""
        pass

    @Group.setter
    def Group(self, value : int) -> None:
        pass

    @property
    def IgnoreEvents(self) -> bool:
        """Defines if event passing is ignored by property, for example to avoid cyclic calls."""
        pass

    @IgnoreEvents.setter
    def IgnoreEvents(self, value : bool) -> None:
        pass

    @property
    def IsVisible(self) -> bool:
        """Turns on/off the visibility of property in Properties panel."""
        pass

    @IsVisible.setter
    def IsVisible(self, value : bool) -> None:
        pass

    @property
    def IsVisibleDesignTime(self) -> bool:
        """Turns on/off the visibility of property in Component Cell Graph panel."""
        pass

    @IsVisibleDesignTime.setter
    def IsVisibleDesignTime(self, value : bool) -> None:
        pass

    @property
    def IsDesignTime(self) -> bool:
        """Defines if property is used for component authoring."""
        pass

    @IsDesignTime.setter
    def IsDesignTime(self, value : bool) -> None:
        pass

    @property
    def IsPersistent(self) -> bool:
        """Defines if property value is saved with component or layout."""
        pass

    @IsPersistent.setter
    def IsPersistent(self, value : bool) -> None:
        pass

    @property
    def ListValueCount(self) -> int:
        """Gets the number of values listed in property."""
        pass

    @property
    def ListValues(self) -> List[vcPropertyListValue]:
        """Gets a list of values for property."""
        pass

    @property
    def Magnitude(self) -> float:
        """Gets the conversion factor of unit assigned to property.
 The conversion factor is used to convert the value of property to and from its canonical unit. For example, if the property has a Quantity of Distance with a Unit of millimeters (mm), the magnitude is 1. If Unit is meters (m), the magnitude is 1000.0.
 Note: You can use setUnitMagnitude() to change the unit of property based on the current unit group of its quantity. For example, a magnitude of 10 would most likely change the unit to centimeters (cm) if the quantity of property was Distance."""
        pass

    @property
    def MaxValue(self) -> Any:
        """If property supports a limit constraint, defines maximum value of property."""
        pass

    @MaxValue.setter
    def MaxValue(self, value : Any) -> None:
        pass

    @property
    def MinValue(self) -> Any:
        """If property supports a limit constraint, defines the minimum value of property."""
        pass

    @MinValue.setter
    def MinValue(self, value : Any) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of property."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Quantity(self) -> Union[vcScalarQuantity, vcVectorQuantity]:
        """Defines the quantity of property.
 Tip: You assign the quantity by name using a string, for example Distance, thereby the application will search for and assign a quantity matching that name."""
        pass

    @Quantity.setter
    def Quantity(self, value : Union[vcScalarQuantity, vcVectorQuantity]) -> None:
        pass

    @property
    def RandomStream(self) -> int:
        """If Distribution type property, defines a stream used for generating pseudo-random values.
 Every layout has a RandomStreams layout item, which has a set of RandomSeedN properties where N is 0 to 63, which contain the seed values for each stream.
 A random stream can be used in distribution function, for example normal(stream,u,s) in which stream is the index of stream in the layout to use, u is mean value and s is standard deviation."""
        pass

    @RandomStream.setter
    def RandomStream(self, value : int) -> None:
        pass

    @property
    def StepValues(self) -> List[Any]:
        """If property has a step constraint, defines a list of step values for property."""
        pass

    @StepValues.setter
    def StepValues(self, value : List[Any]) -> None:
        pass

    @property
    def SupportsTemplate(self) -> bool:
        """Indicates if property supports the use of a templates."""
        pass

    @property
    def Templates(self) -> List[str]:
        """Gets a list of names of the templates in the property."""
        pass

    @property
    def Type(self) -> int:
        """Gets the property type.
 See Property Constants for more information."""
        pass

    @property
    def Unit(self) -> vcUnit:
        """Gets the unit of property.
 Note: Use setUnitMagnitude() to change the unit of property. The magnitude should be the conversion factor of unit in the current unit group of quantity assigned to property."""
        pass

    @property
    def Value(self) -> Any:
        """Gets/Sets property value."""
        pass

    @Value.setter
    def Value(self, value : Any) -> None:
        pass

    @property
    def WritableWhenConnected(self) -> bool:
        """Defines if property value can be set when component of property is connected to another component via interface."""
        pass

    @WritableWhenConnected.setter
    def WritableWhenConnected(self, value : bool) -> None:
        pass

    @property
    def WritableWhenDisconnected(self) -> bool:
        """Defines if property value can be set when component of property is not connected to another component via interface."""
        pass

    @WritableWhenDisconnected.setter
    def WritableWhenDisconnected(self, value : bool) -> None:
        pass

    @property
    def WritableWhenSimulating(self) -> bool:
        """Defines if property value can be set when a simulation is running."""
        pass

    @WritableWhenSimulating.setter
    def WritableWhenSimulating(self, value : bool) -> None:
        pass

    def addValueFromTemplate(self: Any, prop: str) -> vcPropertyListValue:
        """Adds value from template to property."""
        pass

    def deleteValue(self: Any, index: int) -> None:
        """If property has step constraint, deletes a value at a given index from property."""
        pass

    def getValue(self: Any, index: int) -> vcPropertyListValue:
        """If property has step constraint, gets value at a given index from property."""
        pass

    def setUnitMagnitude(self: Any, magnitude: float) -> None:
        """Sets the unit of property based on the given magnitude.
 The magnitude is the conversion factor of unit you want to assign to property. The unit should belong to the current unit group of quantity assigned to property."""
        pass

    OnChanged : Callable[[vcProperty], None]
    """Triggered when value of property is changed."""



class vcPropertyListValue(vcObject):
    """vcPropertyListValue is a list of possible values defined in a vcProperty object.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPropertyListValue.htm"""

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of properties specific to list value."""
        pass

    @property
    def Template(self) -> str:
        """Gets the name of template for list value."""
        pass


class vcPythonKinematics(vcBehaviour):
    """vcPythonKinematics allows you to create custom kinematics, which can be used by robot controllers to drive and manage robot movements.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPythonKinematics.htm"""

    @property
    def Name(self) -> str:
        """Defines the name of the kinematics object."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Application(self) -> vcApplication:
        """Gets the application object."""
        pass

    @property
    def Simulation(self) -> vcSimulation:
        """Gets the simulation object."""
        pass

    @property
    def Script(self) -> str:
        """Defines the executable Python code of kinematics object, thereby the custom kinematics of a vcKinObject object.
 See Python Kinematics for more information."""
        pass

    @Script.setter
    def Script(self, value : str) -> None:
        pass

    def forwardKin(self: Any, values: List[float]) -> vcMatrix:
        """Returns a forward kinematics matrix calculated for given joint values."""
        pass

    def getApplication(self: Any) -> vcApplication:
        """Returns the application object."""
        pass

    def getComponent(self: Any) -> vcComponent:
        """Returns the component of the kinematics object."""
        pass

    def getNode(self: Any) -> vcNode:
        """Returns the node containing the kinematics object."""
        pass

    def getSimulation(self: Any) -> vcSimulation:
        """Returns the simulation object."""
        pass

    def sasa(self: Any, side1: float, angle: float, side2: float) -> float:
        """Returns the angle (in radians) of a triangle based on two given sides and the angle between them.
 In this case, the third side of a triangle is calculated, and then used to calculate the angle between that side and the second side argument."""
        pass

    def sass(self: Any, side1: float, angle: float, side2: float) -> float:
        """Returns the side of a triangle based on two given sides and the angle between them."""
        pass

    def sssa(self: Any, side1: float, side2: float, side3: float) -> float:
        """Returns the angle (in radians) of a triangle based on three given sides.
 In this case, returned angle is the angle opposite the first side argument."""
        pass

    OnCalculateTarget : Callable[[vcMatrix, vcMatrix, vcMatrix, bool], None]
    """Triggered when a motion target is being calculated, thereby allowing you to edit the motion target that will be passed to OnInverse event.
 The fullTarget argument is the target matrix calculated from either World origin or Robot World Frame to TCP.
 The baseFrame and toolFrame arguments define the base and tool frames used for motion target.
 The targetInverted argument can be used to reverse the target's calculation, for example from TCP to base frame.
 Generally, you should use OnCalculateTarget for robots that have less than six degrees of freedom to remove potential effects caused by a tool offset."""


    OnConstrainParams : Callable[[vcKinObject], None]
    """Triggered when the joint configuration of a robot or motion target is being interpolated and requires joint limits to determine valid kinematic solutions.
 Generally, you use OnConstrainParams to avoid potential joint limit errors and narrow possible solutions for a joint motion target. For example, you can specify the limits of a joint for certain types of movements.
 The return value should be a Boolean."""


    OnFinalize : Callable[[], None]
    """Triggered when layout or component is being loaded in 3D world.
 The event occurs, for example, when copying a component, or loading a layout of components. The event is triggered before the needed components are attached to the 3D world.
 Generally, you use OnFinalize to set the joint initial position of a robot or any necessary implementation that uses kinematics."""


    OnForward : Callable[[vcKinObject], None]
    """Triggered when a motion target is calculated using joint values.
 Return a Boolean value to enable or disable forward kinematics."""


    OnGetConfigurationCount : Callable[[], None]
    """Triggered when the configuration count of a robot is requested by the kinematics solver.
 If configuration properties are dynamically changing, this event must be implemented and return a constant integer value, which overrides the default count defined in the OnInitKinObject event.
 Important: If OnGetConfigurationCount is used, you need to implement the OnGetCurrentConfiguration and OnSetCurrentConfiguration events."""


    OnGetCurrentConfiguration : Callable[[], None]
    """Triggered when the current configuration of a robot is requested by its kinematics solver.
 If this event is implemented, you should read the robot's configurations property list, and then return the currently selected index position (integer). That value must be greater than or equal to 0 and less than the value returned by the OnGetConfigurationCount event.
 Important: If OnGetCurrentConfiguration is used, you need to implement the OnGetConfigurationCount and OnSetCurrentConfiguration events."""


    OnGetJointCount : Callable[[], None]
    """Triggered when the joint count of a robot is requested by the kinematics solver.
 In most cases, you should the total joint count as an integer."""


    OnGetJointName : Callable[[int], None]
    """Triggered when the name of a joint at a given index is requested by kinematics solver.
 The return value should be a string."""


    OnGetKinematicJointCount : Callable[[], None]
    """Triggered when the actual number of kinematic joints used in forward kinematics is requested by kinematics solver.
 Generally, additional helper joints are needed for interpolating redundant solutions.
 The return value should be an integer."""


    OnGetSecondaryJointCount : Callable[[], None]
    """Triggered when the external joint count of a robot is requested by kinematics solver.
 In most cases, you should return the total joint count as an integer value."""


    OnGetSecondaryJointName : Callable[[int], None]
    """Triggered when the name of an external joint at a given index is requested by kinematics solver.
 The return value should be a string."""


    OnInitKinObject : Callable[[vcKinObject], None]
    """Triggered when a new instance of vcKinObject is created, thereby allowing you to access and edit the kinematics object of a component.
 Generally, you use OnInitKinObject to add new properties and define initial values for a kinematics object."""


    OnInverse : Callable[[vcKinObject], None]
    """Triggered when the joint values of a motion target need to be calculated and given as a solution for the kinematics object.
 Return a Boolean value to enable or disable inverse kinematics."""


    OnRebuild : Callable[[], None]
    """Triggered when the kinematics object is rebuilt, thereby updating changes made to its properties."""


    OnRelaxParams : Callable[[vcKinObject], None]
    """Triggered when possible solutions for a motion target are being calculated by kinematics solver.
 Generally, you use OnRelaxParams to allow for all possible solutions, even those which exceed joint limits. For example, you might want to force a robot motion with potential risks such as singularity or Gimbal lock."""


    OnSetCurrentConfiguration : Callable[[int], None]
    """Triggered when the configuration of a robot is needed for a kinematic solution.
 If this event is implemented, you should set the robot's configurations property list based on the given configurationIndex.
 Important: If OnSetCurrentConfiguration is used, you need to implement the OnGetConfigurationCount and OnGetCurrentConfiguration events."""


    OnUpdateSecondaryJoints : Callable[[vcKinObject], None]
    """Triggered when external joint values need to be recalculated for motion target updates.
 The return value should be a Boolean."""



class vcPythonProcessHandler(vcBehaviour):
    """vcPythonProcessHandler is a behavior that allows you to define a custom robot statement written in Python. You can also use this behavior as a handler for overriding the default execution of statements in a robot program.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPythonProcessHandler.htm"""

    @property
    def Icon(self) -> vcBitmap:
        """Defines an icon for the process when referenced by a process statement in the GUI."""
        pass

    @Icon.setter
    def Icon(self, value : vcBitmap) -> None:
        pass

    @property
    def Process(self) -> str:
        """Defines the name and id of process."""
        pass

    @Process.setter
    def Process(self, value : str) -> None:
        pass

    @property
    def Script(self) -> str:
        """Defines the executable Python code of process."""
        pass

    @Script.setter
    def Script(self, value : str) -> None:
        pass

    def condition(self: Any, condition: Callable[[], bool], timeout: float = ...) -> None:
        """Runs a conditional test that stops process execution until a given function returns a True value.
 The given function can either be a lambda function or one defined in Script.
 Evaluation of condition is done continuously.
 NOTE: implementation is different in vcScript"""
        pass

    def delay(self: Any, time: float) -> None:
        """Executes timed delay during process execution."""
        pass

    def evaluateCondition(self: Any) -> None:
        """Triggers the evaluation of an active condition() or triggerCondition() function in the script."""
        pass

    def getApplication(self: Any) -> vcApplication:
        """Returns the application object."""
        pass

    def getComponent(self: Any) -> vcComponent:
        """Returns the component containing the process handler."""
        pass

    def getSimulation(self: Any) -> vcSimulation:
        """Returns the simulation object."""
        pass

    def getTrigger(self: Any) -> vcBehaviour:
        """Returns the object triggering an event in Script; otherwise returns None.
 This method is only useful in a condition function passed to condition() and triggerCondition() methods.
 Note: A trigger, for example, is a signal or action connected to process handler."""
        pass

    def resumeRun(self: Any) -> None:
        """Resumes the execution of a suspended OnRun() function."""
        pass

    def suspendRun(self: Any) -> None:
        """Stops the execution of an OnRun() function."""
        pass

    def triggerCondition(self: Any, condition: Callable[[], bool], timeout: float = ...) -> None:
        """Runs a conditional test, triggered during a simulation, that stops process execution until a given function returns a True value.
 The given function can either be a lambda function or one defined in Script.
 Evaluation of condition is done each time a trigger of process handler occurs during a simulation.
 NOTE: implementation is different in vcScript"""
        pass

    OnContinue : Callable[[], None]
    """Triggered when a simulation resumes running after being stopped."""


    OnDestroy : Callable[[], None]
    """Triggered when an object is destroyed in 3D world."""


    OnEvaluate : Callable[[], None]
    """Triggered when component feature tree of process handler is rebuilt."""


    OnFinalize : Callable[[], None]
    """Triggered when layout or component is being loaded in 3D world.
 The event occurs, for example, when copying a component, or loading a layout of components. The event is triggered before the needed components are attached to the 3D world."""


    OnReset : Callable[[], None]
    """Triggered when simulation is reset."""


    OnSignal : Callable[[vcSignal], None]
    """Triggered when the value of a signal connected to process handler is changing."""


    OnStart : Callable[[], None]
    """Triggered at the start of a running simulation."""


    OnStatementAdd : Callable[[vcPositionStatement], None]
    """Triggered when a process statement referring to this process handler is created in robot program.
 Generally, this is used to initialize a vcPositionStatement object referring to this process handler with new properties and initial values."""


    OnStatementDialog : Callable[[vcPositionStatement], None]
    """Triggered when there is an attempt to access properties dialog of process statement referring to this process handler.
 In this case, you need to return True to use standard properties dialog; otherwise return False."""


    OnStatementExecute : Callable[[vcExecutor, vcPositionStatement], None]
    """Triggered when process statement referring to this process handler is executed during a simulation.
 Time consuming methods, for example delay() and condition(), may only be executed in this event handler or in functions called from this event handler.
 Note: A process handler can only be executed at one given time, so multiple calls to the same process will return immediately."""


    OnStatementModified : Callable[[vcPositionStatement], None]
    """Triggered after properties dialog of process statement referring to this process handler is closed."""


    OnStatementRemove : Callable[[vcPositionStatement], None]
    """Triggered when reference to process handler in a process statement is removed."""


    OnStop : Callable[[], None]
    """Triggered when simulation is stopped."""



class vcPythonTransportController(vcTransportController):
    """This is a transport controller behavior that delegates the concrete implementation to user-made Python script(s), which allows creating specialized and custom transport controllers. The behaviour provides events and methods required to handle transport and work tasks. Python transport controller behaviours can be added to static components.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcPythonTransportController.htm"""

    @property
    def Icon(self) -> str:
        """The icon file used to represent this transport controller in UI.
 Defines either filesystem path to the SVG image file or an SVG path data. Both relative and absolute paths with/without .svg extension are allowed. Relative paths are relative to the Icons or Icons. Additional folder under VC installation folder.
 Example: “UPM/pDroneTransportController”"""
        pass

    @Icon.setter
    def Icon(self, value : str) -> None:
        pass

    @property
    def IconColor(self) -> str:
        """Fill color applied to the of the Icon in ARGB, RGB or unqualified-color-name format.
 (e.g. #FFFF0000 or #FF0000 or Red)"""
        pass

    @IconColor.setter
    def IconColor(self, value : str) -> None:
        pass

    @property
    def IsSystem(self) -> bool:
        """Always returns False."""
        pass

    def workDone(self: Any, workId: int) -> None:
        """Notifies the Work statement that work has been done so the process can continue executing."""
        pass

    LinkAssociated : Callable[[vcTransportLink], None]
    """(Deprecated) Use OnLinkAssociated."""


    LinkDisassociated : Callable[[vcTransportLink], None]
    """(Deprecated) Use OnLinkDisassociated."""


    OnBeginTransport : Callable[[List[Tuple[vcTransportLink, vcProduct]]], None]
    """Triggered when the transport controller is asked to transport one or more products. Each product should be transported to the Destination node of the respective transport link."""


    OnBeginWork : Callable[[int, vcProperty, vcMatrix, vcMatrix], None]
    """(DEPRECATED) Use the extended version OnBeginWorkEx instead.
 Triggered when a Work statement gets executed. workDone with correct workId must be called at some point for Work statement to continue execution. If a handler is not registered, Work statement might wait indefinitely.
 workId is a unique (within this transport controller) identifier of this work assignment.
 processTime is a property that defines how long the work itself should take in seconds.
 resourcePosition defines a position hint in world coordinates where the working resource is expected to be while doing the work.
 workPosition defines a position hint in world coordinates where the actual work is expected to happen."""


    OnBeginWorkEx : Callable[[vcDataContainer], None]
    """Triggered when a Work statement gets executed. workDone with correct request id must be called at some point for Work statement to continue execution. If a handler is not registered, Work statement might wait indefinitely.
 The arguments object has the following attributes:
 
 
 
 
 
 
 
 
 
 Name
 Type
 Access
 Description
 
 
 RequestId
 Integer
 R
 
 Unique (within this transport controller) identifier of this work assignment.
 
 
 
 RequestingProcess
 vcProcessRoutine
 R
 
 The process implementation that requested this work.
 
 
 
 ProcessTime
 Real
 R
 
 A value that defines how long the work itself should take in seconds.
 
 
 
 ResourcePositionMatrix
 vcMatrix
 R
 
 Position hint in world coordinates where the working resource is expected to be while doing the work.
 
 
 
 WorkPositionMatrix
 vcMatrix
 R
 
 Position hint in world coordinates where the actual work is expected to happen."""


    OnLinkAssociated : Callable[[vcTransportLink], None]
    """Raised when a transport link is associated with this controller. If a handler is not registered, the default internal implementation is called."""


    OnLinkDisassociated : Callable[[vcTransportLink], None]
    """Raised when a transport link is disassociated from this controller. If a handler is not registered, the default internal implementation is called."""



class vcRealSignal(vcSignal):
    """vcRealSignal is a signal that can send a real number value.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRealSignal.htm"""

    @property
    def Value(self) -> float:
        """Defines the value of signal.
Setting this value does not trigger the OnSignal event unless you use the signal() method."""
        pass

    @Value.setter
    def Value(self, value : float) -> None:
        pass

    def signal(self: Any, value: float = ...) -> None:
        """Signals the current value of signal to all connected behaviors, thereby triggering the OnSignal event.
An optional value argument can be given to set the Value property of the signal."""
        pass


class vcReport(vcLayoutItem):
    """vcReport is a layout item used for generating reports of statistics gathered during a simulation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcReport.htm"""

    def getProperty(self: Any, property: str) -> vcProperty:
        """Returns the first property matching a given name in report; otherwise returns None."""
        pass

    def publish(self: Any, Type: str, Name: str) -> None:
        """Saves the report as either an image, csv, Excel sheet or PDF."""
        pass

    def show(self: Any) -> None:
        """Shows the report."""
        pass


class vcReserveProductStatement(vcStatement):
    """Reserve Product statement creates a process requirement for a matching product (vcProduct) to be available and reserves it for this process.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcReserveProductStatement.htm"""

    @property
    def AcceptAllProductTypes(self) -> bool:
        """(Deprecated) Use vcProductFilter.IsEnabled property instead.
 
 When True any product is accepted, ignoring AcceptedFlowGroups and AcceptedProductTypes"""
        pass

    @AcceptAllProductTypes.setter
    def AcceptAllProductTypes(self, value : bool) -> None:
        pass

    @property
    def AcceptedFlowGroups(self) -> List[vcProcessFlowGroup]:
        """(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected flow groups."""
        pass

    @AcceptedFlowGroups.setter
    def AcceptedFlowGroups(self, value : List[vcProcessFlowGroup]) -> None:
        pass

    @property
    def AcceptedProductTypes(self) -> List[vcProductType]:
        """(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected product types."""
        pass

    @AcceptedProductTypes.setter
    def AcceptedProductTypes(self, value : List[vcProductType]) -> None:
        pass

    @property
    def ProductVariableName(self) -> str:
        """Name of the process variable where to store the reserved product instance (vcProduct)."""
        pass

    @ProductVariableName.setter
    def ProductVariableName(self, value : str) -> None:
        pass


class vcRobotController(vcServoController):
    """vcRobotController allows you control a robot and drive its joints. If you need realistic robot simulation, use vcRrsRobotController.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRobotController.htm"""

    @property
    def ApproachAxis(self) -> int:
        """Defines how to orient the robot based on the orientation of the active tool frame.
See Approach Axis Constants for more information."""
        pass

    @ApproachAxis.setter
    def ApproachAxis(self, value : int) -> None:
        pass

    @property
    def Bases(self) -> List[vcBaseFrame]:
        """Gets a list of all base frames available in controller."""
        pass

    @property
    def ConfigurationMode(self) -> int:
        """Defines the configuration mode for joints driven by robot controller during linear motion interpolation.
0 = Fixed
No change. That is, current configuration is used and does not change.
1 = Follow frame
Configuration closest to previous joint values is used.
2 = Interpolate joint values
Configuration is determined by point-to-point interpolation of joint values.
See Motion Target Constants for more information."""
        pass

    @ConfigurationMode.setter
    def ConfigurationMode(self, value : int) -> None:
        pass

    @property
    def FlangeOffset(self) -> str:
        """Defines an offset from flange node origin.
Generally, this is used when flange node origin is not the exact place where to mount a tool or kinematics structure to end of robot arm."""
        pass

    @FlangeOffset.setter
    def FlangeOffset(self, value : str) -> None:
        pass

    @property
    def InitialBase(self) -> str:
        """Defines the initial base frame by name of the controller."""
        pass

    @InitialBase.setter
    def InitialBase(self, value : str) -> None:
        pass

    @property
    def InitialTool(self) -> str:
        """Defines the initial tool frame by name of the controller."""
        pass

    @InitialTool.setter
    def InitialTool(self, value : str) -> None:
        pass

    @property
    def Kinematics(self) -> vcBehaviour:
        """Defines the kinematics object used by the controller which describes the robot's kinematic structure."""
        pass

    @Kinematics.setter
    def Kinematics(self, value : vcBehaviour) -> None:
        pass

    @property
    def LagTime(self) -> float:
        """If linear motion, defines default lag time."""
        pass

    @LagTime.setter
    def LagTime(self, value : float) -> None:
        pass

    @property
    def MaxAngularAccel(self) -> float:
        """If linear motion, defines maximum acceleration for angular movement (degrees/s^2)."""
        pass

    @MaxAngularAccel.setter
    def MaxAngularAccel(self, value : float) -> None:
        pass

    @property
    def MaxAngularSpeed(self) -> float:
        """If linear motion, defines maximum speed for angular movement (degrees/s)."""
        pass

    @MaxAngularSpeed.setter
    def MaxAngularSpeed(self, value : float) -> None:
        pass

    @property
    def MaxCartesianAccel(self) -> float:
        """If linear motion, defines maximum acceleration for linear movement (mm/s^2)."""
        pass

    @MaxCartesianAccel.setter
    def MaxCartesianAccel(self, value : float) -> None:
        pass

    @property
    def MaxCartesianSpeed(self) -> float:
        """If linear motion, defines maximum speed for linear movement (mm/s)."""
        pass

    @MaxCartesianSpeed.setter
    def MaxCartesianSpeed(self, value : float) -> None:
        pass

    @property
    def OrientationInterpolationMode(self) -> int:
        """Defines the orientation interpolation mode for linear movement."""
        pass

    @OrientationInterpolationMode.setter
    def OrientationInterpolationMode(self, value : int) -> None:
        pass

    @property
    def RootOffset(self) -> str:
        """Defines an offset from root node origin, thereby defining the start of kinematics structure."""
        pass

    @RootOffset.setter
    def RootOffset(self, value : str) -> None:
        pass

    @property
    def SettleTime(self) -> float:
        """If linear motion, defines default settle time."""
        pass

    @SettleTime.setter
    def SettleTime(self, value : float) -> None:
        pass

    @property
    def Tools(self) -> List[vcBaseFrame]:
        """Gets a list of all tool frames available in controller."""
        pass

    @property
    def TrackWorldFrameMode(self) -> int:
        """Defines Robot World Frame (RWF) of robot when mounted on track.
0
Track origin is used as RWF.
1
RWF of robot is used as RWF.
See Track World Frame Modes for more information."""
        pass

    @TrackWorldFrameMode.setter
    def TrackWorldFrameMode(self, value : int) -> None:
        pass

    @property
    def WorldTransformMatrix(self) -> vcMatrix:
        """Defines Robot World Frame of robot."""
        pass

    @WorldTransformMatrix.setter
    def WorldTransformMatrix(self, value : vcMatrix) -> None:
        pass

    def addBase(self: Any) -> vcBaseFrame:
        """Adds a new base frame to controller."""
        pass

    @overload
    def addTarget(self: Any, target: vcMotionTarget) -> None:
        """Adds a given motion target or target matrix to robot target list.
If target matrix, current settings of robot controller are used and an optional target_mode can be given to define how target relates to robot. This is similar to moveTo() method.
Generally, you use addTarget() when you are creating a batch of targets and the robot will use non-zero accuracy limits.
See Motion Target Constants for more information."""
        pass

    @overload
    def addTarget(self: Any, matrix: vcMatrix, target_mode: int = ...) -> None:
        """Adds a given motion target or target matrix to robot target list.
If target matrix, current settings of robot controller are used and an optional target_mode can be given to define how target relates to robot. This is similar to moveTo() method.
Generally, you use addTarget() when you are creating a batch of targets and the robot will use non-zero accuracy limits.
See Motion Target Constants for more information."""
        pass

    def addTool(self: Any) -> vcBaseFrame:
        """Adds a new tool frame to controller."""
        pass

    def clearTargets(self: Any) -> None:
        """Removes all motion targets and target matrices from robot target list."""
        pass

    def createMotionInterpolator(self: Any) -> vcMotionInterpolator:
        """Creates a new motion interpolator for robot."""
        pass

    def createTarget(self: Any, matrix: vcMatrix = ...) -> vcMotionTarget:
        """Create a new motion target using current controller settings, and then returns the new motion target.
An optional matrix argument can be given to define target matrix of target."""
        pass

    def move(self: Any) -> None:
        """Moves robot to all targets in robot target list.
Python execution will wait until robot has motioned to all previously added targets."""
        pass

    def moveImmediate(self: Any, target: vcMotionTarget, target_mode: int = ...) -> None:
        """Moves robot to a given target immediately.
An optional target_mode argument can be given to define how target relates to robot.
See Motion Target Constants for more information."""
        pass

    @overload
    def moveTo(self: Any, target: vcMotionTarget) -> None:
        """Moves robot to a given target or matrix, thereby clearing any previously added targets.
An optional target_mode argument can be given to define how target relates to robot.
See Motion Target Constants for more information."""
        pass

    @overload
    def moveTo(self: Any, matrix: vcMatrix, target_mode: int = ...) -> None:
        """Moves robot to a given target or matrix, thereby clearing any previously added targets.
An optional target_mode argument can be given to define how target relates to robot.
See Motion Target Constants for more information."""
        pass

    @overload
    def moveRelTo(self: Any, offset: vcVector, target_mode: int = ...) -> None:
        """Moves robot to a position relative to current robot pose using current controller settings.
An optional target_mode argument can be given to define how target relates to robot.
See Motion Target Constants for more information."""
        pass

    @overload
    def moveRelTo(self: Any, x: float, y: float, z: float, target_mode: int = ...) -> None:
        """Moves robot to a position relative to current robot pose using current controller settings.
An optional target_mode argument can be given to define how target relates to robot.
See Motion Target Constants for more information."""
        pass

    def removeBase(self: Any, Base: vcBaseFrame) -> None:
        """Removes a given Base from controller."""
        pass

    def removeTool(self: Any, Tool: vcBaseFrame) -> None:
        """Removes a given Tool from controller."""
        pass

    OnPosition : Callable[[vcRobotController], None]
    """Triggered when robot reaches a motion target in its robot target list."""



class vcRobotSelectionService(vcObject):
    """Example. Select active robot and controller, also observe their changes
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRobotSelectionService.htm"""

    @property
    def ActiveExecutor(self) -> vcBehaviour:
        """Gets or sets active robot executor"""
        pass

    @ActiveExecutor.setter
    def ActiveExecutor(self, value : vcBehaviour) -> None:
        pass

    @property
    def ActiveController(self) -> vcBehaviour:
        """Gets or sets active robot executor"""
        pass

    @ActiveController.setter
    def ActiveController(self, value : vcBehaviour) -> None:
        pass

    OnActiveExecutorChanged : Callable[[], None]
    """Triggered when robot active executor changes"""


    OnActiveControllerChanged : Callable[[], None]
    """Triggered when robot active controller changes"""



class vcRoutine(vcScope):
    """vcRoutine contains a collection of statements that can be executed in a robot program.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRoutine.htm"""

    @property
    def IsPersistent(self) -> bool:
        """Defines if the routine is saved with the program.
 The default value is True."""
        pass

    @IsPersistent.setter
    def IsPersistent(self, value : bool) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of the routine."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Program(self) -> vcProgram:
        """Gets the program associated with the routine."""
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of properties in the routine."""
        pass

    def createProperty(self: Any, type: int, name: str) -> vcProperty:
        """Creates a new property of a given type and name in the routine, and then returns the new property.
 An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation.
 See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property in the routine."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name in the routine; otherwise returns None."""
        pass


class vcRoutingRule(vcContainer):
    """vcRoutingRule allows you to define rules for transferring components to different connectors, thereby simulating routing rules for material flow.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRoutingRule.htm"""

    @property
    def FlowProxy(self) -> vcComponentFlowProxy:
        """Defines if a proxy is used to check capacity of selected connector before routing a component.
If None, this property is ignored."""
        pass

    @FlowProxy.setter
    def FlowProxy(self, value : vcComponentFlowProxy) -> None:
        pass

    @property
    def RuleComponent(self) -> int:
        """Defines the component used for rule processing.
See Routing Constants for more information."""
        pass

    @RuleComponent.setter
    def RuleComponent(self, value : int) -> None:
        pass

    def createConnector(self: Any) -> int:
        """Adds a new connector in routing rule, and then returns the index of new connector."""
        pass

    def deleteConnector(self: Any, index: int) -> None:
        """Deletes a connector from routing rule at a given index."""
        pass

    def processRoute(self: Any, from_connector: int, component: vcComponent, behavior: vcBehaviour) -> int:
        """Returns the result of a routing test to verify if a given component would be routed based on a capacity test performed by a given behaviour or FlowProxy. Depending on the value of RuleComponent, the component can be either:

The arriving component (if RuleComponent == VC_ROUTING_PROCESSED)
The owner component of the behavior (if RuleComponent == VC_ROUTING_OWNER)

Returns -1 if no valid targets are found."""
        pass

    def setTarget(self: Any, index: int) -> None:
        """Sets the connector by index for routing a component, which should be executed in OnRoute event."""
        pass

    OnRoute : Callable[[int, vcComponent, vcBehaviour], None]
    """Triggered when a component is transferred into routing rule and being processed.
Use the processRoute() method to test a viable option, and then use setTarget() method to override default routing logic."""



class vcRslMotionStatement(vcRslStatement):
    """vcRslMotionStatement is a statement used for robot motions.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRslMotionStatement.htm"""

    @property
    def Acceleration(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum Cartesian acceleration of motion (units/s^2) used to calculate target trajectory."""
        pass

    @Acceleration.setter
    def Acceleration(self, value : float) -> None:
        pass

    @property
    def AngularAcceleration(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum angular acceleration of motion (degrees/s^2) used to calculate target trajectory."""
        pass

    @AngularAcceleration.setter
    def AngularAcceleration(self, value : float) -> None:
        pass

    @property
    def AngularDeceleration(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum angular deceleration of motion (degrees/s^2) used to calculate target trajectory."""
        pass

    @AngularDeceleration.setter
    def AngularDeceleration(self, value : float) -> None:
        pass

    @property
    def ConfigurationMode(self) -> int:
        """This property exist only in: Linear Motion.
Defines the configuration mode for joints driven by robot controller during linear motion interpolation.
 0 = Fixed
 No change. That is, current configuration is used and does not change.
 1 = Follow frame
 Configuration closest to previous joint values is used.
 2 = Interpolate joint values
 Configuration is determined by point-to-point interpolation of joint values."""
        pass

    @ConfigurationMode.setter
    def ConfigurationMode(self, value : int) -> None:
        pass

    @property
    def Deceleration(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum Cartesian deceleration of motion (units/s^2) used to calculate target trajectory."""
        pass

    @Deceleration.setter
    def Deceleration(self, value : float) -> None:
        pass

    @property
    def MaxAngularSpeed(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum angular speed (degrees/s^2) used to calculate target trajectory."""
        pass

    @MaxAngularSpeed.setter
    def MaxAngularSpeed(self, value : float) -> None:
        pass

    @property
    def MaxSpeed(self) -> float:
        """This property exist only in: Linear Motion.
Defines the maximum Cartesian speed (units/s) used to calculate target trajectory."""
        pass

    @MaxSpeed.setter
    def MaxSpeed(self, value : float) -> None:
        pass

    @property
    def OrientationInterpolationMode(self) -> int:
        """This property exist only in: Linear Motion.
Defines the orientation interpolation mode for linear movement."""
        pass

    @OrientationInterpolationMode.setter
    def OrientationInterpolationMode(self, value : int) -> None:
        pass

    @property
    def Configuration(self) -> str:
        """This property exist only in: Point to Point (Joint) Motion.
Defines the joint configuration by name of robot at target.
 Configuration names are defined in robot's kinematics behavior and can be manufacturer specific."""
        pass

    @Configuration.setter
    def Configuration(self, value : str) -> None:
        pass

    def readFromTarget(self: Any, target: vcMotionTarget) -> None:
        """Sets the Target property of statement to equal Target property of a given target."""
        pass

    def writeToTarget(self: Any, target: vcMotionTarget) -> None:
        """Sets the Target property of a given target to equal Target property of statement."""
        pass


class vcRslProcessStatement(vcRslStatement):
    """vcRslProcessStatement is a statement that can execute a defined RSL Process Handler behavior.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRslProcessStatement.htm"""

    @property
    def Process(self) -> str:
        """Defines the name of process to be executed by statement."""
        pass

    @Process.setter
    def Process(self, value : str) -> None:
        pass

    def createProperty(self: Any, type: str, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to statement.
An optional constraints argument can be given to defines constraints for the new property, which must be done at the time of creation."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property from statement."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns the first property matching the given name in statement; otherwise returns None."""
        pass


class vcRslProgramExecutor(vcBehaviour):
    """vcRslProgramExecutor is an executor for robot programs, thereby allowing you to program and simulate robot actions. In this context, a robot program consists of a Main routine, subroutines and statements.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRslProgramExecutor.htm"""

    @property
    def ActionMode(self) -> bool:
        """Defines if the execution of robot program is performed automatically or by a logic controller, for example a pedestal.
 If False, MainRoutine is executed automatically at start of simulation."""
        pass

    @ActionMode.setter
    def ActionMode(self, value : bool) -> None:
        pass

    @property
    def Colour(self) -> vcMaterial:
        """Defines the color of robot program."""
        pass

    @Colour.setter
    def Colour(self, value : vcMaterial) -> None:
        pass

    @property
    def Controller(self) -> Union[vcRobotController, vcServoController]:
        """Defines the controller referenced by executor, which is either a controller for robot or servo."""
        pass

    @Controller.setter
    def Controller(self, value : Union[vcRobotController, vcServoController]) -> None:
        pass

    @property
    def CurrentRoutine(self) -> vcRslRoutine:
        """Gets the current routine in robot program being handled by executor."""
        pass

    @property
    def DigitalMapIn(self) -> vcBooleanSignalMap:
        """Defines the input device used for reading digital signal values."""
        pass

    @DigitalMapIn.setter
    def DigitalMapIn(self, value : vcBooleanSignalMap) -> None:
        pass

    @property
    def DigitalMapOut(self) -> vcBooleanSignalMap:
        """Defines the output device used for sending digital signal values."""
        pass

    @DigitalMapOut.setter
    def DigitalMapOut(self, value : vcBooleanSignalMap) -> None:
        pass

    @property
    def ExecutionMode(self) -> bool:
        """Defines if a robot is controlled by an external executor, for example a virtual robot controller."""
        pass

    @ExecutionMode.setter
    def ExecutionMode(self, value : bool) -> None:
        pass

    @property
    def IntegerMapIn(self) -> vcIntegerSignalMap:
        """Defines the input device used for reading integer values."""
        pass

    @IntegerMapIn.setter
    def IntegerMapIn(self, value : vcIntegerSignalMap) -> None:
        pass

    @property
    def IntegerMapOut(self) -> vcIntegerSignalMap:
        """Defines the output device used for sending integer values."""
        pass

    @IntegerMapOut.setter
    def IntegerMapOut(self, value : vcIntegerSignalMap) -> None:
        pass

    @property
    def Looping(self) -> bool:
        """Defines if the executor loops a robot program during a simulation."""
        pass

    @Looping.setter
    def Looping(self, value : bool) -> None:
        pass

    @property
    def MainRoutine(self) -> vcRslRoutine:
        """Gets the main routine of robot program."""
        pass

    @property
    def ProcessHandlers(self) -> List[vcPythonProcessHandler]:
        """Gets a list of all process statement handlers connected to executor."""
        pass

    @ProcessHandlers.setter
    def ProcessHandlers(self, value : List[vcPythonProcessHandler]) -> None:
        pass

    @property
    def Program(self) -> str:
        """Defines the URI of robot program being handled by executor."""
        pass

    @Program.setter
    def Program(self, value : str) -> None:
        pass

    @property
    def RealMapIn(self) -> vcBehaviour:
        """Defines the device used for reading real number values."""
        pass

    @RealMapIn.setter
    def RealMapIn(self, value : vcBehaviour) -> None:
        pass

    @property
    def RealMapOut(self) -> vcBehaviour:
        """Defines the device used for sending real number values."""
        pass

    @RealMapOut.setter
    def RealMapOut(self, value : vcBehaviour) -> None:
        pass

    @property
    def StringMapIn(self) -> vcStringSignalMap:
        """Defines the device used for reading string values."""
        pass

    @StringMapIn.setter
    def StringMapIn(self, value : vcStringSignalMap) -> None:
        pass

    @property
    def StringMapOut(self) -> vcStringSignalMap:
        """Defines the device used for sending string values."""
        pass

    @StringMapOut.setter
    def StringMapOut(self, value : vcStringSignalMap) -> None:
        pass

    @property
    def SubRoutines(self) -> List[vcRslRoutine]:
        """Gets a list of all subroutines in current robot program being handled by executor."""
        pass

    def callRemoteAction(self: Any, routine: str) -> None:
        """Schedules a remote routine by name in a connected robot to be executed at first opportunity.
 Note: Python execution continues immediately."""
        pass

    def callRoutine(self: Any, routine: str, suspend: bool = ...) -> None:
        """Executes a routine by name in robot program, and then waits for completion of that routine.
 An optional suspend argument can be used to wait or not wait for completion of routine. If False, Python execution continues immediately."""
        pass

    def createSubRoutine(self: Any, routine_name: str) -> vcRslRoutine:
        """Adds a new routine of a given routine_name to robot program."""
        pass

    def delay(self: Any, time: float) -> None:
        """Schedules a delay in the execution of robot program for a given amount of time.
 Note: Python execution continues immediately."""
        pass

    def deleteProgram(self: Any) -> bool:
        """Deletes the robot program being handled by executor, thereby removing all routines and statements.
 If deletion is successful, returns True; otherwise returns False."""
        pass

    def deleteSubRoutine(self: Any, routine: str) -> bool:
        """Deletes a routine by name from robot program.
 If deletion is successful, returns True; otherwise returns False."""
        pass

    def newProgram(self: Any, name: str) -> bool:
        """Creates a new robot program of a given name to be handled by executor."""
        pass

    def setOutput(self: Any, output_index: int, value: bool) -> None:
        """Sets the value of a signal connected to a port at a given output_index in robot."""
        pass

    def waitInput(self: Any, input_index: int, value: bool) -> None:
        """Schedules the executor to wait until a signal connected to a port at a given input_index in robot has a given value.
 Note: Python execution continues immediately."""
        pass

    def waitRemoteAction(self: Any, routine: str) -> None:
        """Schedules the executor to wait for completion of a routine by name in a connected robot.
 Note: Python execution continues immediately."""
        pass

    OnProgramChange : Callable[[vcRslRoutine, vcRslStatement], None]
    """Triggered when a change occurs in robot program, for example when you add/delete a statement from a routine."""



class vcRslRoutine(vcObject):
    """vcRslRoutine is a collection of statements in a robot program.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRslRoutine.htm"""

    @property
    def Name(self) -> str:
        """Gets the name routine."""
        pass

    @property
    def Program(self) -> vcRslProgramExecutor:
        """Gets the robot executor of routine and its program."""
        pass

    @property
    def StatementCount(self) -> int:
        """Gets the number of statements in routine."""
        pass

    @property
    def Statements(self) -> List[vcRslStatement]:
        """Gets a list of all statements in routine."""
        pass

    def beginBatch(self: Any) -> None:
        """Disables the application's GUI to speed up the creation or edits for a batch of statements in routine."""
        pass

    def createStatement(self: Any, type: int) -> vcRslStatement:
        """Adds a new statement of a given type to routine.
See Motion Constants for more information."""
        pass

    def deleteStatement(self: Any, index: int) -> bool:
        """Removes a statement at a given index from routine."""
        pass

    def endBatch(self: Any) -> None:
        """Enables the application's GUI.
In most cases, this method is called after beginBatch()."""
        pass

    def getStatement(self: Any, index: int) -> vcRslStatement:
        """Returns a statement at a given index in routine."""
        pass


class vcRslStatement(vcObject):
    """vcRslStatement is the basic implementation for statements in a robot program.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcRslStatement.htm"""

    @property
    def GridColor(self) -> vcVector:
        """Defines the color associated with the statement, for example when robot program is listed in a panel.
 Color is defined in RGB color space by using a vector containing normalized XYZ values."""
        pass

    @GridColor.setter
    def GridColor(self, value : vcVector) -> None:
        pass

    @property
    def Index(self) -> int:
        """Defines the location (index) of statement in routine."""
        pass

    @Index.setter
    def Index(self, value : int) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of statement."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all properties in statement."""
        pass

    @property
    def Routine(self) -> vcRslRoutine:
        """Gets the routine the statement belongs to in robot program."""
        pass

    @property
    def Type(self) -> int:
        """Gets the statement type.
 See Motion Constants for more information."""
        pass

    @property
    def RoutineName(self) -> str:
        """This property exist only in: Call.
Defines the subroutine to call by name."""
        pass

    @RoutineName.setter
    def RoutineName(self, value : str) -> None:
        pass

    @property
    def Comment(self) -> str:
        """This property exist only in: Comment.
Defines the message to be printed to user."""
        pass

    @Comment.setter
    def Comment(self, value : str) -> None:
        pass

    @property
    def Base(self) -> Union[str, vcBaseFrame]:
        """This property exist only in: Define Base.
Gets/Sets the base frame used by statement.
 To set, give the name of a base frame listed in robot controller, vcRobotController, which is referenced by robot executor of this statement."""
        pass

    @Base.setter
    def Base(self, value : Union[str, vcBaseFrame]) -> None:
        pass

    @property
    def Node(self) -> str:
        """This property exist only in: Define Base, Define Tool.
Defines the parent node of Base."""
        pass

    @Node.setter
    def Node(self, value : str) -> None:
        pass

    @property
    def Position(self) -> vcMatrix:
        """This property exist only in: Define Base, Define Tool.
Defines the location of Base.
 If Relative is set to True, this property references Base coordinate system, thereby changing base frame relative to its current position."""
        pass

    @Position.setter
    def Position(self, value : vcMatrix) -> None:
        pass

    @property
    def Relative(self) -> bool:
        """This property exist only in: Define Base, Define Tool.
Defines if Position provides absolute or relative values for Base location."""
        pass

    @Relative.setter
    def Relative(self, value : bool) -> None:
        pass

    @property
    def Tool(self) -> Union[str, vcBaseFrame]:
        """This property exist only in: Define Tool.
Gets/Sets the tool frame used by statement.
 To set, give the name of a tool frame listed in robot controller, vcRobotController, which is referenced by robot executor of this statement."""
        pass

    @Tool.setter
    def Tool(self, value : Union[str, vcBaseFrame]) -> None:
        pass

    @property
    def Delay(self) -> float:
        """This property exist only in: Delay.
Defines the amount of time (in seconds) to delay program execution."""
        pass

    @Delay.setter
    def Delay(self, value : float) -> None:
        pass

    @property
    def Reset(self) -> bool:
        """This property exist only in: Halt.
Defines if a simulation is reset."""
        pass

    @Reset.setter
    def Reset(self, value : bool) -> None:
        pass

    @property
    def SyncComponents(self) -> List[vcComponent]:
        """This property exist only in: Program Sync.
List of components in the sync program."""
        pass

    @SyncComponents.setter
    def SyncComponents(self, value : List[vcComponent]) -> None:
        pass

    @property
    def SyncMsg(self) -> str:
        """This property exist only in: Program Sync.
Defines the sync message to trigger synchronization."""
        pass

    @SyncMsg.setter
    def SyncMsg(self, value : str) -> None:
        pass

    @property
    def WaitSync(self) -> bool:
        """This property exist only in: Program Sync.
Defines if a robot in sync program waits for all SyncComponents to send SyncMsg.
 If False, robot sends SyncMsg and continues the execution of its program."""
        pass

    @WaitSync.setter
    def WaitSync(self, value : bool) -> None:
        pass

    @property
    def RemoteRoutine(self) -> str:
        """This property exist only in: remote Call, Remote Wait.
Defines the name of routine to remotely call in a robot.
 The format is [component_name]::[routine_name] and the target robot should be connected to calling robot via an abstract interface."""
        pass

    @RemoteRoutine.setter
    def RemoteRoutine(self, value : str) -> None:
        pass

    @property
    def Output(self) -> int:
        """This property exist only in: Set Binary Output.
Defines the output port."""
        pass

    @Output.setter
    def Output(self, value : int) -> None:
        pass

    @property
    def Value(self) -> bool:
        """This property exist only in: Set Binary Output, Wait Binary Output.
Defines the output value."""
        pass

    @Value.setter
    def Value(self, value : bool) -> None:
        pass

    @property
    def Input(self) -> int:
        """This property exist only in: Wait Binary Output.
Defines the input port."""
        pass

    @Input.setter
    def Input(self, value : int) -> None:
        pass

    @property
    def WaitTrigger(self) -> bool:
        """This property exist only in: Wait Binary Output.
Defines if Value is evaluated continuously or when a signal event occurs during a simulation."""
        pass

    @WaitTrigger.setter
    def WaitTrigger(self, value : bool) -> None:
        pass

    def createProperty(self: Any, type: str, name: str, constraints: int = ...) -> vcProperty:
        """Adds a new property of a given type and name to statement.
 An optional constraints argument can be given to define constraints for property, which must be given at the time of creation.
 See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Removes a given property from statement."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns the first matching property of a given name in the statement; otherwise returns None."""
        pass


class vcScalarQuantity(vcObject):
    """vcScalarQuantity is the basic implementation for quantities used in the application and provides access to units.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcScalarQuantity.htm"""

    @property
    def AvailableGroups(self) -> List[vcUnitGroup]:
        """Gets a list of all unit groups that include the quantity, thereby any one of those groups can be used to access and select quantity."""
        pass

    @property
    def Category(self) -> str:
        """If built-in quantity, gets category of quantity; otherwise defines the category of a quantity."""
        pass

    @Category.setter
    def Category(self, value : str) -> None:
        pass

    @property
    def Children(self) -> List[vcScalarQuantity]:
        """Gets a list of all child quantities for the quantity.
If no child quantities, value is empty list."""
        pass

    @property
    def CurrentGroup(self) -> vcUnitGroup:
        """Defines the current unit group used for listing the quantity's properties.
To set, give either a vcUnitGroup object or name of unit group.
If value is None and quantity has a parent quality, uses the current group of parent."""
        pass

    @CurrentGroup.setter
    def CurrentGroup(self, value : vcUnitGroup) -> None:
        pass

    @property
    def EffectiveGroup(self) -> vcUnitGroup:
        """Gets the actual unit group used for listing the quantity's properties.
If CurrentGroup is None, uses unit group of parent quantity."""
        pass

    @property
    def FullName(self) -> str:
        """Gets the full name of quantity, which is the concatenation of parent quantity names with a dot (.) separator and Name.
You can refer to a quantity by referencing its full name."""
        pass

    @property
    def IsBuiltIn(self) -> bool:
        """Indicates if quantity is a built-in quantity which cannot be edited nor destroyed."""
        pass

    @property
    def Name(self) -> str:
        """If quantity is built-in, gets name of quantity; otherwise defines the quantity's name."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Parent(self) -> vcScalarQuantity:
        """If quantity is built-in, gets parent quantity; otherwise defines the parent of quantity.
To set, give either a vcScalarQuantity object or full name of quantity."""
        pass

    @Parent.setter
    def Parent(self, value : vcScalarQuantity) -> None:
        pass

    @property
    def Type(self) -> str:
        """Gets the quantity type.
See Quantity Constants for more information."""
        pass

    def createChildQuantity(self: Any, name: str, type: int) -> vcScalarQuantity:
        """Adds a new child quantity of a given name and type to the quantity.
See Quantity Constants for more information."""
        pass

    def destroy(self: Any) -> None:
        """If quantity is not built-in, destroys the quantity; otherwise throws an exception."""
        pass

    def getEffectiveUnit(self: Any, magnitude: float) -> vcUnit:
        """Returns a unit from effective unit group of quantity that closely matches a given magnitude."""
        pass


class vcSchemaPositionFrame(vcObject):
    """vcSchemaPositionFrame is a position defined by schema properties. Generally, this is a position of a path statement. One case is to extract data from the position, and then export or use the data elsewhere.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSchemaPositionFrame.htm"""


class vcScope(vcObject):
    """vcScope is a collection of statements in a robot program.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcScope.htm"""

    @property
    def ParentStatement(self) -> vcStatement:
        """Gets the statement that owns the scope, for example a conditional If or While statement that has a nested block of statements; otherwise the value is None for routines."""
        pass

    @property
    def Statements(self) -> List[vcStatement]:
        """Gets a list of statements belonging to the scope."""
        pass

    @overload
    def addStatement(self: Any, type: int, index: int = ...) -> vcStatement:
        """Creates a new statement of a given type in the scope, and then returns that statement.
 The default index value is -1 which adds the new statement to the end of the scope.
 An optional icon argument can be given to define the path of an icon used by the statement; otherwise the statement is given a default icon.
 See Statement Constants for more information.
 Note: If you want to add a custom statement, implement a vcPositionStatement as a process statement by passing a type of VC_STATEMENT_PROCESS or create an add-on."""
        pass

    @overload
    def addStatement(self: Any, type: int, index: int, icon: str = ...) -> vcStatement:
        """Creates a new statement of a given type in the scope, and then returns that statement.
 The default index value is -1 which adds the new statement to the end of the scope.
 An optional icon argument can be given to define the path of an icon used by the statement; otherwise the statement is given a default icon.
 See Statement Constants for more information.
 Note: If you want to add a custom statement, implement a vcPositionStatement as a process statement by passing a type of VC_STATEMENT_PROCESS or create an add-on."""
        pass

    def clear(self: Any) -> None:
        """Deletes all statements in the scope."""
        pass

    def deleteStatement(self: Any, statement: vcStatement) -> None:
        """Deletes a given statement in the scope."""
        pass

    def getStatement(self: Any, index: int) -> vcStatement:
        """Returns a statement at a given index in the scope."""
        pass

    OnScopeExecuted : Callable[[vcScope, bool], None]
    """Triggered when a scope is executed. The isImmediate argument defines whether the scope was executed in immediate mode (non time-consuming mode) or not."""


    OnStatementAdded : Callable[[], None]
    """Triggered when a new statement is added to the scope."""


    OnStatementRemoving : Callable[[], None]
    """Triggered when a statement is being deleted from the scope."""



class vcScopeStatement(vcStatement):
    """vcScopeStatement is a robot statement that can execute its own scope of statements.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcScopeStatement.htm"""

    @property
    def Condition(self) -> str:
        """This property exist only in: While.
Defines an expression that when evaluated returns a True or False value.
A True value means the statement will execute its scope of statements and loop back, evaluating its condition before each iteration.
A False value means the statement has been completed and will not execute its scope of statements.
Note: In order to avoid an endless loop, use a condition that references a robot variable, port in robot, Break statement or a controller property."""
        pass

    @Condition.setter
    def Condition(self, value : str) -> None:
        pass

    @property
    def Scope(self) -> vcScope:
        """This property exist only in: While.
Gets the scope of statements executed by the statement."""
        pass


class vcScript(vcBehaviour):
    """vcScript allows you to publish and execute a Python script.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcScript.htm"""

    @property
    def Application(self) -> vcApplication:
        """Gets the application object."""
        pass

    @property
    def Component(self) -> vcComponent:
        """Gets the component of script."""
        pass

    @property
    def IsRunning(self) -> bool:
        """Indicates if code of script is being executed."""
        pass

    @property
    def Node(self) -> vcNode:
        """Gets the node containing script."""
        pass

    @property
    def Script(self) -> str:
        """Defines the executable Python code of script."""
        pass

    @Script.setter
    def Script(self, value : str) -> None:
        pass

    @property
    def Simulation(self) -> vcSimulation:
        """Gets the simulation object."""
        pass

    def condition(self: Any, expression_function: Callable[[], None], timeout: float = ...) -> bool:
        """Delays the execution of script until a given function returns a True value or timeout period.
 The first evaluation of the function is immediate, and then each subsequent test is triggered, for example, by signal connected to script. The default timeout period is zero.
 Returns a True value if condition is True before timeout, otherwise returns a False value.
 NOTE: implementation is different in vcPythonProcessHandler"""
        pass

    def convertToByteCode(self: Any) -> None:
        """Converts the code of script to bytecode.
 Generally, this method is used to encrypt the code of script."""
        pass

    def delay(self: Any, time: float) -> None:
        """Delays the execution of script for a given amount of time."""
        pass

    def evaluateCondition(self: Any) -> None:
        """Triggers the evaluation of an active condition() or triggerCondition() function in the script."""
        pass

    def getApplication(self: Any) -> vcApplication:
        """Returns the application object."""
        pass

    def getComponent(self: Any) -> vcComponent:
        """Returns the component of script."""
        pass

    def getNode(self: Any) -> vcNode:
        """Returns the node containing script."""
        pass

    def getPythonDllPath(self: Any) -> str:
        """Returns the Uri of Python DLL folder as a formatted string."""
        pass

    def getSimulation(self: Any) -> vcSimulation:
        """Returns the simulation object."""
        pass

    def getTrigger(self: Any) -> vcBehaviour:
        """Returns an object that acts as a trigger in script, for example a signal connected to script.
 Generally, this method is called in a condition() or triggerCondition() expression to evaluate a trigger."""
        pass

    def resumeRun(self: Any, timeout: float = ...) -> None:
        """Resumes the execution of OnRun, the main program of script, that was placed in suspended state."""
        pass

    def suspendRun(self: Any) -> None:
        """Suspends the execution of OnRun, the main program of script."""
        pass

    def triggerCondition(self: Any, expression_function: Callable[[], None], timeout: float = ...) -> bool:
        """Delays the execution of script until a given function returns a True value or timeout period.
 The evaluation of the function is triggered, for example, by signal connected to script. The default timeout period is zero.
 Returns a True value if condition is True before timeout, otherwise returns a False value.
 NOTE: implementation is different in vcPythonProcessHandler"""
        pass

    OnAction : Callable[[vcAction], None]
    """Triggered when an Action Container connected to script handles an action."""


    OnContinue : Callable[[], None]
    """Triggered when a simulation resumes after being halted."""


    OnDestroy : Callable[[], None]
    """Triggered when an object is destroyed, for example a node."""


    OnFinalize : Callable[[], None]
    """Triggered when layout or component is being loaded in 3D world.
 The event occurs, for example, when copying a component, or loading a layout of components. The event is triggered before the needed components are attached to the 3D world."""


    OnRebuild : Callable[[], None]
    """Triggered when component geometry is rebuilt."""


    OnReset : Callable[[], None]
    """Triggered when simulation is reset to its initial state and simulation clock is set at zero."""


    OnRun : Callable[[], None]
    """Triggered at the start of a simulation and is used as the main function/loop of script."""


    OnSignal : Callable[[vcSignal], None]
    """Triggered when a signal connected to script signals its value."""


    OnSimulationUpdate : Callable[[float], None]
    """Triggered when simulation and scene are updated."""


    OnSimulationLevelChanged : Callable[[], None]
    """Triggered when the simulation level is changed.
 See Component Constants for more information.
 
 Refers to SimulationLevel Property in vcComponent."""


    OnStart : Callable[[], None]
    """Triggered at the immediate start of simulation."""


    OnStop : Callable[[], None]
    """Triggered when a simulation is halted."""



class vcSelectionManager(vcObject):
    """vcSelectionManager is responsible for handling the types of selections used by the application.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSelectionManager.htm"""

    def clear(self: Any) -> None:
        """Removes all objects from selection."""
        pass

    def getSelection(self: Any, type: int) -> List[Any]:
        """Returns a list of objects of a given type that are in selection.
See Selection Constants for more information."""
        pass

    @overload
    def setSelection(self: Any, object: Any, append: bool = ...) -> None:
        """Creates a new selection for a given object or list of objects of a supported selection type.
An optional append argument can be used to retain current selection, thereby appending the given object(s) to that selection.
See Selection Constants for more information."""
        pass

    @overload
    def setSelection(self: Any, objects: List[Any], append: bool = ...) -> None:
        """Creates a new selection for a given object or list of objects of a supported selection type.
An optional append argument can be used to retain current selection, thereby appending the given object(s) to that selection.
See Selection Constants for more information."""
        pass

    OnSelectionChanged : Callable[[], None]
    """Triggered when a selection has changed in application."""



class vcSequenceProcessConfiguration(vcObject):
    """Provides additional configuration that applies to all vcProcessGroup instances within one vcProcessSequence2.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSequenceProcessConfiguration.htm"""

    @property
    def ProcessGroup(self) -> vcProcessGroup:
        """The vcProcessGroup this configuration is applied to."""
        pass

    @property
    def IsLimitingVisits(self) -> bool:
        """Defines whether MaxVisitCountExpression is taken into use."""
        pass

    @IsLimitingVisits.setter
    def IsLimitingVisits(self, value : bool) -> None:
        pass

    @property
    def MaxVisitCount(self) -> int:
        """Defines how many times a vcProduct can visit this vcProcessGroup."""
        pass

    @MaxVisitCount.setter
    def MaxVisitCount(self, value : int) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets the properties of this vcSequenceProcessConfiguration."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property of the vcSequenceProcessConfiguration."""
        pass


class vcServoController(vcBehaviour):
    """vcServoController is a controller for driving independent joints. The controller itself only supports forward kinematics and cannot be used in robots rather with them. For example, a servo controller can be used for external axis systems, grippers, fixtures, weld guns, and other simple mechanical structures.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcServoController.htm"""

    @property
    def FlangeNode(self) -> vcNode:
        """Defines the flange node of servo, for example the mount plate or carriage for other kinematic structures."""
        pass

    @FlangeNode.setter
    def FlangeNode(self, value : vcNode) -> None:
        pass

    @property
    def HeartbeatTime(self) -> float:
        """If UseHeartbeat is set to True, defines the interval or pulse for updating joints."""
        pass

    @HeartbeatTime.setter
    def HeartbeatTime(self, value : float) -> None:
        pass

    @property
    def JointCount(self) -> int:
        """Gets the number of joints in servo."""
        pass

    @property
    def Joints(self) -> List[vcJoint]:
        """Gets a list of all joints referenced by servo."""
        pass

    @property
    def RootNode(self) -> vcNode:
        """Defines the root node of servo, thereby the fixed base of kinematic structure."""
        pass

    @RootNode.setter
    def RootNode(self, value : vcNode) -> None:
        pass

    @property
    def Speed(self) -> float:
        """Defines joint speed as a percentage of maximum speed for driving joints in range 0 to 100."""
        pass

    @Speed.setter
    def Speed(self, value : float) -> None:
        pass

    @property
    def UseHeartbeat(self) -> bool:
        """Turns on/off the use of a heartbeat or pulse to drive and update joints."""
        pass

    @UseHeartbeat.setter
    def UseHeartbeat(self, value : bool) -> None:
        pass

    def calcMotionTime(self: Any) -> float:
        """Returns the calculated motion time of servo using current joint values and listed targets."""
        pass

    def createJoint(self: Any) -> vcJoint:
        """Adds a new joint in servo.
 (Deprecated)"""
        pass

    @overload
    def deleteJoint(self: Any, joint: vcJoint) -> None:
        """Removes a given joint or one at a given index from servo.
 (Deprecated)"""
        pass

    @overload
    def deleteJoint(self: Any, joint_index: int) -> None:
        """Removes a given joint or one at a given index from servo.
 (Deprecated)"""
        pass

    def findJoint(self: Any, joint_name: str) -> vcJoint:
        """Returns the first joint matching a given name in servo; otherwise returns None."""
        pass

    def getJoint(self: Any, joint_index: int) -> vcJoint:
        """Returns a joint at a given index in servo."""
        pass

    def getJointTarget(self: Any, joint_index: int) -> float:
        """Returns the target value of a joint at a given index in servo."""
        pass

    def getJointValue(self: Any, joint_index: int) -> float:
        """Returns the current value of a joint at a given index in servo."""
        pass

    def move(self: Any, *joints: float) -> float:
        """Drives all joints in servo to target values, and then returns the actual motion time.
 Target values for each joint in servo can be given as separate, optional arguments."""
        pass

    def moveImmediate(self: Any, *joints: float) -> None:
        """Drives all joints in servo to target values in zero simulation time.
 Target values for each joint in servo can be given as separate, optional arguments."""
        pass

    def moveJoint(self: Any, joint_index: int, joint_value: float) -> float:
        """Moves a joint at a given index in servo to a given value, and then returns the actual motion time."""
        pass

    def setJointTarget(self: Any, joint_index: int, joint_value: float) -> None:
        """Sets the target value of a joint at a given index in servo to a given value."""
        pass

    def setMotionTime(self: Any, time: float) -> None:
        """Forces the servo to execute joint movements at a given motion time."""
        pass

    OnHeartbeat : Callable[[vcServoController, int], None]
    """Triggered when a pulse or heartbeat is generated by servo.
 See Controller Constants for more information.
 Note: This event handler can be used by a vcRobotController object executing a vcRslProcessStatement object in robot program."""



class vcSignal(vcBehaviour):
    """vcSignal is the basic implementation for signal type behaviors which can simulate wiring, send a value to other signals and trigger events.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSignal.htm"""

    @property
    def AutomaticReset(self) -> bool:
        """Turns on/off the reset of signal to initial value when simulation is reset."""
        pass

    @AutomaticReset.setter
    def AutomaticReset(self, value : bool) -> None:
        pass

    @property
    def Connections(self) -> List[vcBehaviour]:
        """Defines a list of behaviors connected to signal."""
        pass

    @Connections.setter
    def Connections(self, value : List[vcBehaviour]) -> None:
        pass

    def connect(self: Any, signal: vcSignal, connect_in_gui: bool = ...) -> bool:
        """Connects signals. The default value of the connect_in_gui is True, which means the created connection will be visible in GUI.
If a False value is given, the created connection won't be visible in GUI. Because of this, use the False value only when necessary!"""
        pass

    def disconnect(self: Any, signal: vcSignal, disconnect_in_gui: bool = ...) -> bool:
        """Disconnects signals. The default value of the disconnect_in_gui is True, which means the signal is disconnected also in GUI.
If the signals were connected using the connect method with a False argument in the connect_in_gui, they should be disconnected using a False argument in the disconnect_in_gui"""
        pass

    OnValueChange : Callable[[vcSignal], None]
    """Triggered when the value of signal is changed, thereby signaling all Connections of new value."""



class vcSimInterface(vcBehaviour):
    """vcSimInterface is an interface used for connecting components physically or remotely to one another and exchanging data.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSimInterface.htm"""

    @property
    def AngleTolerance(self) -> float:
        """Defines an angle tolerance for allowing interfaces to connect to the interface when not aligned on same axis."""
        pass

    @AngleTolerance.setter
    def AngleTolerance(self, value : float) -> None:
        pass

    @property
    def ConnectedComponent(self) -> vcComponent:
        """Gets the component connected to interface.
 If no connection, value is None."""
        pass

    @property
    def ConnectedComponents(self) -> List[vcComponent]:
        """If one-to-many interface, gets a list of all components connected to interface.
 If no connection, value is an empty list."""
        pass

    @property
    def ConnectedFromSections(self) -> List[vcSimInterfaceSection]:
        """If one-to-many interface, gets a list of all sections in interface that have an active connection.
 If no connection, value is an empty list."""
        pass

    @property
    def ConnectedSection(self) -> vcSimInterfaceSection:
        """If one-to-one interface, gets a section of interface that have an active connection.
 (Deprecated)"""
        pass

    @property
    def DistanceTolerance(self) -> float:
        """Defines the distance at which the interface snaps to an available connection, thereby completing Plug and Play."""
        pass

    @property
    def ConnectedSections(self) -> List[vcSimInterfaceSection]:
        """If one-to-many interface, gets a list of all sections in interface that have an active connection.
 (Deprecated)"""
        pass

    @property
    def ConnectedToSections(self) -> List[vcSimInterfaceSection]:
        """Gets a list of sections connected to interface.
 If no connection, value is an empty list."""
        pass

    @property
    def ConnectionEditName(self) -> str:
        """Defines the name of a Button property to temporarily create in component for connecting the interface.
 If an empty string, button is not created and/or removed from GUI. The string can use format [tab name]::[button name] to list button in a specific tab. If tab does not exist, it will be automatically created to contain button as long as string refers to that tab. If tab name is not given, button is listed as a default property."""
        pass

    @ConnectionEditName.setter
    def ConnectionEditName(self, value : str) -> None:
        pass

    @property
    def IsAbstract(self) -> bool:
        """Defines if interface supports remote connections."""
        pass

    @IsAbstract.setter
    def IsAbstract(self, value : bool) -> None:
        pass

    @property
    def IsConnected(self) -> bool:
        """If True, interface is connected; otherwise interface is not connected."""
        pass

    @property
    def Sections(self) -> List[vcSimInterfaceSection]:
        """Gets a list of all sections in interface.
 If no sections, value is an empty list."""
        pass

    def canConnect(self: Any, interface: vcSimInterface) -> bool:
        """Returns True if a given interface can connect to the interface; otherwise, returns False."""
        pass

    def connect(self: Any, interface: vcSimInterface, retain_offset: bool = ...) -> bool:
        """Connects a given interface to the interface. An optional retain_offset argument can be used to retain the offset when attaching component to another using Hierarchy field. If connection is successful, returns True; otherwise returns False."""
        pass

    def createSection(self: Any, section_name: str) -> vcSimInterfaceSection:
        """Adds a new section of a given name to interface, and then returns the new section."""
        pass

    def deleteSection(self: Any, index: int) -> bool:
        """If one-to-one interface, deletes a section at a given index from interface.
 Returns True is deletion is successful; otherwise returns False."""
        pass

    def disconnect(self: Any, other_interface: vcSimInterface) -> bool:
        """Removes all connections in interface.
 An optional other_interface argument can be used to disconnect a specific interface from the interface, for example when interface is one-to-many.
 Returns True if disconnection is successful; otherwise returns None."""
        pass

    def overrideEventResult(self: Any, result: int) -> None:
        """Overrides event result to have a given result."""
        pass

    def unConnect(self: Any, other_interface: vcSimInterface = ...) -> bool:
        """(Deprecated) Use disconnect()."""
        pass

    OnConnect : Callable[[vcSimInterface, bool], None]
    """Triggered when interface is connected to another interface."""


    OnDisconnect : Callable[[vcSimInterface], None]
    """Triggered when interface is disconnected from another interface."""


    OnMatch : Callable[[vcSimInterface], None]
    """Triggered when interfaces are tested as being able to connect to one another."""


    OnUnConnect : Callable[[vcSimInterface], None]
    """(Deprecated) Use OnDisconnect."""



class vcSimInterfaceField(vcObject):
    """vcSimInterfaceField is a connector for allowing a certain type of data to be transferred in an interface section.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSimInterfaceField.htm"""

    @property
    def Index(self) -> int:
        """Defines the index of field in section.
Important: The order of fields in a section is evaluated when establishing a connection between sections. For example, sections may have compatible fields but cannot connect because the order of fields differ in each section."""
        pass

    @Index.setter
    def Index(self, value : int) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of field."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all properties in the field."""
        pass

    @property
    def Section(self) -> vcSimInterfaceSection:
        """Gets the section of field."""
        pass

    @property
    def Type(self) -> int:
        """Gets the field type.
See Interface Constants for more information."""
        pass

    @property
    def Actions(self) -> str:
        """This property exist only in: Action Field.
Defines the name of Action Container in component used by field."""
        pass

    @Actions.setter
    def Actions(self, value : str) -> None:
        pass

    @property
    def Connection(self) -> int:
        """This property exist only in: Action Field, signal Field, Transport field.
Defines the role of field.
1
Client requesting actions.
2
Provider accepting action requests.
3
Broker acting as an intermediary for relaying actions between clients and providers."""
        pass

    @Connection.setter
    def Connection(self, value : int) -> None:
        pass

    @property
    def BaseList(self) -> vcBehaviour:
        """This property exist only in: Base Export.
Defines the behavior in component used by field.
The behavior must have the ability to store base frames, for example a Base Container or Robot Controller behavior."""
        pass

    @BaseList.setter
    def BaseList(self, value : vcBehaviour) -> None:
        pass

    @property
    def Export(self) -> bool:
        """This property exist only in: Base Export, Joint Export Field, Tool Export Field.
If True, exports base frames of BaseList; otherwise imports base frames to BaseList."""
        pass

    @Export.setter
    def Export(self, value : bool) -> None:
        pass

    @property
    def Container(self) -> vcContainer:
        """This property exist only in: Flow Field.
Defines the vcFlow type behavior in component used by the field."""
        pass

    @Container.setter
    def Container(self, value : vcContainer) -> None:
        pass

    @property
    def Port(self) -> int:
        """This property exist only in: Flow Field.
Defines which connector of Container is used by field, thereby defining if field transfers components into or out of Container."""
        pass

    @Port.setter
    def Port(self, value : int) -> None:
        pass

    @property
    def Frame(self) -> vcFeature:
        """This property exist only in: Hierarchy Field.
Defines an offset for attaching Node.
If None, Node origin is used by field."""
        pass

    @Frame.setter
    def Frame(self, value : vcFeature) -> None:
        pass

    @property
    def Node(self) -> vcNode:
        """This property exist only in: Hierarchy Field.
If Parent is set to True, defines node in component that will become parent of an attached node; otherwise must be root node of component."""
        pass

    @Node.setter
    def Node(self, value : vcNode) -> None:
        pass

    @property
    def Parent(self) -> bool:
        """This property exist only in: Hierarchy Field, Processor Field.
Defines if Node is to be parent of an attached node or will be attached as a child node."""
        pass

    @Parent.setter
    def Parent(self, value : bool) -> None:
        pass

    @property
    def Value(self) -> int:
        """This property exist only in: Integer Compatibility Field.
Defines the value of field."""
        pass

    @Value.setter
    def Value(self, value : int) -> None:
        pass

    @property
    def Controller(self) -> Union[vcRobotController, vcServoController]:
        """This property exist only in: Joint Export Field.
Defines either a Robot or Servo Controller in component used by field."""
        pass

    @Controller.setter
    def Controller(self, value : Union[vcRobotController, vcServoController]) -> None:
        pass

    @property
    def Path(self) -> vcContainer:
        """This property exist only in: Processor Field.
If Parent is set to True, defines the path or container in component used by field."""
        pass

    @Path.setter
    def Path(self, value : vcContainer) -> None:
        pass

    @property
    def Sensor(self) -> vcBehaviour:
        """This property exist only in: Processor Field.
If Parent is set to False, defines the sensor in component used by field."""
        pass

    @Sensor.setter
    def Sensor(self, value : vcBehaviour) -> None:
        pass

    @property
    def Publish(self) -> bool:
        """This property exist only in: RSL Field.
Turns on/off the publishing of Publisher robot program to a connected section."""
        pass

    @Publish.setter
    def Publish(self, value : bool) -> None:
        pass

    @property
    def Publisher(self) -> vcRslProgramExecutor:
        """This property exist only in: RSL Field.
Defines the robot executor in component used by field."""
        pass

    @Publisher.setter
    def Publisher(self, value : vcRslProgramExecutor) -> None:
        pass

    @property
    def Subscribe(self) -> bool:
        """This property exist only in: RSL Field.
Turns on/off the ability of Publisher to access robot program of a connected section."""
        pass

    @Subscribe.setter
    def Subscribe(self, value : bool) -> None:
        pass

    @property
    def Signal(self) -> vcSignal:
        """This property exist only in: signal Field.
Defines the signal in component used by field."""
        pass

    @Signal.setter
    def Signal(self, value : vcSignal) -> None:
        pass

    @property
    def ToolList(self) -> vcBehaviour:
        """This property exist only in: Tool Export Field.
Defines the behavior in component used by field.
The behavior must have the ability to store tool frames, for example a Tool Container or Robot Controller behavior."""
        pass

    @ToolList.setter
    def ToolList(self, value : vcBehaviour) -> None:
        pass

    @property
    def Transport(self) -> vcTransport:
        """This property exist only in: Transport field.
Defines the Transport Protocol in component used by field."""
        pass

    @Transport.setter
    def Transport(self, value : vcTransport) -> None:
        pass


class vcSimInterfaceSection(vcObject):
    """vcSimInterfaceSection is a collection of connector fields in an interface.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSimInterfaceSection.htm"""

    @property
    def ConnectedToSection(self) -> vcSimInterfaceSection:
        """Gets a section connected to the section.
If section is not connected, value is None."""
        pass

    @property
    def Fields(self) -> List[vcSimInterfaceField]:
        """Gets a list of all fields in section."""
        pass

    @property
    def Frame(self) -> vcFeature:
        """If belonging to physical interface, defines the Frame feature referenced as the location of section."""
        pass

    @Frame.setter
    def Frame(self, value : vcFeature) -> None:
        pass

    @property
    def Index(self) -> int:
        """Defines the index of section in interface."""
        pass

    @Index.setter
    def Index(self, value : int) -> None:
        pass

    @property
    def Interface(self) -> vcSimInterface:
        """Gets the interface of section."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of section."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    def createField(self: Any, field: int, name: str) -> vcSimInterfaceField:
        """Creates a new field of a given type and name in section, and then returns the new field.
See Interface Constants for more information."""
        pass

    def deleteField(self: Any, field_index: int) -> bool:
        """Deletes a field at a given index from the section.
If deletion is successful, returns True; otherwise returns False."""
        pass


class vcSimulation(vcObject):
    """vcSimulation is the object type for simulation engine and scene graph, thereby providing access to simulation controls. This is not the same as the simulation root node which represents 3D world in global node tree.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSimulation.htm"""

    @property
    def IgnoreEvents(self) -> bool:
        """Defines if simulation object ignores event passing in order to avoid cyclic calls."""
        pass

    @IgnoreEvents.setter
    def IgnoreEvents(self, value : bool) -> None:
        pass

    @property
    def IsLooping(self) -> bool:
        """Defines if the simulation gets automatically restarted when finished."""
        pass

    @IsLooping.setter
    def IsLooping(self, value : bool) -> None:
        pass

    @property
    def IsRunning(self) -> bool:
        """Indicates if simulation is running in 3D world."""
        pass

    @property
    def Name(self) -> str:
        """Gets the name of simulation object."""
        pass

    @property
    def ProcessController(self) -> vcProcessController:
        """Gets the global process controller."""
        pass

    @property
    def SimSpeed(self) -> float:
        """Defines the step size or speed of simulation."""
        pass

    @SimSpeed.setter
    def SimSpeed(self, value : float) -> None:
        pass

    @property
    def SimTime(self) -> float:
        """Gets the current time (in seconds) of simulation."""
        pass

    @property
    def SimulationRunTime(self) -> float:
        """Defines a time (in seconds) when simulation should stop running.
 Note: Changing the SimulationRunTime is only allowed in the OnRun event."""
        pass

    @SimulationRunTime.setter
    def SimulationRunTime(self, value : float) -> None:
        pass

    @property
    def SimWarmupTime(self) -> float:
        """Defines a time (in seconds) of simulation warmup time."""
        pass

    @SimWarmupTime.setter
    def SimWarmupTime(self, value : float) -> None:
        pass

    @property
    def Statistics(self) -> vcStatisticsManager:
        """Gets the statistics manager of simulation used for defining intervals."""
        pass

    @property
    def World(self) -> vcNode:
        """Gets the simulation root node (3D world node)."""
        pass

    def autoHalt(self: Any) -> bool:
        """Stops a simulation if there is no active component running a script that generates simulation events, and then returns True."""
        pass

    def continueRun(self: Any, time: float = ...) -> None:
        """Continues running a simulation with a 10 day runtime or a given amount of time."""
        pass

    def halt(self: Any) -> None:
        """Stops a simulation immediately."""
        pass

    def newCollisionDetector(self: Any) -> vcCollisionDetector:
        """Creates a new collision detector in 3D world, and then returns the new detector."""
        pass

    def newVolumeDetector(self: Any) -> vcVolumeDetector:
        """Creates a new volume detector in 3D world, and then returns the new detector."""
        pass

    def reset(self: Any) -> None:
        """Resets simulation and static components to initial state and sets simulation clock at zero."""
        pass

    def restoreInitialState(self: Any) -> None:
        """Restores simulation and static components to initial state."""
        pass

    def run(self: Any, time: float = ...) -> None:
        """Runs simulation with a 10 day runtime or a given amount of time."""
        pass

    def setFastScheduling(self: Any, enabled: bool) -> None:
        """Updates the fast scheduling flag for all conveyors that support the property."""
        pass

    def setInitialState(self: Any) -> None:
        """Saves the current state of simulation and static components."""
        pass

    def update(self: Any) -> None:
        """Updates simulation and 3D world to reflect current state of components."""
        pass

    OnCollision : Callable[[vcCollisionDetector], None]
    """Triggered when a collision is detected using active tests."""


    OnReset : Callable[[vcSimulation], None]
    """Triggered when simulation is reset."""


    OnStartStop : Callable[[vcSimulation, bool], None]
    """Triggered when simulation is started or stopped."""



class vcSimVehicle(vcBehaviour):
    """vcSimVehicle allows you to simulate a component as a moving vehicle.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSimVehicle.htm"""

    @property
    def Acceleration(self) -> float:
        """Defines the maximum acceleration (mm/s^2) of vehicle. That is, how fast vehicle can speed up."""
        pass

    @Acceleration.setter
    def Acceleration(self, value : float) -> None:
        pass

    @property
    def Deceleration(self) -> float:
        """Defines the maximum deceleration (mm/s^2) of vehicle. That is, how fast vehicle can slow down."""
        pass

    @Deceleration.setter
    def Deceleration(self, value : float) -> None:
        pass

    @property
    def DecisionTime(self) -> float:
        """Gets the amount of time it will take vehicle to execute a movement and reach decision point of calculated motion path.
 A decision point is the point at which vehicle will decelerate to stop at target. In some cases, a decision point is used to evaluate a vehicle and target location. For example, you may want to simulate vehicle routing and intersection crossing as well as evaluate if another vehicle is at target location."""
        pass

    @property
    def Interpolation(self) -> float:
        """Sets the tension (0 - n) of calculated motion path for vehicle to reach target.
 (Optional) Default value is 0, which will result in straight lines from each waypoint of path. The bigger the value, the longer the vehicle will navigate along the tangents of waypoints."""
        pass

    @Interpolation.setter
    def Interpolation(self, value : float) -> None:
        pass

    @property
    def LengthIterations(self) -> int:
        """Sets the number of iterations for each path segment when calculating Bezier path length.
 (Optional) Default value is 10. More iterations take longer to compute but give more precise results."""
        pass

    @LengthIterations.setter
    def LengthIterations(self, value : int) -> None:
        pass

    @property
    def MaxSpeed(self) -> float:
        """Defines the maximum speed (mm/s) of vehicle. That is, the top speed of vehicle."""
        pass

    @MaxSpeed.setter
    def MaxSpeed(self, value : float) -> None:
        pass

    @property
    def OffsetMatrix(self) -> vcMatrix:
        """Sets an offset for vehicle origin and orientation.
 (Optional) Default is containing node's origin. In some cases, you may want to retain orientation of vehicle when moving in reverse or along an elevated path."""
        pass

    @OffsetMatrix.setter
    def OffsetMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def PathLength(self) -> float:
        """Gets the length of motion path vehicle will use to reach a target."""
        pass

    @property
    def TotalTime(self) -> float:
        """Gets the total travel time of vehicle to reach a target using calculated path."""
        pass

    def addControlPoint(self: Any, point: vcVector) -> None:
        """Adds a given point to end of vehicle path."""
        pass

    def addOrientationPoint(self: Any, vector: vcVector) -> None:
        """If Interpolation is not zero, adds a given vector to vehicle in order to calculate vehicle orientation at its last control point.
 This method should be called immediately after adding control points to vehicle path. A given vector is not added to path."""
        pass

    def attachWagonAtTheEnd(self: Any, component: vcComponent, distance: float = ...) -> None:
        """Attaches a given component to vehicle as a wagon.
 If no previous wagons, component is added as lead wagon. Otherwise, component is attached to last wagon added to vehicle.
 An optional distance argument can be given to offset distance component is attached to vehicle. By default, the method will use distance of component to vehicle at time of call."""
        pass

    def calculateDecisionTimeToStopAt(self: Any, distance: float) -> float:
        """Returns the total simulation time at which vehicle would need to decelerate (decision point) to stop at a given distance in calculated motion path."""
        pass

    def calculateEnterExitBox(self: Any, Center: vcVector, P1: vcVector, P2: vcVector, distStartAt: float, precision: float) -> Tuple[float, float]:
        """Returns the distance at which vehicle would enter and exit a box based on calculated path, starting distance of vehicle and a given precision.
 The Center, P1 and P2 arguments define box.
 The returned distances will be within one-half of precision to the theoretical intersection."""
        pass

    def calculateFinishedTimeToStopAt(self: Any, distance: float) -> float:
        """Returns the calculated total simulation time that vehicle will stop at a given distance based on calculated path."""
        pass

    def calculateOffsetPathLength(self: Any, offset: vcVector) -> float:
        """Returns the length of calculated path for vehicle based on a given offset."""
        pass

    def calculatePositionAt(self: Any, time: float, isElapsedTime: int) -> Tuple[vcVector, vcVector]:
        """Returns the position and direction of vehicle at a given time based on calculated path.
 If isElapsedTime argument is 0 (default), a given time is the elapsed time since start of vehicle movement. Otherwise, given time is elapsed time since start of simulation."""
        pass

    def calculatePositionWithDistance(self: Any, distance: float) -> Tuple[vcVector]:
        """Returns the position of vehicle at a given distance in calculated path.
 The returned value is a tuple in which first element is position vector."""
        pass

    def calculateSpeedAt(self: Any, time: float, isElapsedTime: int) -> float:
        """Returns the speed of vehicle on calculated path at a given time.
 If isElapsedTime argument is 0 (default), a given time is the elapsed time since start of vehicle movement. Otherwise, given time is elapsed time since start of simulation."""
        pass

    def calculateTravelWithTime(self: Any, time: float, isElapsedTime: int) -> float:
        """Returns the distance traveled by vehicle on calculated path at a given time.
 If isElapsedTime argument is 0 (default), a given time is the elapsed time since start of vehicle movement. Otherwise, given time is elapsed time since start of simulation."""
        pass

    def clearMove(self: Any) -> None:
        """Removes all points from calculated path of vehicle, thereby stopping vehicle movement.
 This method should be called at start of simulation before any control points are added to vehicle."""
        pass

    def clearPassedPoints(self: Any) -> None:
        """Removes points from calculated path that have been reached by vehicle, thereby resetting the origin of calculated path and its length."""
        pass

    def detachAllWagons(self: Any) -> None:
        """Detaches all wagons from vehicle and one another.
 This method should be called when simulation is reset; otherwise components will remain attached to one another."""
        pass

    def getControlPointDistance(self: Any, controlPointIndex: int) -> float:
        """Returns the distance of a control point at a given index in vehicle based on calculated path.
 Note: If wagons are attached to vehicle, there will be control points with negative distances."""
        pass

    def offsetPath(self: Any, offset: vcVector) -> None:
        """Offsets the calculated path of vehicle parametrically (X-axis is tangent, Y-axis is radial, Z-axis is up).
 This method should be called after adding points to vehicle."""
        pass

    def rePlan(self: Any) -> None:
        """Clears all points from vehicle except those between vehicle and its wagons, thereby allowing you to replan route of vehicle using current speed, position and orientation. That is, the vehicle will not stop rather reroute itself to newly added control points."""
        pass

    def resetStopAtDistance(self: Any, distance: float) -> None:
        """Instructs vehicle to stop at a given distance on calculated path.
 This method allows you stop vehicle and recalculated route using same or different control points."""
        pass

    def rotateInPlace(self: Any, angle: float, angularSpeed: float, angularAcceleration: float, angularDeceleration: float) -> None:
        """Rotates vehicle by a given angle using given angularSpeed, angularAcceleration and angularDeceleration arguments.
 Rotation will trigger OnMovementChanged and OnMovementFinished events. To ensure rotation is completed, use a delay, event or trigger before adding new control points to vehicle."""
        pass

    def update(self: Any, time: float) -> None:
        """Updates the position of objects controlled by vehicle."""
        pass

    OnDecisionPointReached : Callable[[vcComponent, float], None]
    """Triggered when vehicle starts to decelerate in order to stop at target. That is, vehicle reaches decision point.
 The component of vehicle and time of occurrence are passed to event."""


    OnFinalDestinationReached : Callable[[vcComponent, float], None]
    """Triggered when vehicle reaches last target. That is, vehicle reaches last control point, and then stops with no more targets in queue.
 The component of vehicle and time of occurrence are passed to event."""


    OnMovementChanged : Callable[[vcComponent, float], None]
    """Triggered when vehicle route is modified, for example points cleared or added to vehicle or change in stop distance.
 The component of vehicle and time of occurrence are passed to event."""


    OnMovementFinished : Callable[[vcComponent, float], None]
    """Triggered when vehicle reaches target.
 The component of vehicle and time of occurrence are passed to event."""



class vcSnapCommand(vcCommand):
    """vcSnapCommand provides options for handling the position and orientation of 3D world points selected using the interactiveSnap command.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSnapCommand.htm"""

    @property
    def Snap(self) -> bool:
        """Turns on or off the ability to snap to a target."""
        pass

    @Snap.setter
    def Snap(self, value : bool) -> None:
        pass

    @property
    def SnapOnCircleCenter(self) -> bool:
        """Turns on or off the center of circles as potential targets."""
        pass

    @SnapOnCircleCenter.setter
    def SnapOnCircleCenter(self, value : bool) -> None:
        pass

    @property
    def SnapOnCurve(self) -> bool:
        """Turns on or off curves as potential targets."""
        pass

    @SnapOnCurve.setter
    def SnapOnCurve(self, value : bool) -> None:
        pass

    @property
    def SnapOnEdge(self) -> bool:
        """Turns on or off edges as potential targets."""
        pass

    @SnapOnEdge.setter
    def SnapOnEdge(self, value : bool) -> None:
        pass

    @property
    def SnapOnEdgeCenter(self) -> bool:
        """Turns on or off the midpoint of edges as potential targets."""
        pass

    @SnapOnEdgeCenter.setter
    def SnapOnEdgeCenter(self, value : bool) -> None:
        pass

    @property
    def SnapOnFaceCenter(self) -> bool:
        """Turns on or off the center of faces as potential targets."""
        pass

    @SnapOnFaceCenter.setter
    def SnapOnFaceCenter(self, value : bool) -> None:
        pass

    @property
    def SnapOnFrame(self) -> bool:
        """Turns on or off frames as potential targets."""
        pass

    @SnapOnFrame.setter
    def SnapOnFrame(self, value : bool) -> None:
        pass

    @property
    def SnapOnNodeCenter(self) -> bool:
        """Turns on or off the center of nodes as potential targets."""
        pass

    @SnapOnNodeCenter.setter
    def SnapOnNodeCenter(self, value : bool) -> None:
        pass

    @property
    def SnapOnNodeOrigin(self) -> bool:
        """Turns on or off the origin of nodes as potential targets."""
        pass

    @SnapOnNodeOrigin.setter
    def SnapOnNodeOrigin(self, value : bool) -> None:
        pass

    @property
    def SnapOnPoint(self) -> bool:
        """Turns on or off points on lines and polygons, for example corner points, as potential targets."""
        pass

    @SnapOnPoint.setter
    def SnapOnPoint(self, value : bool) -> None:
        pass

    @property
    def SnapOnPolygon(self) -> bool:
        """Turns on or off polygons as potential targets."""
        pass

    @SnapOnPolygon.setter
    def SnapOnPolygon(self, value : bool) -> None:
        pass

    @property
    def SnapOnSurface(self) -> bool:
        """Turns on or off faces as potential targets."""
        pass

    @SnapOnSurface.setter
    def SnapOnSurface(self, value : bool) -> None:
        pass

    @property
    def TargetAvailable(self) -> bool:
        """Indicates if pointing at an available target in the 3D world."""
        pass

    @property
    def TargetCircleCenterAvailable(self) -> bool:
        """Indicates if center of a circle is available as a target."""
        pass

    @property
    def TargetCurve(self) -> List[vcVector]:
        """Provides a list of positions for a target curve in World coordinate system."""
        pass

    @property
    def TargetCurveAvailable(self) -> bool:
        """Indicates if a curve is available as a target."""
        pass

    @property
    def TargetCurveIndex(self) -> int:
        """Indicates the index position of a target curve in a geometry set."""
        pass

    @property
    def TargetFaceCenterAvailable(self) -> bool:
        """Indicates if the center of a face is available as a target."""
        pass

    @property
    def TargetGeoset(self) -> vcGeometrySet:
        """Indicates the geometry set of a target."""
        pass

    @property
    def TargetLocked(self) -> bool:
        """Indicates if a target has been selected in the 3D world."""
        pass

    @property
    def TargetMatrix(self) -> vcMatrix:
        """Indicates the position and orientation matrix for target in World coordinates."""
        pass

    @property
    def TargetMatrixAvailable(self) -> bool:
        """Indicates if the position and orientation matrix for a target is available. (only valid for frame type targets)"""
        pass

    @property
    def TargetNode(self) -> vcNode:
        """Indicates the node containing a target."""
        pass

    @property
    def TargetNormal(self) -> vcVector:
        """Indicates the normal vector of a target in World coordinates."""
        pass

    @property
    def TargetNormalAvailable(self) -> bool:
        """Indicates if the normal vector of a target is available. (only valid for polygon and frame type targets)."""
        pass

    @property
    def TargetPosition(self) -> vcVector:
        """Indicates the position of a target in World coordinates."""
        pass

    @property
    def TargetPrimitive(self) -> vcPrimitive:
        """Indicates the geometry primitive object of a target."""
        pass

    @property
    def TargetSurfaceAvailable(self) -> bool:
        """Indicates if the surface of a target is available."""
        pass

    @property
    def TargetSurfaceIndex(self) -> int:
        """Indicates the index position of a target surface in a component, for example the faces of a cube."""
        pass

    def clear(self: Any) -> None:
        """Resets the command and clears its target data."""
        pass

    OnTargetAvailable : Callable[[vcSnapCommand], None]
    """Triggered when pointer is hovering over a valid target in 3D world.
 The command itself as passed as an argument, thereby allowing you to access its updated properties."""


    OnTargetSet : Callable[[vcSnapCommand], None]
    """Triggered when a valid target has been selected in 3D world.
 The command itself as passed as an argument, thereby allowing you to access its updated properties."""



class vcStatement(vcObject):
    """vcStatement is the basic implementation for statements in a robot program and a process routine.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStatement.htm"""

    @property
    def IsEnabled(self) -> bool:
        """Defines if the statement is activated or deactivated."""
        pass

    @IsEnabled.setter
    def IsEnabled(self, value : bool) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of the statement."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def ParentScope(self) -> vcScope:
        """Gets the scope of the statement."""
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of properties of the statement."""
        pass

    @property
    def ParentRoutine(self) -> vcRoutine:
        """Gets the routine of the statement."""
        pass

    @property
    def Type(self) -> int:
        """Gets the statement's type.
 See Statement Constants for more information."""
        pass

    @property
    def TargetProperty(self) -> str:
        """This property exist only in: Assign Variable.
Defines the name of variable to assign a value."""
        pass

    @TargetProperty.setter
    def TargetProperty(self, value : str) -> None:
        pass

    @property
    def ValueExpression(self) -> str:
        """This property exist only in: Assign Variable.
Defines an expression that when evaluated returns the value to assign TargetProperty."""
        pass

    @ValueExpression.setter
    def ValueExpression(self, value : str) -> None:
        pass

    @property
    def Routine(self) -> vcRoutine:
        """This property exist only in: Call Sequence.
Defines a subroutine in robot program called by the statement."""
        pass

    @Routine.setter
    def Routine(self, value : vcRoutine) -> None:
        pass

    @property
    def Comment(self) -> str:
        """This property exist only in: Comment.
Defines the text of the comment."""
        pass

    @Comment.setter
    def Comment(self, value : str) -> None:
        pass

    @property
    def IPOMode(self) -> int:
        """This property exist only in: Define Base, Define Tool.
Defines the interpolation mode of the frame and the external configuration of a referencing robot controller.
 0
 Default setting, so no effect on robot's external configuration.
 1
 Robot position inherits orientation of base frame.
 2
 Robot position inherits orientation of base frame.
 Interpolation constants can be used with this property.
 Note: A conflict can occur if a base-tool pair in a referencing robot have the same IPOMode property value or cannot be used with the robot's current configuration."""
        pass

    @IPOMode.setter
    def IPOMode(self, value : int) -> None:
        pass

    @property
    def IsRelative(self) -> bool:
        """This property exist only in: Define Base, Define Tool.
Defines if Position is based in base frame coordinate system or its parent coordinate system.
 A True value uses base frame coordinate system, so frame will be moved relative to its location at the time of statement execution.
 A False value uses the parent coordinate system of base frame defined in Node, so frame will be moved to an absolute location."""
        pass

    @IsRelative.setter
    def IsRelative(self, value : bool) -> None:
        pass

    @property
    def Node(self) -> vcNode:
        """This property exist only in: Define Base, Define Tool.
Defines the parent node of base frame."""
        pass

    @Node.setter
    def Node(self, value : vcNode) -> None:
        pass

    @property
    def Position(self) -> vcMatrix:
        """This property exist only in: Define Base, Define Tool.
Defines the position matrix of referenced base frame."""
        pass

    @Position.setter
    def Position(self, value : vcMatrix) -> None:
        pass

    @property
    def Base(self) -> vcBaseFrame:
        """This property exist only in: Define Base.
Defines the base frame in robot affected by the statement."""
        pass

    @Base.setter
    def Base(self, value : vcBaseFrame) -> None:
        pass

    @property
    def Tool(self) -> vcBaseFrame:
        """This property exist only in: Define Tool.
Defines the tool frame in robot affected by the statement."""
        pass

    @Tool.setter
    def Tool(self, value : vcBaseFrame) -> None:
        pass

    @property
    def Delay(self) -> float:
        """This property exist only in: Delay, View.
Defines the amount of time in seconds of the delay."""
        pass

    @Delay.setter
    def Delay(self, value : float) -> None:
        pass

    @property
    def HaltSimulation(self) -> bool:
        """This property exist only in: Halt.
Defines if the statement stops a simulation.
 A True value stops a simulation, whereas a False value has no effect on a simulation."""
        pass

    @HaltSimulation.setter
    def HaltSimulation(self, value : bool) -> None:
        pass

    @property
    def ResetSimulation(self) -> bool:
        """This property exist only in: Halt.
Defines if the statement stops and then resets a simulation.
 A True value resets a simulation, whereas a False value has no effect on a simulation."""
        pass

    @ResetSimulation.setter
    def ResetSimulation(self, value : bool) -> None:
        pass

    @property
    def Message(self) -> str:
        """This property exist only in: Print Message, Print.
Defines the text of the message."""
        pass

    @Message.setter
    def Message(self, value : str) -> None:
        pass

    @property
    def SyncComponents(self) -> List[vcComponent]:
        """This property exist only in: Program Synchronize.
Defines a list of components to sync with the statement.
 This means each component is also executing its own Program Synchronize statement."""
        pass

    @SyncComponents.setter
    def SyncComponents(self, value : List[vcComponent]) -> None:
        pass

    @property
    def SyncMessage(self) -> str:
        """This property exist only in: Program Synchronize.
Defines the message to trigger synchronization.
 All components in SyncComponents must use the same message."""
        pass

    @SyncMessage.setter
    def SyncMessage(self, value : str) -> None:
        pass

    @property
    def WaitSync(self) -> bool:
        """This property exist only in: Program Synchronize.
Defines if the statement sends its message and waits to receive the same message from all other components in SyncComponents.
 A True value waits, whereas a False value sends a message and ends the execution of the statement."""
        pass

    @WaitSync.setter
    def WaitSync(self, value : bool) -> None:
        pass

    @property
    def OutputPort(self) -> int:
        """This property exist only in: Set Binary Output.
Defines the port of robot set by the statement."""
        pass

    @OutputPort.setter
    def OutputPort(self, value : int) -> None:
        pass

    @property
    def OutputValue(self) -> bool:
        """This property exist only in: Set Binary Output.
Defines the value of the port set by the statement."""
        pass

    @OutputValue.setter
    def OutputValue(self, value : bool) -> None:
        pass

    @property
    def Statistics(self) -> vcStatistics:
        """This property exist only in: Set Statistics, Flow, Set State.
Defines the statistics behavior of robot referenced by the statement."""
        pass

    @Statistics.setter
    def Statistics(self, value : vcStatistics) -> None:
        pass

    @property
    def State(self) -> str:
        """This property exist only in: Set Statistics, Set State.
Defines the current state of robot. When you create a new Set Statiscs statement, the initial state is NULL. You can also add custom states."""
        pass

    @State.setter
    def State(self, value : str) -> None:
        pass

    @property
    def Condition(self) -> str:
        """This property exist only in: Switch Case, If, Property Condition, Wait Property Condition, Wait Signal, While.
Expression that defines the value against which the case conditions are evaluated.
 See also Robot Statements."""
        pass

    @Condition.setter
    def Condition(self, value : str) -> None:
        pass

    @property
    def Cases(self) -> List[vcCaseScope]:
        """This property exist only in: Switch Case.
All case scopes in this statement. Each scope has an RW property CaseCondition of type String which will be evaluated against statement’s Condition."""
        pass

    @Cases.setter
    def Cases(self, value : List[vcCaseScope]) -> None:
        pass

    @property
    def InputPort(self) -> int:
        """This property exist only in: Wait for Binary Input.
Defines the port of robot evaluated by the statement."""
        pass

    @InputPort.setter
    def InputPort(self, value : int) -> None:
        pass

    @property
    def InputValue(self) -> bool:
        """This property exist only in: Wait for Binary Input.
Defines if InputPort value needs to be True or False to complete the statement."""
        pass

    @InputValue.setter
    def InputValue(self, value : bool) -> None:
        pass

    @property
    def WaitTrigger(self) -> bool:
        """This property exist only in: Wait for Binary Input, Wait Signal.
Defines if InputValue is evaluated when a signal mapped to InputPort has an event, for example a change in its value.
 A True value waits for a signal event or trigger, whereas a False value will not wait to check the value of InputPort.
 Note: A signal event or trigger must occur while the robot is executing the statement, otherwise the robot wil miss the event."""
        pass

    @WaitTrigger.setter
    def WaitTrigger(self, value : bool) -> None:
        pass

    @property
    def AllowDuplicates(self) -> bool:
        """This property exist only in: Append To List.
If already existing values should be added to the target variable."""
        pass

    @AllowDuplicates.setter
    def AllowDuplicates(self, value : bool) -> None:
        pass

    @property
    def SourceVariableName(self) -> str:
        """This property exist only in: Append To List.
Name of the variable from which values are copied. Can be a list or a single variable."""
        pass

    @SourceVariableName.setter
    def SourceVariableName(self, value : str) -> None:
        pass

    @property
    def TargetVariableName(self) -> str:
        """This property exist only in: Append To List.
Name of the variable where values are appended. A new list variable is created if necessary."""
        pass

    @TargetVariableName.setter
    def TargetVariableName(self, value : str) -> None:
        pass

    @property
    def Child(self) -> str:
        """This property exist only in: Attach.
Name of the variable that holds one or more references to the vcProduct that are to be attached to the Parent. Can be a list or a single variable."""
        pass

    @Child.setter
    def Child(self, value : str) -> None:
        pass

    @property
    def Parent(self) -> str:
        """This property exist only in: Attach.
Name of the variable that holds reference to a single vcProduct where to attach."""
        pass

    @Parent.setter
    def Parent(self, value : str) -> None:
        pass

    @property
    def AcceptAllProductTypes(self) -> bool:
        """This property exist only in: Buffer, Detach, Select Products, Start Transport In, Transport In, Transport Pattern In.
(Deprecated) Use vcProductFilter.IsEnabled property instead.
 
 When True, any product is accepted, ignoring AcceptedFlowGroups and AcceptedProductTypes."""
        pass

    @AcceptAllProductTypes.setter
    def AcceptAllProductTypes(self, value : bool) -> None:
        pass

    @property
    def AcceptedFlowGroups(self) -> List[vcProcessFlowGroup]:
        """This property exist only in: Buffer, Detach, Select Products, Start Transport In, Transport In, Transport Pattern In.
(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected flow groups."""
        pass

    @AcceptedFlowGroups.setter
    def AcceptedFlowGroups(self, value : List[vcProcessFlowGroup]) -> None:
        pass

    @property
    def AcceptedProductTypes(self) -> List[vcProductType]:
        """This property exist only in: Buffer, Detach, Select Products, Start Transport In, Transport In, Transport Pattern In.
(Deprecated) Use vcProductFilter instead.
 
 Allows only the selected product types."""
        pass

    @AcceptedProductTypes.setter
    def AcceptedProductTypes(self, value : List[vcProductType]) -> None:
        pass

    @property
    def BreakCondition(self) -> str:
        """This property exist only in: Buffer.
When this expression evaluates to True (at least once), the buffer stops accepting products. This allows the buffer to empty and then the statement execution to end.
 Note: The expression is evaluated at the start of the statement execution and every time a product arrives to or leaves the buffer.
 Note: Must be from the same component.
 See also Process Statement Expressions."""
        pass

    @BreakCondition.setter
    def BreakCondition(self, value : str) -> None:
        pass

    @property
    def BufferMode(self) -> int:
        """This property exist only in: Buffer.
Defines the product access order of the buffer.
 StatisticsFlowDirection
 See BufferMode Constants for more information."""
        pass

    @BufferMode.setter
    def BufferMode(self, value : int) -> None:
        pass

    @property
    def Destination(self) -> int:
        """This property exist only in: Buffer, Start Transport Out, Transport Out.
Defines the destination to where products leave the buffer.
 See TransportOutType Constants for more information."""
        pass

    @Destination.setter
    def Destination(self, value : int) -> None:
        pass

    @property
    def DestinationContainer(self) -> vcContainer:
        """This property exist only in: Buffer.
Component container whose output connection is used to place the outgoing products. Only used when Destination is set to VC_TRANSPORTOUTTYPE_CONTAINER."""
        pass

    @DestinationContainer.setter
    def DestinationContainer(self, value : vcContainer) -> None:
        pass

    @property
    def InputResourcePositionFrame(self) -> vcFrameFeature:
        """This property exist only in: Buffer.
Defines resource position offset from product position and XY plane on which resource position is projected to while emptying the buffer.
 This allows the resource position to move along with the product position but still remain on a certain plane.
 Note: Must be from the same component."""
        pass

    @InputResourcePositionFrame.setter
    def InputResourcePositionFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def ParallelInputLimit(self) -> int:
        """This property exist only in: Buffer.
Defines how many products can be arriving to the buffer in parallel. Note: Must be greater than zero."""
        pass

    @ParallelInputLimit.setter
    def ParallelInputLimit(self, value : int) -> None:
        pass

    @property
    def ParallelOutputLimit(self) -> int:
        """This property exist only in: Buffer.
Defines how many products can be leaving the buffer in parallel.
 Note: Must be greater than zero."""
        pass

    @ParallelOutputLimit.setter
    def ParallelOutputLimit(self, value : int) -> None:
        pass

    @property
    def PatternCount(self) -> vcVector:
        """This property exist only in: Buffer, Transport Pattern In.
Number of buffer slots per X,Y,Z axis. The Real values of the vector are rounded to nearest Integer values. Each dimension should in inclusive range 0 to 1289."""
        pass

    @PatternCount.setter
    def PatternCount(self, value : vcVector) -> None:
        pass

    @property
    def PatternStep(self) -> vcVector:
        """This property exist only in: Buffer, Transport Pattern In.
Step between products in pattern per X,Y,Z axis."""
        pass

    @PatternStep.setter
    def PatternStep(self, value : vcVector) -> None:
        pass

    @property
    def ProductPositionFrame(self) -> vcFrameFeature:
        """This property exist only in: Buffer, Start Transport In, Transport In, Transport Pattern In.
Frame defining the position and orientation of the product pattern in combination with the Offset property.
 Note: Must be from the same component."""
        pass

    @ProductPositionFrame.setter
    def ProductPositionFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def ReservedProductVariableName(self) -> str:
        """This property exist only in: Buffer, Start Transport In, Transport In, Transport Pattern In.
Name of variable containing products already reserved using Reserve Product statement. The buffer will be first filled using these products and then will continue to receive further products as defined by the Source property.
 Note: The product filtering defined by properties AcceptAllProductTypes, AcceptedFlowGroups and AcceptedProductTypes is not applied to the pre-reserved products."""
        pass

    @ReservedProductVariableName.setter
    def ReservedProductVariableName(self, value : str) -> None:
        pass

    @property
    def Source(self) -> int:
        """This property exist only in: Buffer, Transport In.
Defines how products get into the buffer.
 See TransportInType Constants for more information."""
        pass

    @Source.setter
    def Source(self, value : int) -> None:
        pass

    @property
    def DeleteAttached(self) -> bool:
        """This property exist only in: Change Type.
When True, any components attached to the changed product’s component are deleted. When False, any attached components are reattached to new nodes in the rebuilt parent component based on the parent node names."""
        pass

    @DeleteAttached.setter
    def DeleteAttached(self, value : bool) -> None:
        pass

    @property
    def NewType(self) -> vcProductType:
        """This property exist only in: Change Type.
The product type to change the products to."""
        pass

    @NewType.setter
    def NewType(self, value : vcProductType) -> None:
        pass

    @property
    def ProductVariableName(self) -> str:
        """This property exist only in: Change Type, Create, Detach, Flow, Release Product Reservation, Remove, Select Products, Set Next Flow Step Statement, Set Node Material, Set Node Visibility, Set Product Visit State Statement, Start Transport In, Start Transport Out, Transport In, Transport Out, Wait Transport.
Name of variable containing the products (vcProduct) to change. Can be a list of products."""
        pass

    @ProductVariableName.setter
    def ProductVariableName(self, value : str) -> None:
        pass

    @property
    def RetainVisitCount(self) -> str:
        """This property exist only in: Change Type, Set Next Flow Step Statement.
Gets an expression property which defines if vcProduct's process visit counts for all visited processes should be reset back to zero, or preserved as they are when this statement is executed and product changes flow groups. The default is to reset them to zero."""
        pass

    @RetainVisitCount.setter
    def RetainVisitCount(self, value : str) -> None:
        pass

    @property
    def Container(self) -> vcContainer:
        """This property exist only in: Create, Start Transport Out, Transport Out.
Component container where to place the created product’s component.
 If set to None, the associated transport node’s (vcTransportNode) container is used."""
        pass

    @Container.setter
    def Container(self, value : vcContainer) -> None:
        pass

    @property
    def ProductType(self) -> vcProductType:
        """This property exist only in: Create.
The product type to instantiate."""
        pass

    @ProductType.setter
    def ProductType(self, value : vcProductType) -> None:
        pass

    @property
    def Distribution(self) -> str:
        """This property exist only in: Delay.
Defines an expression to calculate a value for the amount of seconds to wait for. A sample is taken when the statement execution begins.
 Available functions include:
 normal( u, s )
 Normal distribution for mean value u, and the standard deviation s.
 lognormal( u, s )
 Log normal distribution for mean u, and the standard deviation s.
 uniform( a, b )
 Uniform distribution in range a <= x < b.
 exponential( lambda )
 Exponential distribution where the mean is 1/lambda and the variance is 1/lambda^2.
 gamma( k, theta )
 Gamma distribution with shape k and scale theta.
 triangular( min, mode, max )
 Triangular distribution with the specified minimum, mode and maximum values.
 weibull( k, lambda )
 Weibull distribution with shape k and scale lambda.
 Tip: Use RandomStream to have the distribution use a stream for seeding a value and generating the same set of random numbers during a simulation. That is, if you reset and run a simulation you should expect the same values given in the previous simulation."""
        pass

    @Distribution.setter
    def Distribution(self, value : str) -> None:
        pass

    @property
    def Expression(self) -> str:
        """This property exist only in: Delay.
Amount to wait for defined as an expression that must evaluate to a Real value at the start of the statement execution.
 Unit is seconds of simulation time.
 See also Process Statement Expressions."""
        pass

    @Expression.setter
    def Expression(self, value : str) -> None:
        pass

    @property
    def TimeSource(self) -> int:
        """This property exist only in: Delay, Work.
Defines whether to evaluate the Distribution or Expression property to get the amount of time to wait for.
 See Time Source Constants for more information."""
        pass

    @TimeSource.setter
    def TimeSource(self, value : int) -> None:
        pass

    @property
    def DetachedVariableName(self) -> str:
        """This property exist only in: Detach.
Name of output variable where to store references to the detached products (vcProduct)."""
        pass

    @DetachedVariableName.setter
    def DetachedVariableName(self, value : str) -> None:
        pass

    @property
    def DetachMany(self) -> bool:
        """This property exist only in: Detach.
When True, detaches all products that match the filter, otherwise only the first one."""
        pass

    @DetachMany.setter
    def DetachMany(self, value : bool) -> None:
        pass

    @property
    def FlowDirection(self) -> int:
        """This property exist only in: Flow.
Whether the product transferred into the process or left it.
 See StatisticsFlowDirection Constants for more information."""
        pass

    @FlowDirection.setter
    def FlowDirection(self, value : int) -> None:
        pass

    @property
    def PropertyVariableName(self) -> str:
        """This property exist only in: Get Property.
Name of the proxy runtime variable to create."""
        pass

    @PropertyVariableName.setter
    def PropertyVariableName(self, value : str) -> None:
        pass

    @property
    def SelectedComponent(self) -> vcComponent:
        """This property exist only in: Get Property, Property Condition.
The static component that owns the target property. None value means parent component of the statement."""
        pass

    @SelectedComponent.setter
    def SelectedComponent(self, value : vcComponent) -> None:
        pass

    @property
    def SelectedBehavior(self) -> vcBehaviour:
        """This property exist only in: Get Property, Property Condition.
Behaviour that owns the target property.
 Must be owned by the SelectedComponent.
 None value means SelectedProperty is a component property of SelectedComponent.
 Must be set after SelectedComponent has been set."""
        pass

    @SelectedBehavior.setter
    def SelectedBehavior(self, value : vcBehaviour) -> None:
        pass

    @property
    def SelectedProperty(self) -> vcProperty:
        """This property exist only in: Get Property, Property Condition.
The target property to get.
 Note: Must be a property of either SelectedComponent or SelectedBehavior depending on the value of SelectedBehavior.
 Note: Must be set after SelectedComponent and SelectedBehavior.
 Note: Value type of the property must be Integer, Real, vcVector, vcMatrix or String."""
        pass

    @SelectedProperty.setter
    def SelectedProperty(self, value : vcProperty) -> None:
        pass

    @property
    def ElseScope(self) -> vcScope:
        """This property exist only in: If.
Scope to execute when Condition evaluates to False."""
        pass

    @property
    def ThenScope(self) -> vcScope:
        """This property exist only in: If.
Scope to execute when Condition evaluates to True."""
        pass

    @property
    def Controller(self) -> vcServoController:
        """This property exist only in: Move Joint, Work.
The controller that owns the joint. This can be a servo controller or a derived controller, e.g. a vcRobotController.
 Note: Must be from the same component."""
        pass

    @Controller.setter
    def Controller(self, value : vcServoController) -> None:
        pass

    @property
    def Joint(self) -> vcJoint:
        """This property exist only in: Move Joint.
The joint to move.
 Note: Must be set after Controller has been set."""
        pass

    @Joint.setter
    def Joint(self, value : vcJoint) -> None:
        pass

    @property
    def MotionTime(self) -> str:
        """This property exist only in: Move Joint.
An expression for motion time. This can be left empty to let the controller plan the motion. If not left empty, this expression must evaluate to a Real or Integer result.
 See also Process Statement Expressions."""
        pass

    @MotionTime.setter
    def MotionTime(self, value : str) -> None:
        pass

    @property
    def TargetValue(self) -> str:
        """This property exist only in: Move Joint.
An expression for the target value.
 Note: Must evaluate to a Real or Integer result.
 See also Process Statement Expressions."""
        pass

    @TargetValue.setter
    def TargetValue(self, value : str) -> None:
        pass

    @property
    def PrependHeader(self) -> bool:
        """This property exist only in: Print.
When True, the message is printed along with a prefix indicating its owner.
 ComponentName::ProcessExecutorName::ProcessRoutineName: YourMessage
 Otherwise prints only result of the Message expression."""
        pass

    @PrependHeader.setter
    def PrependHeader(self, value : bool) -> None:
        pass

    @property
    def Component(self) -> vcComponent:
        """This property exist only in: Run Robot Routine, Send Signal, Wait Signal.
The component from which to search for a robot executor.
 Note: If the component has multiple robot executors, the first one of the these will be selected.
 Note: None can be used to select the component that owns the process executor that is running this statement."""
        pass

    @Component.setter
    def Component(self, value : vcComponent) -> None:
        pass

    @property
    def RoutineName(self) -> str:
        """This property exist only in: Run Robot Routine.
An expression that must evaluate to a string value.
 During execution, the statement will attempt to find a routine from the selected robot executor with that name. This expression evaluation and routine search will be performed again each time the robot becomes idle.
 See also Process Statement Expressions."""
        pass

    @RoutineName.setter
    def RoutineName(self, value : str) -> None:
        pass

    @property
    def SplitVariableName(self) -> str:
        """This property exist only in: Select Products.
Name of the variable where to copy the product instance (vcProduct) references to.
 Note: The variable is created if it does not exist already. The variable is always made into a list of products regardless of if any products got copied from the input."""
        pass

    @SplitVariableName.setter
    def SplitVariableName(self, value : str) -> None:
        pass

    @property
    def Signal(self) -> vcSignal:
        """This property exist only in: Send Signal, Wait Signal.
The signal behavior to trigger.
 Note: Must be either Boolean, Integer, Real or String signal.
 Note: Must be from the component assigned to the Component property.
 Note: Must be set after the Component property has been set."""
        pass

    @Signal.setter
    def Signal(self, value : vcSignal) -> None:
        pass

    @property
    def Value(self) -> str:
        """This property exist only in: Send Signal.
An expression to generate the value for the signal.
 This can reference e.g. static properties or properties in dynamic products.
 See also Process Statement Expressions."""
        pass

    @Value.setter
    def Value(self, value : str) -> None:
        pass

    @property
    def FlowInfoVariableName(self) -> str:
        """This property exist only in: Set Next Flow Step Statement.
Name of the Process variable where to get the Product instances."""
        pass

    @FlowInfoVariableName.setter
    def FlowInfoVariableName(self, value : str) -> None:
        pass

    @property
    def ForceExactFlowStep(self) -> str:
        """This property exist only in: Set Next Flow Step Statement.
An editable list of explicitly accepted process groups. Used with SpecificProcesses mode."""
        pass

    @ForceExactFlowStep.setter
    def ForceExactFlowStep(self, value : str) -> None:
        pass

    @property
    def ForceExactProcessGroup(self) -> str:
        """This property exist only in: Set Next Flow Step Statement.
An expression which defines the number to assign as process visit count."""
        pass

    @ForceExactProcessGroup.setter
    def ForceExactProcessGroup(self, value : str) -> None:
        pass

    @property
    def Force(self) -> bool:
        """This property exist only in: Set Node Material.
When True, sets the vcNode.MaterialInheritance to VC_MATERIAL_FORCE_INHERIT_NODE.
 When False, material inheritance setting in the target node is not changed."""
        pass

    @Force.setter
    def Force(self, value : bool) -> None:
        pass

    @property
    def Material(self) -> vcMaterial:
        """This property exist only in: Set Node Material.
The material to set to the node."""
        pass

    @Material.setter
    def Material(self, value : vcMaterial) -> None:
        pass

    @property
    def NodeName(self) -> str:
        """This property exist only in: Set Node Material, Set Node Visibility.
Name of the target node (vcNode).
 Note: Empty string means the root node of the target product (vcProduct)."""
        pass

    @NodeName.setter
    def NodeName(self, value : str) -> None:
        pass

    @property
    def Visibility(self) -> int:
        """This property exist only in: Set Node Visibility.
Target visibility state to set.
 See NodeVisibilityState Constants for more information."""
        pass

    @Visibility.setter
    def Visibility(self, value : int) -> None:
        pass

    @property
    def TargetProcessMode(self) -> int:
        """This property exist only in: Set Product Visit State Statement.
Defines the selection of process groups that will be affected by this statement."""
        pass

    @TargetProcessMode.setter
    def TargetProcessMode(self, value : int) -> None:
        pass

    @property
    def Processes(self) -> List[vcProcessGroup]:
        """This property exist only in: Set Product Visit State Statement.
An editable list of explicitly accepted process groups. Used with SpecificProcesses mode."""
        pass

    @Processes.setter
    def Processes(self, value : List[vcProcessGroup]) -> None:
        pass

    @property
    def VisitCount(self) -> str:
        """This property exist only in: Set Product Visit State Statement.
An expression which defines the number to assign as process visit count."""
        pass

    @VisitCount.setter
    def VisitCount(self, value : str) -> None:
        pass

    @property
    def VisitCountMode(self) -> int:
        """This property exist only in: Set Product Visit State Statement.
Defines how the result of VisitCount will be applied."""
        pass

    @VisitCountMode.setter
    def VisitCountMode(self, value : int) -> None:
        pass

    @property
    def ResourcePositionFrame(self) -> vcFrameFeature:
        """This property exist only in: Start Transport In, Start Transport Out, Transport In, Transport Out, Transport Pattern In, Work.
Defines a position hint where a transport resource should be when placing the product.
 Must be from the same component."""
        pass

    @ResourcePositionFrame.setter
    def ResourcePositionFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def DestinationNode(self) -> vcTransportNode:
        """This property exist only in: Start Transport Out, Transport Out.
Defines a transport node where to send the products using the transport system (vcProduct).
 Note: Only used when Destination is VC_TRANSPORTOUTTYPE_TRANSPORTNODE"""
        pass

    @DestinationNode.setter
    def DestinationNode(self, value : vcTransportNode) -> None:
        pass

    @property
    def Offset(self) -> vcMatrix:
        """This property exist only in: Transport Pattern In.
Offset of the first product position from ProductPositionFrame."""
        pass

    @Offset.setter
    def Offset(self, value : vcMatrix) -> None:
        pass

    @property
    def VariableName(self) -> str:
        """This property exist only in: Wait Property Condition.
Name of the variable or component property to monitor."""
        pass

    @VariableName.setter
    def VariableName(self, value : str) -> None:
        pass

    @property
    def Timeout(self) -> float:
        """This property exist only in: Wait Signal.
Maximum amount of simulation time in seconds to wait for a value that matches the condition.
 0 means no time limit."""
        pass

    @Timeout.setter
    def Timeout(self, value : float) -> None:
        pass

    @property
    def TimedOutVariableName(self) -> str:
        """This property exist only in: Wait Signal.
Name of a process variable where to store a Boolean value whether the timeout was reached or not.
 Can be left empty."""
        pass

    @TimedOutVariableName.setter
    def TimedOutVariableName(self, value : str) -> None:
        pass

    @property
    def ValueOutputVariableName(self) -> str:
        """This property exist only in: Wait Signal.
Name of a process variable where to store the signal value that passed the condition.
 Can be left empty."""
        pass

    @ValueOutputVariableName.setter
    def ValueOutputVariableName(self, value : str) -> None:
        pass

    @property
    def Scope(self) -> vcScope:
        """This property exist only in: While.
Scope to keep executing while Condition evaluates to True."""
        pass

    @property
    def ProcessTime(self) -> str:
        """This property exist only in: Work.
Defines an expression to calculate a value for the work duration in seconds. A sample is taken when the statement execution begins.
 Available functions include:
 normal( u, s )
 Normal distribution for mean value u, and the standard deviation s.
 lognormal( u, s )
 Log normal distribution for mean u, and the standard deviation s.
 uniform( a, b )
 Uniform distribution in range a <= x < b.
 exponential( lambda )
 Exponential distribution where the mean is 1/lambda and the variance is 1/lambda^2.
 gamma( k, theta )
 Gamma distribution with shape k and scale theta.
 triangular( min, mode, max )
 Triangular distribution with the specified minimum, mode and maximum values.
 weibull( k, lambda )
 Weibull distribution with shape k and scale lambda.
 Tip: Use RandomStream to have the distribution use a stream for seeding a value and generating the same set of random numbers during a simulation. That is, if you reset and run a simulation you should expect the same values given in the previous simulation."""
        pass

    @ProcessTime.setter
    def ProcessTime(self, value : str) -> None:
        pass

    @property
    def ProcessTimeExpression(self) -> str:
        """This property exist only in: Work.
Work duration defined as an expression that must evaluate to a Real value at the start of the statement execution.
 Unit is seconds of simulation time.
 See also Process Statement Expressions."""
        pass

    @ProcessTimeExpression.setter
    def ProcessTimeExpression(self, value : str) -> None:
        pass

    @property
    def WorkPositionFrame(self) -> vcFrameFeature:
        """This property exist only in: Work.
Defines a position hint where the actual work happens."""
        pass

    @WorkPositionFrame.setter
    def WorkPositionFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def View(self) -> str:
        """This property exist only in: View.
Defines the name of view to move camera to in 3D world.
 If the view does not exist in layout, the statement will still execute its Delay."""
        pass

    @View.setter
    def View(self, value : str) -> None:
        pass

    def createProperty(self: Any, type: int, name: str) -> vcProperty:
        """Creates a new property of a given type and name in the statement, and then returns the new property.
 An optional constraints argument can be used to define constraints for new property, which must be defined at the time of creation.
 See Property Constants for more information."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a given property in the statement."""
        pass

    def getProperty(self: Any, name: str) -> vcProperty:
        """Returns a property matching a given name in the statement; otherwise returns None."""
        pass


class vcStatistics(vcBehaviour):
    """vcStatistics allows you to create flow type and state based statistics as well as access the properties of a Statistics behavior and related simulation statistics.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStatistics.htm"""

    @property
    def ComponentMaxCount(self) -> int:
        """Gets the maximum number of components that have been contained in a component at any given time."""
        pass

    @property
    def ComponentMaxTime(self) -> float:
        """Gets the maximum amount of time a component spent contained in a component."""
        pass

    @property
    def ComponentMinCount(self) -> int:
        """Gets the minimum number of components that been contained in a component at any given time."""
        pass

    @property
    def ComponentMinTime(self) -> float:
        """Gets the minimum amount of time a component spent contained in a component."""
        pass

    @property
    def ComponentsArrived(self) -> int:
        """Gets the total number of components that have been transferred into a component."""
        pass

    @property
    def ComponentsAverageTime(self) -> float:
        """Gets the average amount of time components have spent in a component."""
        pass

    @property
    def ComponentsCurrent(self) -> int:
        """Gets the total number of components currently contained in a component."""
        pass

    @property
    def ComponentsDeparted(self) -> int:
        """Gets the total amount of components that have been transferred out of a component."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of Statistics behavior."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def States(self) -> List[Tuple]:
        """Defines a list of defined states mapped to system states.
 A state must be mapped to a system state. See Statistics for more information."""
        pass

    @States.setter
    def States(self, value : List[Tuple]) -> None:
        pass

    @property
    def SystemStates(self) -> List[Tuple]:
        """Gets a list of available system states, which provides system state description and type.
 See Statistics Constants for more information."""
        pass

    @property
    def PartsAverageCount(self) -> float:
        """This property exist only in: Flow type properties.
Gets the average amount of components that have been contained in a component."""
        pass

    @property
    def PartsAverageTime(self) -> float:
        """This property exist only in: Flow type properties.
Gets the average amount of time components spent in a component."""
        pass

    @property
    def PartsCurrent(self) -> int:
        """This property exist only in: Flow type properties.
Gets the current amount of components contained in a component."""
        pass

    @property
    def PartsEntered(self) -> int:
        """This property exist only in: Flow type properties.
Gets/Sets the number of components that have been transferred into a component.
 Generally, this property is set to reset a count or collect from the start of a new process."""
        pass

    @PartsEntered.setter
    def PartsEntered(self, value : int) -> None:
        pass

    @property
    def PartsExited(self) -> int:
        """This property exist only in: Flow type properties.
Gets/Sets the number of components that have been transferred out of a component.
 Generally, this property is set to reset a count or collect from the start of a new process."""
        pass

    @PartsExited.setter
    def PartsExited(self, value : int) -> None:
        pass

    @property
    def PartsMaxCount(self) -> int:
        """This property exist only in: Flow type properties.
Gets the maximum number of components that have been contained in a component at any given time."""
        pass

    @property
    def PartsMaxTime(self) -> float:
        """This property exist only in: Flow type properties.
Gets the maximum amount of time a component has spent in a component."""
        pass

    @property
    def PartsMinCount(self) -> int:
        """This property exist only in: Flow type properties.
Gets the minimum number of components that have been contained in a component at any given time."""
        pass

    @property
    def PartsMinTime(self) -> float:
        """This property exist only in: Flow type properties.
Gets the minimum amount of time a component has spent in a component."""
        pass

    @property
    def PartsTotalTime(self) -> float:
        """This property exist only in: Flow type properties.
Gets sum total of the amount of time each component had spent in a component, for example the duration of each component on a conveyor added together."""
        pass

    @property
    def PartsUtilization(self) -> float:
        """This property exist only in: Flow type properties.
Gets the percentage of a component's capacity being utilized: number of parts divided by component's capacity."""
        pass

    @property
    def PartsIntervalAverageCount(self) -> float:
        """This property exist only in: Flow type properties.
Same as other flow type properties, yet each value reflects the last recorded interval during a simulation, which by default is every 60.0 seconds. See vcStatisticsManager for more information on how to change interval."""
        pass

    @property
    def PartsIntervalAverageTime(self) -> float:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalCurrent(self) -> int:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalEntered(self) -> int:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalExited(self) -> int:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalMaxCount(self) -> int:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalMaxTime(self) -> float:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalMinCount(self) -> int:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalMinTime(self) -> float:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalTotalTime(self) -> float:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def PartsIntervalUtilization(self) -> float:
        """This property exist only in: Flow type properties."""
        pass

    @property
    def IntervalBlockedPercentage(self) -> float:
        """This property exist only in: State based properties.
Same as other state based properties, yet each value reflects the last recorded interval during a simulation, which by default is every 60.0 seconds.
 See vcStatisticsManager for more information on how to change interval."""
        pass

    @property
    def IntervalBreakPercentage(self) -> float:
        """This property exist only in: State based properties."""
        pass

    @property
    def IntervalBusyPercentage(self) -> float:
        """This property exist only in: State based properties."""
        pass

    @property
    def IntervalFailedPercentage(self) -> float:
        """This property exist only in: State based properties."""
        pass

    @property
    def IntervalIdlePercentage(self) -> float:
        """This property exist only in: State based properties."""
        pass

    @property
    def IntervalRepairPercentage(self) -> float:
        """This property exist only in: State based properties."""
        pass

    @property
    def IntervalSetupPercentage(self) -> float:
        """This property exist only in: State based properties."""
        pass

    @property
    def IntervalTotalStateTime(self) -> float:
        """This property exist only in: State based properties."""
        pass

    @property
    def IntervalUtilization(self) -> float:
        """This property exist only in: State based properties."""
        pass

    def flowEnter(self: Any, component: vcComponent) -> None:
        """Manually records a given component transferring into component."""
        pass

    def flowLeave(self: Any, component: vcComponent) -> None:
        """Manually records a given component transferring out of component."""
        pass

    def getIntervalPercentage(self: Any, state: str) -> float:
        """Returns the accumulated time of a given state as a percentage of the last recorded interval during a simulation."""
        pass

    def getPercentage(self: Any, state: str) -> float:
        """Returns the accumulated time of a given state as a percentage of total time at the time of call."""
        pass

    def getSystemIntervalPercentage(self: Any, system_state: int) -> float:
        """Returns the accumulated time of a given system_state as a percentage of the last recorded interval during a simulation."""
        pass

    def getSystemPercentage(self: Any, system_state: int) -> float:
        """Returns the accumulated time of a given system_state as a percentage of total time at the time of call."""
        pass

    def getSystemTime(self: Any, system_state: int) -> float:
        """Returns the accumulated time of a given system_state at the time of call."""
        pass

    def getTime(self: Any, state: str) -> float:
        """Returns the accumulated time of a given state at the time of call."""
        pass

    def warmupCompleted(self: Any) -> None:
        """Marks the completion/end of a component's warm up period, thereby setting all statistics to zero at the time of call.
 For example, a component can be configured to run a delay or a certain number of time consuming tasks at the start of a simulation. When this method is called, warm up time is calculated from simulation start to time of call."""
        pass

    OnFlowChange : Callable[[vcStatistics, float, bool, vcNode], None]
    """Triggered when a component is transferred into or out of a component.
 The statistics argument is the Statistics behavior that recorded the event.
 The time argument is simulation time when flow change occurred.
 The incoming argument is True when component transfers in and False when component transfers out of component."""


    OnStateChange : Callable[[vcStatistics, float, int, vcNode], None]
    """Triggered when the state change occurs in a component.
 The statistics argument is the Statistics behavior that recorded the event.
 The time argument is simulation time when state change occurred.
 The state argument is the new state or system state of component. Refer to States or SystemStates property values as needed."""



class vcStatisticsChart(vcObject):
    """vcStatisticsChart allows you to plot and graph the data of reported items in a chart.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStatisticsChart.htm"""

    @property
    def AllSources(self) -> List[List[Any]]:
        """Gets all sources of reported items, including their components.
 A reported item is a vcProperty object associated with a component. For example, a reported item could be a component property or a property of a component behavior.
 A vcVector object is used to define the display color of reported item in chart.
 Each element in the list is a list that contains these elements: vcProperty property, String expression, vcComponent component, vcVector color, Real thickness"""
        pass

    @property
    def ChartTileType(self) -> int:
        """Defines the location type of chart, thereby indicating whether the tile is an empty or filled with a chart.
 Generally, you would use ChartTileType to parse through several charts in a dashboard to collect data from charts that report items. For example, you could ignore or skip empty tiles."""
        pass

    @ChartTileType.setter
    def ChartTileType(self, value : int) -> None:
        pass

    @property
    def ChartType(self) -> int:
        """Defines the chart type.
 For more information, see Statistics Constants."""
        pass

    @ChartType.setter
    def ChartType(self, value : int) -> None:
        pass

    @property
    def DataRows(self) -> List[List[Any]]:
        """Gets the data collected during a simulation from reported items.
 Each element in the list is a list that contains these elements: Real simulation_time, Real value1, ... Real valueN"""
        pass

    @property
    def DataType(self) -> int:
        """Defines the data type of chart.
 For more information, see Statistics Constants."""
        pass

    @DataType.setter
    def DataType(self, value : int) -> None:
        pass

    @property
    def FieldCountPerProperty(self) -> int:
        """Defines the field count of items reported by chart."""
        pass

    @FieldCountPerProperty.setter
    def FieldCountPerProperty(self, value : int) -> None:
        pass

    @property
    def LegendVisibility(self) -> bool:
        """Turns on/off the display of chart legend."""
        pass

    @LegendVisibility.setter
    def LegendVisibility(self, value : bool) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the title of chart."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Position(self) -> List[Any]:
        """Defines the position chart in tab grid.
 The list contains these elements: String name, Integer column, Integer row, Integer column_span, Integer row_span"""
        pass

    @Position.setter
    def Position(self, value : List[Any]) -> None:
        pass

    @property
    def RecordAccumulatedValues(self) -> bool:
        """Turns on/off the collection of data reported by chart."""
        pass

    @RecordAccumulatedValues.setter
    def RecordAccumulatedValues(self, value : bool) -> None:
        pass

    @property
    def SamplingInterval(self) -> float:
        """Defines how often (in seconds) the chart updates to show recorded data during a simulation.
 If -1, the chart uses the sampling interval of its dashboard."""
        pass

    @SamplingInterval.setter
    def SamplingInterval(self, value : float) -> None:
        pass

    @property
    def Series(self) -> List[vcStatisticsSeries]:
        """Gets a list of data series used by chart to report items."""
        pass

    @property
    def TileType(self) -> int:
        """Same as ChartTileType.
 For more information, see Statistics Constants."""
        pass

    @TileType.setter
    def TileType(self, value : int) -> None:
        pass

    @property
    def TitleVisibility(self) -> bool:
        """Turns on/off the display of chart title."""
        pass

    @TitleVisibility.setter
    def TitleVisibility(self, value : bool) -> None:
        pass

    def addSeries(self: Any) -> vcStatisticsSeries:
        """Adds a new data series to chart."""
        pass

    def clearData(self: Any) -> None:
        """Removes all data reported by chart, thereby emptying DataRows."""
        pass

    def clearSeries(self: Any) -> None:
        """Resets all data series in chart, thereby emptying AllSources."""
        pass

    def deleteSeries(self: Any, data_series: vcStatisticsSeries) -> None:
        """Deletes a given data_series from chart."""
        pass

    def update(self: Any) -> None:
        """Refreshes the chart."""
        pass


class vcStatisticsDashboard(vcObject):
    """vcStatisticsDashboard is a dashboard used for visualizing and reporting statistics collected during a simulation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStatisticsDashboard.htm"""

    @property
    def SelectedTab(self) -> vcStatisticsTab:
        """Defines the active tab in dashboard."""
        pass

    @SelectedTab.setter
    def SelectedTab(self, value : vcStatisticsTab) -> None:
        pass

    @property
    def StatisticsInterval(self) -> float:
        """Defines the global sampling interval for reporting data.
 This will affect data series referencing vcStatistics properties as well as any chart with a sampling interval of -1."""
        pass

    @StatisticsInterval.setter
    def StatisticsInterval(self, value : float) -> None:
        pass

    @property
    def Tabs(self) -> List[vcStatisticsTab]:
        """Gets a list of all tabs in dashboard."""
        pass

    def createTab(self: Any, name: str, activate: bool) -> vcStatisticsTab:
        """Adds a new tab of a given name to the dashboard.
 The activate argument can be used to make the new tab the selected tab in dashboard."""
        pass

    def deleteTab(self: Any) -> None:
        """Removes a given tab from the dashboard."""
        pass


class vcStatisticsManager(vcObject):
    """vcStatisticsManager is used by a vcSimulation object for defining the sampling rate at which interval based statistics are recorded during a simulation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStatisticsManager.htm"""

    @property
    def SamplingInterval(self) -> float:
        """Defines the sampling interval used by simulation for recording interval based statistics.
 The default rate is 60.0 seconds, so an interval is recorded every 60 seconds in simulation."""
        pass

    @SamplingInterval.setter
    def SamplingInterval(self, value : float) -> None:
        pass


class vcStatisticsSeries(vcObject):
    """vcStatisticsSeries is a source of data reported in a chart.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStatisticsSeries.htm"""

    @property
    def Colors(self) -> List[vcVector]:
        """Defines the colors of series, which is displayed in chart.
 For example, data collected from different components should be color-coded to differentiate their data in chart."""
        pass

    @Colors.setter
    def Colors(self, value : List[vcVector]) -> None:
        pass

    @property
    def Components(self) -> List[vcComponent]:
        """Defines the components the series collects data from during a simulation.
 In order to collect data, a listed component must have Property."""
        pass

    @Components.setter
    def Components(self, value : List[vcComponent]) -> None:
        pass

    @property
    def Expression(self) -> str:
        """Defines the expression of series."""
        pass

    @Expression.setter
    def Expression(self, value : str) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of series object."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def ParentChart(self) -> vcStatisticsChart:
        """Gets the chart of series."""
        pass

    @property
    def Property(self) -> vcProperty:
        """Defines the reported item (source) of series."""
        pass

    @Property.setter
    def Property(self, value : vcProperty) -> None:
        pass

    @property
    def SeriesName(self) -> str:
        """Defines the name of series, which is displayed in chart legend."""
        pass

    @SeriesName.setter
    def SeriesName(self, value : str) -> None:
        pass

    @property
    def Sources(self) -> List[List[Any]]:
        """Gets a list of sources for series data.
 This information includes the reported item (vcProperty) and its component.
 Each element in the list is a list that contains these elements: vcProperty property, String expression, vcComponent component, vcVector color, Real thickness"""
        pass

    @property
    def Thickness(self) -> List[float]:
        """Defines the display thickness of series, for example the line thickness of data collected from different components."""
        pass

    @Thickness.setter
    def Thickness(self, value : List[float]) -> None:
        pass


class vcStatisticsTab(vcObject):
    """vcStatisticsTab is a tab listed in a Statistics dashboard and contains one or more charts which are organized in a grid.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStatisticsTab.htm"""

    @property
    def Charts(self) -> List[vcStatisticsChart]:
        """Defines the charts of tab."""
        pass

    @Charts.setter
    def Charts(self, value : List[vcStatisticsChart]) -> None:
        pass

    @property
    def Layouts(self) -> List[List[Any]]:
        """Defines the available layouts for tab grid.
 Each element in the list is a list with following content:
 First element is String layoutName
 Next elements are Lists, each of which contains info about a single tile or placeholder.
 The tile info lists each contain these elements: String placeholder_name, Integer column, Integer row, Integer column_span, Integer row_span"""
        pass

    @Layouts.setter
    def Layouts(self, value : List[List[Any]]) -> None:
        pass

    @property
    def MaxColumns(self) -> int:
        """Defines the maximum number of columns in tab grid."""
        pass

    @property
    def MaxRows(self) -> int:
        """Defines the maximum number of rows in tab grid."""
        pass

    @property
    def Name(self) -> str:
        """Defines the name of tab."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def SelectedChart(self) -> vcStatisticsChart:
        """Defines the active chart of tab."""
        pass

    @SelectedChart.setter
    def SelectedChart(self, value : vcStatisticsChart) -> None:
        pass

    @property
    def SelectedLayout(self) -> int:
        """Defines the current layout of tab grid."""
        pass

    @SelectedLayout.setter
    def SelectedLayout(self, value : int) -> None:
        pass

    @property
    def SelectedLayoutItem(self) -> List[Any]:
        """Defines the attributes of SelectedLayout.
 First element of the list is String layoutName
 Next elements are Lists, each of which contains info about a single tile or placeholder.
 The tile info lists each contain these elements: String placeholder_name, Integer column, Integer row, Integer column_span, Integer row_span"""
        pass

    def clearLayout(self: Any) -> None:
        """Deletes all charts from tab grid."""
        pass

    def createChart(self: Any, location: vcStatisticsChart, chart_type: int, activate: bool) -> vcStatisticsChart:
        """Adds a new chart of a given type to tab grid.
 The location argument specifies where in grid to insert the new chart. In this context, the vcStatisticsChart object is a grid location. It can be a chart with existing data or an empty chart used as a placeholder. In either case, a call will remove the existing chart and exchange it with a new one in the grid.
 The activate argument can be used to make the new chart the active chart in tab.
 For more information on the chart_type argument, see Statistics Constants."""
        pass

    def createLayout(self: Any) -> None:
        """Creates a new layout for tab grid."""
        pass

    @overload
    def deleteChart(self: Any, index: int) -> None:
        """Removes a chart from tab grid, thereby replacing the old chart with a new empty chart used as a placeholder in grid."""
        pass

    @overload
    def deleteChart(self: Any, chart: vcStatisticsChart) -> None:
        """Removes a chart from tab grid, thereby replacing the old chart with a new empty chart used as a placeholder in grid."""
        pass

    @overload
    def selectChart(self: Any, index: int) -> vcStatisticsChart:
        """Selects a chart in tab, thereby making it the active chart in tab."""
        pass

    @overload
    def selectChart(self: Any, chart: vcStatisticsChart) -> vcStatisticsChart:
        """Selects a chart in tab, thereby making it the active chart in tab."""
        pass


class vcStringSignal(vcSignal):
    """vcStringSignal is a signal that can send a string value.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStringSignal.htm"""

    @property
    def Value(self) -> str:
        """Defines the value of signal.
Setting this value does not trigger the OnSignal event unless you use the signal() method."""
        pass

    @Value.setter
    def Value(self, value : str) -> None:
        pass

    def signal(self: Any, value: str = ...) -> None:
        """Signals the current value of signal to all connected behaviors, thereby triggering the OnSignal event.
An optional value argument can be given to set the Value property of the signal."""
        pass


class vcStringSignalMap(vcBehaviour):
    """vcStringSignalMap allows you to map String signals to ports in a continuous IO space.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcStringSignalMap.htm"""

    @property
    def Listeners(self) -> List[vcBehaviour]:
        """Defines a list of behaviors using the signal map."""
        pass

    @Listeners.setter
    def Listeners(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def PortCount(self) -> int:
        """Defines the amount of ports in the signal map."""
        pass

    @PortCount.setter
    def PortCount(self, value : int) -> None:
        pass

    def input(self: Any, index: int) -> str:
        """Returns the value of a port at a given index."""
        pass

    def output(self: Any, index: int, value: str) -> None:
        """Sets the value of a port at a given index to a given value."""
        pass


class vcSweptVolume(vcLayoutItem):
    """vcSweptVolume is a layout item used to measure and simulate volume displacement of moving objects and detect collisions.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSweptVolume.htm"""

    @property
    def Decomposition(self) -> int:
        """Defines the number of convex hulls created for included nodes, for example one conveyor hull encompassing all nodes or several convex hulls based on geometry of each node.
 0
 One convex hull.
 1
 One or more convex hulls using convex decomposition.
 2
 One convex hull for each triangle mesh in input nodes.
 See Decomposition Modes for more information."""
        pass

    @Decomposition.setter
    def Decomposition(self, value : int) -> None:
        pass

    @property
    def DecompositionDecimationTarget(self) -> int:
        """If Decomposition set to 1, sets the number of triangle sets remaining after decimation process of input nodes with fewer triangle sets than decimation target, thereby allowing you to expedite/speed up the process.
 Set to zero to have no effect."""
        pass

    @DecompositionDecimationTarget.setter
    def DecompositionDecimationTarget(self, value : int) -> None:
        pass

    @property
    def DecompositionQuality(self) -> float:
        """If Decomposition set to 1, sets the quality of decomposition in range 0 to 100, thereby affecting the approximation of convex hulls to the shape of input node geometry.
 A higher value produces better approximation and convex-shaped triangle sets at the cost of increasing a component's data count and simulation performance."""
        pass

    @DecompositionQuality.setter
    def DecompositionQuality(self, value : float) -> None:
        pass

    @property
    def InputNodeList(self) -> List[Tuple[int, int]]:
        """Defines which nodes will be swept during a simulation.
 The value type is similar to Nodes property of a vcNodeList object in which a given node and its scope is either included or excluded from swept volume."""
        pass

    @InputNodeList.setter
    def InputNodeList(self, value : List[Tuple[int, int]]) -> None:
        pass

    @property
    def Method(self) -> int:
        """Sets the method used for generating convex hulls as swept geometry, for example hollow or filled convex hulls.
 0
 Uses lofting. Good for movements requiring small changes, for example small rotational and directional changes in linear motions and bending of curves.
 1
 Uses hull from hulls generation. Creates internal faces and more points, thereby a higher data count but supports all types of movement.
 2
 Uses hull from silhouettes generation. Balance of methods 0 and 1 to support small and complex movements.
 Note: Each method type has about the same performance level.
 See Swept Generation for more information."""
        pass

    @Method.setter
    def Method(self, value : int) -> None:
        pass

    @property
    def TargetNode(self) -> vcNode:
        """Sets the node used for containing swept geometry, which should be static and not move during simulation."""
        pass

    @TargetNode.setter
    def TargetNode(self, value : vcNode) -> None:
        pass

    def begin(self: Any, vector: vcVector = ...) -> None:
        """Starts swept volume process, thereby initiating decomposition.
 An optional vector argument can be given to define a frame of reference or center point in input node. If not, process uses center point of input node bound box."""
        pass

    def clear(self: Any) -> None:
        """Removes all swept geometry of layout item from 3D world."""
        pass

    def end(self: Any) -> None:
        """Stops swept volume process.
 After swept volume process has ended, you can perform capping of swept geometry."""
        pass

    def next(self: Any, vector: vcVector = ...) -> None:
        """Executes an iterative process that renders swept geometry based on positions of input nodes. That is, you should call this method each time you want to render swept volume in 3D world during swept process.
 An optional vector argument can be given to define a frame of reference or center point in input node as it moves during a simulation. If not, process uses center point of input node bound box. Generally, this is used to offset swept geometry."""
        pass

    def store(self: Any) -> vcFeature:
        """Stores swept geometry in TargetNode, thereby allowing you to save swept geometry in component and/or layout.
 Returns the Geometry feature where swept volume is stored in TargetNode. The naming convention for feature is VC_SweptVolumeResult, and the feature is an immediate child of TargetNode root feature.
 If no swept geometry is generated during simulation, returns None.
 Generally, you should call store() method after calling end() method and before clear() method."""
        pass


class vcSwitchCaseStatement(vcStatement):
    """A vcSwitchCaseStatement executes the first vcCaseScope for which the value of its CaseCondition property matches that of statement’s Condition property.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcSwitchCaseStatement.htm"""

    @property
    def Condition(self) -> str:
        """Expression that defines the value against which the case conditions are evaluated.
 See also Process Statement Expressions and Robot Statements."""
        pass

    @Condition.setter
    def Condition(self, value : str) -> None:
        pass

    @property
    def Cases(self) -> List[vcCaseScope]:
        """All case scopes in this statement. Each scope has an RW property CaseCondition of type String which will be evaluated against statement’s Condition."""
        pass

    @Cases.setter
    def Cases(self, value : List[vcCaseScope]) -> None:
        pass

    @overload
    def addCase(self: Any) -> Union[vcCaseScope, None]:
        """Creates a new case and appends it to the end.
 or
 Creates a new case and inserts it to the given index. If index is less than zero or greater than the current case count, the case will be appended to the end.
 or
 Inserts an existing case to the given index. If index is less than zero or greater than the current case count, the case will be appended to the end."""
        pass

    @overload
    def addCase(self: Any, index: int) -> Union[vcCaseScope, None]:
        """Creates a new case and appends it to the end.
 or
 Creates a new case and inserts it to the given index. If index is less than zero or greater than the current case count, the case will be appended to the end.
 or
 Inserts an existing case to the given index. If index is less than zero or greater than the current case count, the case will be appended to the end."""
        pass

    @overload
    def addCase(self: Any, index: int, scope: vcCaseScope) -> Union[vcCaseScope, None]:
        """Creates a new case and appends it to the end.
 or
 Creates a new case and inserts it to the given index. If index is less than zero or greater than the current case count, the case will be appended to the end.
 or
 Inserts an existing case to the given index. If index is less than zero or greater than the current case count, the case will be appended to the end."""
        pass

    def moveCase(self: Any, scope: vcCaseScope, newIndex: int) -> None:
        """Moves an existing case to the new position. If the given index is less than zero or greater than the current case count, the case will be moved to the end."""
        pass

    def deleteCase(self: Any, scope: vcCaseScope) -> None:
        """Removes an existing case and deletes it."""
        pass

    def releaseCase(self: Any, scope: vcCaseScope) -> None:
        """Removes an existing case."""
        pass

    def getCase(self: Any, index: int) -> vcCaseScope:
        """Gets an existing case."""
        pass

    OnCaseAdded : Callable[[vcCaseScope, int], None]
    """Event that occurs when a case has been added. Provides an index where case was inserted."""


    OnCaseMoved : Callable[[vcCaseScope, int, int], None]
    """Event that occurs when a case has been moved to a new index. Provides both old and new indices."""


    OnCaseRemoved : Callable[[vcCaseScope, int], None]
    """Event that occurs when a case has been removed. Provides an index case was removed from."""



class vcTeachContext(vcContext):
    """vcTeachContext is the context of the application for robot programming.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTeachContext.htm"""

    @property
    def ActiveRobot(self) -> vcComponent:
        """Defines the active robot in context."""
        pass

    @ActiveRobot.setter
    def ActiveRobot(self, value : vcComponent) -> None:
        pass

    @property
    def ActiveRoutine(self) -> vcRoutine:
        """Gets the active routine in the ActiveRobot program."""
        pass

    @property
    def ActiveScope(self) -> vcScope:
        """Gets the active routine or scope of statement in ActiveRobot program."""
        pass

    @property
    def ActiveStatement(self) -> Any:
        """Gets the active statement in ActiveRobot program."""
        pass

    @property
    def ActiveStatementIndex(self) -> int:
        """Gets the index of active statement in ActiveRobot program."""
        pass

    def setActiveStatement(self: Any, scope: vcScope, index: int) -> None:
        """Sets the statement at the given index in the given scope to be ActiveStatement."""
        pass

    ActiveRobotChanged : Callable[[], None]
    """Triggered when a different robot becomes the active robot in context."""



class vcText2DSet(vcGeometrySet):
    """vcText2DSet is a geometry set used for generating 2D text. Unlike 3D text, 2D text is rendered directly on screen by converting a position vector to screen coordinates. Furthermore, 2D text supports an inherited Billboard property, thereby text can always face camera and be right-side up in 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcText2DSet.htm"""

    @property
    def DepthBuffered(self) -> bool:
        """Turns on/off the obstruction of text by other objects that are in front of it on screen.
 If False, text is always set to front of foreground."""
        pass

    @DepthBuffered.setter
    def DepthBuffered(self, value : bool) -> None:
        pass

    @property
    def OffsetX(self) -> int:
        """Defines an offset (in pixels) for horizontal axis when text is projected on screen."""
        pass

    @OffsetX.setter
    def OffsetX(self, value : int) -> None:
        pass

    @property
    def OffsetY(self) -> int:
        """Defines an offset (in pixels) for vertical axis when text is projected on screen."""
        pass

    @OffsetY.setter
    def OffsetY(self, value : int) -> None:
        pass

    @property
    def Position(self) -> vcVector:
        """Defines the position vector of text in 3D world.
 Text is rendered in which left end of its baseline coincides with Position on screen. If OffsetX or OffsetY are non-zero values, position is shifted by those values."""
        pass

    @Position.setter
    def Position(self, value : vcVector) -> None:
        pass

    @property
    def Text(self) -> str:
        """Defines a string of characters to render as one line of text."""
        pass

    @Text.setter
    def Text(self, value : str) -> None:
        pass

    def getTextHeight(self: Any) -> int:
        """Returns the calculated height of text in pixels."""
        pass

    def getTextWidth(self: Any) -> int:
        """Returns the calculated width of text in pixels."""
        pass

    def update(self: Any) -> None:
        """Updates the geometry of text in 3D world."""
        pass


class vcText3DSet(vcGeometrySet):
    """vcText3DSet is a geometry set used for generating 3D text. Unlike 2D text, 3D text is generated using geometry and has both a position and orientation in 3D world.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcText3DSet.htm"""

    @property
    def Matrix(self) -> vcMatrix:
        """Defines the position matrix of text."""
        pass

    @Matrix.setter
    def Matrix(self, value : vcMatrix) -> None:
        pass

    @property
    def OffsetX(self) -> int:
        """Defines an offset (in pixels) for horizontal axis when text is projected on screen."""
        pass

    @OffsetX.setter
    def OffsetX(self, value : int) -> None:
        pass

    @property
    def OffsetY(self) -> int:
        """Defines an offset (in pixels) for vertical axis when text is projected on screen."""
        pass

    @OffsetY.setter
    def OffsetY(self, value : int) -> None:
        pass

    @property
    def Text(self) -> str:
        """Defines a string of characters to render as a one line of 3D text."""
        pass

    @Text.setter
    def Text(self, value : str) -> None:
        pass

    def getTextHeight(self: Any) -> int:
        """Returns the calculated height of text in pixels."""
        pass

    def getTextWidth(self: Any) -> int:
        """Returns the calculated width of text in pixels."""
        pass

    def update(self: Any) -> None:
        """Updates the geometry of text in 3D world."""
        pass


class vcToolContainer(vcBehaviour):
    """vcToolContainer is a container of vcBaseFrame objects which are used as tool frames/tool center points.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcToolContainer.htm"""

    @property
    def Tools(self) -> List[vcBaseFrame]:
        """Gets a list of all tool frames referenced by container."""
        pass

    def addTool(self: Any) -> vcBaseFrame:
        """Adds a new tool frame to container, and then returns the new tool frame."""
        pass

    def removeTool(self: Any, tool: vcBaseFrame) -> None:
        """Removes a given tool frame from container."""
        pass


class vcTopology(vcObject):
    """vcTopology represents the topology data of tessellated geometry and can be used to generate simple and complex geometry, for example NURBS, meshes and splines.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTopology.htm"""

    @property
    def CurveCount(self) -> int:
        """Gets the total number of curves in set."""
        pass

    @property
    def CurveLoopCount(self) -> int:
        """Gets the total number of curve loops in set."""
        pass

    @property
    def FaceCount(self) -> int:
        """Gets the total number of faces in set."""
        pass

    @property
    def PointCount(self) -> int:
        """Gets the total number of points considered boundary-corners in mesh, for example curve ends. If set is not a mesh, gives zero.
 Note: To get the total number of points in set, use PointCount in vcTriangleSet."""
        pass

    def brepAvailable(self: Any) -> bool:
        """Returns True if set contains boundary representation; otherwise returns False."""
        pass

    def createCurveLoop(self: Any, face: int) -> int:
        """Adds a new curve loop to a face at a given index in set, and then returns the index of new curve loop in set."""
        pass

    def createNurbsFace(self: Any, udegree: int, vdegree: int, ctrl_pts: List[vcVector], umultiply: List[int], vmultiply: List[int], uknots: List[float], vknots: List[float], ctrl_weights: List[float]) -> int:
        """Adds a new non-uniform b-spline surface (NURBS) to set, and then returns the index of new surface in set."""
        pass

    def createPlanarFace(self: Any, pos: vcVector, normal: vcVector) -> int:
        """Adds a new planar (unlimited) face using given position and surface normal vectors, and then returns the index of new face in set."""
        pass

    def createOffsetSurface(self: Any, face: int, offset: float, target: vcTriangleSet) -> int:
        """Creates a copy of face at a given index in set, and then returns the index of new face in a given geometry set.
 New face is offset from original face. If offset argument is positive value, new face is offset in surface normal direction; otherwise offset is the opposite direction of surface normal."""
        pass

    def createTrimPolyLine(self: Any, loop: int) -> int:
        """Creates a new polyline using a curve loop at a given index in set, which can then be used for trimming and extending operations, and polyline is surface domain (XY coordinates only).
 The returned value is the index of trim polyline in set."""
        pass

    def createTrimSpline(self: Any, loop: int, degree: int, ctrl_pts: List[vcVector], knotmultiply: List[int], knots: List[float], weights: List[float]) -> int:
        """Create a new spline in set used for trimming and extending operations, and spline is surface domain (XY coordinates only)."""
        pass

    def deleteNurbFace(self: Any, face: int) -> None:
        """Deletes a NURBS face at a given index in set.
 If NURBS surface contains more than one face, geometry is tessellated after deletion."""
        pass

    def getCurveCurveLoop(self: Any, curveindex: int) -> int:
        """Returns the index of curve loop that a curve belongs to in set."""
        pass

    def getCurveFace(self: Any, curveindex: int) -> int:
        """Returns the index of face that a curve belongs to in set."""
        pass

    def getCurveIntersections(self: Any, face: int, curveset: vcCompactLineSet, curve: int) -> List[Tuple[vcVector, float, float, float]]:
        """Returns a list of curve intersection points based on given arguments."""
        pass

    def getCurveLength(self: Any, curve_index: int) -> float:
        """Returns the length of a curve at a given index in set. That is, the total distance along the curve."""
        pass

    def getCurveLoopCurve(self: Any, curveloopindex: int, relcurveindex: int) -> int:
        """Returns the absolute index of an inner curve loop relative to its curve loop in set."""
        pass

    def getCurveLoopCurveCount(self: Any, curveloopindex: int) -> int:
        """Returns the total number of inner curve loops for a curve loop of face in set."""
        pass

    def getCurveNeighbor(self: Any, curve_index: int) -> int:
        """Returns the index of a curve neighboring another curve in set."""
        pass

    def getCurvePointCount(self: Any, curveindex: int) -> int:
        """Returns the total number of points for a curve at a given index in set."""
        pass

    def getCurvePointIndex(self: Any, curveindex: int, relpointindex: int) -> int:
        """Returns the absolute index of point relative to its curve in set."""
        pass

    def getCurvePosition(self: Any, curve_index: int, position: float) -> vcMatrix:
        """Returns the position matrix of a point on a curve at a given distance along curve.
 Details about the position matrix:
 Position vector
 Actual position of point on curve.
 Normal vector
 Direction of curve at the given point (derivative of curve position).
 Orientation vector
 Aligned to face inwards of curve's face.
 Approach vector
 Surface normal of face at curve position.
 See table footnotes for more information."""
        pass

    def getCurvePositions(self: Any, curve_index: int, minstep: float = ..., maxstep: float = ..., maxerror: float = ..., maxangle: float = ...) -> List[vcMatrix]:
        """Returns a list of position matrices for points along a curve using different criteria.
 The minstep and maxstep arguments define the step values along distance of curve for generating new points.
 The maxerror argument defines a maximum distance error along length of curve for generating a new point.
 The maxangle argument defines a angle tolerance along curve for generating new points.
 See table footnotes for more information."""
        pass

    def getCurveType(self: Any, curve: int) -> int:
        """Returns a trim curve's type, which is either a polyline or spline.
 See Topology Constants for more information."""
        pass

    def getFaceBound(self: Any, face_index: int) -> Tuple[vcMatrix, vcVector]:
        """Returns bound box data for a face as an ordered pair (position matrix of bound box center, vector of bound box half-diagonal).
 See table footnotes for more information."""
        pass

    def getFaceCurveLoop(self: Any, faceindex: int, relcurveloopindex: int) -> int:
        """Returns the absolute index of a curve loop relative to its face in set."""
        pass

    def getFaceCurveLoopCount(self: Any, faceindex: int) -> int:
        """Returns the total number of curve loops in a face."""
        pass

    def getFaceMinPointDistance(self: Any, face: int, point: vcVector) -> Tuple[vcVector, vcVector, float]:
        """Returns UV coordinates, position vector and distance of a given point to a face."""
        pass

    def getFaceNormal(self: Any, face: int, uv: vcVector) -> vcVector:
        """Returns surface normal of a face at parametric UV coordinates."""
        pass

    def getFacePlaneIntersections(self: Any, face_index: int, plane: vcMatrix, minstep: float, maxstep: float, maxerror: float, maxangle: float) -> List[List[vcMatrix]]:
        """Returns a list containing lists of position matrices for points where a defined plane intersects a face.
 Each time a plane goes through hole in face a new list is added, thereby allowing you to infer hole points on face-plane intersection.
 Details about the position matrix:
 Position vector
 Actual position of point intersection.
 Normal vector
 Direction along plane intersecting face.
 Orientation vector
 Projected from normal of plane to surface of face using face derivate for projected direction.
 Approach vector
 Surface normal of face.
 See table footnotes for more information."""
        pass

    def getFacePoint(self: Any, face: int, uv: vcVector) -> vcVector:
        """Returns the position vector of a point on a face at given UV coordinates."""
        pass

    def getFacePointAndDerivate(self: Any, face: int, uv: vcVector) -> Tuple[vcVector, vcVector, vcVector]:
        """Returns the position vector and UV direction first derivates of a face at given UV coordinates."""
        pass

    def getFaceStartTriangle(self: Any, face_index: int) -> int:
        """Returns the absolute index of first triangle of a face in set."""
        pass

    def getFaceTriangleCount(self: Any, face_index: int) -> int:
        """Returns the total number of triangles of a face."""
        pass

    def getFaceType(self: Any, face: int) -> int:
        """Returns the type of a face, which is either a tessellated, planar or NURBS.
 See Topology Constants for more information."""
        pass

    def getNurbsFaceControlPoints(self: Any, face: int) -> List[vcVector]:
        """Returns a list of control points for a NURBS face."""
        pass

    def getNurbsFaceControlWeights(self: Any, face: int) -> List[float]:
        """Returns a list of control weights for a NURBS face."""
        pass

    def getNurbsFaceDegree(self: Any, face: int) -> Tuple[int, int]:
        """Returns UV degree values for a NURBS face."""
        pass

    def getNurbsFaceUKnots(self: Any, face: int) -> Tuple[List[float], List[int]]:
        """Returns U direction knot weight values and knot multiplicities."""
        pass

    def getNurbsFaceVKnots(self: Any, face: int) -> Tuple[List[float], List[int]]:
        """Returns V direction knot weight values and knot multiplicities."""
        pass

    def getPlanarFacePositionAndNormal(self: Any, face: int) -> Tuple[vcVector, vcVector]:
        """Returns a planar face position and normal vectors."""
        pass

    def getPolyLineCurvePoints(self: Any, curve: int) -> List[vcVector]:
        """Returns a list of position vectors for all points in a polyline."""
        pass

    def getPoint(self: Any, pointindex: int) -> vcVector:
        """Returns the position vector of a curve end (corner point) at a given index relative to either its curve or face."""
        pass

    def getSplineCurveDegree(self: Any, curve: int) -> int:
        """Returns the degree of a spline."""
        pass

    def getSplineCurveControlPoints(self: Any, curve: int) -> List[vcVector]:
        """Returns a list of control points for a face trimming spline."""
        pass

    def getSplineCurveControlWeights(self: Any, curve: int) -> List[float]:
        """Returns a list of control weight values for a face trimming spline."""
        pass

    def getSplineCurveKnots(self: Any, curve: int) -> Tuple[List[float], List[int]]:
        """Returns a list of knot weights and multiplicities for a face trimming spline as an ordered pair."""
        pass

    def getSurfaceIntersections(self: Any, face: int, other_set: vcTriangleSet, other_face: int, approxtol: float, angletol: float, target: vcCompactLineSet) -> Tuple[int, int]:
        """Returns the amount of intersecting curves between two faces in the same vcGeometryContainer object."""
        pass

    def isCurveCircular(self: Any, curve_index: int) -> bool:
        """Returns True if a curve at a given index in set is circular where start and end points are same; otherwise returns False."""
        pass

    def isFaceLinear(self: Any, face: int) -> Tuple[bool, bool]:
        """Returns True if a face at a given index in set is linear in parametric UV directions; otherwise returns False."""
        pass

    def projectCurve(self: Any, face: int, curve: vcCompactLineSet, approxtol: float, maxdist: float, deviation: float, targetlineset: vcCompactLineSet) -> Tuple[int, int]:
        """Projects a given curve along the shape of a given face based on direction vector of curve."""
        pass

    def trimFace(self: Any, face: int) -> int:
        """Trims a face at a given index in set using trimming polylines and/or splines.
 Returns 1/True if trimming is successful; otherwise returns 0/False."""
        pass


class vcTopologyPickCommand(vcCommand):
    """vcTopologyPickCommand provides options for handling the selection and creation of points, lines and curves using the interactiveTopologyPick command.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTopologyPickCommand.htm"""

    @property
    def ContinuousMode(self) -> bool:
        """Turns on/off the use of continuous curve selection in 3D world."""
        pass

    @ContinuousMode.setter
    def ContinuousMode(self, value : bool) -> None:
        pass

    @property
    def SnapOnCurve(self) -> bool:
        """Turns on/off the ability to select a curve."""
        pass

    @SnapOnCurve.setter
    def SnapOnCurve(self, value : bool) -> None:
        pass

    @property
    def SnapOnCurveLoop(self) -> bool:
        """Turns on/off the ability to select a curve loop."""
        pass

    @SnapOnCurveLoop.setter
    def SnapOnCurveLoop(self, value : bool) -> None:
        pass

    @property
    def SnapOnSurface(self) -> bool:
        """Turns on/off the ability to select a point on a face."""
        pass

    @SnapOnSurface.setter
    def SnapOnSurface(self, value : bool) -> None:
        pass

    @property
    def TargetAvailable(self) -> bool:
        """Indicates if pointing at a valid target."""
        pass

    @property
    def TargetCurveAvailable(self) -> bool:
        """Indicates if pointing at an available curve."""
        pass

    @property
    def TargetCurveIndex(self) -> int:
        """Gets the index of an available curve."""
        pass

    @property
    def TargetCurveLoopAvailable(self) -> bool:
        """Indicates if pointing at an available curve loop."""
        pass

    @property
    def TargetCurveLoopIndex(self) -> int:
        """Gets the index of an available curve loop."""
        pass

    @property
    def TargetCurves(self) -> List[Tuple[vcNode, vcGeometrySet, int, bool]]:
        """Gets a list of curve data for target."""
        pass

    @property
    def TargetGeoset(self) -> vcGeometrySet:
        """Gets geometry set of a target."""
        pass

    @property
    def TargetLocked(self) -> bool:
        """Indicates if target has been selected in 3D world."""
        pass

    @property
    def TargetNode(self) -> vcNode:
        """Gets the node containing target."""
        pass

    @property
    def TargetNormal(self) -> vcVector:
        """If available, gets surface normal of target."""
        pass

    @property
    def TargetNormalAvailable(self) -> bool:
        """Indicates if surface normal is available for target."""
        pass

    @property
    def TargetPosition(self) -> vcVector:
        """Gets the position vector of target in World coordinate system."""
        pass

    @property
    def TargetSurfaceAvailable(self) -> bool:
        """Indicates if pointing at an available point on surface."""
        pass

    @property
    def TargetSurfaceIndex(self) -> int:
        """Gets the index of an available surface."""
        pass

    OnTargetAvailable : Callable[[vcTopologyPickCommand], None]
    """Triggered when pointing at an available target.
 The command itself is passed as an event argument, thereby providing access to updated property values."""


    OnTargetSet : Callable[[vcTopologyPickCommand], None]
    """Triggered when a valid target has been selected in 3D world.
 The command itself is passed as an event argument, thereby providing access to updated property values."""



class vcTransport(vcContainer):
    """vcTransport is a protocol for handling transport actions, which usually involves the use of Action Container and Python Script behaviors.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTransport.htm"""

    def setTargetInfo(self: Any, availability: int, node: vcNode, container: vcContainer, location: vcMatrix) -> None:
        """Sets target information for a transportation action.
 The availability argument is used to notify resource of target/pick up container status. See Transportation Constants for more information.
 The node or container argument should be used to specify a buffer area.
 The location argument is used to specify the location of a delivered component in either node or container."""
        pass

    OnTransportInfo : Callable[[vcComponent], None]
    """Triggered when protocol requests transport details about a component."""



class vcTransportController(vcBehaviour):
    """vcTransportController is a base class for transport controllers, which implement transport of product instances over transport links. The system conveyor transport controller uses the generic vcTransportController.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTransportController.htm"""

    @property
    def IsSystem(self) -> bool:
        """True if this controller is part of the application."""
        pass


class vcTransportLink(vcObject):
    """Transport link is a single-directional logical connection between two transport nodes that defines navigability and transportation parameters for a specific flow group of products. Each link has to be associated with a vcTransportController that implements the link and can add its own custom properties to it.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTransportLink.htm"""

    @property
    def Source(self) -> vcTransportNode:
        """The transport node to start moving from."""
        pass

    @property
    def Destination(self) -> vcTransportNode:
        """The destination transport node."""
        pass

    @property
    def Implementer(self) -> vcTransportController:
        """The controller that will take care of moving the product through this link.
 Note that when reassigning the implementer, the transport controllers usually modify the link’s properties immediately in event handlers."""
        pass

    @Implementer.setter
    def Implementer(self, value : vcTransportController) -> None:
        pass

    @property
    def SupportedGroup(self) -> vcProcessFlowGroup:
        """Only product types belonging to this flow group can travel through this link."""
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets the properties that have vcProperty implementation."""
        pass

    def createProperty(self: Any, property: vcProperty) -> vcProperty:
        """Creates a new dynamic property to this transport link."""
        pass

    def getProperty(self: Any, propertyName: str) -> vcProperty:
        """Returns a property from this transport link."""
        pass

    def deleteProperty(self: Any, property: vcProperty) -> None:
        """Deletes a property from this transport link."""
        pass


class vcTransportNode(vcBehaviour):
    """Defines a logical place where product instances can be transported to and from. Each transport node has to be assigned a component container, but can also be connected to a vcMotionPath as a sensor. When connected as a sensor, the node will grab arriving products from the path to its component container and can similarly place leaving components to the connected path.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTransportNode.htm"""

    @property
    def TransportSystem(self) -> vcTransportSystem:
        """The associated transport system."""
        pass

    @property
    def TransportLinks(self) -> List[vcTransportLink]:
        """The transportLinks coming into, and going out from, this node."""
        pass

    @property
    def ProcessExecutor(self) -> vcProcessExecutor:
        """The associated process executor.
 This property is read only; it’s value can be changed by setting the TransportNode property on a ProcessExecutor.
 (Deprecated) Should not assume 1 to 1 mapping between process executors and transport nodes and thus this property may get removed."""
        pass

    @property
    def ComponentContainer(self) -> vcContainer:
        """The component container this node monitors for arriving products.
 Using other than vcComponentContainer may cause issues."""
        pass

    @ComponentContainer.setter
    def ComponentContainer(self, value : vcContainer) -> None:
        pass

    @property
    def VisualPositionFrame(self) -> vcFrameFeature:
        """Defines visualization position of the node. The frame feature must be in the same component as this transport node behavior."""
        pass

    @VisualPositionFrame.setter
    def VisualPositionFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def VisualPosition(self) -> vcMatrix:
        """Visualization position of this node in world coordinates."""
        pass

    @property
    def DefaultProductPositionFrame(self) -> vcFrameFeature:
        """The default position for products."""
        pass

    @DefaultProductPositionFrame.setter
    def DefaultProductPositionFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def DefaultResourcePositionFrame(self) -> vcFrameFeature:
        """The default position for resources."""
        pass

    @DefaultResourcePositionFrame.setter
    def DefaultResourcePositionFrame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def Frame(self) -> vcFrameFeature:
        """Only used when connected to a path as sensor.
 Defines the Frame feature referenced as the sensor's physical location."""
        pass

    @Frame.setter
    def Frame(self, value : vcFrameFeature) -> None:
        pass

    @property
    def ResetAt(self) -> int:
        """Only used when connected to a path as sensor.
 Defines the mode for resetting the sensor.
 See Path Constants for more information."""
        pass

    @ResetAt.setter
    def ResetAt(self, value : int) -> None:
        pass

    @property
    def TriggerAt(self) -> int:
        """Only used when connected to a path as sensor.
 Defines the mode for triggering the sensor.
 See Path Constants for more information."""
        pass

    @TriggerAt.setter
    def TriggerAt(self, value : int) -> None:
        pass

    def createTransportTarget(self: Any, product: vcProduct) -> vcTransportTarget:
        """Creates a new transport target object for this node and assigns it for the given product instance.
 The target is created with the default values of this transport node.
 Replaces any existing transport target assigned to the given product in this node.
 Note that the node automatically deletes any transport targets when they are no longer needed."""
        pass

    def getTransportTarget(self: Any, product: vcProduct) -> vcTransportTarget:
        """Gets transport target in this node assigned for a given product instance.
 Returns None if a target is not defined.
 Note that the node automatically deletes any transport targets when they are no longer needed."""
        pass

    def deleteTransportTarget(self: Any, product: vcProduct) -> None:
        """Deletes a transport target assigned for a given product instance.
 Note that the default transport target is used if a product instance doesn’t have a specific target defined."""
        pass

    def beginTransportOut(self: Any, product: vcProduct) -> None:
        """Begin the process of transporting the given product through its transport solution.
 Note that transport is asynchronous i.e. the product won’t leave immediately."""
        pass

    OnProductArriving : Callable[[vcProduct, vcTransportLink, vcEventReturnData], None]
    """This event is raised when a product instance arrives to this node.
 Link is the link that the product arrived to this node from.
 The listener should check that eventData.Handled is False before performing any operations on this product, and should set eventData.Handled to True (it was False originally) if the listener accepted this product and handled it.
 If no Python listeners set Handled to True, the product will be handled by internal logic, which includes allowing process statements to receive it."""


    OnProductLeaving : Callable[[vcProduct, vcTransportLink], None]
    """This event is raised when the product leaves in this transport node.
 Link is the link that the product left towards and can be None if the product doesn’t have a transport solution or the solution doesn’t have a transport link going out from this transport node."""


    OnTransportTargetRequested : Callable[[vcProduct, vcTransportTarget], None]
    """This event is raised when a transport target is requested for the product. In practice, this happens each time that a transport controller or resource is transporting a product instance and needs a target for the product instance. See an example below."""



class vcTransportSolution(vcObject):
    """Transport solution is a single route from one transport node (vcTransportNode) to another transport node without any branches or loops. The transport solutions are enforced to be valid when they are created or modified. The solution consists of an ordered list of transport link references (vcTransportLink), starting from the Source node and ending to the Destination node.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTransportSolution.htm"""

    @property
    def Source(self) -> vcTransportNode:
        """The transport node this route starts from.
 Returns None if the solution is empty."""
        pass

    @property
    def Destination(self) -> vcTransportNode:
        """The transport node this route ends to.
 Returns None if the solution is empty."""
        pass

    @property
    def Links(self) -> List[vcTransportLink]:
        """The list of transport links that need to be travelled to get from the Source node to the Destination node, starting from Source."""
        pass

    def getNextLink(self: Any, node: vcTransportNode) -> vcTransportLink:
        """Returns the transport link (there can be only one) that has the given transport node as its Source.
 Returns None if such link doesn’t exist in the solution i.e. the route doesn’t start from or pass through that transport node."""
        pass

    def replaceLinks(self: Any, links: List[vcTransportLink]) -> None:
        """Replaces the route with given links. If the given links do not form a valid transport solution, an error is raised and the previous route is preserved."""
        pass

    OnSolutionInvalidated : Callable[[vcTransportSolution], None]
    """Triggered when any of the transport links in this solution has been deleted from the transport system, which would make the solution either invalid or change its ends.
 Note: All transport links are removed from the solution before this event is triggered. The solution parameter is always this transport solution instance."""



class vcTransportSystem(vcObject):
    """Transport system is a management and query service for vcTransportNode and vcTransportLink objects that form a transportation graph. It is owned by a vcProcessController.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTransportSystem.htm"""

    @property
    def ProcessController(self) -> vcProcessController:
        """Parent controller that owns this system."""
        pass

    @property
    def Nodes(self) -> List[vcTransportNode]:
        """Gets all transport nodes associated with this system."""
        pass

    @property
    def Links(self) -> List[vcTransportLink]:
        """Gets all transport links owned by this system."""
        pass

    @property
    def Controllers(self) -> List[vcTransportController]:
        """Gets all available transport controllers. Includes both system and user-implemented controllers."""
        pass

    def createTransportLink(self: Any, source: vcTransportNode, destination: vcTransportNode, implementer: vcTransportController, group: vcProcessFlowGroup) -> vcTransportLink:
        """Creates a new transport link from source to destination node and registers it to the system. Source and destination have to be in this transport system and cannot be the same."""
        pass

    def deleteTransportLink(self: Any, link: vcTransportLink) -> None:
        """Removes the given link from this system and deletes it."""
        pass

    def createTransportSolution(self: Any) -> vcTransportSolution:
        """Creates an empty transport solution."""
        pass

    def findSolution(self: Any, source: vcTransportNode, destination: vcTransportNode, flowGroup: vcProcessFlowGroup) -> vcTransportSolution:
        """Tries to find a valid route from source to destination, only considers links that support the given flow group. The route isn’t optimized.
 Returns None if a valid route doesn’t exist."""
        pass

    def findAllLinksBetweenNodeSets(self: Any, sourceNodes: List[vcTransportNode], destinationNodes: List[vcTransportNode], group: vcProcessFlowGroup) -> List[vcTransportLink]:
        """Finds a set containing all links that are part of any valid path from any node in sourceNodes set to any node in the destinationNodes set. This can be used to e.g. check navigability between all implementations of two processes.
 The source and destination node sets can overlap.
 Only considers transport links that support the given flow group."""
        pass

    OnTransportControllerAdded : Callable[[vcTransportController], None]
    """Event that occurs when a new transport controller has become available."""


    OnTransportControllerRemoving : Callable[[vcTransportController], None]
    """Event that occurs when a transport controller is being removed."""


    OnTransportNodeAdded : Callable[[vcTransportNode], None]
    """Event that occurs when a new transport node has been added to this system."""


    OnTransportNodeRemoving : Callable[[vcTransportNode], None]
    """Event that occurs when the transport node is being removed from this system."""


    OnTransportLinkAdded : Callable[[vcTransportLink], None]
    """Event that occurs when a new transport link has been created to this system."""


    OnTransportLinkRemoving : Callable[[vcTransportLink], None]
    """Event that occurs when a transport link is being deleted."""


    OnTransportLinkRemoved : Callable[[vcProcessFlowGroup, vcTransportNode, vcTransportNode], None]
    """Event that occurs when a transport link has been deleted."""



class vcTransportTarget(vcObject):
    """A transport target defines where a product instance is to be physically placed when it arrives to a transport node (vcTransportNode). This information is used by the transport controllers.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTransportTarget.htm"""

    @property
    def ProductPosition(self) -> vcMatrix:
        """Target position where a product should be placed. This matrix is expressed in world coordinates and denotes the target position and orientation of the product. Note that this is not the same as the position and orientation of the product: the difference is the offset defined in the corresponding vcProductType."""
        pass

    @ProductPosition.setter
    def ProductPosition(self, value : vcMatrix) -> None:
        pass

    @property
    def ResourcePosition(self) -> vcMatrix:
        """Hint for the desired location of a resource while it is placing a product instance to the ProductPosition. Expressed in world coordinates."""
        pass

    @ResourcePosition.setter
    def ResourcePosition(self, value : vcMatrix) -> None:
        pass

    @property
    def ProductPositionNode(self) -> vcNode:
        """By default, the node that contains ResourcePositionFrame, which is set in the transporting statement (TransportIn, TransportOut, or TransportPatternIn). If frames have not been selected, the statements use the transport node. In TransportOut, ProductPositionNode is set no None. 
 Reference node to ProductPositionInNode. Note that a reference to the vcProduct itself can be used to get the current position of the product instance at any time."""
        pass

    @ProductPositionNode.setter
    def ProductPositionNode(self, value : vcNode) -> None:
        pass

    @property
    def ResourcePositionNode(self) -> vcNode:
        """By default, the node that contains ResourcePositionFrame, which is set in the transporting statement (TransportIn and TransportPatternIn). If frames have not been set, the statements use the transport node. Reference node to ResourcePositionInNode."""
        pass

    @ResourcePositionNode.setter
    def ResourcePositionNode(self, value : vcNode) -> None:
        pass

    @property
    def ProductPositionInNode(self) -> vcMatrix:
        """Position in relation to ProductPositionNode, if the value of ProductPositionNode is not None. The property can be used to transport the product from or into moving processes or nodes."""
        pass

    @ProductPositionInNode.setter
    def ProductPositionInNode(self, value : vcMatrix) -> None:
        pass

    @property
    def ResourcePositionInNode(self) -> vcMatrix:
        """Position in relation to ResourcePositionNode, if the value of ResourcePositionNode is not None. The property can be used to transport the product from or into moving processes or nodes."""
        pass

    @ResourcePositionInNode.setter
    def ResourcePositionInNode(self, value : vcMatrix) -> None:
        pass


class vcTriangleSet(vcGeometrySet):
    """vcTriangleSet is a geometry set used for creating and storing a collection of triangles and tessellated surface data.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTriangleSet.htm"""

    @property
    def CreaseAngle(self) -> float:
        """Defines angle tolerance for triangle edge shading in which edge angles less than tolerance are rendered as smooth surfaces during light calculations."""
        pass

    @CreaseAngle.setter
    def CreaseAngle(self, value : float) -> None:
        pass

    @property
    def DynamicTextureCoordinates1(self) -> bool:
        """Defines if texture coordinates of set can be updated during simulation."""
        pass

    @DynamicTextureCoordinates1.setter
    def DynamicTextureCoordinates1(self, value : bool) -> None:
        pass

    @property
    def DynamicUpdate(self) -> bool:
        """Defines if geometry of set can be updated during simulation."""
        pass

    @DynamicUpdate.setter
    def DynamicUpdate(self, value : bool) -> None:
        pass

    @property
    def Name(self) -> str:
        """Defines the name of set."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def PointCount(self) -> int:
        """Gets the total number of points in set."""
        pass

    @property
    def PolygonCount(self) -> int:
        """Gets the total number of triangles in set."""
        pass

    @property
    def PolygonTable(self) -> List[int]:
        """Defines a polygon table in the form of an ordered list used for generating triangles of set.
 In order to generate triangles, the vertex count of polygon is given first followed by the index for each vertex and so on for each subsequent polygon. For example, [3,0,1,2,3,0,2,3] would define two polygons with each having three vertices in which two are shared. Any polygon with four or more vertices will be tessellated.
 The actual positions of vertices are defined in PositionTable.
 See Example. Use polygon table to generate triangles for more information."""
        pass

    @PolygonTable.setter
    def PolygonTable(self, value : List[int]) -> None:
        pass

    @property
    def PositionTable(self) -> List[float]:
        """Defines a position table in the form of an ordered list used for generating triangles of set.
 In order to generate triangles, position values should have a known index and be in XYZ order. For example, [123.0,45.0,4.5,15.0,45.0,90.0] would define the position of two points which are aligned on Y-axis.
 If the number of entries is not enough for all points in set, those points will be deleted from set as a clean up operation.
 If number is more than is needed for points, additional points are created in set."""
        pass

    @PositionTable.setter
    def PositionTable(self, value : List[float]) -> None:
        pass

    @property
    def TextureCoordinateTable(self) -> List[float]:
        """Gets/Sets texture coordinates for points in set.
 f the number of entries is not enough for all points in set, those points will be deleted from set as a clean up operation.
 If number is more than is needed for points, additional points are created in set."""
        pass

    @TextureCoordinateTable.setter
    def TextureCoordinateTable(self, value : List[float]) -> None:
        pass

    @property
    def Topology(self) -> vcTopology:
        """Gets the container of topology data for points in set."""
        pass

    @property
    def TriangleCount(self) -> int:
        """Gets the total number of triangles in set."""
        pass

    @property
    def TriangleTable(self) -> List[int]:
        """Gets/Sets the triangle table of set, which is an ordered list of vertex indices for each triangle."""
        pass

    @TriangleTable.setter
    def TriangleTable(self, value : List[int]) -> None:
        pass

    @property
    def UseTextureCoordinates1(self) -> bool:
        """Turns on/off the use of texture coordinates in set."""
        pass

    @UseTextureCoordinates1.setter
    def UseTextureCoordinates1(self, value : bool) -> None:
        pass

    @overload
    def addPoint(self: Any, vector: vcVector) -> int:
        """Adds a point to set, and then returns index of point in set."""
        pass

    @overload
    def addPoint(self: Any, x: float, y: float, z: float) -> int:
        """Adds a point to set, and then returns index of point in set."""
        pass

    def addTriangle(self: Any, vertex1: int, vertex2: int, vertex3: int) -> int:
        """Adds a triangle to set, and then returns new triangle count of set.
 See Example. Create sphere with triangle sets for more information."""
        pass

    def collapsePoint(self: Any, indexPoint1: int, indexPoint2: int) -> None:
        """Collapses a point at a given index into another point at a given index in set, thereby updating triangles referencing first point to now reference second point.
 Generally, this is used to clean up redundant vertices, reduce data count or simplify geometry."""
        pass

    def convexHull(self: Any, value: bool) -> vcTriangleSet:
        """Creates a convex hull from geometry of set.
 If value is True, returns a new triangle set containing the resultant geometry.
 If value is False, modifies the current geometry of set and returns the same set."""
        pass

    def decimate(self: Any, quality: float, maxError: float) -> float:
        """Simplifies triangles of set by merging points within a given maxError tolerance until a given quality level is achieved or tolerance is exceeded."""
        pass

    def decompose(self: Any) -> None:
        """Regroups triangles in set into different sets based on the connection of each triangle to one another."""
        pass

    def deleteTriangle(self: Any, index: int) -> None:
        """Deletes a triangle at a given index in set.
 You should call the update() method after deleting one or more triangles from set."""
        pass

    def getClosestPointAndNormal(self: Any, referencePoint: vcVector) -> Tuple[vcVector, vcVector]:
        """Returns the closest point to a given referencePoint in the set. The object coordinate system of the set is used to find the point, which is returned along with its surface normal."""
        pass

    def getTexCoord1(self: Any, index: int) -> Tuple[float, float]:
        """Returns the texture coordinates of a point at a given index in set."""
        pass

    def getTextureCoordinates(self: Any, indices: List[int]) -> List[Tuple[float, float]]:
        """Returns a list containing an ordered pair of UV coordinates for points at given indices in set."""
        pass

    def getPoint(self: Any, index: int) -> vcVector:
        """Returns the position vector of point at a given index in set."""
        pass

    @overload
    def getPointIndexesWithin(self: Any, position: vcVector, side_length: float) -> List[int]:
        """Returns a list of indices for points in set within an area defined by a given position and side_length.
 A normal argument can be given to filter points with the same surface normal.
 
 See Example. Get position of points for more information."""
        pass

    @overload
    def getPointIndexesWithin(self: Any, position: vcVector, side_length: float, normal: vcVector) -> List[int]:
        """Returns a list of indices for points in set within an area defined by a given position and side_length.
 A normal argument can be given to filter points with the same surface normal.
 
 See Example. Get position of points for more information."""
        pass

    @overload
    def getPointNormals(self: Any, indices: List[int]) -> List[vcVector]:
        """Returns a list of surface normal vectors for points at a given list of indices in set.
 A convert argument can be used to transform each vector by a given matrix."""
        pass

    @overload
    def getPointNormals(self: Any, indices: List[int], convert: vcMatrix) -> List[vcVector]:
        """Returns a list of surface normal vectors for points at a given list of indices in set.
 A convert argument can be used to transform each vector by a given matrix."""
        pass

    @overload
    def getPointPositions(self: Any, indices: List[int]) -> List[vcVector]:
        """Returns a list of position vectors for points at a given list of indices in set.
 A convert argument can be used to transform each vector by a given matrix."""
        pass

    @overload
    def getPointPositions(self: Any, indices: List[int], convert: vcMatrix) -> List[vcVector]:
        """Returns a list of position vectors for points at a given list of indices in set.
 A convert argument can be used to transform each vector by a given matrix."""
        pass

    def getTriangle(self: Any, index: int) -> Tuple[int, int, int]:
        """Returns the indices of vertices for a triangle at a given index in set."""
        pass

    def getTriangleEdgeNeighbor(self: Any, index: int, vertex: int) -> Tuple[int, int]:
        """Returns the index of a triangle neighboring another triangle at a given index and vertex in set.
 The vertex argument should be either 0, 1 or 2.
 The returned value is an ordered pair identifying neighboring triangle and shared vertex in set."""
        pass

    def getTriangleEdgeType(self: Any, index: int, vertex: int) -> int:
        """Returns the type of edge for a triangle at a given index and vertex in set.
 The vertex argument should be either 0, 1 or 2.
 The returned type is one of seven possibilities:
 0 = UNKOWN
 Type is unknown.
 1 = LINE
 No triangle attached to edge.
 2 = CO_PLANAR
 Two triangles attached to edge and their surface normals are parallel.
 3 = SOFT
 Two triangles attached to edge and angle between surface normals is within angle tolerance of set, that is smooth surface.
 4 = HARD
 Two triangles attached to edge and angle between surface normals is outside angle tolerance of set, that is coarse surface.
 5 = BOUNDARY
 One triangle attached to edge.
 6 = NON_MANIFOLD
 More than two triangles attached to edge."""
        pass

    def getTriangleNormal(self: Any, index: int) -> vcVector:
        """Returns the surface normal of a triangle at a given index in set."""
        pass

    @overload
    def mergePoints(self: Any, tolerance: float) -> None:
        """Merges points of triangles within a given tolerance that are not connected to one another by adding lines.
 A onlyBoundaryPoints argument can be used to only merge points that border one another and that are within the given tolerance."""
        pass

    @overload
    def mergePoints(self: Any, tolerance: float, onlyBoundaryPoints: bool) -> None:
        """Merges points of triangles within a given tolerance that are not connected to one another by adding lines.
 A onlyBoundaryPoints argument can be used to only merge points that border one another and that are within the given tolerance."""
        pass

    def setPoint(self: Any, index: int, vector: vcVector) -> None:
        """Sets the position vector of a point at a given index in set."""
        pass

    def setTexCoord1(self: Any, index: int, u: float, v: float) -> None:
        """Sets the texture coordinates of a point at a given index in set."""
        pass

    def setTextureCoordinates(self: Any, indices: List[int], coordinates: List[Tuple[float, float]]) -> None:
        """Sets the texture coordinates of points at a given list of indices in set."""
        pass

    def setTriangle(self: Any, index: int, vertex1: int, vertex2: int, vertex3: int) -> None:
        """Sets the vertex indices of a triangle at a given index in set."""
        pass

    @overload
    def subdivide(self: Any, max_edge_length: float) -> None:
        """Modifies triangles in set into smaller triangles with edge lengths smaller or equal to a given max_edge_length.
 A max_triangles argument can be given to stop subdivision when triangle count reaches a maximum limit."""
        pass

    @overload
    def subdivide(self: Any, max_edge_length: float, max_triangles: int) -> None:
        """Modifies triangles in set into smaller triangles with edge lengths smaller or equal to a given max_edge_length.
 A max_triangles argument can be given to stop subdivision when triangle count reaches a maximum limit."""
        pass

    def update(self: Any) -> None:
        """Updates the set and its bound box."""
        pass


class vcTwoDirectionalPath(vcContainer):
    """Inherits: vcContainer
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcTwoDirectionalPath.htm"""

    @property
    def Direction(self) -> int:
        """Defines the direction components move along the path.
 See Conveyor Direction Constants for more information."""
        pass

    @Direction.setter
    def Direction(self, value : int) -> None:
        pass

    @property
    def Interpolation(self) -> int:
        """Defines the mode of interpolating the motion of components along the path.
 See Conveyor Interpolation Mode Constants for more information."""
        pass

    @Interpolation.setter
    def Interpolation(self, value : int) -> None:
        pass

    @property
    def Path(self) -> List[vcFeature]:
        """Defines an ordered list of Frame features that represent waypoints of the path."""
        pass

    @Path.setter
    def Path(self, value : List[vcFeature]) -> None:
        pass

    @property
    def RetainOffset(self) -> bool:
        """Defines if the location of a component is retained when the component is placed or transferred onto the path.
 A True value means a component is not snapped to the axis of the path defined by its waypoints."""
        pass

    @RetainOffset.setter
    def RetainOffset(self, value : bool) -> None:
        pass

    @property
    def Sensors(self) -> List[vcBehaviour]:
        """Defines a list of sensor type behaviors connected to the path.
 This type of path only supports Component Path and Process Point sensors."""
        pass

    @Sensors.setter
    def Sensors(self, value : List[vcBehaviour]) -> None:
        pass

    @property
    def Speed(self) -> float:
        """Defines the speed (mm/s) of the path."""
        pass

    @Speed.setter
    def Speed(self, value : float) -> None:
        pass


class vcUnit(vcObject):
    """vcUnit represents a single unit of measurement complete with a name, suffix and properties for describing linear mapping between canonical and unit values.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcUnit.htm"""

    @property
    def Factor(self) -> float:
        """If unit is built-in, gets conversion factor; otherwise defines conversion factor. That is, the size of unit in canonical units which must be larger than zero."""
        pass

    @Factor.setter
    def Factor(self, value : float) -> None:
        pass

    @property
    def Group(self) -> vcUnitGroup:
        """Gets the unit group of unit, which is defined at the time of unit creation."""
        pass

    @property
    def IsBuiltIn(self) -> bool:
        """Indicates if unit is built-in."""
        pass

    @property
    def Name(self) -> str:
        """If unit is built-in, gets the unit's name; otherwise defines the name of unit."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Offset(self) -> float:
        """If unit is built-in, gets zero-point offset; otherwise defines the canonical value at which the unit value is zero."""
        pass

    @Offset.setter
    def Offset(self, value : float) -> None:
        pass

    @property
    def Suffix(self) -> str:
        """If built-in, gets unit's suffix; otherwise defines the suffix of unit , which is displayed in GUI with property values."""
        pass

    @Suffix.setter
    def Suffix(self, value : str) -> None:
        pass

    def convertFromCanonical(self: Any, value: float) -> float:
        """Converts a given canonical value to a unit value, and then returns the unit value."""
        pass

    def convertToCanonical(self: Any, value: float) -> float:
        """Converts a given unit value to a canonical value, and then returns the canonical value."""
        pass

    def getConstantExpression(self: Any, value: float) -> str:
        """Converts a given canonical value to a unit value, and then returns an expression of unit value with an appended unit specification."""
        pass

    def getRelativeMagnitude(self: Any, magnitude: float) -> float:
        """Returns the size of unit in relation to a given magnitude using a logarithm of unit factor and a given magnitude which must be greater than zero."""
        pass


class vcUnitFamily(vcObject):
    """vcUnitFamily is a collection of units that belong to the same system of measurements. This unit family concept is not a strict definition rather a way to simplify unit selection
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcUnitFamily.htm"""

    @property
    def Groups(self) -> List[vcUnitGroup]:
        """Gets a list of all unit groups in unit family."""
        pass

    @property
    def IsBuiltIn(self) -> bool:
        """Indicates if unit family is a built-in type.
If True, adding and removing custom unit groups from unit family is allowed but not for built-in unit groups."""
        pass

    @property
    def Name(self) -> str:
        """If unit family is built-in, gets the unit family's name; otherwise defines the name of unit family which cannot contain any dot (.) characters."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @overload
    def addGroup(self: Any, group: vcUnitGroup) -> int:
        """Adds a given unit group or one matching a given name to unit family, and then returns the index of unit group in unit family."""
        pass

    @overload
    def addGroup(self: Any, groupName: str) -> int:
        """Adds a given unit group or one matching a given name to unit family, and then returns the index of unit group in unit family."""
        pass

    @overload
    def containsGroup(self: Any, group: vcUnitGroup) -> bool:
        """Returns True if a given unit group or one matching a given name is in the unit family; otherwise returns False."""
        pass

    @overload
    def containsGroup(self: Any, groupName: str) -> bool:
        """Returns True if a given unit group or one matching a given name is in the unit family; otherwise returns False."""
        pass

    @overload
    def removeGroup(self: Any, group: vcUnitGroup) -> bool:
        """Removes a given unit group or one matching a given name from unit family.
Returns True if removal is successful; otherwise returns False if name does not match a unit group or throws an exception if unit group is built-in."""
        pass

    @overload
    def removeGroup(self: Any, groupName: str) -> bool:
        """Removes a given unit group or one matching a given name from unit family.
Returns True if removal is successful; otherwise returns False if name does not match a unit group or throws an exception if unit group is built-in."""
        pass

    def removeGroupAt(self: Any, index: int) -> None:
        """Removes a unit group at a given index from unit family.
This method throws an exception if unit group is built-in."""
        pass


class vcUnitGroup(vcObject):
    """vcUnitGroup represents a group of units that apply to the same quantity and belong to the same unit family, thereby allowing you to create and delete vcUnit objects.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcUnitGroup.htm"""

    @property
    def IsBuiltIn(self) -> bool:
        """Indicates if unit group is a built-in group."""
        pass

    @property
    def Name(self) -> str:
        """If unit group is built-in, gets the unit group's name; otherwise defines the name of unit group which cannot contain any dot (.) characters."""
        pass

    @Name.setter
    def Name(self, value : str) -> None:
        pass

    @property
    def Quantity(self) -> vcScalarQuantity:
        """Gets the quantity referencing unit group."""
        pass

    @property
    def Units(self) -> List[vcUnit]:
        """Gets a list of all units in unit group."""
        pass

    def createUnit(self: Any, name: str, suffix: str) -> int:
        """If not a built-in unit group, adds a new unit of a given name and suffix to unit group, and then returns the index of new unit in unit group.
If built-in unit group, throws an exception."""
        pass

    def deleteUnitAt(self: Any, index: int) -> None:
        """If not a built-in unit group, removes a unit at a given index in unit group.
If built-in unit group, throws an exception."""
        pass

    def getUnitWithMagnitude(self: Any, magnitude: float) -> vcUnit:
        """Returns a unit in unit group that best matches a given magnitude."""
        pass


class vcVector(vcObject):
    """vcVector is a 4x1 column vector and is generally used to define joint lengths in robots, offsets and directions, and angles of rotation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcVector.htm"""

    @property
    def W(self) -> float:
        """Defines w-component (fourth element) of vector."""
        pass

    @W.setter
    def W(self, value : float) -> None:
        pass

    @property
    def X(self) -> float:
        """Defines x-component (first element) of vector."""
        pass

    @X.setter
    def X(self, value : float) -> None:
        pass

    @property
    def Y(self) -> float:
        """Defines y-component (second element) of vector."""
        pass

    @Y.setter
    def Y(self, value : float) -> None:
        pass

    @property
    def Z(self) -> float:
        """Defines z-component (third element) of vector."""
        pass

    @Z.setter
    def Z(self, value : float) -> None:
        pass

    def __mul__(self: Any, other: vcVector) -> vcVector:
        """Allows you to get the dot product of vectors."""
        pass

    def __xor__(self: Any, other: vcVector) -> vcVector:
        """Allows you to get the cross product of vectors."""
        pass

    def __add__(self: Any, other: vcVector) -> vcVector:
        """Allows you to add vectors."""
        pass

    def __sub__(self: Any, other: vcVector) -> vcVector:
        """Allows you to subtract vectors."""
        pass

    def angle(self: Any, vector: vcVector) -> float:
        """Returns the angle (in radians) between vector and a given vector."""
        pass

    def getQuaternionAngle(self: Any, vector: vcVector) -> vcVector:
        """Returns the quaternion angle between vector and a given vector."""
        pass

    def length(self: Any) -> float:
        """Returns the magnitude (length) of vector."""
        pass

    def normalize(self: Any) -> None:
        """Normalizes vector."""
        pass

    def square(self: Any) -> float:
        """Returns the square of vector."""
        pass


class vcVectorQuantity(vcScalarQuantity):
    """vcVectorQuantity extends vcScalarQuantity to support vector quantities.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcVectorQuantity.htm"""

    @property
    def IsAngular(self) -> bool:
        """Defines if vector quantity is angular or Cartesian type.
If quantity is built-in, you can only get value."""
        pass

    @IsAngular.setter
    def IsAngular(self, value : bool) -> None:
        pass

    @property
    def Pair(self) -> vcVectorQuantity:
        """Defines a vector quantity paired with the quantity in order to be used as matrix properties.
If IsAngular is set to True, pair must be a Cartesian vector quantity; otherwise the pair must be an angular vector quantity.
If quantity is built-in, you can only get value."""
        pass

    @Pair.setter
    def Pair(self, value : vcVectorQuantity) -> None:
        pass

    @property
    def VectorName(self) -> str:
        """Defines an alternative name for quantity instead of its inherited Name property.
If value is None or empty string, quantity uses its inherited Name property."""
        pass

    @VectorName.setter
    def VectorName(self, value : str) -> None:
        pass


class vcView(vcObject):
    """vcView provides access to 3D views created in application.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcView.htm"""

    @property
    def CameraFar(self) -> float:
        """Defines the distance of far clipping plane from camera location."""
        pass

    @CameraFar.setter
    def CameraFar(self, value : float) -> None:
        pass

    @property
    def CameraFovy(self) -> float:
        """Defines the field of view (in degrees) for camera."""
        pass

    @CameraFovy.setter
    def CameraFovy(self, value : float) -> None:
        pass

    @property
    def CameraIsOrtho(self) -> bool:
        """Turns on/off orthographic mode in camera."""
        pass

    @CameraIsOrtho.setter
    def CameraIsOrtho(self, value : bool) -> None:
        pass

    @property
    def CameraMatrix(self) -> vcMatrix:
        """Defines the location of camera in World coordinate system."""
        pass

    @CameraMatrix.setter
    def CameraMatrix(self, value : vcMatrix) -> None:
        pass

    @property
    def CameraNear(self) -> float:
        """Defines the distance of near clipping plane from camera location."""
        pass

    @CameraNear.setter
    def CameraNear(self, value : float) -> None:
        pass

    @property
    def Flags(self) -> int:
        """Defines if camera, light and shading settings are stored in view.
0
Include none.
1
Include camera.
2
Include lights.
3
Include camera and lights.
4
Include shading.
5
Include camera and shading.
6
Include lights and shading.
7
Include camera, lights and shading."""
        pass

    @Flags.setter
    def Flags(self, value : int) -> None:
        pass

    @property
    def Properties(self) -> List[vcProperty]:
        """Gets a list of all properties for view."""
        pass

    @property
    def ShadingEdge(self) -> int:
        """Defines the shading mode of view.
0
No edges.
1
All edges.
2
Hard edges.
3
Silhouette edges (Currently not implemented).
4
Edge analysis."""
        pass

    @ShadingEdge.setter
    def ShadingEdge(self, value : int) -> None:
        pass

    @property
    def ShadingRender(self) -> int:
        """Defines rendering mode of view.
0
No rendering.
1
Bounding boxes.
2
No filling.
3
Background.
4
Constant filling (Currently not implemented).
5
Flat shaded.
6
Smooth shaded."""
        pass

    @ShadingRender.setter
    def ShadingRender(self, value : int) -> None:
        pass


class vcViewAnimation(vcLayoutItem):
    """vcViewAnimation is a layout item used for animating camera movements during a simulation.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcViewAnimation.htm"""

    @property
    def Program(self) -> vcProgram:
        """Gets the program of animator."""
        pass

    def getProgram(self: Any) -> vcProgram:
        """Returns the program of animator."""
        pass


class vcVolumeDetector(vcObject):
    """vcVolumeDetector allows you to detect collisions in the 3D world using a box. Collision detection requires at least one node list and a box defined by lower and upper corners.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcVolumeDetector.htm"""

    @property
    def Corner1(self) -> vcVector:
        """Defines the lower corner of box in World coordinate system."""
        pass

    @Corner1.setter
    def Corner1(self, value : vcVector) -> None:
        pass

    @property
    def Corner2(self) -> vcVector:
        """Defines the upper corner of box in World coordinate system."""
        pass

    @Corner2.setter
    def Corner2(self, value : vcVector) -> None:
        pass

    @property
    def HitCount(self) -> int:
        """Gets the number of detected collisions with box."""
        pass

    @property
    def NodeList(self) -> List[Tuple[vcNode, int, int]]:
        """Defines a list of one or more nodes that can trigger a collision with box.
 See Collision Detector Constants for more information."""
        pass

    @NodeList.setter
    def NodeList(self, value : List[Tuple[vcNode, int, int]]) -> None:
        pass

    @property
    def TestMethod(self) -> int:
        """Defines test method for detecting collisions.
 See Collision Detector Constants for more information."""
        pass

    @TestMethod.setter
    def TestMethod(self, value : int) -> None:
        pass

    @property
    def Transformation(self) -> vcMatrix:
        """Defines the position matrix of box in World coordinate system."""
        pass

    @Transformation.setter
    def Transformation(self, value : vcMatrix) -> None:
        pass

    def getHitFeature(self: Any, index: int) -> vcFeature:
        """Returns a feature at a given index in detected collisions list."""
        pass

    def getHitGeometrySet(self: Any, index: int) -> vcGeometrySet:
        """Returns a geometry set at a given index in detected collisions list."""
        pass

    def getHitNode(self: Any, index: int) -> vcNode:
        """Returns a node at a given index in detected collisions list."""
        pass

    def testAllCollisions(self: Any, tolerance: float = ...) -> bool:
        """Detects all collisions of box with node list.
 An optional tolerance argument can be given to detect collisions within a certain distance. By default, tolerance is zero.
 If a collision is detected, returns True; otherwise returns False."""
        pass

    def testOneCollision(self: Any, tolerance: float = ...) -> bool:
        """Detects the first collision of box with node list.
 An optional tolerance argument can be given to detect collisions within a certain distance. By default, tolerance is zero.
 If a collision is detected, returns True; otherwise returns False."""
        pass


class vcVREvents(vcObject):
    """vcVREvents is used together with Visual Components Experience for interactive Virtual Reality (VR) applications.
https://help.visualcomponents.com/4.8/Premium/en/Python_API/vcVREvents.htm"""

    @property
    def Buttons(self) -> List[int]:
        """- Index 0: a bitmask for pressed buttons, first 32 bits (see ulButtonPressed )
 - Index 1: see above, last 32 bits
 - Index 2: a bitmask for touched buttons, first 32 bits (see ulButtonTouched )
 - Index 3: see above, last 32 bits"""
        pass

    @property
    def ClientId(self) -> int:
        """A number identifying which client sent the data that is currently stored in the VREvents object"""
        pass

    @property
    def DeviceInputs(self) -> List[Dict[Any, Any]]:
        """A list of dictionaries, where each dictionary contains the following key-value pairs
 - key: "DeviceRole", value: string, "LeftHanded"/"RightHanded"
 - key: "Axis2DInputs", value: dict<string, Tuple<float, float>>, 2D inputs (e.g. touchpad)
 - key: "AxisInputs", value: dict<string, float>, 1D inputs (e.g. trigger)
 - key: "ButtonInputs", value: dict<string, bool>, digital (0/1) button inputs
 Note: in all input dictionaries the key value is a string value identifying the input type
 (see InputFeatureUsage column in Unity XR input mappings)"""
        pass

    @property
    def DeviceModel(self) -> str:
        """The model of the connected VR device"""
        pass

    @property
    def Directions(self) -> List[vcVector]:
        """- Index 0: right controller - forward
 - Index 1: right controller - right
 - Index 2: left controller - forward
 - Index 3: left controller - right
 - Index 4: HMD - forward
 - Index 5: HMD - right
 Note: the up vector can be computed as the crossproduct of the right and forward vector"""
        pass

    @property
    def EventCounter(self) -> int:
        """The number of events processed by the server"""
        pass

    @property
    def EventsEnabled(self) -> bool:
        """Enable/disable the events"""
        pass

    @EventsEnabled.setter
    def EventsEnabled(self, value : bool) -> None:
        pass

    @property
    def MaxUpdateRate(self) -> int:
        """Defines the maximum update rate"""
        pass

    @MaxUpdateRate.setter
    def MaxUpdateRate(self, value : int) -> None:
        pass

    @property
    def OneMeterLength(self) -> float:
        """Defines the scale of the units used in Experience. For example, when the value is 1000.0, one meter in Experience is 1000 units in simulation."""
        pass

    @OneMeterLength.setter
    def OneMeterLength(self, value : float) -> None:
        pass

    @property
    def Position(self) -> List[vcVector]:
        """- Index 0: right controller position
 - Index 1: left controller position
 - Index 2: Head-mounted device (HMD) position"""
        pass

    @property
    def RealEventCounter(self) -> int:
        """Number of events sent by the client"""
        pass

    @property
    def RoomCenter(self) -> vcVector:
        """The physical location of the room"""
        pass

    @property
    def Times(self) -> List[float]:
        """- Index 0: time as reported by Experience
 - Index 1: delta from the last message sent by Experience
 - Index 2: delta from the last update (basically the frametime in Experience)
 - Index 3: VR event updates skipped before the last update (the client skips sending updates according to the MaxUpdateRate and also if the server is still processing a certain number of old messages)
 - Index 4: VR event updates skipped in total"""
        pass

    @property
    def Touches(self) -> List[vcVector]:
        """- Index 0: Vector (touchpad x-axis, touchpad y-axis, touchpad is pressed (0.0/1.0)) (right controller)
 - Index 1: Vector (??? x-axis, ??? y-axis, 0.0) (right controller, device-specific)
 - Index 2: Vector (trigger value, has teleported (0.0/1.0), trigger pressed (0.0/1.0)) (right controller)"""
        pass

    def toggleAction(self: Any, clientId: int, action: str, value: bool) -> None:
        """Makes it possible to enable or disable certain VR actions in Visual Components Experience. The clientId argument is the ClientId received through the VREvents object. The action argument defines the action to be enabled or disabled. Teleport toggles the user's ability to teleport, Elevator toggles the user's ability to use the built-in elevator platform Pause toggles the user's ability to pause and resume the simulation within Experience. The value argument denotes whether the action is enabled (True) or disabled (False)."""
        pass

    OnVREvents : Callable[[], None]
    """Called when a VR event has been received and the data in the VREvents object has been updated."""
